

-- UUAGC 0.9.32 (src/Transform.ag)
module Transform(transform) where

{-# LINE 8 "src/Transform.ag" #-}

import Common
import Ast
import Errs
import Data.Sequence(Seq)
import qualified Data.Sequence as Seq
import Data.Map(Map)
import qualified Data.Map as Map
import Data.IntMap(IntMap)
import qualified Data.IntMap as IntMap
import Data.Set(Set)
import qualified Data.Set as Set
import Env
import Data.Monoid
import Data.List(nub, isPrefixOf, intersect, sortBy, partition, groupBy, sort)
import Pretty
import UU.Scanner.Position
import Opts
import Data.Maybe
import Data.Char
import Data.Graph
import Data.Foldable(toList)
import DepAnalysis
import Debug.Trace(trace)
{-# LINE 32 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}
{-# LINE 37 "src/Transform.ag" #-}

transform :: Pos -> Opts -> Program -> (Errs, String, String, String)
transform pos opts prog
  = (errs, txtPretty, txtTarget, txtGraph)
  where
    inh  = Inh_Program { opts_Inh_Program = opts, pos_Inh_Program = pos }
    syn  = wrap_Program sem inh
    sem  = sem_Program prog
    errs = firstErrs [ errs0_Syn_Program syn
                     , errs1_Syn_Program syn
                     , errs2_Syn_Program syn
                     , errs3_Syn_Program syn
                     , errs4_Syn_Program syn
                     , errs5_Syn_Program syn ]
    
    resPretty = pretty_Syn_Program syn
    txtPretty = disp resPretty 999999 ""
    resTarget = pp_Syn_Program syn
    txtTarget = disp resTarget 999999 ""
    resGraph  = graph_Syn_Program syn
    txtGraph  = disp resGraph 999999 ""

firstErrs :: [Errs] -> Errs
firstErrs [] = Seq.empty
firstErrs (x:xs) = if Seq.null x then firstErrs xs else x
{-# LINE 59 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 128 "src/Transform.ag" #-}

addDefErrs :: Env QIdent v -> Errs -> Errs
addDefErrs env es
  = Seq.fromList (map (Err_Dup . map head) ds) Seq.>< es
  where ds = map (map fst) (dups env)

addUseErrs :: Env QIdent v -> Errs -> Errs
addUseErrs env es
  = Seq.fromList (map (Err_Missing . map head) ms) Seq.>< es
  where ms = missing env

addDefErrs' :: Env Ident v -> Errs -> Errs
addDefErrs' env es
  = Seq.fromList (map Err_Dup ds) Seq.>< es
  where ds = map (map fst) (dups env)

addUseErrs' :: Env Ident v -> Errs -> Errs
addUseErrs' env es
  = Seq.fromList (map Err_Missing ms) Seq.>< es
  where ms = missing env

addDefUseErrs' :: Env Ident v -> Errs -> Errs
addDefUseErrs' env = addDefErrs' env . addUseErrs' env

addDefErrs'' :: Env (Ident,Ident,Bool) v -> Errs -> Errs
addDefErrs'' env es
  = Seq.fromList (map mkDupErr ds) Seq.>< es
  where ds = map (map fst) (dups env)
        mkDupErr ((c,n,b):_) = Err_DupAttr b c n

addUseErrs'' :: Env (Ident,Ident,Bool) v -> Errs -> Errs
addUseErrs'' env es
  = Seq.fromList (map mkMissErr ms) Seq.>< es
  where ms = missing env
        mkMissErr ((c,n,b):_) = Err_MissingAttr b c n

addDefUseErrs'' :: Env (Ident,Ident,Bool) v -> Errs -> Errs
addDefUseErrs'' env = addDefErrs'' env . addUseErrs'' env
{-# LINE 100 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 173 "src/Transform.ag" #-}

type ItfEnv = Env QIdent ()
{-# LINE 105 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 187 "src/Transform.ag" #-}

type VisitEnv = Env QIdent ()
{-# LINE 110 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 205 "src/Transform.ag" #-}

mkCoIdent :: Ident -> Ident -> Ident
mkCoIdent itf vis = Ident ("Co_" ++ show itf ++ "_" ++ show vis) (identPos itf)
{-# LINE 116 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 210 "src/Transform.ag" #-}

type AttrEnv = Env QIdent String
{-# LINE 121 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 234 "src/Transform.ag" #-}

type NontermEnv = Env QIdent ()
type ClausesEnv = Env QIdent ()
type DataSemEnv = Env Ident ()
{-# LINE 128 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 301 "src/Transform.ag" #-}

type DataEnv  = Env Ident ()
type ConEnv   = Env QIdent FieldEnv
type FieldEnv = Env Ident (Int,Either Ident String)
{-# LINE 135 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 352 "src/Transform.ag" #-}

type VarsEnv = Env Ident ()
{-# LINE 140 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 451 "src/Transform.ag" #-}

sortAssocs :: [(Ident, (Int, a))] -> [(Ident, a)]
sortAssocs = map (\(nm,(_,tp)) -> (nm,tp)) . sortBy (\(_,(n1,_)) (_,(n2,_)) -> compare n1 n2)
{-# LINE 146 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 488 "src/Transform.ag" #-}

astIdent :: Ident
astIdent = Ident "ast" noPos
{-# LINE 152 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 557 "src/Transform.ag" #-}

unknIdent :: Ident
unknIdent = ident "<undefined>"

unknQIdent :: QIdent
unknQIdent = [unknIdent]

locQIdent :: QIdent
locQIdent = [locIdent]

lhsQIdent :: QIdent
lhsQIdent = [lhsIdent]

visQIdent :: QIdent
visQIdent = [visIdent]
{-# LINE 170 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 583 "src/Transform.ag" #-}

type RenameMap = Map Ident (Map Ident Ident)
{-# LINE 175 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 605 "src/Transform.ag" #-}

renameAttr :: RenameMap -> Ident -> Ident -> Ident
renameAttr mp child nm = Map.findWithDefault nm nm $ Map.findWithDefault Map.empty child mp
renameAttrFwd = renameAttr
renameAttrBwd = renameAttr
{-# LINE 183 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 637 "src/Transform.ag" #-}

trim :: String -> String
trim = reverse . dropWhile isSpace . reverse . dropWhile isSpace
{-# LINE 189 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 769 "src/Transform.ag" #-}

prependEmptyVisits _ _ t [] = t
prependEmptyVisits basename pos t (v:vs)
  = SemVisit_Visit pos v False [] [] (ClausesTop_Top [Clause_Clause pos (mkClauseName pos v basename) []
      (prependEmptyVisits basename pos t vs) ])

mkClauseName :: Pos -> Ident -> QIdent -> Ident
mkClauseName pos v vs
  = Ident (show v ++ concatMap (\v' -> "_" ++ show v') vs) pos

checkVisitSequence :: Pos -> Ident -> [Ident] -> (Errs, [Ident])
checkVisitSequence _ _ [] = (Seq.empty, [])  -- dont report more errors if already erroneous
checkVisitSequence pos nm (nm' : nms)
  | nm == nm' = (Seq.empty, nms)
  | otherwise = (Seq.singleton $ Err_ExpVisit pos nm nm', [])  -- mismatch
{-# LINE 207 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 798 "src/Transform.ag" #-}

unionWithPlusplus :: Ord k => Map k [v] -> Map k [v] -> Map k [v]
unionWithParallel, unionWithSequential :: (Ord k, Ord v) => Map k [[v]] -> Map k [[v]] -> Map k [[v]]

unionWithPlusplus   = Map.unionWith (++)
unionWithParallel mp1 mp2 = Map.unionWith (++) mp1' mp2'
  where addleft  = Map.map (const [[]]) (mp2 `Map.difference` mp1)
        addright = Map.map (const [[]]) (mp1 `Map.difference` mp2)
        mp1' = addleft `Map.union` mp1
        mp2' = addright `Map.union` mp2
unionWithSequential = Map.unionWith (\[h] t -> map (h++) t)

unionWithUnion :: (Ord k, Monoid v) => Map k v -> Map k v -> Map k v
unionWithUnion = Map.unionWith mappend
{-# LINE 224 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 818 "src/Transform.ag" #-}

nextAfterInvoked :: [Ident] -> [Ident] -> Ident
nextAfterInvoked (a:as) (b:bs)
  | a == b    = nextAfterInvoked as bs
  | otherwise = b
{-# LINE 232 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 857 "src/Transform.ag" #-}

type AttrMap = Map Ident (Map Ident String)
type VisitAttrMap = Map Ident AttrMap
{-# LINE 238 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 965 "src/Transform.ag" #-}

common :: [[Ident]] -> [Ident]
common []     = []
common [x]    = x
common (x:xs) = x `intersect` common xs
{-# LINE 246 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 983 "src/Transform.ag" #-}

type At = (Ident,Ident,Bool)  -- True: inherited attr, False: syn attr
type DefsEnv = Env At (Maybe String)

locIdent, lhsIdent, visIdent :: Ident
locIdent = ident "loc"
lhsIdent = ident "lhs"
visIdent = ident "vis"
{-# LINE 257 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1147 "src/Transform.ag" #-}

replPos :: Pos -> Ident -> Ident
replPos p i = Ident (identName i) p
{-# LINE 263 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1196 "src/Transform.ag" #-}

findChild nm env = itf
  where (([itf], _), _) = find [nm] (unknQIdent,unknQIdent) env
{-# LINE 269 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1260 "src/Transform.ag" #-}

visAvailable child itf vis invokeMap orderMap
  = any (\start -> vis `elem` dropWhile (/= start) order) invokes
  where
    invokes = Set.toList $ Map.findWithDefault Set.empty child invokeMap
    order   = Map.findWithDefault [] itf orderMap

hasSynAttr nm itf mp = Map.member nm $ Map.findWithDefault Map.empty itf mp
findVisitOfAttr nm itf mp = Map.findWithDefault (ident "<unknownvisit>") (False,nm) (Map.findWithDefault Map.empty itf mp)
{-# LINE 281 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1290 "src/Transform.ag" #-}

nextUnique :: Int -> (Int, Int)
nextUnique x = (x+1, x)
{-# LINE 287 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1302 "src/Transform.ag" #-}

unionWithMin :: Map Ident Int -> Map Ident Int -> Map Ident Int
unionWithMin = Map.unionWith min
{-# LINE 293 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1365 "src/Transform.ag" #-}

type AttrVisMap = Map Ident (Map (Bool,Ident) Ident)
{-# LINE 298 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1379 "src/Transform.ag" #-}

type DataMap  = Map Ident ConMap
type ConMap   = Map Ident (Int, FieldMap)
type FieldMap = Map Ident (Int, Either Ident String)
{-# LINE 305 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1530 "src/Transform.ag" #-}

conItf   dt con = Ident ("Con_" ++ show dt ++ "_" ++ show con) (identPos con)
deconItf dt con = Ident ("Decon_" ++ show dt ++ "_" ++ show con) (identPos con)
noIterNm dt con = Ident ("NoIter_" ++ show dt ++ "_" ++ show con) (identPos con)
{-# LINE 312 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1571 "src/Transform.ag" #-}

visitAfter :: Ident -> [Ident] -> Maybe Ident
visitAfter nm (a : b : nms)
  | nm == a    = Just b
  | otherwise  = visitAfter nm (b : nms)
visitAfter _ _ = Nothing

laterVisit :: [Ident] -> Maybe Ident -> Maybe Ident -> Maybe Ident
laterVisit _ Nothing  Nothing  = Nothing
laterVisit _ Nothing  (Just x) = Just x
laterVisit _ (Just x) Nothing  = Just x
laterVisit xs (Just l) (Just r) = Just $ laterVisit' xs l r

laterVisit' [] _ r = r
laterVisit' (x:xs) l r
  | x == l    = l
  | x == r    = r
  | otherwise = laterVisit' xs l r
{-# LINE 333 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1665 "src/Transform.ag" #-}

intersectionsInvoke []     = Map.empty
intersectionsInvoke [x]    = x
intersectionsInvoke (x:xs) = Map.intersectionWith Set.intersection x (intersectionsInvoke xs)
{-# LINE 340 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1728 "src/Transform.ag" #-}

rangeUpTo :: Ident -> [Ident] -> [Ident]
rangeUpTo _ [] = []
rangeUpTo vis (x:xs)
  | x == vis  = [x]
  | otherwise = x : rangeUpTo vis xs
{-# LINE 349 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1777 "src/Transform.ag" #-}

notIn :: Ord a => Set a -> a -> b -> Bool
notIn s k _ = not (k `Set.member` s)

diffInside :: Map Ident (Set Ident) -> Map Ident (Set Ident) -> Map Ident (Set Ident)
diffInside = Map.differenceWith f where
  f a b = let r = Set.difference a b
          in if Set.null r then Nothing else Just r
{-# LINE 360 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1869 "src/Transform.ag" #-}

getDestVisit :: Int -> IntMap Ident -> Ident
getDestVisit  rank ranks
  = maybe (ident "unknownDestVisit") fst mbMax
  where (smaller, _) = IntMap.split rank ranks
        mbMax        = IntMap.maxView smaller
{-# LINE 369 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 1881 "src/Transform.ag" #-}

type CycVisMap = Map Ident (Set Ident)
{-# LINE 374 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2008 "src/Transform.ag" #-}

unknDepItem :: DepItem
unknDepItem = DepVisStart [ident "errorunknown"]
{-# LINE 380 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2047 "src/Transform.ag" #-}

type AttrSourceMap = Map (Bool,Ident,Ident) DepItem  -- Bool: True = inherited attr
{-# LINE 385 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2107 "src/Transform.ag" #-}

type ChildSourceMap = Map Ident (Map Ident DepItem)
{-# LINE 390 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2126 "src/Transform.ag" #-}

type VisitSourceMap = Map Ident (Map Ident DepItem)
{-# LINE 395 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2177 "src/Transform.ag" #-}

data Dep = Dep !DepItem !Reason !([DepItem])
  deriving (Eq,Ord,Show)

type Deps = Seq Dep

addDep :: DepItem -> Reason -> [DepItem] -> Deps -> Deps
addDep item reason deps = (Seq.<|) (Dep item reason deps)

unknDep :: Dep
unknDep = Dep unknDepItem ReasonError [unknDepItem]
{-# LINE 409 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2203 "src/Transform.ag" #-}

mkUnknownDep :: Show a => a -> DepItem
mkUnknownDep s = DepVisStart [ident ("unknown" ++ show s)]
{-# LINE 415 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2265 "src/Transform.ag" #-}

nearestVisitEntry :: Bool -> Ident -> [Ident] -> Map Ident DepItem -> Maybe (Ident,DepItem)
nearestVisitEntry inclusive vis order mp
  = case [ (b, Map.findWithDefault (trace "nearestVisitEntry.unknown" unknDepItem) b mp) | b <- befores, Map.member b mp ] of
      []    -> Nothing
      (e:_) -> Just e
  where
    entries = Map.assocs mp
    befores = reverse $ (takeWhile (/= vis) order ++ (if inclusive then [vis] else []))
{-# LINE 427 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2364 "src/Transform.ag" #-}

mostDescriptiveReason r1 r2
  = case r2 of
      ReasonAttrReq _ _  -> r2
      _                  -> r1

instance Show a => Show (SCC a) where
  show (CyclicSCC xs) = unwords (map show xs)
  show (AcyclicSCC x) = show x
{-# LINE 439 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2404 "src/Transform.ag" #-}

instance PP Ident where
  pp = text . identName
{-# LINE 445 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2494 "src/Transform.ag" #-}

modifySpacing :: Int -> Int -> String -> [String]
modifySpacing n m s
  = take (length ls) (r : rs)
  where
    ls = lines s
    (f : fs) = ls ++ [""]
    r  = shift n f
    rs = map (drop (m-1)) fs
    
shift :: Int -> String -> String
shift n
  | n <= 0 = drop n
  | n > 0  = (replicate n ' ' ++)

addSpaces :: Int -> PP_Doc -> PP_Doc
addSpaces n d = text (replicate n ' ') >|< d
{-# LINE 465 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 2601 "src/Transform.ag" #-}

data Prio
  = PrioTop | PrioCons | PrioCon
  deriving (Eq, Ord)

needParens :: Prio -> Prio -> Bool -> Bool
needParens myPrio lhsPrio isRight = myPrio <= lhsPrio && (myPrio /= lhsPrio || isRight)

addParens :: Bool -> PP_Doc -> PP_Doc
addParens True  = pp_parens
addParens False = id
{-# LINE 479 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 11 "src/TargetHaskell.ag" #-}

hItfNm nm = "I_" ++ show nm
hCoItfNm nm vis = hItfNm (mkCoIdent nm vis)
hItfVsNm nm vis = "I_" ++ show nm ++ "_" ++ show vis
hCoItfVsNm nm vis = hItfVsNm (mkCoIdent nm vis) vis
hNt x = "_nt_" ++ show x
hVis x = "_vis_" ++ show x
hSemNm k v = "_sem_" ++ show k ++ "_" ++ show v

hInp child name
  | show child == "loc" = show child ++ "L" ++ show name
  | show child == "lhs" = show child ++ "I" ++ show name
  | show child == "vis" = show child ++ "I" ++ show name
  | otherwise           = show child ++ "S" ++ show name

hOutp child name
  | show child == "loc" = show child ++ "L" ++ show name
  | show child == "lhs" = show child ++ "S" ++ show name
  | show child == "vis" = show child ++ "S" ++ show name
  | otherwise           = show child ++ "I" ++ show name

hOutpLoc child name = show child ++ "L" ++ show name
hInpLoc child name = show child ++ "L" ++ show name

hInhFldNm nm itf vis = show nm ++ "_Inh_" ++ show itf
hSynFldNm nm itf vis = show nm ++ "_Syn_" ++ show itf
hInhFldNmFull nm itf vis = hInhFldNm nm itf vis ++ "_" ++ show vis
hSynFldNmFull nm itf vis = hSynFldNm nm itf vis ++ "_" ++ show vis
hCoInhFldNm nm itf vis = hInhFldNm nm (mkCoIdent itf vis) vis
hCoSynFldNm nm itf vis = hSynFldNm nm (mkCoIdent itf vis) vis
hCoInhFldNmFull nm itf vis = hCoInhFldNm nm itf vis ++ "_" ++ show vis
hCoSynFldNmFull nm itf vis = hCoSynFldNm nm itf vis ++ "_" ++ show vis

hInhDt itf vis = "Inh_" ++ show itf ++ "_" ++ show vis
hSynDt itf vis = "Syn_" ++ show itf ++ "_" ++ show vis
hCoInhDt itf vis = hInhDt (mkCoIdent itf vis) vis
hCoSynDt itf vis = hSynDt (mkCoIdent itf vis) vis

hInvNm itf nm = "invoke_" ++ show itf ++ "_" ++ show nm
hCoInvNm itf nm = "coinvoke_" ++ show itf ++ "_" ++ show nm
hNextNm itf nm = "next_" ++ show itf ++ "_" ++ show nm
hCurrentNm itf nm = "current_" ++ show itf ++ "_" ++ show nm

hDtNm nm = show nm
hConNm dt nm = show dt ++ "_" ++ show nm
hFldNm dt con nm = show nm ++ "_" ++ show dt ++ "_" ++ show con
hDtSemNm nm = "dnt_" ++ show nm

hDfltNm nm nr = "dflt_" ++ show nm ++ "_" ++ show nr

hCatch :: (PP a, PP b) => a -> b -> PP_Doc
hCatch l r = "catchError"
             >-< indent 2 (pp_parens (pp l))
             >-< indent 2 (pp_parens (pp r))

hThrow msg = "throwError" >#< pp_parens ("strMsg" >#< show msg)
{-# LINE 538 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 138 "src/TargetHaskell.ag" #-}

nextIdent :: Ident
nextIdent = ident "next_"

repIdent :: Ident
repIdent = ident "rep_"
{-# LINE 547 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 162 "src/TargetHaskell.ag" #-}

stripSpacing :: String -> PP_Doc
stripSpacing = pp_block "(" ")" " " . map text . lines
{-# LINE 553 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 241 "src/TargetHaskell.ag" #-}

hWrapLinePragma :: PP a => Opts -> Pos -> a -> PP_Doc
hWrapLinePragma opts pos doc
  | isJust (outputFile opts) && not (hNoLinePragmas opts)
      = let nrIn  = line pos
            nmIn  = file pos
            nmOut = fromJust (outputFile opts)
        in ""
           >-< "{-# LINE" >#< show nrIn >#< show nmIn >#< "#-}"
           >-< doc
           >-< "{-# LINE" >#< ppWithLineNr (\n -> pp $ show $ n + 1) >#< show nmOut >#< "#-}"
           >-< ""
  | otherwise = pp doc
{-# LINE 569 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 304 "src/TargetHaskell.ag" #-}

hppStmtBlock :: PP a => [[a]] -> PP_Doc
hppStmtBlock = vlist . map ppComp
  where ppComp []  = empty
        ppComp [x] = pp x
        ppComp xs  = "let" >#< vlist (map pp xs)
{-# LINE 578 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 361 "src/TargetHaskell.ag" #-}

hParensWithPos :: PP a => Opts -> Pos -> a -> PP_Doc
hParensWithPos opts pos doc
  = ""
    >-< "("
    >-< indent 2 (hWrapLinePragma opts pos doc)
    >-< " )"
    >-< ""
{-# LINE 589 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 495 "src/TargetHaskell.ag" #-}

ppBind :: (PP a, PP b) => Bool -> a -> b -> PP_Doc
ppBind True  pat expr = pp_parens (pp pat) >#< "="  >-< indent 2 (pp_parens (pp expr))
ppBind False pat expr = pp_parens (pp pat) >#< "<-" >-< indent 2 (pp_parens (pp expr))

ppBindPos :: (PP a, PP b) => Opts -> Pos -> Bool -> a -> b -> PP_Doc
-- ppBindPos _ _ = ppBind
ppBindPos opts pos True pat expr  = hWrapLinePragma opts pos (pp pat) >#< "="  >-< indent 2 (hWrapLinePragma opts pos (pp expr))
ppBindPos opts pos False pat expr = hWrapLinePragma opts pos (pp pat) >#< "<-" >-< indent 2 (hWrapLinePragma opts pos (pp expr))

hppWrapRet :: PP a => Bool -> a -> PP_Doc
hppWrapRet True d  = "return" >#< pp_parens (pp d)
hppWrapRet False d = pp d
{-# LINE 605 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 611 "src/TargetHaskell.ag" #-}

rankIsLower :: Int -> (Int, PP_Doc) -> Bool
rankIsLower m (n,_) = n < m
{-# LINE 611 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 638 "src/TargetHaskell.ag" #-}

sortPairs :: [(Int,a)] -> [a]
sortPairs = map snd . sortBy (\(x,_) (y,_) -> x `compare` y)

groupPairs :: [(Int,a)] -> [[a]]
groupPairs = map (map snd) . groupBy (\(x,_) (y,_) -> x == y) . sortBy (\(x,_) (y,_) -> x `compare` y)
{-# LINE 620 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 10 "src/TargetJs.ag" #-}

jsInp child name
  | show child == "loc" = show child ++ "L" ++ show name
  | show child == "lhs" = show child ++ "I" ++ show name
  | show child == "vis" = show child ++ "I" ++ show name
  | otherwise           = show child ++ "S" ++ show name

jsOutp child name
  | show child == "loc" = show child ++ "L" ++ show name
  | show child == "lhs" = show child ++ "S" ++ show name
  | show child == "vis" = show child ++ "S" ++ show name
  | otherwise           = show child ++ "I" ++ show name

jsDtSemNm nm = "dnt_" ++ show nm

jsVis nm vis = "vis_" ++ show nm ++ "_" ++ show vis

jsConNm dt nm = show dt ++ "_" ++ show nm
{-# LINE 641 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 66 "src/TargetJs.ag" #-}

jsTpCheck nm tp
  = "var _val = this." >|< show nm >|< ";"
    >-< "if (_val === undefined) { throw \"Undefined attribute: " >|< show nm >|< "\"; }"
    >-< if all isSpace tp
        then empty
        else "var _assert =" >#< tp >#< ";"
             >-< "if (!_assert) { throw \"Assert function undefined\"; }"
             >-< "var _outcome = _assert(_val);"
             >-< "if (!_outcome) { throw \"Attribute fails predicate: " >|< show nm >|< "\"; }"
{-# LINE 654 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 183 "src/TargetJs.ag" #-}

jsppStmtBlock :: PP a => [[a]] -> PP_Doc
jsppStmtBlock = vlist . map ppComp
  where ppComp []  = empty
        ppComp [x] = pp x
        ppComp xs  = vlist (map pp xs)
{-# LINE 663 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}

{-# LINE 23 "src/TargetGraph.ag" #-}

isOnCycle :: DepItem -> Map DepItem (Bool,Int) -> Bool
isOnCycle d mp
  = case Map.lookup d mp of
      Nothing    -> False
      Just (b,_) -> b

ppgProp :: PP a => String -> a -> PP_Doc
ppgProp s d = s >|< "=" >|< pp_doubleQuotes (pp d)

ppgNms :: QIdent -> PP_Doc
ppgNms = hlist . map show

ppgDeps :: PP a => [a] -> PP_Doc
ppgDeps [x] = pp x
ppgDeps xs  = pp_block "{" "}" ";" (map pp xs)

ppgNode :: Pos -> DepItem -> Map DepItem (Bool,Int) -> PP_Doc
ppgNode pos item rankMap
  = case item of
      DepMatch n      -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "label" l, c] >|< ";"
      DepAssert n     -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "label" l, c] >|< ";"
      DepDefault n    -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "label" l, c] >|< ";"
      DepAttach n     -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "shape" "box",ppgProp "label" l, c] >|< ";"
      DepInvoke nms   -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "shape" "box",ppgProp "skew" ".3",ppgProp "label" l,c] >|< ";"
      DepVisStart nms -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "shape" "box",ppgProp "skew" ".3",ppgProp "label" l,c] >|< ";"
      DepVisEnd nms   -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "shape" "box",ppgProp "skew" ".3",ppgProp "label" l,c] >|< ";"
      DepClause nms   -> ppgKey pos item >#< pp_block "[" "]" "," [ppgProp "shape" "box",ppgProp "skew" ".3",ppgProp "label" l,c] >|< ";"
  where mbInfo = Map.lookup item rankMap
        l = ppgLabel pos item (maybe Nothing (Just . snd) mbInfo)
        c = ppgColor (maybe False fst mbInfo)

ppgColor :: Bool -> PP_Doc
ppgColor True  = ppgProp "color" "red4"
ppgColor False = ppgProp "color" "black"

ppgLabel :: Pos -> DepItem -> Maybe Int -> PP_Doc
ppgLabel pos item mbRank
  = case item of
      DepMatch m   -> r >#< show m >|< "?@" >|< show (line pos)
      DepAssert n  -> r >#< show n >|< "@" >|< show (line pos)
      DepDefault o -> r >#< "d" >|< show o
      DepAttach n  -> r >#< "@" >|< show (line pos)
      DepInvoke (visit:name:_) -> r >#< name >|< "." >|< visit >|< "@" >|< show (line $ identPos name)
      DepInvoke _              -> r >#< text "i???"
      DepVisStart (visit:_)    -> r >#< ">" >|< show visit >|< "@" >|< show (line $ identPos visit)
      DepVisStart _            -> r >#< text ">v???"
      DepVisEnd (visit:_)      -> r >#< show visit >|< "@" >|< show (line $ identPos visit) >|< "<"
      DepVisEnd _              -> r >#< text "<v???"
      DepClause (clause:_)     -> r >#< "|" >|< show clause >|< "@" >|< show (line $ identPos clause)
      DepClause _              -> r >#< text "|???"
  where
    r = case mbRank of
          Nothing -> empty
          Just k  -> show k >|< ":"

ppgKey :: Pos -> DepItem -> PP_Doc
ppgKey pos item
  = case item of
      DepMatch n      -> "s"  >|< show n
      DepAssert n     -> "s"  >|< show n
      DepDefault n    -> "d"  >|< show n
      DepAttach n     -> "a"  >|< show n
      DepInvoke nms   -> "iv" >|< ppgNms nms
      DepVisStart nms -> "vb" >|< ppgNms nms
      DepVisEnd nms   -> "ve" >|< ppgNms nms
      DepClause nms   -> "cl" >|< ppgNms nms

ppgReason :: Reason -> Maybe PP_Doc
ppgReason reason
  = case reason of
      ReasonScopeVisit i      -> Nothing -- Just ("sc-vis-pre" >#< show i)
      ReasonScopeClause i     -> Nothing -- Just ("sc-cl" >#< show i)
      ReasonScopeEnd i        -> Nothing -- Just ("sc-vis-end" >#< show i)
      ReasonAttrReq chld attr -> Just (show chld >|< "." >|< show attr)
      ReasonInvokeReq i       -> Just ("inv" >#< show i)
      ReasonChildReq i        -> Nothing -- Just ("chld" >#< show i)
      ReasonAttach i v        -> Just ("att" >#< show i >|< "." >|< show v)
      ReasonDefault attr      -> Nothing -- Just ("def." >|< show attr)
      ReasonDetach _ _        -> Nothing -- Just $ text "detach"
      ReasonError             -> Just $ text "error"
{-# LINE 747 "dist/src/sdist.34564/ruler-core-1.0/dist/build/ruler-core/ruler-core-tmp/Transform.hs" #-}
-- AliasType ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         name                 : Ident
         pos                  : Pos
         vars                 : Vars 
      chained attribute:
         distDatas            : DataEnv
      synthesized attributes:
         alias                : SELF 
         data                 : Data
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative List:
         child type           : {Ident}
         visit 0:
            local distDatas_augmented_f1 : _
            local alias       : _
            local distDatas_augmented_syn : _
      alternative Maybe:
         child type           : {Ident}
         visit 0:
            local distDatas_augmented_f1 : _
            local alias       : _
            local distDatas_augmented_syn : _
      alternative Prod:
         child fields         : {[Ident]}
         visit 0:
            local distDatas_augmented_f1 : _
            local alias       : _
            local distDatas_augmented_syn : _
-}
-- cata
sem_AliasType :: AliasType  ->
                 T_AliasType 
sem_AliasType (AliasType_List _type )  =
    (sem_AliasType_List _type )
sem_AliasType (AliasType_Maybe _type )  =
    (sem_AliasType_Maybe _type )
sem_AliasType (AliasType_Prod _fields )  =
    (sem_AliasType_Prod _fields )
-- semantic domain
type T_AliasType  = DataEnv ->
                    Ident ->
                    Pos ->
                    Vars  ->
                    ( AliasType ,Data,DataEnv,PP_Doc,PP_Doc,PP_Doc)
sem_AliasType_List :: Ident ->
                      T_AliasType 
sem_AliasType_List type_  =
    (\ _lhsIdistDatas
       _lhsIname
       _lhsIpos
       _lhsIvars ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOdata :: Data
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOalias :: AliasType 
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 481 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 815 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 481 "src/Transform.ag" #-}
                   snd . find type_ ()
                   {-# LINE 820 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1455, column 12)
              _lhsOdata =
                  ({-# LINE 1455 "src/Transform.ag" #-}
                   Data_Data _lhsIpos _lhsIname _lhsIvars
                     [ Con_Con _lhsIpos (Ident "Cons" _lhsIpos) []
                         [ Field_Field (Ident "hd" _lhsIpos) (FieldType_Nonterm type_)
                         , Field_Field (Ident "tl" _lhsIpos) (FieldType_Nonterm _lhsIname)
                         ]
                     , Con_Con _lhsIpos (Ident "Nil" _lhsIpos) [] []
                     ] []
                   {-# LINE 831 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2454, column 12)
              _lhsOpp =
                  ({-# LINE 2454 "src/Transform.ag" #-}
                   pp_brackets (text $ show type_)
                   {-# LINE 836 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 193, column 12)
              _lhsOhpp =
                  ({-# LINE 193 "src/TargetHaskell.ag" #-}
                   pp_brackets $ text $ show type_
                   {-# LINE 841 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 123, column 12)
              _lhsOjspp =
                  ({-# LINE 123 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 846 "src/Transform.hs" #-})
              -- self rule
              _alias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   AliasType_List type_
                   {-# LINE 851 "src/Transform.hs" #-})
              -- self rule
              _lhsOalias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   _alias
                   {-# LINE 856 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDatas_augmented_syn =
                  ({-# LINE 481 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 861 "src/Transform.hs" #-})
          in  ( _lhsOalias,_lhsOdata,_lhsOdistDatas,_lhsOhpp,_lhsOjspp,_lhsOpp)))
sem_AliasType_Maybe :: Ident ->
                       T_AliasType 
sem_AliasType_Maybe type_  =
    (\ _lhsIdistDatas
       _lhsIname
       _lhsIpos
       _lhsIvars ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOdata :: Data
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOalias :: AliasType 
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 482 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 880 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 482 "src/Transform.ag" #-}
                   snd . find type_ ()
                   {-# LINE 885 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1462, column 12)
              _lhsOdata =
                  ({-# LINE 1462 "src/Transform.ag" #-}
                   Data_Data _lhsIpos _lhsIname _lhsIvars
                     [ Con_Con _lhsIpos (Ident "Just" _lhsIpos) []
                         [ Field_Field (Ident "just" _lhsIpos) (FieldType_Nonterm type_)
                         ]
                     , Con_Con _lhsIpos (Ident "Nothing" _lhsIpos) [] []
                     ] []
                   {-# LINE 895 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2455, column 12)
              _lhsOpp =
                  ({-# LINE 2455 "src/Transform.ag" #-}
                   "Maybe" >#< show type_
                   {-# LINE 900 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 194, column 12)
              _lhsOhpp =
                  ({-# LINE 194 "src/TargetHaskell.ag" #-}
                   "Maybe" >#< pp_parens (text $ show type_)
                   {-# LINE 905 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 124, column 12)
              _lhsOjspp =
                  ({-# LINE 124 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 910 "src/Transform.hs" #-})
              -- self rule
              _alias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   AliasType_Maybe type_
                   {-# LINE 915 "src/Transform.hs" #-})
              -- self rule
              _lhsOalias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   _alias
                   {-# LINE 920 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDatas_augmented_syn =
                  ({-# LINE 482 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 925 "src/Transform.hs" #-})
          in  ( _lhsOalias,_lhsOdata,_lhsOdistDatas,_lhsOhpp,_lhsOjspp,_lhsOpp)))
sem_AliasType_Prod :: ([Ident]) ->
                      T_AliasType 
sem_AliasType_Prod fields_  =
    (\ _lhsIdistDatas
       _lhsIname
       _lhsIpos
       _lhsIvars ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOdata :: Data
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOalias :: AliasType 
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 480 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 944 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 480 "src/Transform.ag" #-}
                   \env -> foldr (\tp -> snd . find tp ()) env fields_
                   {-# LINE 949 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1452, column 12)
              _lhsOdata =
                  ({-# LINE 1452 "src/Transform.ag" #-}
                   let mkFld i nm = Field_Field (Ident ("x" ++ show i) _lhsIpos) (FieldType_Nonterm nm)
                   in Data_Data _lhsIpos _lhsIname _lhsIvars
                        [Con_Con _lhsIpos (Ident "Prod" _lhsIpos) [] (zipWith mkFld [1..] fields_) ] []
                   {-# LINE 956 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2453, column 12)
              _lhsOpp =
                  ({-# LINE 2453 "src/Transform.ag" #-}
                   pp_block "(" ")" "," (map (text . show) fields_)
                   {-# LINE 961 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 192, column 12)
              _lhsOhpp =
                  ({-# LINE 192 "src/TargetHaskell.ag" #-}
                   pp_block "(" ")" "," (map (text . show) fields_)
                   {-# LINE 966 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 122, column 12)
              _lhsOjspp =
                  ({-# LINE 122 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 971 "src/Transform.hs" #-})
              -- self rule
              _alias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   AliasType_Prod fields_
                   {-# LINE 976 "src/Transform.hs" #-})
              -- self rule
              _lhsOalias =
                  ({-# LINE 1431 "src/Transform.ag" #-}
                   _alias
                   {-# LINE 981 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDatas_augmented_syn =
                  ({-# LINE 480 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 986 "src/Transform.hs" #-})
          in  ( _lhsOalias,_lhsOdata,_lhsOdistDatas,_lhsOhpp,_lhsOjspp,_lhsOpp)))
-- Attr --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         coItf                : QIdent
         itf                  : QIdent
         opts                 : Opts
         visCyclic            : Bool
         visit                : QIdent
      chained attributes:
         gathInhs             : AttrEnv
         gathSyns             : AttrEnv
      synthesized attributes:
         gathAttrVisMap       : Map (Bool,Ident) Ident
         gathVisitInhAttrs    : Map Ident String
         gathVisitSynAttrs    : Map Ident String
         hCoInhDeclPPs        : [PP_Doc]
         hCoSynDeclPPs        : [PP_Doc]
         hInhDeclPPs          : [PP_Doc]
         hSynDeclPPs          : [PP_Doc]
         pp                   : PP_Doc
   alternatives:
      alternative Inh:
         child name           : {Ident}
         child type           : {String}
         visit 0:
            local gathInhs_augmented_f1 : _
            local gathSyns_augmented_f1 : _
            local itfNm       : _
            local visNm       : _
            local isInh       : _
            local hTpPP       : _
            local pos         : _
            local hBoxed      : _
            local hFldNm      : _
            local hCoFldNm    : _
            local gathInhs_augmented_syn : _
            local gathSyns_augmented_syn : _
      alternative Syn:
         child name           : {Ident}
         child type           : {String}
         visit 0:
            local gathInhs_augmented_f1 : _
            local gathSyns_augmented_f1 : _
            local itfNm       : _
            local visNm       : _
            local isInh       : _
            local hTpPP       : _
            local pos         : _
            local hBoxed      : _
            local hFldNm      : _
            local hCoFldNm    : _
            local gathInhs_augmented_syn : _
            local gathSyns_augmented_syn : _
-}
-- cata
sem_Attr :: Attr  ->
            T_Attr 
sem_Attr (Attr_Inh _name _type )  =
    (sem_Attr_Inh _name _type )
sem_Attr (Attr_Syn _name _type )  =
    (sem_Attr_Syn _name _type )
-- semantic domain
type T_Attr  = QIdent ->
               AttrEnv ->
               AttrEnv ->
               QIdent ->
               Opts ->
               Bool ->
               QIdent ->
               ( (Map (Bool,Ident) Ident),AttrEnv,AttrEnv,(Map Ident String),(Map Ident String),([PP_Doc]),([PP_Doc]),([PP_Doc]),([PP_Doc]),PP_Doc)
sem_Attr_Inh :: Ident ->
                String ->
                T_Attr 
sem_Attr_Inh name_ type_  =
    (\ _lhsIcoItf
       _lhsIgathInhs
       _lhsIgathSyns
       _lhsIitf
       _lhsIopts
       _lhsIvisCyclic
       _lhsIvisit ->
         (let _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisitInhAttrs :: (Map Ident String)
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOpp :: PP_Doc
              _lhsOhInhDeclPPs :: ([PP_Doc])
              _lhsOhCoSynDeclPPs :: ([PP_Doc])
              _lhsOgathVisitSynAttrs :: (Map Ident String)
              _lhsOhCoInhDeclPPs :: ([PP_Doc])
              _lhsOhSynDeclPPs :: ([PP_Doc])
              -- augmented rule
              _lhsOgathInhs =
                  ({-# LINE 221 "src/Transform.ag" #-}
                   foldr ($) _gathInhs_augmented_syn [_gathInhs_augmented_f1]
                   {-# LINE 1084 "src/Transform.hs" #-})
              -- augment function
              _gathInhs_augmented_f1 =
                  ({-# LINE 221 "src/Transform.ag" #-}
                   extend (name_ : _lhsIitf) type_
                   {-# LINE 1089 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathSyns =
                  ({-# LINE 222 "src/Transform.ag" #-}
                   foldr ($) _gathSyns_augmented_syn [_gathSyns_augmented_f1]
                   {-# LINE 1094 "src/Transform.hs" #-})
              -- augment function
              _gathSyns_augmented_f1 =
                  ({-# LINE 222 "src/Transform.ag" #-}
                   extend (name_ : _lhsIcoItf) type_
                   {-# LINE 1099 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 868, column 10)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 868 "src/Transform.ag" #-}
                   Map.singleton name_ type_
                   {-# LINE 1104 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1338, column 14)
              _itfNm =
                  ({-# LINE 1338 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 1109 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1339, column 14)
              _visNm =
                  ({-# LINE 1339 "src/Transform.ag" #-}
                   head _lhsIvisit
                   {-# LINE 1114 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1372, column 21)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1372 "src/Transform.ag" #-}
                   Map.singleton (_isInh    , name_) (head _lhsIvisit)
                   {-# LINE 1119 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1373, column 17)
              _isInh =
                  ({-# LINE 1373 "src/Transform.ag" #-}
                   True
                   {-# LINE 1124 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2433, column 18)
              _lhsOpp =
                  ({-# LINE 2433 "src/Transform.ag" #-}
                   "inh" >#< name_ >#< "::" >#< type_
                   {-# LINE 1129 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 149, column 14)
              _hTpPP =
                  ({-# LINE 149 "src/TargetHaskell.ag" #-}
                   stripSpacing type_
                   {-# LINE 1134 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 150, column 14)
              _pos =
                  ({-# LINE 150 "src/TargetHaskell.ag" #-}
                   identPos name_
                   {-# LINE 1139 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 151, column 14)
              _hBoxed =
                  ({-# LINE 151 "src/TargetHaskell.ag" #-}
                   if _lhsIvisCyclic then empty else text "!"
                   {-# LINE 1144 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 152, column 14)
              _hFldNm =
                  ({-# LINE 152 "src/TargetHaskell.ag" #-}
                   hInhFldNm name_ _itfNm     _visNm
                   {-# LINE 1149 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 153, column 14)
              _lhsOhInhDeclPPs =
                  ({-# LINE 153 "src/TargetHaskell.ag" #-}
                   [hWrapLinePragma _lhsIopts (identPos name_) (_hFldNm     >#< "::" >#< _hBoxed     >|< _hTpPP    )]
                   {-# LINE 1154 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 157, column 14)
              _hCoFldNm =
                  ({-# LINE 157 "src/TargetHaskell.ag" #-}
                   hCoSynFldNm name_ _itfNm     _visNm
                   {-# LINE 1159 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 158, column 14)
              _lhsOhCoSynDeclPPs =
                  ({-# LINE 158 "src/TargetHaskell.ag" #-}
                   [hWrapLinePragma _lhsIopts (identPos name_) (_hCoFldNm     >#< "::" >#< _hBoxed     >|< _hTpPP    )]
                   {-# LINE 1164 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 1169 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 1174 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 1179 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathInhs_augmented_syn =
                  ({-# LINE 221 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 1184 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathSyns_augmented_syn =
                  ({-# LINE 222 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 1189 "src/Transform.hs" #-})
          in  ( _lhsOgathAttrVisMap,_lhsOgathInhs,_lhsOgathSyns,_lhsOgathVisitInhAttrs,_lhsOgathVisitSynAttrs,_lhsOhCoInhDeclPPs,_lhsOhCoSynDeclPPs,_lhsOhInhDeclPPs,_lhsOhSynDeclPPs,_lhsOpp)))
sem_Attr_Syn :: Ident ->
                String ->
                T_Attr 
sem_Attr_Syn name_ type_  =
    (\ _lhsIcoItf
       _lhsIgathInhs
       _lhsIgathSyns
       _lhsIitf
       _lhsIopts
       _lhsIvisCyclic
       _lhsIvisit ->
         (let _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisitSynAttrs :: (Map Ident String)
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOpp :: PP_Doc
              _lhsOhSynDeclPPs :: ([PP_Doc])
              _lhsOhCoInhDeclPPs :: ([PP_Doc])
              _lhsOgathVisitInhAttrs :: (Map Ident String)
              _lhsOhCoSynDeclPPs :: ([PP_Doc])
              _lhsOhInhDeclPPs :: ([PP_Doc])
              -- augmented rule
              _lhsOgathInhs =
                  ({-# LINE 224 "src/Transform.ag" #-}
                   foldr ($) _gathInhs_augmented_syn [_gathInhs_augmented_f1]
                   {-# LINE 1216 "src/Transform.hs" #-})
              -- augment function
              _gathInhs_augmented_f1 =
                  ({-# LINE 224 "src/Transform.ag" #-}
                   extend (name_ : _lhsIcoItf) type_
                   {-# LINE 1221 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathSyns =
                  ({-# LINE 223 "src/Transform.ag" #-}
                   foldr ($) _gathSyns_augmented_syn [_gathSyns_augmented_f1]
                   {-# LINE 1226 "src/Transform.hs" #-})
              -- augment function
              _gathSyns_augmented_f1 =
                  ({-# LINE 223 "src/Transform.ag" #-}
                   extend (name_ : _lhsIitf) type_
                   {-# LINE 1231 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 869, column 10)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 869 "src/Transform.ag" #-}
                   Map.singleton name_ type_
                   {-# LINE 1236 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1338, column 14)
              _itfNm =
                  ({-# LINE 1338 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 1241 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1339, column 14)
              _visNm =
                  ({-# LINE 1339 "src/Transform.ag" #-}
                   head _lhsIvisit
                   {-# LINE 1246 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1372, column 21)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1372 "src/Transform.ag" #-}
                   Map.singleton (_isInh    , name_) (head _lhsIvisit)
                   {-# LINE 1251 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1374, column 17)
              _isInh =
                  ({-# LINE 1374 "src/Transform.ag" #-}
                   False
                   {-# LINE 1256 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2434, column 18)
              _lhsOpp =
                  ({-# LINE 2434 "src/Transform.ag" #-}
                   "syn" >#< name_ >#< "::" >#< type_
                   {-# LINE 1261 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 149, column 14)
              _hTpPP =
                  ({-# LINE 149 "src/TargetHaskell.ag" #-}
                   stripSpacing type_
                   {-# LINE 1266 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 150, column 14)
              _pos =
                  ({-# LINE 150 "src/TargetHaskell.ag" #-}
                   identPos name_
                   {-# LINE 1271 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 151, column 14)
              _hBoxed =
                  ({-# LINE 151 "src/TargetHaskell.ag" #-}
                   if _lhsIvisCyclic then empty else text "!"
                   {-# LINE 1276 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 154, column 14)
              _hFldNm =
                  ({-# LINE 154 "src/TargetHaskell.ag" #-}
                   hSynFldNm name_ _itfNm     _visNm
                   {-# LINE 1281 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 155, column 14)
              _lhsOhSynDeclPPs =
                  ({-# LINE 155 "src/TargetHaskell.ag" #-}
                   [hWrapLinePragma _lhsIopts (identPos name_) (_hFldNm     >#< "::" >#< _hBoxed     >|< _hTpPP    )]
                   {-# LINE 1286 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 159, column 14)
              _hCoFldNm =
                  ({-# LINE 159 "src/TargetHaskell.ag" #-}
                   hCoInhFldNm name_ _itfNm     _visNm
                   {-# LINE 1291 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 160, column 14)
              _lhsOhCoInhDeclPPs =
                  ({-# LINE 160 "src/TargetHaskell.ag" #-}
                   [hWrapLinePragma _lhsIopts (identPos name_) (_hCoFldNm     >#< "::" >#< _hBoxed     >|< _hTpPP    )]
                   {-# LINE 1296 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 1301 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 1306 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 1311 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathInhs_augmented_syn =
                  ({-# LINE 224 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 1316 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathSyns_augmented_syn =
                  ({-# LINE 223 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 1321 "src/Transform.hs" #-})
          in  ( _lhsOgathAttrVisMap,_lhsOgathInhs,_lhsOgathSyns,_lhsOgathVisitInhAttrs,_lhsOgathVisitSynAttrs,_lhsOhCoInhDeclPPs,_lhsOhCoSynDeclPPs,_lhsOhInhDeclPPs,_lhsOhSynDeclPPs,_lhsOpp)))
-- AttrTypeCode ------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         child                : Ident
         childItf             : Ident
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         name                 : Ident
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Child:
         visit 0:
            local distDefs_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local visitOrder  : _
            local visitOfAttr : _
            local minRanges   : _
            local potentialReqs : _
            local actualReqs  : _
            local invokeReqs  : _
            local attrDep     : _
            local depKey      : _
            local gathDeps_augmented_syn : _
            local distDefs_augmented_syn : _
      alternative Lhs:
         visit 0:
            local distDefs_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local attrDep     : _
            local depKey      : _
            local gathDeps_augmented_syn : _
            local distDefs_augmented_syn : _
      alternative ProdLocal:
         visit 0:
            local distDefs_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local attrDep     : _
            local depKey      : _
            local gathDeps_augmented_syn : _
            local distDefs_augmented_syn : _
      alternative VisLocal:
         visit 0:
            local distVisLocalDefs_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local attrDep     : _
            local depKey      : _
            local gathDeps_augmented_syn : _
            local distVisLocalDefs_augmented_syn : _
      alternative Visit:
         visit 0:
            local distDefs_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local attrDep     : _
            local depKey      : _
            local gathDeps_augmented_syn : _
            local distDefs_augmented_syn : _
-}
-- cata
sem_AttrTypeCode :: AttrTypeCode  ->
                    T_AttrTypeCode 
sem_AttrTypeCode (AttrTypeCode_Child )  =
    (sem_AttrTypeCode_Child )
sem_AttrTypeCode (AttrTypeCode_Lhs )  =
    (sem_AttrTypeCode_Lhs )
sem_AttrTypeCode (AttrTypeCode_ProdLocal )  =
    (sem_AttrTypeCode_ProdLocal )
sem_AttrTypeCode (AttrTypeCode_VisLocal )  =
    (sem_AttrTypeCode_VisLocal )
sem_AttrTypeCode (AttrTypeCode_Visit )  =
    (sem_AttrTypeCode_Visit )
-- semantic domain
type T_AttrTypeCode  = (Map Ident (Set Ident)) ->
                       (Set Ident) ->
                       (Map Ident (Set Ident)) ->
                       QIdent ->
                       Ident ->
                       Ident ->
                       Ident ->
                       Int ->
                       (Map Ident (Map Ident String)) ->
                       (Map Ident String) ->
                       (Map Ident AliasType) ->
                       (Map Ident [Ident]) ->
                       AttrSourceMap ->
                       AttrVisMap ->
                       (Env QIdent (QIdent,QIdent)) ->
                       (Map Ident (Set Ident)) ->
                       (Map Ident [Ident]) ->
                       (Map Ident Int) ->
                       ChildSourceMap ->
                       CycVisMap ->
                       ConEnv ->
                       DataMap ->
                       DataSemEnv ->
                       DataEnv ->
                       (Map Ident (Bool,Maybe Int)) ->
                       DefsEnv ->
                       AttrMap ->
                       ItfEnv ->
                       (Map DepItem (Bool,Int)) ->
                       RenameMap ->
                       AttrMap ->
                       DefsEnv ->
                       VisitAttrMap ->
                       (Map Ident [Ident]) ->
                       VisitSourceMap ->
                       VisitAttrMap ->
                       VisitEnv ->
                       ([Ident]) ->
                       ClausesEnv ->
                       DataSemEnv ->
                       DefsEnv ->
                       NontermEnv ->
                       DefsEnv ->
                       ([(Int,PP_Doc)]) ->
                       QIdent ->
                       ([(Int,PP_Doc)]) ->
                       Int ->
                       Ident ->
                       QIdent ->
                       Opts ->
                       DepItem ->
                       Reason ->
                       DepItem ->
                       DepItem ->
                       DepItem ->
                       Reason ->
                       ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,AttrSourceMap,(Set DepItem),ChildSourceMap,ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)))
sem_AttrTypeCode_Child :: T_AttrTypeCode 
sem_AttrTypeCode_Child  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDefs :: DefsEnv
              _lhsOgathDeps :: Deps
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDefs =
                  ({-# LINE 1144 "src/Transform.ag" #-}
                   foldr ($) _distDefs_augmented_syn [_distDefs_augmented_f1]
                   {-# LINE 1625 "src/Transform.hs" #-})
              -- augment function
              _distDefs_augmented_f1 =
                  ({-# LINE 1144 "src/Transform.ag" #-}
                   snd . find (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 1630 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 1635 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   addDep _lhsIstmtSource (ReasonAttrReq _lhsIchild _lhsIname) [_attrDep    ]
                   {-# LINE 1640 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 719, column 27)
              _visitOrder =
                  ({-# LINE 719 "src/Transform.ag" #-}
                   Map.findWithDefault [] _lhsIchildItf _lhsIdistVisitOrder
                   {-# LINE 1645 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1737, column 3)
              _visitOfAttr =
                  ({-# LINE 1737 "src/Transform.ag" #-}
                   Map.findWithDefault unknIdent (False,_lhsIname)
                     (Map.findWithDefault Map.empty _lhsIchildItf _lhsIdistAttrVisMap)
                   {-# LINE 1651 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1739, column 3)
              _minRanges =
                  ({-# LINE 1739 "src/Transform.ag" #-}
                   Set.fromList $ Map.findWithDefault [] _lhsIchild _lhsIdistAllChildMinRanges
                   {-# LINE 1656 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1740, column 3)
              _potentialReqs =
                  ({-# LINE 1740 "src/Transform.ag" #-}
                   dropWhile (/= _visitOfAttr    ) $ reverse _visitOrder
                   {-# LINE 1661 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1741, column 3)
              _actualReqs =
                  ({-# LINE 1741 "src/Transform.ag" #-}
                   take (1 + length (takeWhile (\x -> not $ Set.member x _minRanges    ) _potentialReqs    )) _potentialReqs
                   {-# LINE 1666 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1743, column 3)
              _invokeReqs =
                  ({-# LINE 1743 "src/Transform.ag" #-}
                   Map.singleton _lhsIchild $ Set.fromList _actualReqs
                   {-# LINE 1671 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1744, column 3)
              _lhsOminReqInvokes =
                  ({-# LINE 1744 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 1676 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1745, column 3)
              _lhsOallReqInvokes =
                  ({-# LINE 1745 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 1681 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1797, column 3)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1797 "src/Transform.ag" #-}
                   Set.fromList [ (k, v) | (k,vs) <- Map.assocs (_invokeReqs     `diffInside` _lhsIallAvailInvokes)
                                , v <- Set.toList vs ]
                   {-# LINE 1687 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2195, column 3)
              _attrDep =
                  ({-# LINE 2195 "src/Transform.ag" #-}
                   Map.findWithDefault (mkUnknownDep _depKey    ) _depKey     _lhsIdistAttrSource
                   {-# LINE 1692 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2201, column 3)
              _depKey =
                  ({-# LINE 2201 "src/Transform.ag" #-}
                   (False,_lhsIchild,_lhsIname)
                   {-# LINE 1697 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 547, column 16)
              _lhsOhpp =
                  ({-# LINE 547 "src/TargetHaskell.ag" #-}
                   text $ hInp _lhsIchild _lhsIname
                   {-# LINE 1702 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 343, column 24)
              _lhsOjspp =
                  ({-# LINE 343 "src/TargetJs.ag" #-}
                   text $ jsInp  _lhsIchild _lhsIname
                   {-# LINE 1707 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1712 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1717 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1722 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1727 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1732 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1737 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 1742 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 1747 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 1752 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1757 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 1762 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 1767 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1772 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 1777 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1782 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 1787 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 1792 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 1797 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 1802 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 1807 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 1812 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 1817 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDefs_augmented_syn =
                  ({-# LINE 1144 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 1822 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 1827 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 1832 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 1837 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 1842 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 1847 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 1852 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 1857 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 1862 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 1867 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypeCode_Lhs :: T_AttrTypeCode 
sem_AttrTypeCode_Lhs  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDefs :: DefsEnv
              _lhsOgathDeps :: Deps
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDefs =
                  ({-# LINE 1143 "src/Transform.ag" #-}
                   foldr ($) _distDefs_augmented_syn [_distDefs_augmented_f1]
                   {-# LINE 1968 "src/Transform.hs" #-})
              -- augment function
              _distDefs_augmented_f1 =
                  ({-# LINE 1143 "src/Transform.ag" #-}
                   snd . find (_lhsIchild, _lhsIname, True)  Nothing
                   {-# LINE 1973 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 1978 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   addDep _lhsIstmtSource (ReasonAttrReq _lhsIchild _lhsIname) [_attrDep    ]
                   {-# LINE 1983 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2195, column 3)
              _attrDep =
                  ({-# LINE 2195 "src/Transform.ag" #-}
                   Map.findWithDefault (mkUnknownDep _depKey    ) _depKey     _lhsIdistAttrSource
                   {-# LINE 1988 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2198, column 3)
              _depKey =
                  ({-# LINE 2198 "src/Transform.ag" #-}
                   (True,_lhsIchild,_lhsIname)
                   {-# LINE 1993 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 547, column 16)
              _lhsOhpp =
                  ({-# LINE 547 "src/TargetHaskell.ag" #-}
                   text $ hInp _lhsIchild _lhsIname
                   {-# LINE 1998 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 343, column 24)
              _lhsOjspp =
                  ({-# LINE 343 "src/TargetJs.ag" #-}
                   text $ jsInp  _lhsIchild _lhsIname
                   {-# LINE 2003 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2008 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2013 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2018 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2023 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2028 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2033 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2038 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2043 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2048 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2053 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2058 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2063 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2068 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2073 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2078 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2083 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2088 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2093 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2098 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2103 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 2108 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 2113 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 2118 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 2123 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 2128 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDefs_augmented_syn =
                  ({-# LINE 1143 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 2133 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 2138 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 2143 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 2148 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 2153 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 2158 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 2163 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 2168 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 2173 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 2178 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypeCode_ProdLocal :: T_AttrTypeCode 
sem_AttrTypeCode_ProdLocal  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDefs :: DefsEnv
              _lhsOgathDeps :: Deps
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDefs =
                  ({-# LINE 1142 "src/Transform.ag" #-}
                   foldr ($) _distDefs_augmented_syn [_distDefs_augmented_f1]
                   {-# LINE 2279 "src/Transform.hs" #-})
              -- augment function
              _distDefs_augmented_f1 =
                  ({-# LINE 1142 "src/Transform.ag" #-}
                   snd . find (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 2284 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 2289 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   addDep _lhsIstmtSource (ReasonAttrReq _lhsIchild _lhsIname) [_attrDep    ]
                   {-# LINE 2294 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2195, column 3)
              _attrDep =
                  ({-# LINE 2195 "src/Transform.ag" #-}
                   Map.findWithDefault (mkUnknownDep _depKey    ) _depKey     _lhsIdistAttrSource
                   {-# LINE 2299 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2201, column 3)
              _depKey =
                  ({-# LINE 2201 "src/Transform.ag" #-}
                   (False,_lhsIchild,_lhsIname)
                   {-# LINE 2304 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 545, column 16)
              _lhsOhpp =
                  ({-# LINE 545 "src/TargetHaskell.ag" #-}
                   text $ hInpLoc _lhsIchild _lhsIname
                   {-# LINE 2309 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 343, column 24)
              _lhsOjspp =
                  ({-# LINE 343 "src/TargetJs.ag" #-}
                   text $ jsInp  _lhsIchild _lhsIname
                   {-# LINE 2314 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2319 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2324 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2329 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2334 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2339 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2344 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2349 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2354 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2359 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2364 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2369 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2374 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2379 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2384 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2389 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2394 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2399 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2404 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2409 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2414 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 2419 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 2424 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 2429 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 2434 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 2439 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDefs_augmented_syn =
                  ({-# LINE 1142 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 2444 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 2449 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 2454 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 2459 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 2464 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 2469 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 2474 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 2479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 2484 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 2489 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypeCode_VisLocal :: T_AttrTypeCode 
sem_AttrTypeCode_VisLocal  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDeps :: Deps
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistVisLocalDefs =
                  ({-# LINE 1141 "src/Transform.ag" #-}
                   foldr ($) _distVisLocalDefs_augmented_syn [_distVisLocalDefs_augmented_f1]
                   {-# LINE 2590 "src/Transform.hs" #-})
              -- augment function
              _distVisLocalDefs_augmented_f1 =
                  ({-# LINE 1141 "src/Transform.ag" #-}
                   snd . find (_lhsIchild, _lhsIname,True) Nothing
                   {-# LINE 2595 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 2600 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   addDep _lhsIstmtSource (ReasonAttrReq _lhsIchild _lhsIname) [_attrDep    ]
                   {-# LINE 2605 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2195, column 3)
              _attrDep =
                  ({-# LINE 2195 "src/Transform.ag" #-}
                   Map.findWithDefault (mkUnknownDep _depKey    ) _depKey     _lhsIdistAttrSource
                   {-# LINE 2610 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2198, column 3)
              _depKey =
                  ({-# LINE 2198 "src/Transform.ag" #-}
                   (True,_lhsIchild,_lhsIname)
                   {-# LINE 2615 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 547, column 16)
              _lhsOhpp =
                  ({-# LINE 547 "src/TargetHaskell.ag" #-}
                   text $ hInp _lhsIchild _lhsIname
                   {-# LINE 2620 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 343, column 24)
              _lhsOjspp =
                  ({-# LINE 343 "src/TargetJs.ag" #-}
                   text $ jsInp  _lhsIchild _lhsIname
                   {-# LINE 2625 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2630 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2635 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2640 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2645 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2650 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2655 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2660 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2665 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2670 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2675 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2680 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2685 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2690 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2695 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2700 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2705 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2710 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2715 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2720 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2725 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 2730 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 2735 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 2740 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 2745 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 2750 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 2755 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 2760 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distVisLocalDefs_augmented_syn =
                  ({-# LINE 1141 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 2765 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 2770 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 2775 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 2780 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 2785 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 2790 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 2795 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 2800 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypeCode_Visit :: T_AttrTypeCode 
sem_AttrTypeCode_Visit  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDefs :: DefsEnv
              _lhsOgathDeps :: Deps
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDefs =
                  ({-# LINE 1145 "src/Transform.ag" #-}
                   foldr ($) _distDefs_augmented_syn [_distDefs_augmented_f1]
                   {-# LINE 2901 "src/Transform.hs" #-})
              -- augment function
              _distDefs_augmented_f1 =
                  ({-# LINE 1145 "src/Transform.ag" #-}
                   snd . find (_lhsIchild, _lhsIname, True)  Nothing
                   {-# LINE 2906 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 2911 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   addDep _lhsIstmtSource (ReasonAttrReq _lhsIchild _lhsIname) [_attrDep    ]
                   {-# LINE 2916 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2195, column 3)
              _attrDep =
                  ({-# LINE 2195 "src/Transform.ag" #-}
                   Map.findWithDefault (mkUnknownDep _depKey    ) _depKey     _lhsIdistAttrSource
                   {-# LINE 2921 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2201, column 3)
              _depKey =
                  ({-# LINE 2201 "src/Transform.ag" #-}
                   (False,_lhsIchild,_lhsIname)
                   {-# LINE 2926 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 547, column 16)
              _lhsOhpp =
                  ({-# LINE 547 "src/TargetHaskell.ag" #-}
                   text $ hInp _lhsIchild _lhsIname
                   {-# LINE 2931 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 343, column 24)
              _lhsOjspp =
                  ({-# LINE 343 "src/TargetJs.ag" #-}
                   text $ jsInp  _lhsIchild _lhsIname
                   {-# LINE 2936 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2941 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2946 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2951 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2956 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2961 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2966 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2971 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2976 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 2981 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2986 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2194 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 2991 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 2996 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3001 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3006 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3011 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3016 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3021 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3026 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3031 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3036 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 3041 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 3046 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 3051 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 3056 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 3061 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDefs_augmented_syn =
                  ({-# LINE 1145 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 3066 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 3071 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 3076 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 3081 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 3086 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 3091 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 3096 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 3101 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 3106 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 3111 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
-- AttrTypePat -------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         child                : Ident
         childItf             : Ident
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         name                 : Ident
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Child:
         visit 0:
            local errs2_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local visitOrder  : _
            local visits      : _
            local inhMap      : _
            local allowedDefs : _
            local errs2_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDefs_augmented_syn : _
      alternative Lhs:
         visit 0:
            local errs2_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local allowedDefs : _
            local errs2_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDefs_augmented_syn : _
      alternative ProdLocal:
         visit 0:
            local gathAttrSource_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local gathAttrSource_augmented_syn : _
            local gathDefs_augmented_syn : _
      alternative VisLocal:
         visit 0:
            local errs2_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathVisLocalDefs_augmented_f1 : _
            local allowedDefs : _
            local errs2_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathVisLocalDefs_augmented_syn : _
      alternative Visit:
         visit 0:
            local errs2_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local allowedDefs : _
            local errs2_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDefs_augmented_syn : _
-}
-- cata
sem_AttrTypePat :: AttrTypePat  ->
                   T_AttrTypePat 
sem_AttrTypePat (AttrTypePat_Child )  =
    (sem_AttrTypePat_Child )
sem_AttrTypePat (AttrTypePat_Lhs )  =
    (sem_AttrTypePat_Lhs )
sem_AttrTypePat (AttrTypePat_ProdLocal )  =
    (sem_AttrTypePat_ProdLocal )
sem_AttrTypePat (AttrTypePat_VisLocal )  =
    (sem_AttrTypePat_VisLocal )
sem_AttrTypePat (AttrTypePat_Visit )  =
    (sem_AttrTypePat_Visit )
-- semantic domain
type T_AttrTypePat  = (Map Ident (Set Ident)) ->
                      (Set Ident) ->
                      (Map Ident (Set Ident)) ->
                      QIdent ->
                      Ident ->
                      Ident ->
                      Ident ->
                      Int ->
                      (Map Ident (Map Ident String)) ->
                      (Map Ident String) ->
                      (Map Ident AliasType) ->
                      (Map Ident [Ident]) ->
                      AttrSourceMap ->
                      AttrVisMap ->
                      (Env QIdent (QIdent,QIdent)) ->
                      (Map Ident (Set Ident)) ->
                      (Map Ident [Ident]) ->
                      (Map Ident Int) ->
                      ChildSourceMap ->
                      CycVisMap ->
                      ConEnv ->
                      DataMap ->
                      DataSemEnv ->
                      DataEnv ->
                      (Map Ident (Bool,Maybe Int)) ->
                      DefsEnv ->
                      AttrMap ->
                      ItfEnv ->
                      (Map DepItem (Bool,Int)) ->
                      RenameMap ->
                      AttrMap ->
                      DefsEnv ->
                      VisitAttrMap ->
                      (Map Ident [Ident]) ->
                      VisitSourceMap ->
                      VisitAttrMap ->
                      VisitEnv ->
                      ([Ident]) ->
                      ClausesEnv ->
                      DataSemEnv ->
                      DefsEnv ->
                      NontermEnv ->
                      DefsEnv ->
                      ([(Int,PP_Doc)]) ->
                      QIdent ->
                      ([(Int,PP_Doc)]) ->
                      Int ->
                      Ident ->
                      QIdent ->
                      Opts ->
                      DepItem ->
                      Reason ->
                      DepItem ->
                      DepItem ->
                      DepItem ->
                      Reason ->
                      ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,AttrSourceMap,(Set DepItem),ChildSourceMap,ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)))
sem_AttrTypePat_Child :: T_AttrTypePat 
sem_AttrTypePat_Child  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 3412 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   ( if Map.member _lhsIname _allowedDefs
                     then Seq.empty
                     else Seq.singleton (Err_UndeclAttr _lhsIchild _lhsIname) ) Seq.><
                   {-# LINE 3419 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 3424 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   Map.insert (True,_lhsIchild,_lhsIname) _lhsIstmtSource
                   {-# LINE 3429 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1134 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 3434 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1134 "src/Transform.ag" #-}
                   extend (_lhsIchild, _lhsIname, True)  Nothing
                   {-# LINE 3439 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 718, column 27)
              _visitOrder =
                  ({-# LINE 718 "src/Transform.ag" #-}
                   Map.findWithDefault [] _lhsIchildItf _lhsIdistVisitOrder
                   {-# LINE 3444 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 953, column 7)
              _visits =
                  ({-# LINE 953 "src/Transform.ag" #-}
                   Set.toList $ Map.findWithDefault Set.empty _lhsIchild _lhsIdistChildEffRanges
                   {-# LINE 3449 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 954, column 7)
              _inhMap =
                  ({-# LINE 954 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty _lhsIchildItf _lhsIdistVisitInhAttrs
                   {-# LINE 3454 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 955, column 7)
              _allowedDefs =
                  ({-# LINE 955 "src/Transform.ag" #-}
                   Map.unions (map (\v -> Map.findWithDefault Map.empty v _inhMap    ) _visits    )
                   {-# LINE 3459 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 542, column 16)
              _lhsOhpp =
                  ({-# LINE 542 "src/TargetHaskell.ag" #-}
                   text $ hOutp _lhsIchild _lhsIname
                   {-# LINE 3464 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 342, column 24)
              _lhsOjspp =
                  ({-# LINE 342 "src/TargetJs.ag" #-}
                   text $ jsOutp _lhsIchild _lhsIname
                   {-# LINE 3469 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3474 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3479 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3484 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3489 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3494 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3499 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3504 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3509 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3514 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3519 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3524 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3529 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3534 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3539 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3544 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3549 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3554 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3564 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 3569 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 3574 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 3579 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 3584 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 3589 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 3594 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 3599 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 3604 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 3609 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 3614 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 3619 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDefs_augmented_syn =
                  ({-# LINE 1134 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 3624 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 3629 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 3634 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 3639 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypePat_Lhs :: T_AttrTypePat 
sem_AttrTypePat_Lhs  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 3739 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   ( if Map.member _lhsIname _allowedDefs
                     then Seq.empty
                     else Seq.singleton (Err_UndeclAttr _lhsIchild _lhsIname) ) Seq.><
                   {-# LINE 3746 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 3751 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.insert (False,_lhsIchild,_lhsIname) _lhsIstmtSource
                   {-# LINE 3756 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1133 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 3761 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1133 "src/Transform.ag" #-}
                   extend (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 3766 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 951, column 7)
              _allowedDefs =
                  ({-# LINE 951 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty (head _lhsIitf) _lhsIdistSynAttrs
                   {-# LINE 3771 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 542, column 16)
              _lhsOhpp =
                  ({-# LINE 542 "src/TargetHaskell.ag" #-}
                   text $ hOutp _lhsIchild _lhsIname
                   {-# LINE 3776 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 342, column 24)
              _lhsOjspp =
                  ({-# LINE 342 "src/TargetJs.ag" #-}
                   text $ jsOutp _lhsIchild _lhsIname
                   {-# LINE 3781 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3786 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3791 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3796 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3801 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3806 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3811 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3816 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3821 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3826 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3831 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3836 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3841 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 3846 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3851 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3856 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3861 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3866 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 3871 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 3876 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 3881 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 3886 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 3891 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 3896 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 3901 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 3906 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 3911 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 3916 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 3921 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 3926 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 3931 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDefs_augmented_syn =
                  ({-# LINE 1133 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 3936 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 3941 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 3946 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 3951 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypePat_ProdLocal :: T_AttrTypePat 
sem_AttrTypePat_ProdLocal  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 4051 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.insert (False,_lhsIchild,_lhsIname) _lhsIstmtSource
                   {-# LINE 4056 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1132 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 4061 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1132 "src/Transform.ag" #-}
                   extend (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 4066 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 540, column 16)
              _lhsOhpp =
                  ({-# LINE 540 "src/TargetHaskell.ag" #-}
                   text $ hOutpLoc _lhsIchild _lhsIname
                   {-# LINE 4071 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 342, column 24)
              _lhsOjspp =
                  ({-# LINE 342 "src/TargetJs.ag" #-}
                   text $ jsOutp _lhsIchild _lhsIname
                   {-# LINE 4076 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4081 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4086 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4091 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4096 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4101 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4106 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4111 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4116 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4121 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4126 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4131 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4136 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4141 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4146 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4151 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4156 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4161 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4166 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4171 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 4176 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 4181 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 4186 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 4191 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 4196 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 4201 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 4206 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 4211 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 4216 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 4221 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 4226 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDefs_augmented_syn =
                  ({-# LINE 1132 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 4231 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 4236 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 4241 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 4246 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypePat_VisLocal :: T_AttrTypePat 
sem_AttrTypePat_VisLocal  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 4346 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   ( if Map.member _lhsIname _allowedDefs
                     then Seq.empty
                     else Seq.singleton (Err_UndeclAttr _lhsIchild _lhsIname) ) Seq.><
                   {-# LINE 4353 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 4358 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.insert (False,_lhsIchild,_lhsIname) _lhsIstmtSource
                   {-# LINE 4363 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisLocalDefs =
                  ({-# LINE 1131 "src/Transform.ag" #-}
                   foldr ($) _gathVisLocalDefs_augmented_syn [_gathVisLocalDefs_augmented_f1]
                   {-# LINE 4368 "src/Transform.hs" #-})
              -- augment function
              _gathVisLocalDefs_augmented_f1 =
                  ({-# LINE 1131 "src/Transform.ag" #-}
                   extend (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 4373 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 959, column 7)
              _allowedDefs =
                  ({-# LINE 959 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 4378 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 542, column 16)
              _lhsOhpp =
                  ({-# LINE 542 "src/TargetHaskell.ag" #-}
                   text $ hOutp _lhsIchild _lhsIname
                   {-# LINE 4383 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 342, column 24)
              _lhsOjspp =
                  ({-# LINE 342 "src/TargetJs.ag" #-}
                   text $ jsOutp _lhsIchild _lhsIname
                   {-# LINE 4388 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4393 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4398 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4403 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4408 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4413 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4418 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4423 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2093 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4428 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4433 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4438 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4443 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4448 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4453 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4458 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4463 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4468 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4473 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4478 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4483 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 4488 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 4493 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 4498 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 4503 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 4508 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 4513 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 4518 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 4523 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 4528 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 4533 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 4538 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 4543 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 4548 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathVisLocalDefs_augmented_syn =
                  ({-# LINE 1131 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 4553 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 4558 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_AttrTypePat_Visit :: T_AttrTypePat 
sem_AttrTypePat_Visit  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIchild
       _lhsIchildItf
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIname
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 4658 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   ( if Map.member _lhsIname _allowedDefs
                     then Seq.empty
                     else Seq.singleton (Err_UndeclAttr _lhsIchild _lhsIname) ) Seq.><
                   {-# LINE 4665 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 4670 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   Map.insert (True,_lhsIchild,_lhsIname) _lhsIstmtSource
                   {-# LINE 4675 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1135 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 4680 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1135 "src/Transform.ag" #-}
                   extend (_lhsIchild, _lhsIname, False) Nothing
                   {-# LINE 4685 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 957, column 7)
              _allowedDefs =
                  ({-# LINE 957 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty _lhsIchild _lhsIdirectVisitAttrs
                   {-# LINE 4690 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 542, column 16)
              _lhsOhpp =
                  ({-# LINE 542 "src/TargetHaskell.ag" #-}
                   text $ hOutp _lhsIchild _lhsIname
                   {-# LINE 4695 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 342, column 24)
              _lhsOjspp =
                  ({-# LINE 342 "src/TargetJs.ag" #-}
                   text $ jsOutp _lhsIchild _lhsIname
                   {-# LINE 4700 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4705 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4710 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4715 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 961 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4720 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4725 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4730 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4735 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2095 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4740 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4745 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4750 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4755 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4760 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 4765 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4770 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4775 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4780 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4785 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 4790 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 4795 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 4800 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 4805 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 4810 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 4815 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 4820 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 4825 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 4830 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 4835 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 4840 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 4845 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 4850 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDefs_augmented_syn =
                  ({-# LINE 1135 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 4855 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 4860 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 4865 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 4870 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes)))
-- Attrs -------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         coItf                : QIdent
         itf                  : QIdent
         opts                 : Opts
         visCyclic            : Bool
         visit                : QIdent
      chained attributes:
         gathInhs             : AttrEnv
         gathSyns             : AttrEnv
      synthesized attributes:
         gathAttrVisMap       : Map (Bool,Ident) Ident
         gathVisitInhAttrs    : Map Ident String
         gathVisitSynAttrs    : Map Ident String
         hCoInhDeclPPs        : [PP_Doc]
         hCoSynDeclPPs        : [PP_Doc]
         hInhDeclPPs          : [PP_Doc]
         hSynDeclPPs          : [PP_Doc]
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Attr 
         child tl             : Attrs 
      alternative Nil:
-}
-- cata
sem_Attrs :: Attrs  ->
             T_Attrs 
sem_Attrs list  =
    (Prelude.foldr sem_Attrs_Cons sem_Attrs_Nil (Prelude.map sem_Attr list) )
-- semantic domain
type T_Attrs  = QIdent ->
                AttrEnv ->
                AttrEnv ->
                QIdent ->
                Opts ->
                Bool ->
                QIdent ->
                ( (Map (Bool,Ident) Ident),AttrEnv,AttrEnv,(Map Ident String),(Map Ident String),([PP_Doc]),([PP_Doc]),([PP_Doc]),([PP_Doc]),([PP_Doc]))
sem_Attrs_Cons :: T_Attr  ->
                  T_Attrs  ->
                  T_Attrs 
sem_Attrs_Cons hd_ tl_  =
    (\ _lhsIcoItf
       _lhsIgathInhs
       _lhsIgathSyns
       _lhsIitf
       _lhsIopts
       _lhsIvisCyclic
       _lhsIvisit ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOgathVisitInhAttrs :: (Map Ident String)
              _lhsOgathVisitSynAttrs :: (Map Ident String)
              _lhsOhCoInhDeclPPs :: ([PP_Doc])
              _lhsOhCoSynDeclPPs :: ([PP_Doc])
              _lhsOhInhDeclPPs :: ([PP_Doc])
              _lhsOhSynDeclPPs :: ([PP_Doc])
              _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              _hdOcoItf :: QIdent
              _hdOgathInhs :: AttrEnv
              _hdOgathSyns :: AttrEnv
              _hdOitf :: QIdent
              _hdOopts :: Opts
              _hdOvisCyclic :: Bool
              _hdOvisit :: QIdent
              _tlOcoItf :: QIdent
              _tlOgathInhs :: AttrEnv
              _tlOgathSyns :: AttrEnv
              _tlOitf :: QIdent
              _tlOopts :: Opts
              _tlOvisCyclic :: Bool
              _tlOvisit :: QIdent
              _hdIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _hdIgathInhs :: AttrEnv
              _hdIgathSyns :: AttrEnv
              _hdIgathVisitInhAttrs :: (Map Ident String)
              _hdIgathVisitSynAttrs :: (Map Ident String)
              _hdIhCoInhDeclPPs :: ([PP_Doc])
              _hdIhCoSynDeclPPs :: ([PP_Doc])
              _hdIhInhDeclPPs :: ([PP_Doc])
              _hdIhSynDeclPPs :: ([PP_Doc])
              _hdIpp :: PP_Doc
              _tlIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _tlIgathInhs :: AttrEnv
              _tlIgathSyns :: AttrEnv
              _tlIgathVisitInhAttrs :: (Map Ident String)
              _tlIgathVisitSynAttrs :: (Map Ident String)
              _tlIhCoInhDeclPPs :: ([PP_Doc])
              _tlIhCoSynDeclPPs :: ([PP_Doc])
              _tlIhInhDeclPPs :: ([PP_Doc])
              _tlIhSynDeclPPs :: ([PP_Doc])
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2633, column 11)
              _lhsOpps =
                  ({-# LINE 2633 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 4972 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1370, column 57)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1370 "src/Transform.ag" #-}
                   _hdIgathAttrVisMap `Map.union` _tlIgathAttrVisMap
                   {-# LINE 4977 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   _hdIgathVisitInhAttrs `mappend` _tlIgathVisitInhAttrs
                   {-# LINE 4982 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   _hdIgathVisitSynAttrs `mappend` _tlIgathVisitSynAttrs
                   {-# LINE 4987 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   _hdIhCoInhDeclPPs ++ _tlIhCoInhDeclPPs
                   {-# LINE 4992 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   _hdIhCoSynDeclPPs ++ _tlIhCoSynDeclPPs
                   {-# LINE 4997 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   _hdIhInhDeclPPs ++ _tlIhInhDeclPPs
                   {-# LINE 5002 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   _hdIhSynDeclPPs ++ _tlIhSynDeclPPs
                   {-# LINE 5007 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathInhs
                   {-# LINE 5012 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathSyns
                   {-# LINE 5017 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 200 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 5022 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 5027 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 5032 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 184 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 5037 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 5042 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisCyclic =
                  ({-# LINE 1887 "src/Transform.ag" #-}
                   _lhsIvisCyclic
                   {-# LINE 5047 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisit =
                  ({-# LINE 200 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 5052 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 200 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 5057 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathInhs
                   {-# LINE 5062 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathSyns
                   {-# LINE 5067 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 184 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 5072 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 5077 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisCyclic =
                  ({-# LINE 1887 "src/Transform.ag" #-}
                   _lhsIvisCyclic
                   {-# LINE 5082 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisit =
                  ({-# LINE 200 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 5087 "src/Transform.hs" #-})
              ( _hdIgathAttrVisMap,_hdIgathInhs,_hdIgathSyns,_hdIgathVisitInhAttrs,_hdIgathVisitSynAttrs,_hdIhCoInhDeclPPs,_hdIhCoSynDeclPPs,_hdIhInhDeclPPs,_hdIhSynDeclPPs,_hdIpp) =
                  hd_ _hdOcoItf _hdOgathInhs _hdOgathSyns _hdOitf _hdOopts _hdOvisCyclic _hdOvisit 
              ( _tlIgathAttrVisMap,_tlIgathInhs,_tlIgathSyns,_tlIgathVisitInhAttrs,_tlIgathVisitSynAttrs,_tlIhCoInhDeclPPs,_tlIhCoSynDeclPPs,_tlIhInhDeclPPs,_tlIhSynDeclPPs,_tlIpps) =
                  tl_ _tlOcoItf _tlOgathInhs _tlOgathSyns _tlOitf _tlOopts _tlOvisCyclic _tlOvisit 
          in  ( _lhsOgathAttrVisMap,_lhsOgathInhs,_lhsOgathSyns,_lhsOgathVisitInhAttrs,_lhsOgathVisitSynAttrs,_lhsOhCoInhDeclPPs,_lhsOhCoSynDeclPPs,_lhsOhInhDeclPPs,_lhsOhSynDeclPPs,_lhsOpps)))
sem_Attrs_Nil :: T_Attrs 
sem_Attrs_Nil  =
    (\ _lhsIcoItf
       _lhsIgathInhs
       _lhsIgathSyns
       _lhsIitf
       _lhsIopts
       _lhsIvisCyclic
       _lhsIvisit ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOgathVisitInhAttrs :: (Map Ident String)
              _lhsOgathVisitSynAttrs :: (Map Ident String)
              _lhsOhCoInhDeclPPs :: ([PP_Doc])
              _lhsOhCoSynDeclPPs :: ([PP_Doc])
              _lhsOhInhDeclPPs :: ([PP_Doc])
              _lhsOhSynDeclPPs :: ([PP_Doc])
              _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              -- "src/Transform.ag"(line 2634, column 11)
              _lhsOpps =
                  ({-# LINE 2634 "src/Transform.ag" #-}
                   []
                   {-# LINE 5116 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1370, column 57)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1370 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5121 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5126 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 865, column 60)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 865 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5131 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 5136 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhCoSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 5141 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhInhDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 5146 "src/Transform.hs" #-})
              -- use rule "src/TargetHaskell.ag"(line 146, column 75)
              _lhsOhSynDeclPPs =
                  ({-# LINE 146 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 5151 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 5156 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 5161 "src/Transform.hs" #-})
          in  ( _lhsOgathAttrVisMap,_lhsOgathInhs,_lhsOgathSyns,_lhsOgathVisitInhAttrs,_lhsOgathVisitSynAttrs,_lhsOhCoInhDeclPPs,_lhsOhCoSynDeclPPs,_lhsOhInhDeclPPs,_lhsOhSynDeclPPs,_lhsOpps)))
-- Bind --------------------------------------------------------
{-
   visit 0:
      synthesized attributes:
         isFun                : Bool
         pp                   : PP_Doc
         width                : Int
   alternatives:
      alternative Fun:
      alternative Monadic:
-}
-- cata
sem_Bind :: Bind  ->
            T_Bind 
sem_Bind (Bind_Fun )  =
    (sem_Bind_Fun )
sem_Bind (Bind_Monadic )  =
    (sem_Bind_Monadic )
-- semantic domain
type T_Bind  = ( Bool,PP_Doc,Int)
sem_Bind_Fun :: T_Bind 
sem_Bind_Fun  =
    (let _lhsOisFun :: Bool
         _lhsOpp :: PP_Doc
         _lhsOwidth :: Int
         -- "src/Transform.ag"(line 1979, column 15)
         _lhsOisFun =
             ({-# LINE 1979 "src/Transform.ag" #-}
              True
              {-# LINE 5192 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2561, column 18)
         _lhsOpp =
             ({-# LINE 2561 "src/Transform.ag" #-}
              text "="
              {-# LINE 5197 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2566, column 18)
         _lhsOwidth =
             ({-# LINE 2566 "src/Transform.ag" #-}
              1
              {-# LINE 5202 "src/Transform.hs" #-})
     in  ( _lhsOisFun,_lhsOpp,_lhsOwidth))
sem_Bind_Monadic :: T_Bind 
sem_Bind_Monadic  =
    (let _lhsOisFun :: Bool
         _lhsOpp :: PP_Doc
         _lhsOwidth :: Int
         -- "src/Transform.ag"(line 1980, column 15)
         _lhsOisFun =
             ({-# LINE 1980 "src/Transform.ag" #-}
              False
              {-# LINE 5213 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2562, column 18)
         _lhsOpp =
             ({-# LINE 2562 "src/Transform.ag" #-}
              text "<-"
              {-# LINE 5218 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2567, column 18)
         _lhsOwidth =
             ({-# LINE 2567 "src/Transform.ag" #-}
              2
              {-# LINE 5223 "src/Transform.hs" #-})
     in  ( _lhsOisFun,_lhsOpp,_lhsOwidth))
-- Block -------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         jsSpilledStmts       : [(Int,PP_Doc)]
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataCons         : ConEnv
         gathDataSems         : DataSemEnv
         gathDatas            : DataEnv
         gathDefs             : DefsEnv
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathNonterms         : NontermEnv
         gathSyns             : AttrEnv
         gathVisLocalDefs     : DefsEnv
         gathVisits           : VisitEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathAliasses         : Map Ident AliasType
         gathAttrVisMap       : AttrVisMap
         gathAvoidVisits      : Set DepItem
         gathCycVisMap        : CycVisMap
         gathDataMap          : DataMap
         gathDeps             : Deps
         gathInhAttrs         : AttrMap
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathSynAttrs         : AttrMap
         gathVisitEnds        : Seq DepItem
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitStarts      : Seq DepItem
         gathVisitSynAttrs    : VisitAttrMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Data:
         child data           : Data 
      alternative DataSem:
         child sem            : DataSem 
         visit 0:
            local itf         : _
            local coItf       : _
      alternative Item:
         child name           : {Ident}
         child item           : Item 
         visit 0:
            local itf         : _
            local coItf       : _
      alternative Itf:
         child itf            : Itf 
      alternative Section:
         child code           : Code 
         visit 0:
            local itf         : _
            local coItf       : _
      alternative Type:
         child type           : Type 
-}
-- cata
sem_Block :: Block  ->
             T_Block 
sem_Block (Block_Data _data )  =
    (sem_Block_Data (sem_Data _data ) )
sem_Block (Block_DataSem _sem )  =
    (sem_Block_DataSem (sem_DataSem _sem ) )
sem_Block (Block_Item _name _item )  =
    (sem_Block_Item _name (sem_Item _item ) )
sem_Block (Block_Itf _itf )  =
    (sem_Block_Itf (sem_Itf _itf ) )
sem_Block (Block_Section _code )  =
    (sem_Block_Section (sem_Code _code ) )
sem_Block (Block_Type _type )  =
    (sem_Block_Type (sem_Type _type ) )
-- semantic domain
type T_Block  = (Map Ident (Set Ident)) ->
                (Set Ident) ->
                (Map Ident (Set Ident)) ->
                QIdent ->
                Int ->
                (Map Ident (Map Ident String)) ->
                (Map Ident String) ->
                (Map Ident AliasType) ->
                (Map Ident [Ident]) ->
                AttrSourceMap ->
                AttrVisMap ->
                (Env QIdent (QIdent,QIdent)) ->
                (Map Ident (Set Ident)) ->
                (Map Ident [Ident]) ->
                (Map Ident Int) ->
                ChildSourceMap ->
                CycVisMap ->
                ConEnv ->
                DataMap ->
                DataSemEnv ->
                DataEnv ->
                (Map Ident (Bool,Maybe Int)) ->
                DefsEnv ->
                AttrMap ->
                ItfEnv ->
                (Map DepItem (Bool,Int)) ->
                RenameMap ->
                AttrMap ->
                DefsEnv ->
                VisitAttrMap ->
                (Map Ident [Ident]) ->
                VisitSourceMap ->
                VisitAttrMap ->
                VisitEnv ->
                ([Ident]) ->
                (Env QIdent (QIdent, QIdent)) ->
                ClausesEnv ->
                ConEnv ->
                DataSemEnv ->
                DataEnv ->
                DefsEnv ->
                AttrEnv ->
                ItfEnv ->
                NontermEnv ->
                AttrEnv ->
                DefsEnv ->
                VisitEnv ->
                ([(Int,PP_Doc)]) ->
                ([(Int,PP_Doc)]) ->
                Int ->
                Opts ->
                DepItem ->
                Reason ->
                DepItem ->
                DepItem ->
                DepItem ->
                Reason ->
                ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,Blocks,(Map Ident AliasType),AttrVisMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,CycVisMap,ConEnv,DataMap,DataSemEnv,DataEnv,DefsEnv,Deps,AttrMap,AttrEnv,(Map DepItem DepItem),ItfEnv,(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),AttrMap,AttrEnv,DefsEnv,(Seq DepItem),VisitAttrMap,(Map Ident [Ident]),(Seq DepItem),VisitAttrMap,VisitEnv,PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),PP_Doc)
sem_Block_Data :: T_Data  ->
                  T_Block 
sem_Block_Data data_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _dataOdistAliasses :: (Map Ident AliasType)
              _dataOdistDatas :: DataEnv
              _dataOgathDataCons :: ConEnv
              _dataOgathDatas :: DataEnv
              _dataOopts :: Opts
              _dataIdistDatas :: DataEnv
              _dataIerrs0 :: Errs
              _dataIerrs1 :: Errs
              _dataIerrs2 :: Errs
              _dataIerrs3 :: Errs
              _dataIerrs4 :: Errs
              _dataIerrs5 :: Errs
              _dataIextraBlocks :: Blocks
              _dataIgathDataCons :: ConEnv
              _dataIgathDataMap :: DataMap
              _dataIgathDatas :: DataEnv
              _dataIhpp :: PP_Doc
              _dataIjspp :: PP_Doc
              _dataIpp :: PP_Doc
              -- "src/Transform.ag"(line 2419, column 18)
              _lhsOpp =
                  ({-# LINE 2419 "src/Transform.ag" #-}
                   _dataIpp
                   {-# LINE 5549 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 82, column 14)
              _lhsOhpp =
                  ({-# LINE 82 "src/TargetHaskell.ag" #-}
                   if noDataGen _lhsIopts then empty else _dataIhpp
                   {-# LINE 5554 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 42, column 14)
              _lhsOjspp =
                  ({-# LINE 42 "src/TargetJs.ag" #-}
                   _dataIjspp
                   {-# LINE 5559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5564 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs0
                   {-# LINE 5569 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs1
                   {-# LINE 5574 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs2
                   {-# LINE 5579 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs3
                   {-# LINE 5584 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs4
                   {-# LINE 5589 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs5
                   {-# LINE 5594 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _dataIextraBlocks
                   {-# LINE 5599 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5604 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5609 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 5614 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5619 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   _dataIgathDataMap
                   {-# LINE 5624 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 5629 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5634 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5639 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 5644 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 5649 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5654 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5659 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 5664 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5669 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5674 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 5679 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 5684 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 5689 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 5694 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 5699 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 5704 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 5709 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _dataIdistDatas
                   {-# LINE 5714 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 5719 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 5724 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 5729 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 5734 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 5739 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 5744 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _dataIgathDataCons
                   {-# LINE 5749 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 5754 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _dataIgathDatas
                   {-# LINE 5759 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 5764 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 5769 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 5774 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 5779 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 5784 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 5789 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 5794 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 5799 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 5804 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 5809 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 5814 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 5819 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 5824 "src/Transform.hs" #-})
              ( _dataIdistDatas,_dataIerrs0,_dataIerrs1,_dataIerrs2,_dataIerrs3,_dataIerrs4,_dataIerrs5,_dataIextraBlocks,_dataIgathDataCons,_dataIgathDataMap,_dataIgathDatas,_dataIhpp,_dataIjspp,_dataIpp) =
                  data_ _dataOdistAliasses _dataOdistDatas _dataOgathDataCons _dataOgathDatas _dataOopts 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Block_DataSem :: T_DataSem  ->
                     T_Block 
sem_Block_DataSem sem_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _semOnonterm :: QIdent
              _lhsOpp :: PP_Doc
              _semOindent :: Int
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _semOallAvailInvokes :: (Map Ident (Set Ident))
              _semOallVisits :: (Set Ident)
              _semOavailInvokes :: (Map Ident (Set Ident))
              _semObasename :: QIdent
              _semOcoItf :: Ident
              _semOcodeIdCounter :: Int
              _semOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _semOdirectVisitLocalAttrs :: (Map Ident String)
              _semOdistAliasses :: (Map Ident AliasType)
              _semOdistAllChildMinRanges :: (Map Ident [Ident])
              _semOdistAttrSource :: AttrSourceMap
              _semOdistAttrVisMap :: AttrVisMap
              _semOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _semOdistChildEffRanges :: (Map Ident (Set Ident))
              _semOdistChildMinRanges :: (Map Ident [Ident])
              _semOdistChildOcc :: (Map Ident Int)
              _semOdistChildSource :: ChildSourceMap
              _semOdistCycVisMap :: CycVisMap
              _semOdistDataCons :: ConEnv
              _semOdistDataMap :: DataMap
              _semOdistDataSems :: DataSemEnv
              _semOdistDatas :: DataEnv
              _semOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _semOdistDefs :: DefsEnv
              _semOdistInhAttrs :: AttrMap
              _semOdistItfs :: ItfEnv
              _semOdistRanks :: (Map DepItem (Bool,Int))
              _semOdistRenames :: RenameMap
              _semOdistSynAttrs :: AttrMap
              _semOdistVisLocalDefs :: DefsEnv
              _semOdistVisitInhAttrs :: VisitAttrMap
              _semOdistVisitOrder :: (Map Ident [Ident])
              _semOdistVisitSource :: VisitSourceMap
              _semOdistVisitSynAttrs :: VisitAttrMap
              _semOdistVisits :: VisitEnv
              _semOdoneVisits :: ([Ident])
              _semOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _semOgathClauses :: ClausesEnv
              _semOgathDataSems :: DataSemEnv
              _semOgathDefs :: DefsEnv
              _semOgathNonterms :: NontermEnv
              _semOgathVisLocalDefs :: DefsEnv
              _semOhSpilledStmts :: ([(Int,PP_Doc)])
              _semOitf :: QIdent
              _semOjsSpilledStmts :: ([(Int,PP_Doc)])
              _semOlexCounter :: Int
              _semOopts :: Opts
              _semOscopeDep :: DepItem
              _semOscopeReason :: Reason
              _semOstmtSource :: DepItem
              _semOvisitBeginDep :: DepItem
              _semOvisitEndDep :: DepItem
              _semOvisitEndReason :: Reason
              _semIallReqInvokes :: (Map Ident (Set Ident))
              _semIcodeIdCounter :: Int
              _semIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _semIdistDataCons :: ConEnv
              _semIdistDataSems :: DataSemEnv
              _semIdistDatas :: DataEnv
              _semIdistDefs :: DefsEnv
              _semIdistItfs :: ItfEnv
              _semIdistVisLocalDefs :: DefsEnv
              _semIdistVisits :: VisitEnv
              _semIerrs0 :: Errs
              _semIerrs1 :: Errs
              _semIerrs2 :: Errs
              _semIerrs3 :: Errs
              _semIerrs4 :: Errs
              _semIerrs5 :: Errs
              _semIgathAvoidVisits :: (Set DepItem)
              _semIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _semIgathClauses :: ClausesEnv
              _semIgathDataSems :: DataSemEnv
              _semIgathDefs :: DefsEnv
              _semIgathDeps :: Deps
              _semIgathItemVisits :: (Map DepItem DepItem)
              _semIgathLegalCycStmts :: (Set DepItem)
              _semIgathNonterms :: NontermEnv
              _semIgathSemStarts :: (Seq DepItem)
              _semIgathStmtPosMap :: (Map DepItem Pos)
              _semIgathVisLocalDefs :: DefsEnv
              _semIgathVisitEnds :: (Seq DepItem)
              _semIgathVisitStarts :: (Seq DepItem)
              _semIhpp :: PP_Doc
              _semIjspp :: PP_Doc
              _semIlexCounter :: Int
              _semIminReqInvokes :: (Map Ident (Set Ident))
              _semIpos :: Pos
              _semIpp :: PP_Doc
              -- "src/Transform.ag"(line 246, column 22)
              _semOnonterm =
                  ({-# LINE 246 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 6034 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 411, column 3)
              _itf =
                  ({-# LINE 411 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 6039 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 412, column 3)
              _coItf =
                  ({-# LINE 412 "src/Transform.ag" #-}
                   ident "<root>"
                   {-# LINE 6044 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2422, column 18)
              _lhsOpp =
                  ({-# LINE 2422 "src/Transform.ag" #-}
                   _semIpp
                   {-# LINE 6049 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2487, column 23)
              _semOindent =
                  ({-# LINE 2487 "src/Transform.ag" #-}
                   1
                   {-# LINE 6054 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 87, column 14)
              _lhsOhpp =
                  ({-# LINE 87 "src/TargetHaskell.ag" #-}
                   _semIhpp
                   {-# LINE 6059 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 45, column 14)
              _lhsOjspp =
                  ({-# LINE 45 "src/TargetJs.ag" #-}
                   _semIjspp
                   {-# LINE 6064 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _semIallReqInvokes
                   {-# LINE 6069 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs0
                   {-# LINE 6074 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs1
                   {-# LINE 6079 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs2
                   {-# LINE 6084 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs3
                   {-# LINE 6089 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs4
                   {-# LINE 6094 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs5
                   {-# LINE 6099 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 6104 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6109 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6114 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _semIgathAvoidVisits
                   {-# LINE 6119 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6124 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6129 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _semIgathDeps
                   {-# LINE 6134 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6139 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _semIgathItemVisits
                   {-# LINE 6144 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _semIgathLegalCycStmts
                   {-# LINE 6149 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _semIgathSemStarts
                   {-# LINE 6154 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _semIgathStmtPosMap
                   {-# LINE 6159 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6164 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _semIgathVisitEnds
                   {-# LINE 6169 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6174 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6179 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _semIgathVisitStarts
                   {-# LINE 6184 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6189 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _semIminReqInvokes
                   {-# LINE 6194 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _semIcodeIdCounter
                   {-# LINE 6199 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _semIdistChildDefs
                   {-# LINE 6204 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _semIdistDataCons
                   {-# LINE 6209 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _semIdistDataSems
                   {-# LINE 6214 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _semIdistDatas
                   {-# LINE 6219 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIdistDefs
                   {-# LINE 6224 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _semIdistItfs
                   {-# LINE 6229 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIdistVisLocalDefs
                   {-# LINE 6234 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _semIdistVisits
                   {-# LINE 6239 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _semIgathChildDefs
                   {-# LINE 6244 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _semIgathClauses
                   {-# LINE 6249 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 6254 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _semIgathDataSems
                   {-# LINE 6259 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 6264 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIgathDefs
                   {-# LINE 6269 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 6274 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 6279 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _semIgathNonterms
                   {-# LINE 6284 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 6289 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIgathVisLocalDefs
                   {-# LINE 6294 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 6299 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _semIlexCounter
                   {-# LINE 6304 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 6309 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 6314 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 6319 "src/Transform.hs" #-})
              -- copy rule (down)
              _semObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 6324 "src/Transform.hs" #-})
              -- copy rule (from local)
              _semOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _coItf
                   {-# LINE 6329 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 6334 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 6339 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 6344 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 6349 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 6354 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 6359 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 6364 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 6369 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 6374 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 6379 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 6384 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 6389 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 6394 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 6399 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 6404 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 6409 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 6414 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 6419 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 6424 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 6429 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 6434 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 6439 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 6444 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 6449 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 6454 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 6459 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 6464 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 6469 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 6474 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 6479 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 6484 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 6489 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 6494 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 6499 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 6504 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 6509 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 6514 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 6519 "src/Transform.hs" #-})
              -- copy rule (from local)
              _semOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _itf
                   {-# LINE 6524 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 6529 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 6534 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 6539 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 6544 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 6549 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 6554 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 6559 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 6564 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 6569 "src/Transform.hs" #-})
              ( _semIallReqInvokes,_semIcodeIdCounter,_semIdistChildDefs,_semIdistDataCons,_semIdistDataSems,_semIdistDatas,_semIdistDefs,_semIdistItfs,_semIdistVisLocalDefs,_semIdistVisits,_semIerrs0,_semIerrs1,_semIerrs2,_semIerrs3,_semIerrs4,_semIerrs5,_semIgathAvoidVisits,_semIgathChildDefs,_semIgathClauses,_semIgathDataSems,_semIgathDefs,_semIgathDeps,_semIgathItemVisits,_semIgathLegalCycStmts,_semIgathNonterms,_semIgathSemStarts,_semIgathStmtPosMap,_semIgathVisLocalDefs,_semIgathVisitEnds,_semIgathVisitStarts,_semIhpp,_semIjspp,_semIlexCounter,_semIminReqInvokes,_semIpos,_semIpp) =
                  sem_ _semOallAvailInvokes _semOallVisits _semOavailInvokes _semObasename _semOcoItf _semOcodeIdCounter _semOdirectVisitAttrs _semOdirectVisitLocalAttrs _semOdistAliasses _semOdistAllChildMinRanges _semOdistAttrSource _semOdistAttrVisMap _semOdistChildDefs _semOdistChildEffRanges _semOdistChildMinRanges _semOdistChildOcc _semOdistChildSource _semOdistCycVisMap _semOdistDataCons _semOdistDataMap _semOdistDataSems _semOdistDatas _semOdistDeflStmts _semOdistDefs _semOdistInhAttrs _semOdistItfs _semOdistRanks _semOdistRenames _semOdistSynAttrs _semOdistVisLocalDefs _semOdistVisitInhAttrs _semOdistVisitOrder _semOdistVisitSource _semOdistVisitSynAttrs _semOdistVisits _semOdoneVisits _semOgathChildDefs _semOgathClauses _semOgathDataSems _semOgathDefs _semOgathNonterms _semOgathVisLocalDefs _semOhSpilledStmts _semOindent _semOitf _semOjsSpilledStmts _semOlexCounter _semOnonterm _semOopts _semOscopeDep _semOscopeReason _semOstmtSource _semOvisitBeginDep _semOvisitEndDep _semOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Block_Item :: Ident ->
                  T_Item  ->
                  T_Block 
sem_Block_Item name_ item_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _itemOnonterm :: QIdent
              _lhsOpp :: PP_Doc
              _itemOindent :: Int
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _itemOallAvailInvokes :: (Map Ident (Set Ident))
              _itemOallVisits :: (Set Ident)
              _itemOavailInvokes :: (Map Ident (Set Ident))
              _itemObasename :: QIdent
              _itemOcoItf :: Ident
              _itemOcodeIdCounter :: Int
              _itemOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _itemOdirectVisitLocalAttrs :: (Map Ident String)
              _itemOdistAliasses :: (Map Ident AliasType)
              _itemOdistAllChildMinRanges :: (Map Ident [Ident])
              _itemOdistAttrSource :: AttrSourceMap
              _itemOdistAttrVisMap :: AttrVisMap
              _itemOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemOdistChildEffRanges :: (Map Ident (Set Ident))
              _itemOdistChildMinRanges :: (Map Ident [Ident])
              _itemOdistChildOcc :: (Map Ident Int)
              _itemOdistChildSource :: ChildSourceMap
              _itemOdistCycVisMap :: CycVisMap
              _itemOdistDataCons :: ConEnv
              _itemOdistDataMap :: DataMap
              _itemOdistDataSems :: DataSemEnv
              _itemOdistDatas :: DataEnv
              _itemOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _itemOdistDefs :: DefsEnv
              _itemOdistInhAttrs :: AttrMap
              _itemOdistItfs :: ItfEnv
              _itemOdistRanks :: (Map DepItem (Bool,Int))
              _itemOdistRenames :: RenameMap
              _itemOdistSynAttrs :: AttrMap
              _itemOdistVisLocalDefs :: DefsEnv
              _itemOdistVisitInhAttrs :: VisitAttrMap
              _itemOdistVisitOrder :: (Map Ident [Ident])
              _itemOdistVisitSource :: VisitSourceMap
              _itemOdistVisitSynAttrs :: VisitAttrMap
              _itemOdistVisits :: VisitEnv
              _itemOdoneVisits :: ([Ident])
              _itemOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemOgathClauses :: ClausesEnv
              _itemOgathDataSems :: DataSemEnv
              _itemOgathDefs :: DefsEnv
              _itemOgathNonterms :: NontermEnv
              _itemOgathVisLocalDefs :: DefsEnv
              _itemOhSpilledStmts :: ([(Int,PP_Doc)])
              _itemOitf :: QIdent
              _itemOjsSpilledStmts :: ([(Int,PP_Doc)])
              _itemOlexCounter :: Int
              _itemOopts :: Opts
              _itemOscopeDep :: DepItem
              _itemOscopeReason :: Reason
              _itemOstmtSource :: DepItem
              _itemOvisitBeginDep :: DepItem
              _itemOvisitEndDep :: DepItem
              _itemOvisitEndReason :: Reason
              _itemIallReqInvokes :: (Map Ident (Set Ident))
              _itemIcodeIdCounter :: Int
              _itemIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemIdistDataCons :: ConEnv
              _itemIdistDataSems :: DataSemEnv
              _itemIdistDatas :: DataEnv
              _itemIdistDefs :: DefsEnv
              _itemIdistItfs :: ItfEnv
              _itemIdistVisLocalDefs :: DefsEnv
              _itemIdistVisits :: VisitEnv
              _itemIerrs0 :: Errs
              _itemIerrs1 :: Errs
              _itemIerrs2 :: Errs
              _itemIerrs3 :: Errs
              _itemIerrs4 :: Errs
              _itemIerrs5 :: Errs
              _itemIgathAvoidVisits :: (Set DepItem)
              _itemIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemIgathClauses :: ClausesEnv
              _itemIgathDataSems :: DataSemEnv
              _itemIgathDefs :: DefsEnv
              _itemIgathDeps :: Deps
              _itemIgathItemVisits :: (Map DepItem DepItem)
              _itemIgathLegalCycStmts :: (Set DepItem)
              _itemIgathMissingInvokes :: (Set (Ident,Ident))
              _itemIgathNonterms :: NontermEnv
              _itemIgathSemStarts :: (Seq DepItem)
              _itemIgathStmtPosMap :: (Map DepItem Pos)
              _itemIgathVisLocalDefs :: DefsEnv
              _itemIgathVisitEnds :: (Seq DepItem)
              _itemIgathVisitStarts :: (Seq DepItem)
              _itemIhpp :: PP_Doc
              _itemIhppType :: PP_Doc
              _itemIjspp :: PP_Doc
              _itemIlexCounter :: Int
              _itemIminReqInvokes :: (Map Ident (Set Ident))
              _itemIpp :: PP_Doc
              -- "src/Transform.ag"(line 245, column 22)
              _itemOnonterm =
                  ({-# LINE 245 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 6781 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 411, column 3)
              _itf =
                  ({-# LINE 411 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 6786 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 412, column 3)
              _coItf =
                  ({-# LINE 412 "src/Transform.ag" #-}
                   ident "<root>"
                   {-# LINE 6791 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2421, column 18)
              _lhsOpp =
                  ({-# LINE 2421 "src/Transform.ag" #-}
                   name_ >#< "=" >-< indent 2 _itemIpp
                   {-# LINE 6796 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2486, column 23)
              _itemOindent =
                  ({-# LINE 2486 "src/Transform.ag" #-}
                   1
                   {-# LINE 6801 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 84, column 14)
              _lhsOhpp =
                  ({-# LINE 84 "src/TargetHaskell.ag" #-}
                   "mk" >|< show name_ >#< "::" >#< _itemIhppType
                   >-< "mk" >|< show name_ >#< "="
                   >-< indent 2 _itemIhpp
                   {-# LINE 6808 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 44, column 14)
              _lhsOjspp =
                  ({-# LINE 44 "src/TargetJs.ag" #-}
                   "var mk" >|< show name_ >#< "=" >-< indent 2 _itemIjspp
                   {-# LINE 6813 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemIallReqInvokes
                   {-# LINE 6818 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs0
                   {-# LINE 6823 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs1
                   {-# LINE 6828 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs2
                   {-# LINE 6833 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs3
                   {-# LINE 6838 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs4
                   {-# LINE 6843 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemIerrs5
                   {-# LINE 6848 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 6853 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6858 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6863 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _itemIgathAvoidVisits
                   {-# LINE 6868 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6873 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 6878 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _itemIgathDeps
                   {-# LINE 6883 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6888 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _itemIgathItemVisits
                   {-# LINE 6893 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _itemIgathLegalCycStmts
                   {-# LINE 6898 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _itemIgathSemStarts
                   {-# LINE 6903 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _itemIgathStmtPosMap
                   {-# LINE 6908 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6913 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemIgathVisitEnds
                   {-# LINE 6918 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6923 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6928 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemIgathVisitStarts
                   {-# LINE 6933 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 6938 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemIminReqInvokes
                   {-# LINE 6943 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _itemIcodeIdCounter
                   {-# LINE 6948 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _itemIdistChildDefs
                   {-# LINE 6953 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _itemIdistDataCons
                   {-# LINE 6958 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _itemIdistDataSems
                   {-# LINE 6963 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _itemIdistDatas
                   {-# LINE 6968 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemIdistDefs
                   {-# LINE 6973 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _itemIdistItfs
                   {-# LINE 6978 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemIdistVisLocalDefs
                   {-# LINE 6983 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _itemIdistVisits
                   {-# LINE 6988 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _itemIgathChildDefs
                   {-# LINE 6993 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemIgathClauses
                   {-# LINE 6998 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 7003 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _itemIgathDataSems
                   {-# LINE 7008 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 7013 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemIgathDefs
                   {-# LINE 7018 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 7023 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 7028 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemIgathNonterms
                   {-# LINE 7033 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 7038 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemIgathVisLocalDefs
                   {-# LINE 7043 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 7048 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _itemIlexCounter
                   {-# LINE 7053 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 7058 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 7063 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 7068 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 7073 "src/Transform.hs" #-})
              -- copy rule (from local)
              _itemOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _coItf
                   {-# LINE 7078 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 7083 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 7088 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 7093 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 7098 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 7103 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 7108 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 7113 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 7118 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 7123 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 7128 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 7133 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 7138 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 7143 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 7148 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 7153 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 7158 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 7163 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 7168 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 7173 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 7178 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 7183 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 7188 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 7193 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 7198 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 7203 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 7208 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 7213 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 7218 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 7223 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 7228 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 7233 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 7238 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 7243 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 7248 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 7253 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 7258 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 7263 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 7268 "src/Transform.hs" #-})
              -- copy rule (from local)
              _itemOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _itf
                   {-# LINE 7273 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 7278 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 7283 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 7288 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 7293 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 7298 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 7303 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 7308 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 7313 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 7318 "src/Transform.hs" #-})
              ( _itemIallReqInvokes,_itemIcodeIdCounter,_itemIdistChildDefs,_itemIdistDataCons,_itemIdistDataSems,_itemIdistDatas,_itemIdistDefs,_itemIdistItfs,_itemIdistVisLocalDefs,_itemIdistVisits,_itemIerrs0,_itemIerrs1,_itemIerrs2,_itemIerrs3,_itemIerrs4,_itemIerrs5,_itemIgathAvoidVisits,_itemIgathChildDefs,_itemIgathClauses,_itemIgathDataSems,_itemIgathDefs,_itemIgathDeps,_itemIgathItemVisits,_itemIgathLegalCycStmts,_itemIgathMissingInvokes,_itemIgathNonterms,_itemIgathSemStarts,_itemIgathStmtPosMap,_itemIgathVisLocalDefs,_itemIgathVisitEnds,_itemIgathVisitStarts,_itemIhpp,_itemIhppType,_itemIjspp,_itemIlexCounter,_itemIminReqInvokes,_itemIpp) =
                  item_ _itemOallAvailInvokes _itemOallVisits _itemOavailInvokes _itemObasename _itemOcoItf _itemOcodeIdCounter _itemOdirectVisitAttrs _itemOdirectVisitLocalAttrs _itemOdistAliasses _itemOdistAllChildMinRanges _itemOdistAttrSource _itemOdistAttrVisMap _itemOdistChildDefs _itemOdistChildEffRanges _itemOdistChildMinRanges _itemOdistChildOcc _itemOdistChildSource _itemOdistCycVisMap _itemOdistDataCons _itemOdistDataMap _itemOdistDataSems _itemOdistDatas _itemOdistDeflStmts _itemOdistDefs _itemOdistInhAttrs _itemOdistItfs _itemOdistRanks _itemOdistRenames _itemOdistSynAttrs _itemOdistVisLocalDefs _itemOdistVisitInhAttrs _itemOdistVisitOrder _itemOdistVisitSource _itemOdistVisitSynAttrs _itemOdistVisits _itemOdoneVisits _itemOgathChildDefs _itemOgathClauses _itemOgathDataSems _itemOgathDefs _itemOgathNonterms _itemOgathVisLocalDefs _itemOhSpilledStmts _itemOindent _itemOitf _itemOjsSpilledStmts _itemOlexCounter _itemOnonterm _itemOopts _itemOscopeDep _itemOscopeReason _itemOstmtSource _itemOvisitBeginDep _itemOvisitEndDep _itemOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Block_Itf :: T_Itf  ->
                 T_Block 
sem_Block_Itf itf_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _itfOgathInhs :: AttrEnv
              _itfOgathItfs :: ItfEnv
              _itfOgathSyns :: AttrEnv
              _itfOgathVisits :: VisitEnv
              _itfOopts :: Opts
              _itfIerrs0 :: Errs
              _itfIerrs1 :: Errs
              _itfIerrs2 :: Errs
              _itfIerrs3 :: Errs
              _itfIerrs4 :: Errs
              _itfIerrs5 :: Errs
              _itfIextraBlocks :: Blocks
              _itfIgathAttrVisMap :: AttrVisMap
              _itfIgathCycVisMap :: CycVisMap
              _itfIgathInhAttrs :: AttrMap
              _itfIgathInhs :: AttrEnv
              _itfIgathItfs :: ItfEnv
              _itfIgathSynAttrs :: AttrMap
              _itfIgathSyns :: AttrEnv
              _itfIgathVisitInhAttrs :: VisitAttrMap
              _itfIgathVisitOrder :: (Map Ident [Ident])
              _itfIgathVisitSynAttrs :: VisitAttrMap
              _itfIgathVisits :: VisitEnv
              _itfIhpp :: PP_Doc
              _itfIjspp :: PP_Doc
              _itfIpp :: PP_Doc
              -- "src/Transform.ag"(line 2418, column 18)
              _lhsOpp =
                  ({-# LINE 2418 "src/Transform.ag" #-}
                   _itfIpp
                   {-# LINE 7463 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 81, column 14)
              _lhsOhpp =
                  ({-# LINE 81 "src/TargetHaskell.ag" #-}
                   _itfIhpp
                   {-# LINE 7468 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 41, column 14)
              _lhsOjspp =
                  ({-# LINE 41 "src/TargetJs.ag" #-}
                   _itfIjspp
                   {-# LINE 7473 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7478 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs0
                   {-# LINE 7483 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs1
                   {-# LINE 7488 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs2
                   {-# LINE 7493 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs3
                   {-# LINE 7498 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs4
                   {-# LINE 7503 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itfIerrs5
                   {-# LINE 7508 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _itfIextraBlocks
                   {-# LINE 7513 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7518 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   _itfIgathAttrVisMap
                   {-# LINE 7523 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 7528 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   _itfIgathCycVisMap
                   {-# LINE 7533 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7538 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 7543 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _itfIgathInhAttrs
                   {-# LINE 7548 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7553 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 7558 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 7563 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7568 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _itfIgathSynAttrs
                   {-# LINE 7573 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 7578 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _itfIgathVisitInhAttrs
                   {-# LINE 7583 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   _itfIgathVisitOrder
                   {-# LINE 7588 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 7593 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _itfIgathVisitSynAttrs
                   {-# LINE 7598 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 7603 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 7608 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 7613 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 7618 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 7623 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 7628 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 7633 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 7638 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 7643 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 7648 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 7653 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 7658 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 7663 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 7668 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 7673 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 7678 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _itfIgathInhs
                   {-# LINE 7683 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _itfIgathItfs
                   {-# LINE 7688 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 7693 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _itfIgathSyns
                   {-# LINE 7698 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 7703 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _itfIgathVisits
                   {-# LINE 7708 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 7713 "src/Transform.hs" #-})
              -- copy rule (down)
              _itfOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 7718 "src/Transform.hs" #-})
              -- copy rule (down)
              _itfOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 7723 "src/Transform.hs" #-})
              -- copy rule (down)
              _itfOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 7728 "src/Transform.hs" #-})
              -- copy rule (down)
              _itfOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 7733 "src/Transform.hs" #-})
              -- copy rule (down)
              _itfOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 7738 "src/Transform.hs" #-})
              ( _itfIerrs0,_itfIerrs1,_itfIerrs2,_itfIerrs3,_itfIerrs4,_itfIerrs5,_itfIextraBlocks,_itfIgathAttrVisMap,_itfIgathCycVisMap,_itfIgathInhAttrs,_itfIgathInhs,_itfIgathItfs,_itfIgathSynAttrs,_itfIgathSyns,_itfIgathVisitInhAttrs,_itfIgathVisitOrder,_itfIgathVisitSynAttrs,_itfIgathVisits,_itfIhpp,_itfIjspp,_itfIpp) =
                  itf_ _itfOgathInhs _itfOgathItfs _itfOgathSyns _itfOgathVisits _itfOopts 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Block_Section :: T_Code  ->
                     T_Block 
sem_Block_Section code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _codeOnonterm :: QIdent
              _lhsOpp :: PP_Doc
              _codeOindent :: Int
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOlexCounter :: Int
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpp :: PP_Doc
              -- "src/Transform.ag"(line 244, column 22)
              _codeOnonterm =
                  ({-# LINE 244 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 7948 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 411, column 3)
              _itf =
                  ({-# LINE 411 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 7953 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 412, column 3)
              _coItf =
                  ({-# LINE 412 "src/Transform.ag" #-}
                   ident "<root>"
                   {-# LINE 7958 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2417, column 18)
              _lhsOpp =
                  ({-# LINE 2417 "src/Transform.ag" #-}
                   "{" >-< _codeIpp >-< "}"
                   {-# LINE 7963 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2485, column 23)
              _codeOindent =
                  ({-# LINE 2485 "src/Transform.ag" #-}
                   1
                   {-# LINE 7968 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 80, column 14)
              _lhsOhpp =
                  ({-# LINE 80 "src/TargetHaskell.ag" #-}
                   _codeIhpp
                   {-# LINE 7973 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 40, column 14)
              _lhsOjspp =
                  ({-# LINE 40 "src/TargetJs.ag" #-}
                   _codeIjspp
                   {-# LINE 7978 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIallReqInvokes
                   {-# LINE 7983 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs0
                   {-# LINE 7988 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs1
                   {-# LINE 7993 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs2
                   {-# LINE 7998 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs3
                   {-# LINE 8003 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs4
                   {-# LINE 8008 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs5
                   {-# LINE 8013 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 8018 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8023 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8028 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _codeIgathAvoidVisits
                   {-# LINE 8033 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8038 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8043 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _codeIgathDeps
                   {-# LINE 8048 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8053 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _codeIgathItemVisits
                   {-# LINE 8058 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _codeIgathLegalCycStmts
                   {-# LINE 8063 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _codeIgathSemStarts
                   {-# LINE 8068 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _codeIgathStmtPosMap
                   {-# LINE 8073 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8078 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitEnds
                   {-# LINE 8083 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8088 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8093 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitStarts
                   {-# LINE 8098 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8103 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIminReqInvokes
                   {-# LINE 8108 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 8113 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 8118 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 8123 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 8128 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 8133 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 8138 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 8143 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 8148 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 8153 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 8158 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 8163 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 8168 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 8173 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 8178 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 8183 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 8188 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 8193 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 8198 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 8203 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 8208 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 8213 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 8218 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 8223 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 8228 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 8233 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 8238 "src/Transform.hs" #-})
              -- copy rule (from local)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _coItf
                   {-# LINE 8243 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 8248 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 8253 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 8258 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 8263 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 8268 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 8273 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 8278 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 8283 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 8288 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 8293 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 8298 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 8303 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 8308 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 8313 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 8318 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 8323 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 8328 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 8333 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 8338 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 8343 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 8348 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 8353 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 8358 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 8363 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 8368 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 8373 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 8378 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 8383 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 8388 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 8393 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 8398 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 8403 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 8408 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 8413 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 8418 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 8423 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 8428 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 8433 "src/Transform.hs" #-})
              -- copy rule (from local)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _itf
                   {-# LINE 8438 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 8443 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 8448 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 8453 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 8458 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 8463 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 8468 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 8473 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 8478 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 8483 "src/Transform.hs" #-})
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOindent _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Block_Type :: T_Type  ->
                  T_Block 
sem_Block_Type type_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _typeOdistAliasses :: (Map Ident AliasType)
              _typeOdistDatas :: DataEnv
              _typeOgathDataCons :: ConEnv
              _typeOgathDatas :: DataEnv
              _typeOopts :: Opts
              _typeIdistDatas :: DataEnv
              _typeIerrs0 :: Errs
              _typeIerrs1 :: Errs
              _typeIerrs2 :: Errs
              _typeIerrs3 :: Errs
              _typeIerrs4 :: Errs
              _typeIerrs5 :: Errs
              _typeIgathAliasses :: (Map Ident AliasType)
              _typeIgathDataCons :: ConEnv
              _typeIgathDataMap :: DataMap
              _typeIgathDatas :: DataEnv
              _typeIhpp :: PP_Doc
              _typeIjspp :: PP_Doc
              _typeIpp :: PP_Doc
              -- "src/Transform.ag"(line 2420, column 18)
              _lhsOpp =
                  ({-# LINE 2420 "src/Transform.ag" #-}
                   _typeIpp
                   {-# LINE 8621 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 83, column 14)
              _lhsOhpp =
                  ({-# LINE 83 "src/TargetHaskell.ag" #-}
                   if noDataGen _lhsIopts then empty else _typeIhpp
                   {-# LINE 8626 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 43, column 14)
              _lhsOjspp =
                  ({-# LINE 43 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 8631 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8636 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs0
                   {-# LINE 8641 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs1
                   {-# LINE 8646 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs2
                   {-# LINE 8651 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs3
                   {-# LINE 8656 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs4
                   {-# LINE 8661 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _typeIerrs5
                   {-# LINE 8666 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 8671 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   _typeIgathAliasses
                   {-# LINE 8676 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8681 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 8686 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8691 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   _typeIgathDataMap
                   {-# LINE 8696 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 8701 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8706 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8711 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 8716 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 8721 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8726 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8731 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 8736 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8741 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8746 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 8751 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 8756 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 8761 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 8766 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 8771 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 8776 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 8781 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _typeIdistDatas
                   {-# LINE 8786 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 8791 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 8796 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 8801 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 8806 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 8811 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 8816 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _typeIgathDataCons
                   {-# LINE 8821 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 8826 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _typeIgathDatas
                   {-# LINE 8831 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 8836 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 8841 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 8846 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 8851 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 8856 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 8861 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 8866 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 8871 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 8876 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 8881 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 8886 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 8891 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 8896 "src/Transform.hs" #-})
              ( _typeIdistDatas,_typeIerrs0,_typeIerrs1,_typeIerrs2,_typeIerrs3,_typeIerrs4,_typeIerrs5,_typeIgathAliasses,_typeIgathDataCons,_typeIgathDataMap,_typeIgathDatas,_typeIhpp,_typeIjspp,_typeIpp) =
                  type_ _typeOdistAliasses _typeOdistDatas _typeOgathDataCons _typeOgathDatas _typeOopts 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
-- Blocks ------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         jsSpilledStmts       : [(Int,PP_Doc)]
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataCons         : ConEnv
         gathDataSems         : DataSemEnv
         gathDatas            : DataEnv
         gathDefs             : DefsEnv
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathNonterms         : NontermEnv
         gathSyns             : AttrEnv
         gathVisLocalDefs     : DefsEnv
         gathVisits           : VisitEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathAliasses         : Map Ident AliasType
         gathAttrVisMap       : AttrVisMap
         gathAvoidVisits      : Set DepItem
         gathCycVisMap        : CycVisMap
         gathDataMap          : DataMap
         gathDeps             : Deps
         gathInhAttrs         : AttrMap
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathSynAttrs         : AttrMap
         gathVisitEnds        : Seq DepItem
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitStarts      : Seq DepItem
         gathVisitSynAttrs    : VisitAttrMap
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         minReqInvokes        : Map Ident (Set Ident)
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Block 
         child tl             : Blocks 
      alternative Nil:
-}
-- cata
sem_Blocks :: Blocks  ->
              T_Blocks 
sem_Blocks list  =
    (Prelude.foldr sem_Blocks_Cons sem_Blocks_Nil (Prelude.map sem_Block list) )
-- semantic domain
type T_Blocks  = (Map Ident (Set Ident)) ->
                 (Set Ident) ->
                 (Map Ident (Set Ident)) ->
                 QIdent ->
                 Int ->
                 (Map Ident (Map Ident String)) ->
                 (Map Ident String) ->
                 (Map Ident AliasType) ->
                 (Map Ident [Ident]) ->
                 AttrSourceMap ->
                 AttrVisMap ->
                 (Env QIdent (QIdent,QIdent)) ->
                 (Map Ident (Set Ident)) ->
                 (Map Ident [Ident]) ->
                 (Map Ident Int) ->
                 ChildSourceMap ->
                 CycVisMap ->
                 ConEnv ->
                 DataMap ->
                 DataSemEnv ->
                 DataEnv ->
                 (Map Ident (Bool,Maybe Int)) ->
                 DefsEnv ->
                 AttrMap ->
                 ItfEnv ->
                 (Map DepItem (Bool,Int)) ->
                 RenameMap ->
                 AttrMap ->
                 DefsEnv ->
                 VisitAttrMap ->
                 (Map Ident [Ident]) ->
                 VisitSourceMap ->
                 VisitAttrMap ->
                 VisitEnv ->
                 ([Ident]) ->
                 (Env QIdent (QIdent, QIdent)) ->
                 ClausesEnv ->
                 ConEnv ->
                 DataSemEnv ->
                 DataEnv ->
                 DefsEnv ->
                 AttrEnv ->
                 ItfEnv ->
                 NontermEnv ->
                 AttrEnv ->
                 DefsEnv ->
                 VisitEnv ->
                 ([(Int,PP_Doc)]) ->
                 ([(Int,PP_Doc)]) ->
                 Int ->
                 Opts ->
                 DepItem ->
                 Reason ->
                 DepItem ->
                 DepItem ->
                 DepItem ->
                 Reason ->
                 ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,Blocks,(Map Ident AliasType),AttrVisMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,CycVisMap,ConEnv,DataMap,DataSemEnv,DataEnv,DefsEnv,Deps,AttrMap,AttrEnv,(Map DepItem DepItem),ItfEnv,(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),AttrMap,AttrEnv,DefsEnv,(Seq DepItem),VisitAttrMap,(Map Ident [Ident]),(Seq DepItem),VisitAttrMap,VisitEnv,([PP_Doc]),([PP_Doc]),Int,(Map Ident (Set Ident)),([PP_Doc]))
sem_Blocks_Cons :: T_Block  ->
                   T_Blocks  ->
                   T_Blocks 
sem_Blocks_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataCons :: ConEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDatas :: DataEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathInhs :: AttrEnv
              _hdOgathItfs :: ItfEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathSyns :: AttrEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOgathVisits :: VisitEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataCons :: ConEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDatas :: DataEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathInhs :: AttrEnv
              _tlOgathItfs :: ItfEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathSyns :: AttrEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOgathVisits :: VisitEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIextraBlocks :: Blocks
              _hdIgathAliasses :: (Map Ident AliasType)
              _hdIgathAttrVisMap :: AttrVisMap
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathClauses :: ClausesEnv
              _hdIgathCycVisMap :: CycVisMap
              _hdIgathDataCons :: ConEnv
              _hdIgathDataMap :: DataMap
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDatas :: DataEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathInhAttrs :: AttrMap
              _hdIgathInhs :: AttrEnv
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathItfs :: ItfEnv
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathSynAttrs :: AttrMap
              _hdIgathSyns :: AttrEnv
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitInhAttrs :: VisitAttrMap
              _hdIgathVisitOrder :: (Map Ident [Ident])
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIgathVisitSynAttrs :: VisitAttrMap
              _hdIgathVisits :: VisitEnv
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIextraBlocks :: Blocks
              _tlIgathAliasses :: (Map Ident AliasType)
              _tlIgathAttrVisMap :: AttrVisMap
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathClauses :: ClausesEnv
              _tlIgathCycVisMap :: CycVisMap
              _tlIgathDataCons :: ConEnv
              _tlIgathDataMap :: DataMap
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDatas :: DataEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathInhAttrs :: AttrMap
              _tlIgathInhs :: AttrEnv
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathItfs :: ItfEnv
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathSynAttrs :: AttrMap
              _tlIgathSyns :: AttrEnv
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitInhAttrs :: VisitAttrMap
              _tlIgathVisitOrder :: (Map Ident [Ident])
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIgathVisitSynAttrs :: VisitAttrMap
              _tlIgathVisits :: VisitEnv
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2625, column 11)
              _lhsOpps =
                  ({-# LINE 2625 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 9394 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 558, column 11)
              _lhsOhpps =
                  ({-# LINE 558 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 9399 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 353, column 11)
              _lhsOjspps =
                  ({-# LINE 353 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 9404 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 9409 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 9414 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 9419 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 9424 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 9429 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 9434 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 9439 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _hdIextraBlocks ++ _tlIextraBlocks
                   {-# LINE 9444 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   _hdIgathAliasses `Map.union` _tlIgathAliasses
                   {-# LINE 9449 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   _hdIgathAttrVisMap `Map.union` _tlIgathAttrVisMap
                   {-# LINE 9454 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 9459 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   _hdIgathCycVisMap `Map.union` _tlIgathCycVisMap
                   {-# LINE 9464 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   _hdIgathDataMap `Map.union` _tlIgathDataMap
                   {-# LINE 9469 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 9474 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _hdIgathInhAttrs `mappend` _tlIgathInhAttrs
                   {-# LINE 9479 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 9484 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 9489 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 9494 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 9499 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _hdIgathSynAttrs `mappend` _tlIgathSynAttrs
                   {-# LINE 9504 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 9509 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _hdIgathVisitInhAttrs `mappend` _tlIgathVisitInhAttrs
                   {-# LINE 9514 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   _hdIgathVisitOrder `mappend` _tlIgathVisitOrder
                   {-# LINE 9519 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 9524 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _hdIgathVisitSynAttrs `mappend` _tlIgathVisitSynAttrs
                   {-# LINE 9529 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 9534 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 9539 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 9544 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 9549 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 9554 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 9559 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 9564 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 9569 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 9574 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 9579 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 9584 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 9589 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _tlIgathDataCons
                   {-# LINE 9594 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 9599 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _tlIgathDatas
                   {-# LINE 9604 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 9609 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathInhs
                   {-# LINE 9614 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _tlIgathItfs
                   {-# LINE 9619 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 9624 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathSyns
                   {-# LINE 9629 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 9634 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _tlIgathVisits
                   {-# LINE 9639 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 9644 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 9649 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 9654 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 9659 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 9664 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 9669 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 9674 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 9679 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 9684 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 9689 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 9694 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 9699 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 9704 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 9709 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 9714 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 9719 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 9724 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 9729 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 9734 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 9739 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 9744 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 9749 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 9754 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 9759 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 9764 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 9769 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 9774 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 9779 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 9784 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 9789 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 9794 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 9799 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 9804 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 9809 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 9814 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 9819 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 9824 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 9829 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 9834 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 9839 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 9844 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 9849 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 9854 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 9859 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 9864 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 9869 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 9874 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 9879 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 9884 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 9889 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 9894 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 9899 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 9904 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 9909 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 9914 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 9919 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 9924 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 9929 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 9934 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 9939 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 9944 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 9949 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 9954 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 9959 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 9964 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 9969 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 9974 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 9979 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 9984 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 9989 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 9994 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 9999 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 10004 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 10009 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 10014 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 10019 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 10024 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 10029 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 10034 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 10039 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 10044 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 10049 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 10054 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 10059 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 10064 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 10069 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 10074 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 10079 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 10084 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 10089 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 10094 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 10099 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 10104 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 10109 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 10114 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _hdIgathDataCons
                   {-# LINE 10119 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 10124 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _hdIgathDatas
                   {-# LINE 10129 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 10134 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathInhs
                   {-# LINE 10139 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _hdIgathItfs
                   {-# LINE 10144 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 10149 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathSyns
                   {-# LINE 10154 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 10159 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _hdIgathVisits
                   {-# LINE 10164 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 10169 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 10174 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 10179 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 10184 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 10189 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 10194 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 10199 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 10204 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 10209 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 10214 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIextraBlocks,_hdIgathAliasses,_hdIgathAttrVisMap,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathClauses,_hdIgathCycVisMap,_hdIgathDataCons,_hdIgathDataMap,_hdIgathDataSems,_hdIgathDatas,_hdIgathDefs,_hdIgathDeps,_hdIgathInhAttrs,_hdIgathInhs,_hdIgathItemVisits,_hdIgathItfs,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathSynAttrs,_hdIgathSyns,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitInhAttrs,_hdIgathVisitOrder,_hdIgathVisitStarts,_hdIgathVisitSynAttrs,_hdIgathVisits,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIminReqInvokes,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataCons _hdOgathDataSems _hdOgathDatas _hdOgathDefs _hdOgathInhs _hdOgathItfs _hdOgathNonterms _hdOgathSyns _hdOgathVisLocalDefs _hdOgathVisits _hdOhSpilledStmts _hdOjsSpilledStmts _hdOlexCounter _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIextraBlocks,_tlIgathAliasses,_tlIgathAttrVisMap,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathClauses,_tlIgathCycVisMap,_tlIgathDataCons,_tlIgathDataMap,_tlIgathDataSems,_tlIgathDatas,_tlIgathDefs,_tlIgathDeps,_tlIgathInhAttrs,_tlIgathInhs,_tlIgathItemVisits,_tlIgathItfs,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathSynAttrs,_tlIgathSyns,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitInhAttrs,_tlIgathVisitOrder,_tlIgathVisitStarts,_tlIgathVisitSynAttrs,_tlIgathVisits,_tlIhpps,_tlIjspps,_tlIlexCounter,_tlIminReqInvokes,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataCons _tlOgathDataSems _tlOgathDatas _tlOgathDefs _tlOgathInhs _tlOgathItfs _tlOgathNonterms _tlOgathSyns _tlOgathVisLocalDefs _tlOgathVisits _tlOhSpilledStmts _tlOjsSpilledStmts _tlOlexCounter _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
sem_Blocks_Nil :: T_Blocks 
sem_Blocks_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2626, column 11)
              _lhsOpps =
                  ({-# LINE 2626 "src/Transform.ag" #-}
                   []
                   {-# LINE 10334 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 559, column 11)
              _lhsOhpps =
                  ({-# LINE 559 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 10339 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 354, column 11)
              _lhsOjspps =
                  ({-# LINE 354 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 10344 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10349 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10354 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10359 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10364 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10369 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10374 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10379 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 10384 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10389 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10394 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 10399 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10404 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10409 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10414 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10419 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10424 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 10429 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10434 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10439 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10444 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10449 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10454 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10459 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10464 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10469 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10474 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 10479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 10484 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 10489 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 10494 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 10499 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 10504 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 10509 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 10514 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 10519 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 10524 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 10529 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 10534 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 10539 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 10544 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 10549 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 10554 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 10559 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 10564 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 10569 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 10574 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 10579 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 10584 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
-- BlocksTop ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         jsSpilledStmts       : [(Int,PP_Doc)]
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataCons         : ConEnv
         gathDataSems         : DataSemEnv
         gathDatas            : DataEnv
         gathDefs             : DefsEnv
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathNonterms         : NontermEnv
         gathSyns             : AttrEnv
         gathVisLocalDefs     : DefsEnv
         gathVisits           : VisitEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAliasses         : Map Ident AliasType
         gathAttrVisMap       : AttrVisMap
         gathAvoidVisits      : Set DepItem
         gathCycVisMap        : CycVisMap
         gathDataMap          : DataMap
         gathDeps             : Deps
         gathInhAttrs         : AttrMap
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathSynAttrs         : AttrMap
         gathVisitEnds        : Seq DepItem
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitStarts      : Seq DepItem
         gathVisitSynAttrs    : VisitAttrMap
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         minReqInvokes        : Map Ident (Set Ident)
         pps                  : [PP_Doc]
   alternatives:
      alternative None:
      alternative Top:
         child blocks         : Blocks 
         visit 0:
            inst  extra       : BlocksTop 
-}
-- cata
sem_BlocksTop :: BlocksTop  ->
                 T_BlocksTop 
sem_BlocksTop (BlocksTop_None )  =
    (sem_BlocksTop_None )
sem_BlocksTop (BlocksTop_Top _blocks )  =
    (sem_BlocksTop_Top (sem_Blocks _blocks ) )
-- semantic domain
type T_BlocksTop  = (Map Ident (Set Ident)) ->
                    (Set Ident) ->
                    (Map Ident (Set Ident)) ->
                    QIdent ->
                    Int ->
                    (Map Ident (Map Ident String)) ->
                    (Map Ident String) ->
                    (Map Ident AliasType) ->
                    (Map Ident [Ident]) ->
                    AttrSourceMap ->
                    AttrVisMap ->
                    (Env QIdent (QIdent,QIdent)) ->
                    (Map Ident (Set Ident)) ->
                    (Map Ident [Ident]) ->
                    (Map Ident Int) ->
                    ChildSourceMap ->
                    CycVisMap ->
                    ConEnv ->
                    DataMap ->
                    DataSemEnv ->
                    DataEnv ->
                    (Map Ident (Bool,Maybe Int)) ->
                    DefsEnv ->
                    AttrMap ->
                    ItfEnv ->
                    (Map DepItem (Bool,Int)) ->
                    RenameMap ->
                    AttrMap ->
                    DefsEnv ->
                    VisitAttrMap ->
                    (Map Ident [Ident]) ->
                    VisitSourceMap ->
                    VisitAttrMap ->
                    VisitEnv ->
                    ([Ident]) ->
                    (Env QIdent (QIdent, QIdent)) ->
                    ClausesEnv ->
                    ConEnv ->
                    DataSemEnv ->
                    DataEnv ->
                    DefsEnv ->
                    AttrEnv ->
                    ItfEnv ->
                    NontermEnv ->
                    AttrEnv ->
                    DefsEnv ->
                    VisitEnv ->
                    ([(Int,PP_Doc)]) ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    Opts ->
                    DepItem ->
                    Reason ->
                    DepItem ->
                    DepItem ->
                    DepItem ->
                    Reason ->
                    ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident AliasType),AttrVisMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,CycVisMap,ConEnv,DataMap,DataSemEnv,DataEnv,DefsEnv,Deps,AttrMap,AttrEnv,(Map DepItem DepItem),ItfEnv,(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),AttrMap,AttrEnv,DefsEnv,(Seq DepItem),VisitAttrMap,(Map Ident [Ident]),(Seq DepItem),VisitAttrMap,VisitEnv,([PP_Doc]),([PP_Doc]),Int,(Map Ident (Set Ident)),([PP_Doc]))
sem_BlocksTop_None :: T_BlocksTop 
sem_BlocksTop_None  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2622, column 11)
              _lhsOpps =
                  ({-# LINE 2622 "src/Transform.ag" #-}
                   []
                   {-# LINE 10863 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 555, column 11)
              _lhsOhpps =
                  ({-# LINE 555 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 10868 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 350, column 11)
              _lhsOjspps =
                  ({-# LINE 350 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 10873 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10878 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10883 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10888 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10893 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10898 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10903 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10908 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10913 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10918 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 10923 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10928 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10933 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10938 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10943 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10948 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 10953 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10958 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10963 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10968 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10973 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10978 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10983 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 10988 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 10993 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 10998 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 11003 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 11008 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 11013 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 11018 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 11023 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 11028 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 11033 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 11038 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 11043 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 11048 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 11053 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 11058 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 11063 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 11068 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 11073 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 11078 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 11083 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 11088 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 11093 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 11098 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 11103 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 11108 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
sem_BlocksTop_Top :: T_Blocks  ->
                     T_BlocksTop 
sem_BlocksTop_Top blocks_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataCons
       _lhsIgathDataSems
       _lhsIgathDatas
       _lhsIgathDefs
       _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathNonterms
       _lhsIgathSyns
       _lhsIgathVisLocalDefs
       _lhsIgathVisits
       _lhsIhSpilledStmts
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let extra_val_ :: BlocksTop 
              _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAliasses :: (Map Ident AliasType)
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOgathDataMap :: DataMap
              _lhsOgathDeps :: Deps
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDatas :: DataEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOlexCounter :: Int
              _blocksOallAvailInvokes :: (Map Ident (Set Ident))
              _blocksOallVisits :: (Set Ident)
              _blocksOavailInvokes :: (Map Ident (Set Ident))
              _blocksObasename :: QIdent
              _blocksOcodeIdCounter :: Int
              _blocksOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _blocksOdirectVisitLocalAttrs :: (Map Ident String)
              _blocksOdistAliasses :: (Map Ident AliasType)
              _blocksOdistAllChildMinRanges :: (Map Ident [Ident])
              _blocksOdistAttrSource :: AttrSourceMap
              _blocksOdistAttrVisMap :: AttrVisMap
              _blocksOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _blocksOdistChildEffRanges :: (Map Ident (Set Ident))
              _blocksOdistChildMinRanges :: (Map Ident [Ident])
              _blocksOdistChildOcc :: (Map Ident Int)
              _blocksOdistChildSource :: ChildSourceMap
              _blocksOdistCycVisMap :: CycVisMap
              _blocksOdistDataCons :: ConEnv
              _blocksOdistDataMap :: DataMap
              _blocksOdistDataSems :: DataSemEnv
              _blocksOdistDatas :: DataEnv
              _blocksOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _blocksOdistDefs :: DefsEnv
              _blocksOdistInhAttrs :: AttrMap
              _blocksOdistItfs :: ItfEnv
              _blocksOdistRanks :: (Map DepItem (Bool,Int))
              _blocksOdistRenames :: RenameMap
              _blocksOdistSynAttrs :: AttrMap
              _blocksOdistVisLocalDefs :: DefsEnv
              _blocksOdistVisitInhAttrs :: VisitAttrMap
              _blocksOdistVisitOrder :: (Map Ident [Ident])
              _blocksOdistVisitSource :: VisitSourceMap
              _blocksOdistVisitSynAttrs :: VisitAttrMap
              _blocksOdistVisits :: VisitEnv
              _blocksOdoneVisits :: ([Ident])
              _blocksOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _blocksOgathClauses :: ClausesEnv
              _blocksOgathDataCons :: ConEnv
              _blocksOgathDataSems :: DataSemEnv
              _blocksOgathDatas :: DataEnv
              _blocksOgathDefs :: DefsEnv
              _blocksOgathInhs :: AttrEnv
              _blocksOgathItfs :: ItfEnv
              _blocksOgathNonterms :: NontermEnv
              _blocksOgathSyns :: AttrEnv
              _blocksOgathVisLocalDefs :: DefsEnv
              _blocksOgathVisits :: VisitEnv
              _blocksOhSpilledStmts :: ([(Int,PP_Doc)])
              _blocksOjsSpilledStmts :: ([(Int,PP_Doc)])
              _blocksOlexCounter :: Int
              _blocksOopts :: Opts
              _blocksOscopeDep :: DepItem
              _blocksOscopeReason :: Reason
              _blocksOstmtSource :: DepItem
              _blocksOvisitBeginDep :: DepItem
              _blocksOvisitEndDep :: DepItem
              _blocksOvisitEndReason :: Reason
              _extraOallAvailInvokes :: (Map Ident (Set Ident))
              _extraOallVisits :: (Set Ident)
              _extraOavailInvokes :: (Map Ident (Set Ident))
              _extraObasename :: QIdent
              _extraOcodeIdCounter :: Int
              _extraOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _extraOdirectVisitLocalAttrs :: (Map Ident String)
              _extraOdistAliasses :: (Map Ident AliasType)
              _extraOdistAllChildMinRanges :: (Map Ident [Ident])
              _extraOdistAttrSource :: AttrSourceMap
              _extraOdistAttrVisMap :: AttrVisMap
              _extraOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _extraOdistChildEffRanges :: (Map Ident (Set Ident))
              _extraOdistChildMinRanges :: (Map Ident [Ident])
              _extraOdistChildOcc :: (Map Ident Int)
              _extraOdistChildSource :: ChildSourceMap
              _extraOdistCycVisMap :: CycVisMap
              _extraOdistDataCons :: ConEnv
              _extraOdistDataMap :: DataMap
              _extraOdistDataSems :: DataSemEnv
              _extraOdistDatas :: DataEnv
              _extraOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _extraOdistDefs :: DefsEnv
              _extraOdistInhAttrs :: AttrMap
              _extraOdistItfs :: ItfEnv
              _extraOdistRanks :: (Map DepItem (Bool,Int))
              _extraOdistRenames :: RenameMap
              _extraOdistSynAttrs :: AttrMap
              _extraOdistVisLocalDefs :: DefsEnv
              _extraOdistVisitInhAttrs :: VisitAttrMap
              _extraOdistVisitOrder :: (Map Ident [Ident])
              _extraOdistVisitSource :: VisitSourceMap
              _extraOdistVisitSynAttrs :: VisitAttrMap
              _extraOdistVisits :: VisitEnv
              _extraOdoneVisits :: ([Ident])
              _extraOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _extraOgathClauses :: ClausesEnv
              _extraOgathDataCons :: ConEnv
              _extraOgathDataSems :: DataSemEnv
              _extraOgathDatas :: DataEnv
              _extraOgathDefs :: DefsEnv
              _extraOgathInhs :: AttrEnv
              _extraOgathItfs :: ItfEnv
              _extraOgathNonterms :: NontermEnv
              _extraOgathSyns :: AttrEnv
              _extraOgathVisLocalDefs :: DefsEnv
              _extraOgathVisits :: VisitEnv
              _extraOhSpilledStmts :: ([(Int,PP_Doc)])
              _extraOjsSpilledStmts :: ([(Int,PP_Doc)])
              _extraOlexCounter :: Int
              _extraOopts :: Opts
              _extraOscopeDep :: DepItem
              _extraOscopeReason :: Reason
              _extraOstmtSource :: DepItem
              _extraOvisitBeginDep :: DepItem
              _extraOvisitEndDep :: DepItem
              _extraOvisitEndReason :: Reason
              _blocksIallReqInvokes :: (Map Ident (Set Ident))
              _blocksIcodeIdCounter :: Int
              _blocksIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _blocksIdistDataCons :: ConEnv
              _blocksIdistDataSems :: DataSemEnv
              _blocksIdistDatas :: DataEnv
              _blocksIdistDefs :: DefsEnv
              _blocksIdistItfs :: ItfEnv
              _blocksIdistVisLocalDefs :: DefsEnv
              _blocksIdistVisits :: VisitEnv
              _blocksIerrs0 :: Errs
              _blocksIerrs1 :: Errs
              _blocksIerrs2 :: Errs
              _blocksIerrs3 :: Errs
              _blocksIerrs4 :: Errs
              _blocksIerrs5 :: Errs
              _blocksIextraBlocks :: Blocks
              _blocksIgathAliasses :: (Map Ident AliasType)
              _blocksIgathAttrVisMap :: AttrVisMap
              _blocksIgathAvoidVisits :: (Set DepItem)
              _blocksIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _blocksIgathClauses :: ClausesEnv
              _blocksIgathCycVisMap :: CycVisMap
              _blocksIgathDataCons :: ConEnv
              _blocksIgathDataMap :: DataMap
              _blocksIgathDataSems :: DataSemEnv
              _blocksIgathDatas :: DataEnv
              _blocksIgathDefs :: DefsEnv
              _blocksIgathDeps :: Deps
              _blocksIgathInhAttrs :: AttrMap
              _blocksIgathInhs :: AttrEnv
              _blocksIgathItemVisits :: (Map DepItem DepItem)
              _blocksIgathItfs :: ItfEnv
              _blocksIgathLegalCycStmts :: (Set DepItem)
              _blocksIgathNonterms :: NontermEnv
              _blocksIgathSemStarts :: (Seq DepItem)
              _blocksIgathStmtPosMap :: (Map DepItem Pos)
              _blocksIgathSynAttrs :: AttrMap
              _blocksIgathSyns :: AttrEnv
              _blocksIgathVisLocalDefs :: DefsEnv
              _blocksIgathVisitEnds :: (Seq DepItem)
              _blocksIgathVisitInhAttrs :: VisitAttrMap
              _blocksIgathVisitOrder :: (Map Ident [Ident])
              _blocksIgathVisitStarts :: (Seq DepItem)
              _blocksIgathVisitSynAttrs :: VisitAttrMap
              _blocksIgathVisits :: VisitEnv
              _blocksIhpps :: ([PP_Doc])
              _blocksIjspps :: ([PP_Doc])
              _blocksIlexCounter :: Int
              _blocksIminReqInvokes :: (Map Ident (Set Ident))
              _blocksIpps :: ([PP_Doc])
              _extraIallReqInvokes :: (Map Ident (Set Ident))
              _extraIcodeIdCounter :: Int
              _extraIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _extraIdistDataCons :: ConEnv
              _extraIdistDataSems :: DataSemEnv
              _extraIdistDatas :: DataEnv
              _extraIdistDefs :: DefsEnv
              _extraIdistItfs :: ItfEnv
              _extraIdistVisLocalDefs :: DefsEnv
              _extraIdistVisits :: VisitEnv
              _extraIerrs0 :: Errs
              _extraIerrs1 :: Errs
              _extraIerrs2 :: Errs
              _extraIerrs3 :: Errs
              _extraIerrs4 :: Errs
              _extraIerrs5 :: Errs
              _extraIgathAliasses :: (Map Ident AliasType)
              _extraIgathAttrVisMap :: AttrVisMap
              _extraIgathAvoidVisits :: (Set DepItem)
              _extraIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _extraIgathClauses :: ClausesEnv
              _extraIgathCycVisMap :: CycVisMap
              _extraIgathDataCons :: ConEnv
              _extraIgathDataMap :: DataMap
              _extraIgathDataSems :: DataSemEnv
              _extraIgathDatas :: DataEnv
              _extraIgathDefs :: DefsEnv
              _extraIgathDeps :: Deps
              _extraIgathInhAttrs :: AttrMap
              _extraIgathInhs :: AttrEnv
              _extraIgathItemVisits :: (Map DepItem DepItem)
              _extraIgathItfs :: ItfEnv
              _extraIgathLegalCycStmts :: (Set DepItem)
              _extraIgathNonterms :: NontermEnv
              _extraIgathSemStarts :: (Seq DepItem)
              _extraIgathStmtPosMap :: (Map DepItem Pos)
              _extraIgathSynAttrs :: AttrMap
              _extraIgathSyns :: AttrEnv
              _extraIgathVisLocalDefs :: DefsEnv
              _extraIgathVisitEnds :: (Seq DepItem)
              _extraIgathVisitInhAttrs :: VisitAttrMap
              _extraIgathVisitOrder :: (Map Ident [Ident])
              _extraIgathVisitStarts :: (Seq DepItem)
              _extraIgathVisitSynAttrs :: VisitAttrMap
              _extraIgathVisits :: VisitEnv
              _extraIhpps :: ([PP_Doc])
              _extraIjspps :: ([PP_Doc])
              _extraIlexCounter :: Int
              _extraIminReqInvokes :: (Map Ident (Set Ident))
              _extraIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 1487, column 3)
              extra_val_ =
                  ({-# LINE 1487 "src/Transform.ag" #-}
                   if null _blocksIextraBlocks
                   then BlocksTop_None
                   else BlocksTop_Top _blocksIextraBlocks
                   {-# LINE 11442 "src/Transform.hs" #-})
              extra_inst_ =
                  (sem_BlocksTop extra_val_ )
              -- "src/Transform.ag"(line 2621, column 11)
              _lhsOpps =
                  ({-# LINE 2621 "src/Transform.ag" #-}
                   _blocksIpps ++ _extraIpps
                   {-# LINE 11449 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 554, column 11)
              _lhsOhpps =
                  ({-# LINE 554 "src/TargetHaskell.ag" #-}
                   _blocksIhpps ++ (if noDataGen _lhsIopts then [] else _extraIhpps)
                   {-# LINE 11454 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 349, column 11)
              _lhsOjspps =
                  ({-# LINE 349 "src/TargetJs.ag" #-}
                   _blocksIjspps
                   {-# LINE 11459 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _blocksIallReqInvokes `unionWithUnion` _extraIallReqInvokes
                   {-# LINE 11464 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs0 Seq.>< _extraIerrs0
                   {-# LINE 11469 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs1 Seq.>< _extraIerrs1
                   {-# LINE 11474 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs2 Seq.>< _extraIerrs2
                   {-# LINE 11479 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs3 Seq.>< _extraIerrs3
                   {-# LINE 11484 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs4 Seq.>< _extraIerrs4
                   {-# LINE 11489 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs5 Seq.>< _extraIerrs5
                   {-# LINE 11494 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1432, column 53)
              _lhsOgathAliasses =
                  ({-# LINE 1432 "src/Transform.ag" #-}
                   _blocksIgathAliasses `Map.union` _extraIgathAliasses
                   {-# LINE 11499 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1369, column 54)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1369 "src/Transform.ag" #-}
                   _blocksIgathAttrVisMap `Map.union` _extraIgathAttrVisMap
                   {-# LINE 11504 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _blocksIgathAvoidVisits `Set.union` _extraIgathAvoidVisits
                   {-# LINE 11509 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1885, column 53)
              _lhsOgathCycVisMap =
                  ({-# LINE 1885 "src/Transform.ag" #-}
                   _blocksIgathCycVisMap `Map.union` _extraIgathCycVisMap
                   {-# LINE 11514 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   _blocksIgathDataMap `Map.union` _extraIgathDataMap
                   {-# LINE 11519 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _blocksIgathDeps Seq.>< _extraIgathDeps
                   {-# LINE 11524 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _blocksIgathInhAttrs `mappend` _extraIgathInhAttrs
                   {-# LINE 11529 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _blocksIgathItemVisits `Map.union` _extraIgathItemVisits
                   {-# LINE 11534 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _blocksIgathLegalCycStmts `Set.union` _extraIgathLegalCycStmts
                   {-# LINE 11539 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _blocksIgathSemStarts Seq.>< _extraIgathSemStarts
                   {-# LINE 11544 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _blocksIgathStmtPosMap `Map.union` _extraIgathStmtPosMap
                   {-# LINE 11549 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _blocksIgathSynAttrs `mappend` _extraIgathSynAttrs
                   {-# LINE 11554 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _blocksIgathVisitEnds Seq.>< _extraIgathVisitEnds
                   {-# LINE 11559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _blocksIgathVisitInhAttrs `mappend` _extraIgathVisitInhAttrs
                   {-# LINE 11564 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   _blocksIgathVisitOrder `mappend` _extraIgathVisitOrder
                   {-# LINE 11569 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _blocksIgathVisitStarts Seq.>< _extraIgathVisitStarts
                   {-# LINE 11574 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _blocksIgathVisitSynAttrs `mappend` _extraIgathVisitSynAttrs
                   {-# LINE 11579 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _blocksIminReqInvokes `unionWithUnion` _extraIminReqInvokes
                   {-# LINE 11584 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _extraIcodeIdCounter
                   {-# LINE 11589 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _extraIdistChildDefs
                   {-# LINE 11594 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _extraIdistDataCons
                   {-# LINE 11599 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _extraIdistDataSems
                   {-# LINE 11604 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _extraIdistDatas
                   {-# LINE 11609 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _extraIdistDefs
                   {-# LINE 11614 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _extraIdistItfs
                   {-# LINE 11619 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _extraIdistVisLocalDefs
                   {-# LINE 11624 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _extraIdistVisits
                   {-# LINE 11629 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _extraIgathChildDefs
                   {-# LINE 11634 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _extraIgathClauses
                   {-# LINE 11639 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _extraIgathDataCons
                   {-# LINE 11644 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _extraIgathDataSems
                   {-# LINE 11649 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _extraIgathDatas
                   {-# LINE 11654 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _extraIgathDefs
                   {-# LINE 11659 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _extraIgathInhs
                   {-# LINE 11664 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _extraIgathItfs
                   {-# LINE 11669 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _extraIgathNonterms
                   {-# LINE 11674 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _extraIgathSyns
                   {-# LINE 11679 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _extraIgathVisLocalDefs
                   {-# LINE 11684 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _extraIgathVisits
                   {-# LINE 11689 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _extraIlexCounter
                   {-# LINE 11694 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 11699 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 11704 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 11709 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 11714 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 11719 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 11724 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 11729 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 11734 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 11739 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 11744 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 11749 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 11754 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 11759 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 11764 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 11769 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 11774 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 11779 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 11784 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 11789 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 11794 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 11799 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 11804 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 11809 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 11814 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 11819 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 11824 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 11829 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 11834 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 11839 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 11844 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 11849 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 11854 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 11859 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 11864 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 11869 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 11874 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 11879 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 11884 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 11889 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 11894 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 11899 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 11904 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 11909 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 11914 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 11919 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 11924 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 11929 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 11934 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 11939 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 11944 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 11949 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 11954 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 11959 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 11964 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 11969 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 11974 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 11979 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 11984 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 11989 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 11994 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 11999 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _blocksIcodeIdCounter
                   {-# LINE 12004 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 12009 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 12014 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 12019 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 12024 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 12029 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 12034 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _blocksIdistChildDefs
                   {-# LINE 12039 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 12044 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 12049 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 12054 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 12059 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 12064 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _blocksIdistDataCons
                   {-# LINE 12069 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 12074 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _blocksIdistDataSems
                   {-# LINE 12079 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _blocksIdistDatas
                   {-# LINE 12084 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 12089 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _blocksIdistDefs
                   {-# LINE 12094 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 12099 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _blocksIdistItfs
                   {-# LINE 12104 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 12109 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 12114 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 12119 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _blocksIdistVisLocalDefs
                   {-# LINE 12124 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 12129 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 12134 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 12139 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 12144 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _blocksIdistVisits
                   {-# LINE 12149 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 12154 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _blocksIgathChildDefs
                   {-# LINE 12159 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _blocksIgathClauses
                   {-# LINE 12164 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _blocksIgathDataCons
                   {-# LINE 12169 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _blocksIgathDataSems
                   {-# LINE 12174 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _blocksIgathDatas
                   {-# LINE 12179 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _blocksIgathDefs
                   {-# LINE 12184 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _blocksIgathInhs
                   {-# LINE 12189 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _blocksIgathItfs
                   {-# LINE 12194 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _blocksIgathNonterms
                   {-# LINE 12199 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _blocksIgathSyns
                   {-# LINE 12204 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _blocksIgathVisLocalDefs
                   {-# LINE 12209 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _blocksIgathVisits
                   {-# LINE 12214 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 12219 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 12224 "src/Transform.hs" #-})
              -- copy rule (chain)
              _extraOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _blocksIlexCounter
                   {-# LINE 12229 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 12234 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 12239 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 12244 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 12249 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 12254 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 12259 "src/Transform.hs" #-})
              -- copy rule (down)
              _extraOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 12264 "src/Transform.hs" #-})
              ( _blocksIallReqInvokes,_blocksIcodeIdCounter,_blocksIdistChildDefs,_blocksIdistDataCons,_blocksIdistDataSems,_blocksIdistDatas,_blocksIdistDefs,_blocksIdistItfs,_blocksIdistVisLocalDefs,_blocksIdistVisits,_blocksIerrs0,_blocksIerrs1,_blocksIerrs2,_blocksIerrs3,_blocksIerrs4,_blocksIerrs5,_blocksIextraBlocks,_blocksIgathAliasses,_blocksIgathAttrVisMap,_blocksIgathAvoidVisits,_blocksIgathChildDefs,_blocksIgathClauses,_blocksIgathCycVisMap,_blocksIgathDataCons,_blocksIgathDataMap,_blocksIgathDataSems,_blocksIgathDatas,_blocksIgathDefs,_blocksIgathDeps,_blocksIgathInhAttrs,_blocksIgathInhs,_blocksIgathItemVisits,_blocksIgathItfs,_blocksIgathLegalCycStmts,_blocksIgathNonterms,_blocksIgathSemStarts,_blocksIgathStmtPosMap,_blocksIgathSynAttrs,_blocksIgathSyns,_blocksIgathVisLocalDefs,_blocksIgathVisitEnds,_blocksIgathVisitInhAttrs,_blocksIgathVisitOrder,_blocksIgathVisitStarts,_blocksIgathVisitSynAttrs,_blocksIgathVisits,_blocksIhpps,_blocksIjspps,_blocksIlexCounter,_blocksIminReqInvokes,_blocksIpps) =
                  blocks_ _blocksOallAvailInvokes _blocksOallVisits _blocksOavailInvokes _blocksObasename _blocksOcodeIdCounter _blocksOdirectVisitAttrs _blocksOdirectVisitLocalAttrs _blocksOdistAliasses _blocksOdistAllChildMinRanges _blocksOdistAttrSource _blocksOdistAttrVisMap _blocksOdistChildDefs _blocksOdistChildEffRanges _blocksOdistChildMinRanges _blocksOdistChildOcc _blocksOdistChildSource _blocksOdistCycVisMap _blocksOdistDataCons _blocksOdistDataMap _blocksOdistDataSems _blocksOdistDatas _blocksOdistDeflStmts _blocksOdistDefs _blocksOdistInhAttrs _blocksOdistItfs _blocksOdistRanks _blocksOdistRenames _blocksOdistSynAttrs _blocksOdistVisLocalDefs _blocksOdistVisitInhAttrs _blocksOdistVisitOrder _blocksOdistVisitSource _blocksOdistVisitSynAttrs _blocksOdistVisits _blocksOdoneVisits _blocksOgathChildDefs _blocksOgathClauses _blocksOgathDataCons _blocksOgathDataSems _blocksOgathDatas _blocksOgathDefs _blocksOgathInhs _blocksOgathItfs _blocksOgathNonterms _blocksOgathSyns _blocksOgathVisLocalDefs _blocksOgathVisits _blocksOhSpilledStmts _blocksOjsSpilledStmts _blocksOlexCounter _blocksOopts _blocksOscopeDep _blocksOscopeReason _blocksOstmtSource _blocksOvisitBeginDep _blocksOvisitEndDep _blocksOvisitEndReason 
              ( _extraIallReqInvokes,_extraIcodeIdCounter,_extraIdistChildDefs,_extraIdistDataCons,_extraIdistDataSems,_extraIdistDatas,_extraIdistDefs,_extraIdistItfs,_extraIdistVisLocalDefs,_extraIdistVisits,_extraIerrs0,_extraIerrs1,_extraIerrs2,_extraIerrs3,_extraIerrs4,_extraIerrs5,_extraIgathAliasses,_extraIgathAttrVisMap,_extraIgathAvoidVisits,_extraIgathChildDefs,_extraIgathClauses,_extraIgathCycVisMap,_extraIgathDataCons,_extraIgathDataMap,_extraIgathDataSems,_extraIgathDatas,_extraIgathDefs,_extraIgathDeps,_extraIgathInhAttrs,_extraIgathInhs,_extraIgathItemVisits,_extraIgathItfs,_extraIgathLegalCycStmts,_extraIgathNonterms,_extraIgathSemStarts,_extraIgathStmtPosMap,_extraIgathSynAttrs,_extraIgathSyns,_extraIgathVisLocalDefs,_extraIgathVisitEnds,_extraIgathVisitInhAttrs,_extraIgathVisitOrder,_extraIgathVisitStarts,_extraIgathVisitSynAttrs,_extraIgathVisits,_extraIhpps,_extraIjspps,_extraIlexCounter,_extraIminReqInvokes,_extraIpps) =
                  extra_inst_ _extraOallAvailInvokes _extraOallVisits _extraOavailInvokes _extraObasename _extraOcodeIdCounter _extraOdirectVisitAttrs _extraOdirectVisitLocalAttrs _extraOdistAliasses _extraOdistAllChildMinRanges _extraOdistAttrSource _extraOdistAttrVisMap _extraOdistChildDefs _extraOdistChildEffRanges _extraOdistChildMinRanges _extraOdistChildOcc _extraOdistChildSource _extraOdistCycVisMap _extraOdistDataCons _extraOdistDataMap _extraOdistDataSems _extraOdistDatas _extraOdistDeflStmts _extraOdistDefs _extraOdistInhAttrs _extraOdistItfs _extraOdistRanks _extraOdistRenames _extraOdistSynAttrs _extraOdistVisLocalDefs _extraOdistVisitInhAttrs _extraOdistVisitOrder _extraOdistVisitSource _extraOdistVisitSynAttrs _extraOdistVisits _extraOdoneVisits _extraOgathChildDefs _extraOgathClauses _extraOgathDataCons _extraOgathDataSems _extraOgathDatas _extraOgathDefs _extraOgathInhs _extraOgathItfs _extraOgathNonterms _extraOgathSyns _extraOgathVisLocalDefs _extraOgathVisits _extraOhSpilledStmts _extraOjsSpilledStmts _extraOlexCounter _extraOopts _extraOscopeDep _extraOscopeReason _extraOstmtSource _extraOvisitBeginDep _extraOvisitEndDep _extraOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAliasses,_lhsOgathAttrVisMap,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathCycVisMap,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDataSems,_lhsOgathDatas,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItemVisits,_lhsOgathItfs,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitStarts,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
-- BoundCode ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         isFun                : Bool
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pos                  : Pos
         pp                   : PP_Doc
   alternatives:
      alternative Code:
         child bind           : Bind 
         child pos            : {Pos}
         child code           : Code 
-}
-- cata
sem_BoundCode :: BoundCode  ->
                 T_BoundCode 
sem_BoundCode (BoundCode_Code _bind _pos _code )  =
    (sem_BoundCode_Code (sem_Bind _bind ) _pos (sem_Code _code ) )
-- semantic domain
type T_BoundCode  = (Map Ident (Set Ident)) ->
                    (Set Ident) ->
                    (Map Ident (Set Ident)) ->
                    QIdent ->
                    Ident ->
                    Int ->
                    (Map Ident (Map Ident String)) ->
                    (Map Ident String) ->
                    (Map Ident AliasType) ->
                    (Map Ident [Ident]) ->
                    AttrSourceMap ->
                    AttrVisMap ->
                    (Env QIdent (QIdent,QIdent)) ->
                    (Map Ident (Set Ident)) ->
                    (Map Ident [Ident]) ->
                    (Map Ident Int) ->
                    ChildSourceMap ->
                    CycVisMap ->
                    ConEnv ->
                    DataMap ->
                    DataSemEnv ->
                    DataEnv ->
                    (Map Ident (Bool,Maybe Int)) ->
                    DefsEnv ->
                    AttrMap ->
                    ItfEnv ->
                    (Map DepItem (Bool,Int)) ->
                    RenameMap ->
                    AttrMap ->
                    DefsEnv ->
                    VisitAttrMap ->
                    (Map Ident [Ident]) ->
                    VisitSourceMap ->
                    VisitAttrMap ->
                    VisitEnv ->
                    ([Ident]) ->
                    (Env QIdent (QIdent, QIdent)) ->
                    ClausesEnv ->
                    DataSemEnv ->
                    DefsEnv ->
                    NontermEnv ->
                    DefsEnv ->
                    ([(Int,PP_Doc)]) ->
                    QIdent ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    QIdent ->
                    Opts ->
                    DepItem ->
                    Reason ->
                    DepItem ->
                    DepItem ->
                    DepItem ->
                    Reason ->
                    ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),PP_Doc,Bool,PP_Doc,Int,(Map Ident (Set Ident)),Pos,PP_Doc)
sem_BoundCode_Code :: T_Bind  ->
                      Pos ->
                      T_Code  ->
                      T_BoundCode 
sem_BoundCode_Code bind_ pos_ code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _codeOindent :: Int
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOisFun :: Bool
              _lhsOlexCounter :: Int
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOlexCounter :: Int
              _codeOnonterm :: QIdent
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _bindIisFun :: Bool
              _bindIpp :: PP_Doc
              _bindIwidth :: Int
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpp :: PP_Doc
              -- "src/Transform.ag"(line 2044, column 23)
              _lhsOpos =
                  ({-# LINE 2044 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 12614 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2461, column 18)
              _lhsOpp =
                  ({-# LINE 2461 "src/Transform.ag" #-}
                   _bindIpp >#< _codeIpp
                   {-# LINE 12619 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2488, column 23)
              _codeOindent =
                  ({-# LINE 2488 "src/Transform.ag" #-}
                   column pos_ + _bindIwidth
                   {-# LINE 12624 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 205, column 18)
              _lhsOhpp =
                  ({-# LINE 205 "src/TargetHaskell.ag" #-}
                   _codeIhpp
                   {-# LINE 12629 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 135, column 18)
              _lhsOjspp =
                  ({-# LINE 135 "src/TargetJs.ag" #-}
                   _codeIjspp
                   {-# LINE 12634 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIallReqInvokes
                   {-# LINE 12639 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs0
                   {-# LINE 12644 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs1
                   {-# LINE 12649 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs2
                   {-# LINE 12654 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs3
                   {-# LINE 12659 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs4
                   {-# LINE 12664 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs5
                   {-# LINE 12669 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _codeIgathAvoidVisits
                   {-# LINE 12674 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _codeIgathDeps
                   {-# LINE 12679 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _codeIgathItemVisits
                   {-# LINE 12684 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _codeIgathLegalCycStmts
                   {-# LINE 12689 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _codeIgathMissingInvokes
                   {-# LINE 12694 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _codeIgathSemStarts
                   {-# LINE 12699 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _codeIgathStmtPosMap
                   {-# LINE 12704 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitEnds
                   {-# LINE 12709 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitStarts
                   {-# LINE 12714 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIminReqInvokes
                   {-# LINE 12719 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 12724 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 12729 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 12734 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 12739 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 12744 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 12749 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 12754 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 12759 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 12764 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 12769 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 12774 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 12779 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 12784 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 12789 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 12794 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOisFun =
                  ({-# LINE 1977 "src/Transform.ag" #-}
                   _bindIisFun
                   {-# LINE 12799 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 12804 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 12809 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 12814 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 12819 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 12824 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 12829 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 12834 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 12839 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 12844 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 12849 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 12854 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 12859 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 12864 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 12869 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 12874 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 12879 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 12884 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 12889 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 12894 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 12899 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 12904 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 12909 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 12914 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 12919 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 12924 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 12929 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 12934 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 12939 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 12944 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 12949 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 12954 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 12959 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 12964 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 12969 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 12974 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 12979 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 12984 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 12989 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 12994 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 12999 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 13004 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 13009 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 13014 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 13019 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 13024 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 13029 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 13034 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 13039 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 13044 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 13049 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 13054 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 13059 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 13064 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 13069 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 13074 "src/Transform.hs" #-})
              ( _bindIisFun,_bindIpp,_bindIwidth) =
                  bind_ 
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOindent _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisFun,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
-- Clause ------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         clauseExtras         : Map Ident Stmts
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distNextVisits       : Map Ident (Maybe Ident)
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclic           : Bool
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         localAttrs           : Map Ident String
         masterPos            : Pos
         myNextVisits         : Map Ident (Maybe Ident)
         nextVisits           : [Ident]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         semBasename          : QIdent
         stmtSource           : DepItem
         visit                : Ident
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
         visitNr              : Int
         withinCoSem          : Bool
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         gathVisitNames       : Env Ident ()
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         explInvokes          : Map Ident (Set Ident)
         gathAllowCycVisits   : Set Ident
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathClauseNames      : Set Ident
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemAttrSource    : AttrSourceMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisRankMap       : IntMap Ident
         gathVisitAttrs       : Map Ident (Map Ident String)
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minRank              : Int
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Clause:
         child pos            : {Pos}
         child name           : {Ident}
         child stmts          : Stmts 
         child next           : SemVisit 
         visit 0:
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local gathClauses_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathDeps_augmented_f3 : _
            local gathDeps_augmented_f4 : _
            local gathItemVisits_augmented_f1 : _
            local distRenames : _
            inst  stmts       : T_Stmts 
            local extraStmts  : _
            local masterPos   : _
            local isDeepest   : _
            local enterF      : _
            local leaveF      : _
            local enterWithF  : _
            local _tup1       : _
            local nextVisitLocDefs : _
            local _tup2       : _
            local nextVisitLocDefs' : _
            local missingLocalAttrMap : _
            local deflLocalAttrMap : _
            local deflLocalAttrs : _
            local synAttrMap  : _
            local missingAttrMap : _
            local _tup3       : _
            local deflAttrMap : _
            local undefAttrMap : _
            local deflAttrs   : _
            inst  impls       : ImplStmts 
            inst  deflts      : ImplStmts 
            local distChildOcc : _
            local itfNm       : _
            local basename    : _
            local distChildMinRanges : _
            local distAllChildMinRanges : _
            local distChildEffRanges : _
            local introChildren : _
            local minReqInvokes1 : _
            local allReqInvokes1 : _
            local minReqInvokes : _
            local allReqInvokes : _
            local implicitInvokes : _
            local additionalInvokes : _
            local availInvokes : _
            local allAvailInvokes : _
            local missingInvokes : _
            local distDeflStmts : _
            local distAttrSource : _
            local distChildSource : _
            local distVisitSource : _
            local scopeReason : _
            local scopeDep    : _
            local _tup4       : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local hChildren   : _
            local hChns       : _
            local hNext       : _
            local hVisLocs    : _
            local hRestart    : _
            local hResVal     : _
            local _tup5       : _
            local hoStmts     : _
            local hGroupedStmts : _
            local _tup6       : _
            local jsoStmts    : _
            local jsGroupedStmts : _
            local _tup7       : {(Int,Int)}
            local lexOrder    : {Int}
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathClauses_augmented_syn : _
-}
-- cata
sem_Clause :: Clause  ->
              T_Clause 
sem_Clause (Clause_Clause _pos _name _stmts _next )  =
    (sem_Clause_Clause _pos _name (sem_Stmts _stmts ) (sem_SemVisit _next ) )
-- semantic domain
type T_Clause  = (Map Ident (Set Ident)) ->
                 (Set Ident) ->
                 (Set Ident) ->
                 (Map Ident (Set Ident)) ->
                 QIdent ->
                 (Map Ident Stmts) ->
                 Ident ->
                 Int ->
                 (Map Ident (Map Ident String)) ->
                 (Map Ident String) ->
                 (Map Ident AliasType) ->
                 (Map Ident [Ident]) ->
                 AttrSourceMap ->
                 AttrVisMap ->
                 (Env QIdent (QIdent,QIdent)) ->
                 (Map Ident (Set Ident)) ->
                 (Map Ident [Ident]) ->
                 (Map Ident Int) ->
                 ChildSourceMap ->
                 CycVisMap ->
                 ConEnv ->
                 DataMap ->
                 DataSemEnv ->
                 DataEnv ->
                 (Map Ident (Bool,Maybe Int)) ->
                 DefsEnv ->
                 AttrMap ->
                 ItfEnv ->
                 (Map Ident (Maybe Ident)) ->
                 (Map DepItem (Bool,Int)) ->
                 RenameMap ->
                 AttrMap ->
                 DefsEnv ->
                 (IntMap Ident) ->
                 VisitAttrMap ->
                 (Map Ident [Ident]) ->
                 VisitSourceMap ->
                 VisitAttrMap ->
                 VisitEnv ->
                 ([Ident]) ->
                 Bool ->
                 (Set Ident) ->
                 (Env QIdent (QIdent, QIdent)) ->
                 ClausesEnv ->
                 DataSemEnv ->
                 DefsEnv ->
                 NontermEnv ->
                 DefsEnv ->
                 (Env Ident ()) ->
                 ([(Int,PP_Doc)]) ->
                 Int ->
                 QIdent ->
                 ([(Int,PP_Doc)]) ->
                 Int ->
                 (Map Ident String) ->
                 Pos ->
                 (Map Ident (Maybe Ident)) ->
                 ([Ident]) ->
                 QIdent ->
                 Opts ->
                 DepItem ->
                 Reason ->
                 QIdent ->
                 DepItem ->
                 Ident ->
                 DepItem ->
                 DepItem ->
                 Reason ->
                 Int ->
                 Bool ->
                 ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident (Set Ident)),(Set Ident),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,(Set Ident),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,AttrSourceMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,(IntMap Ident),(Map Ident (Map Ident String)),(Seq DepItem),(Env Ident ()),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,Int,(Map Ident (Set Ident)),PP_Doc)
sem_Clause_Clause :: Pos ->
                     Ident ->
                     T_Stmts  ->
                     T_SemVisit  ->
                     T_Clause 
sem_Clause_Clause pos_ name_ stmts_ next_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathClauseNames :: (Set Ident)
              _nextOclauseExtras :: (Map Ident Stmts)
              stmts_val_ :: T_Stmts  ->
                            T_Stmts 
              _nextOgathDefs :: DefsEnv
              _implsOgathDefs :: DefsEnv
              _nextOdistDefs :: DefsEnv
              _implsOdistDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOdistDefs :: DefsEnv
              impls_val_ :: ImplStmts 
              deflts_val_ :: ImplStmts 
              _stmtsOgathNextVisits :: (Map Ident (Maybe Ident))
              _nextOdistNextVisits :: (Map Ident (Maybe Ident))
              _nextOdistChildEffRanges :: (Map Ident (Set Ident))
              _lhsOminRank :: Int
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _nextOhSpilledStmts :: ([(Int,PP_Doc)])
              _lhsOjspp :: PP_Doc
              _nextOjsSpilledStmts :: ([(Int,PP_Doc)])
              __tup7 :: ((Int,Int))
              _stmtsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOlexCounter :: Int
              _stmtsOallAvailInvokes :: (Map Ident (Set Ident))
              _stmtsOallVisits :: (Set Ident)
              _stmtsOallowCycVisits :: (Set Ident)
              _stmtsOavailInvokes :: (Map Ident (Set Ident))
              _stmtsObasename :: QIdent
              _stmtsOcoItf :: Ident
              _stmtsOcodeIdCounter :: Int
              _stmtsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _stmtsOdirectVisitLocalAttrs :: (Map Ident String)
              _stmtsOdistAliasses :: (Map Ident AliasType)
              _stmtsOdistAllChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistAttrSource :: AttrSourceMap
              _stmtsOdistAttrVisMap :: AttrVisMap
              _stmtsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsOdistChildEffRanges :: (Map Ident (Set Ident))
              _stmtsOdistChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistChildOcc :: (Map Ident Int)
              _stmtsOdistChildSource :: ChildSourceMap
              _stmtsOdistCycVisMap :: CycVisMap
              _stmtsOdistDataCons :: ConEnv
              _stmtsOdistDataMap :: DataMap
              _stmtsOdistDataSems :: DataSemEnv
              _stmtsOdistDatas :: DataEnv
              _stmtsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsOdistDefs :: DefsEnv
              _stmtsOdistInhAttrs :: AttrMap
              _stmtsOdistItfs :: ItfEnv
              _stmtsOdistRanks :: (Map DepItem (Bool,Int))
              _stmtsOdistRenames :: RenameMap
              _stmtsOdistSynAttrs :: AttrMap
              _stmtsOdistVisLocalDefs :: DefsEnv
              _stmtsOdistVisRankMap :: (IntMap Ident)
              _stmtsOdistVisitInhAttrs :: VisitAttrMap
              _stmtsOdistVisitOrder :: (Map Ident [Ident])
              _stmtsOdistVisitSource :: VisitSourceMap
              _stmtsOdistVisitSynAttrs :: VisitAttrMap
              _stmtsOdistVisits :: VisitEnv
              _stmtsOdoneVisits :: ([Ident])
              _stmtsOfullCyclicVisits :: (Set Ident)
              _stmtsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsOgathClauses :: ClausesEnv
              _stmtsOgathDataSems :: DataSemEnv
              _stmtsOgathDefs :: DefsEnv
              _stmtsOgathNonterms :: NontermEnv
              _stmtsOgathVisLocalDefs :: DefsEnv
              _stmtsOhSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOindent :: Int
              _stmtsOitf :: QIdent
              _stmtsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOnonterm :: QIdent
              _stmtsOopts :: Opts
              _stmtsOscopeDep :: DepItem
              _stmtsOscopeReason :: Reason
              _stmtsOstmtSource :: DepItem
              _stmtsOvisitBeginDep :: DepItem
              _stmtsOvisitEndDep :: DepItem
              _stmtsOvisitEndReason :: Reason
              _nextOallAvailInvokes :: (Map Ident (Set Ident))
              _nextOallVisits :: (Set Ident)
              _nextOallowCycVisits :: (Set Ident)
              _nextOavailInvokes :: (Map Ident (Set Ident))
              _nextObasename :: QIdent
              _nextOcoItf :: Ident
              _nextOcodeIdCounter :: Int
              _nextOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _nextOdirectVisitLocalAttrs :: (Map Ident String)
              _nextOdistAliasses :: (Map Ident AliasType)
              _nextOdistAllChildMinRanges :: (Map Ident [Ident])
              _nextOdistAttrSource :: AttrSourceMap
              _nextOdistAttrVisMap :: AttrVisMap
              _nextOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _nextOdistChildMinRanges :: (Map Ident [Ident])
              _nextOdistChildOcc :: (Map Ident Int)
              _nextOdistChildSource :: ChildSourceMap
              _nextOdistCycVisMap :: CycVisMap
              _nextOdistDataCons :: ConEnv
              _nextOdistDataMap :: DataMap
              _nextOdistDataSems :: DataSemEnv
              _nextOdistDatas :: DataEnv
              _nextOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _nextOdistInhAttrs :: AttrMap
              _nextOdistItfs :: ItfEnv
              _nextOdistRanks :: (Map DepItem (Bool,Int))
              _nextOdistRenames :: RenameMap
              _nextOdistSynAttrs :: AttrMap
              _nextOdistVisLocalDefs :: DefsEnv
              _nextOdistVisRankMap :: (IntMap Ident)
              _nextOdistVisitInhAttrs :: VisitAttrMap
              _nextOdistVisitOrder :: (Map Ident [Ident])
              _nextOdistVisitSource :: VisitSourceMap
              _nextOdistVisitSynAttrs :: VisitAttrMap
              _nextOdistVisits :: VisitEnv
              _nextOdoneVisits :: ([Ident])
              _nextOfullCyclic :: Bool
              _nextOfullCyclicVisits :: (Set Ident)
              _nextOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _nextOgathClauses :: ClausesEnv
              _nextOgathDataSems :: DataSemEnv
              _nextOgathNonterms :: NontermEnv
              _nextOgathVisLocalDefs :: DefsEnv
              _nextOgathVisitNames :: (Env Ident ())
              _nextOindent :: Int
              _nextOitf :: QIdent
              _nextOlexCounter :: Int
              _nextOlocalAttrs :: (Map Ident String)
              _nextOmasterPos :: Pos
              _nextOmyNextVisits :: (Map Ident (Maybe Ident))
              _nextOnextVisits :: ([Ident])
              _nextOnonterm :: QIdent
              _nextOopts :: Opts
              _nextOscopeDep :: DepItem
              _nextOscopeReason :: Reason
              _nextOsemBasename :: QIdent
              _nextOstmtSource :: DepItem
              _nextOvisit :: Ident
              _nextOvisitBeginDep :: DepItem
              _nextOvisitEndDep :: DepItem
              _nextOvisitEndReason :: Reason
              _nextOvisitNr :: Int
              _nextOwithinCoSem :: Bool
              _implsOallAvailInvokes :: (Map Ident (Set Ident))
              _implsOallVisits :: (Set Ident)
              _implsOallowCycVisits :: (Set Ident)
              _implsOavailInvokes :: (Map Ident (Set Ident))
              _implsObasename :: QIdent
              _implsOcoItf :: Ident
              _implsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _implsOdirectVisitLocalAttrs :: (Map Ident String)
              _implsOdistAliasses :: (Map Ident AliasType)
              _implsOdistAllChildMinRanges :: (Map Ident [Ident])
              _implsOdistAttrSource :: AttrSourceMap
              _implsOdistAttrVisMap :: AttrVisMap
              _implsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOdistChildEffRanges :: (Map Ident (Set Ident))
              _implsOdistChildMinRanges :: (Map Ident [Ident])
              _implsOdistChildOcc :: (Map Ident Int)
              _implsOdistChildSource :: ChildSourceMap
              _implsOdistCycVisMap :: CycVisMap
              _implsOdistDataCons :: ConEnv
              _implsOdistDataMap :: DataMap
              _implsOdistDataSems :: DataEnv
              _implsOdistDatas :: DataEnv
              _implsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _implsOdistInhAttrs :: AttrMap
              _implsOdistItfs :: ItfEnv
              _implsOdistRanks :: (Map DepItem (Bool,Int))
              _implsOdistRenames :: RenameMap
              _implsOdistSynAttrs :: AttrMap
              _implsOdistVisLocalDefs :: DefsEnv
              _implsOdistVisRankMap :: (IntMap Ident)
              _implsOdistVisitInhAttrs :: VisitAttrMap
              _implsOdistVisitOrder :: (Map Ident [Ident])
              _implsOdistVisitSource :: VisitSourceMap
              _implsOdistVisitSynAttrs :: VisitAttrMap
              _implsOdistVisits :: VisitEnv
              _implsOdoneVisits :: ([Ident])
              _implsOfullCyclicVisits :: (Set Ident)
              _implsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOgathClauses :: ClausesEnv
              _implsOgathNextVisits :: (Map Ident (Maybe Ident))
              _implsOgathNonterms :: NontermEnv
              _implsOgathVisLocalDefs :: DefsEnv
              _implsOhSpilledStmts :: ([(Int,PP_Doc)])
              _implsOitf :: QIdent
              _implsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _implsOlexCounter :: Int
              _implsOnonterm :: QIdent
              _implsOopts :: Opts
              _implsOscopeDep :: DepItem
              _implsOscopeReason :: Reason
              _implsOstmtSource :: DepItem
              _implsOvisitBeginDep :: DepItem
              _implsOvisitEndDep :: DepItem
              _implsOvisitEndReason :: Reason
              _defltsOallAvailInvokes :: (Map Ident (Set Ident))
              _defltsOallVisits :: (Set Ident)
              _defltsOallowCycVisits :: (Set Ident)
              _defltsOavailInvokes :: (Map Ident (Set Ident))
              _defltsObasename :: QIdent
              _defltsOcoItf :: Ident
              _defltsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _defltsOdirectVisitLocalAttrs :: (Map Ident String)
              _defltsOdistAliasses :: (Map Ident AliasType)
              _defltsOdistAllChildMinRanges :: (Map Ident [Ident])
              _defltsOdistAttrSource :: AttrSourceMap
              _defltsOdistAttrVisMap :: AttrVisMap
              _defltsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOdistChildEffRanges :: (Map Ident (Set Ident))
              _defltsOdistChildMinRanges :: (Map Ident [Ident])
              _defltsOdistChildOcc :: (Map Ident Int)
              _defltsOdistChildSource :: ChildSourceMap
              _defltsOdistCycVisMap :: CycVisMap
              _defltsOdistDataCons :: ConEnv
              _defltsOdistDataMap :: DataMap
              _defltsOdistDataSems :: DataEnv
              _defltsOdistDatas :: DataEnv
              _defltsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _defltsOdistDefs :: DefsEnv
              _defltsOdistInhAttrs :: AttrMap
              _defltsOdistItfs :: ItfEnv
              _defltsOdistRanks :: (Map DepItem (Bool,Int))
              _defltsOdistRenames :: RenameMap
              _defltsOdistSynAttrs :: AttrMap
              _defltsOdistVisLocalDefs :: DefsEnv
              _defltsOdistVisRankMap :: (IntMap Ident)
              _defltsOdistVisitInhAttrs :: VisitAttrMap
              _defltsOdistVisitOrder :: (Map Ident [Ident])
              _defltsOdistVisitSource :: VisitSourceMap
              _defltsOdistVisitSynAttrs :: VisitAttrMap
              _defltsOdistVisits :: VisitEnv
              _defltsOdoneVisits :: ([Ident])
              _defltsOfullCyclicVisits :: (Set Ident)
              _defltsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOgathClauses :: ClausesEnv
              _defltsOgathDefs :: DefsEnv
              _defltsOgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsOgathNonterms :: NontermEnv
              _defltsOgathVisLocalDefs :: DefsEnv
              _defltsOhSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOitf :: QIdent
              _defltsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOlexCounter :: Int
              _defltsOnonterm :: QIdent
              _defltsOopts :: Opts
              _defltsOscopeDep :: DepItem
              _defltsOscopeReason :: Reason
              _defltsOstmtSource :: DepItem
              _defltsOvisitBeginDep :: DepItem
              _defltsOvisitEndDep :: DepItem
              _defltsOvisitEndReason :: Reason
              _stmtsIallReqInvokes :: (Map Ident (Set Ident))
              _stmtsIbannedInvokes :: (Map Ident (Set Ident))
              _stmtsIcodeIdCounter :: Int
              _stmtsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsIdistDataCons :: ConEnv
              _stmtsIdistDataSems :: DataSemEnv
              _stmtsIdistDatas :: DataEnv
              _stmtsIdistDefs :: DefsEnv
              _stmtsIdistItfs :: ItfEnv
              _stmtsIdistVisLocalDefs :: DefsEnv
              _stmtsIdistVisits :: VisitEnv
              _stmtsIerrs0 :: Errs
              _stmtsIerrs1 :: Errs
              _stmtsIerrs2 :: Errs
              _stmtsIerrs3 :: Errs
              _stmtsIerrs4 :: Errs
              _stmtsIerrs5 :: Errs
              _stmtsIexplInvokes :: (Map Ident (Set Ident))
              _stmtsIgathAttrSource :: AttrSourceMap
              _stmtsIgathAvoidVisits :: (Set DepItem)
              _stmtsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsIgathChildEffRanges :: (Map Ident (Set Ident))
              _stmtsIgathChildMinRanges :: (Map Ident [Ident])
              _stmtsIgathChildOcc :: (Map Ident Int)
              _stmtsIgathChildSource :: ChildSourceMap
              _stmtsIgathClauses :: ClausesEnv
              _stmtsIgathDataSems :: DataSemEnv
              _stmtsIgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsIgathDefs :: DefsEnv
              _stmtsIgathDeps :: Deps
              _stmtsIgathItemVisits :: (Map DepItem DepItem)
              _stmtsIgathLegalCycStmts :: (Set DepItem)
              _stmtsIgathMissingInvokes :: (Set (Ident,Ident))
              _stmtsIgathNextVisits :: (Map Ident (Maybe Ident))
              _stmtsIgathNonterms :: NontermEnv
              _stmtsIgathRenames :: RenameMap
              _stmtsIgathSemStarts :: (Seq DepItem)
              _stmtsIgathStmtPosMap :: (Map DepItem Pos)
              _stmtsIgathVisLocalDefs :: DefsEnv
              _stmtsIgathVisitEnds :: (Seq DepItem)
              _stmtsIgathVisitSource :: VisitSourceMap
              _stmtsIgathVisitStarts :: (Seq DepItem)
              _stmtsIhopps :: ([(Int, PP_Doc)])
              _stmtsIjsopps :: ([(Int, PP_Doc)])
              _stmtsIlexCounter :: Int
              _stmtsIminReqInvokes :: (Map Ident (Set Ident))
              _stmtsIpps :: ([PP_Doc])
              _nextIallReqInvokes :: (Map Ident (Set Ident))
              _nextIbannedInvokes :: (Map Ident (Set Ident))
              _nextIcodeIdCounter :: Int
              _nextIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _nextIdistDataCons :: ConEnv
              _nextIdistDataSems :: DataSemEnv
              _nextIdistDatas :: DataEnv
              _nextIdistDefs :: DefsEnv
              _nextIdistItfs :: ItfEnv
              _nextIdistVisLocalDefs :: DefsEnv
              _nextIdistVisits :: VisitEnv
              _nextIerrs0 :: Errs
              _nextIerrs1 :: Errs
              _nextIerrs2 :: Errs
              _nextIerrs3 :: Errs
              _nextIerrs4 :: Errs
              _nextIerrs5 :: Errs
              _nextIgathAllowCycVisits :: (Set Ident)
              _nextIgathAttrSource :: AttrSourceMap
              _nextIgathAvoidVisits :: (Set DepItem)
              _nextIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _nextIgathChildSource :: ChildSourceMap
              _nextIgathClauses :: ClausesEnv
              _nextIgathDataSems :: DataSemEnv
              _nextIgathDefs :: DefsEnv
              _nextIgathDeps :: Deps
              _nextIgathItemVisits :: (Map DepItem DepItem)
              _nextIgathLegalCycStmts :: (Set DepItem)
              _nextIgathMissingInvokes :: (Set (Ident,Ident))
              _nextIgathNonterms :: NontermEnv
              _nextIgathSemAttrSource :: AttrSourceMap
              _nextIgathSemStarts :: (Seq DepItem)
              _nextIgathStmtPosMap :: (Map DepItem Pos)
              _nextIgathVisLocalDefs :: DefsEnv
              _nextIgathVisRankMap :: (IntMap Ident)
              _nextIgathVisitAttrs :: (Map Ident (Map Ident String))
              _nextIgathVisitEnds :: (Seq DepItem)
              _nextIgathVisitNames :: (Env Ident ())
              _nextIgathVisitSource :: VisitSourceMap
              _nextIgathVisitStarts :: (Seq DepItem)
              _nextIhpp :: PP_Doc
              _nextIisInternal :: Bool
              _nextIjspp :: PP_Doc
              _nextIlexCounter :: Int
              _nextImbNextVisit :: (Maybe Ident)
              _nextIminRank :: Int
              _nextIminReqInvokes :: (Map Ident (Set Ident))
              _nextIpp :: PP_Doc
              _implsIdistDefs :: DefsEnv
              _implsIdistVisLocalDefs :: DefsEnv
              _implsIerrs2 :: Errs
              _implsIerrs3 :: Errs
              _implsIerrs4 :: Errs
              _implsIerrs5 :: Errs
              _implsIgathAttrSource :: AttrSourceMap
              _implsIgathChildSource :: ChildSourceMap
              _implsIgathDefs :: DefsEnv
              _implsIgathDeps :: Deps
              _implsIgathItemVisits :: (Map DepItem DepItem)
              _implsIgathLegalCycStmts :: (Set DepItem)
              _implsIgathNextVisits :: (Map Ident (Maybe Ident))
              _implsIgathStmtPosMap :: (Map DepItem Pos)
              _implsIgathVisLocalDefs :: DefsEnv
              _implsIgathVisitSource :: VisitSourceMap
              _implsIhopps :: ([(Int, PP_Doc)])
              _implsIjsopps :: ([(Int, PP_Doc)])
              _implsIlexCounter :: Int
              _implsIpps :: ([PP_Doc])
              _defltsIdistDefs :: DefsEnv
              _defltsIdistVisLocalDefs :: DefsEnv
              _defltsIerrs2 :: Errs
              _defltsIerrs3 :: Errs
              _defltsIerrs4 :: Errs
              _defltsIerrs5 :: Errs
              _defltsIgathAttrSource :: AttrSourceMap
              _defltsIgathChildSource :: ChildSourceMap
              _defltsIgathDefs :: DefsEnv
              _defltsIgathDeps :: Deps
              _defltsIgathItemVisits :: (Map DepItem DepItem)
              _defltsIgathLegalCycStmts :: (Set DepItem)
              _defltsIgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsIgathStmtPosMap :: (Map DepItem Pos)
              _defltsIgathVisLocalDefs :: DefsEnv
              _defltsIgathVisitSource :: VisitSourceMap
              _defltsIhopps :: ([(Int, PP_Doc)])
              _defltsIjsopps :: ([(Int, PP_Doc)])
              _defltsIlexCounter :: Int
              _defltsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1806 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 13859 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1806 "src/Transform.ag" #-}
                   Seq.fromList (map (\(nm,vs) -> Err_MissingVisit pos_ nm vs) _missingInvokes    ) Seq.><
                   {-# LINE 13864 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1089 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2]
                   {-# LINE 13869 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1089 "src/Transform.ag" #-}
                   addUseErrs'' _nextVisitLocDefs'
                   {-# LINE 13874 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1089 "src/Transform.ag" #-}
                   addDefErrs'' _nextVisitLocDefs
                   {-# LINE 13879 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathClauses =
                  ({-# LINE 261 "src/Transform.ag" #-}
                   foldr ($) _gathClauses_augmented_syn [_gathClauses_augmented_f1]
                   {-# LINE 13884 "src/Transform.hs" #-})
              -- augment function
              _gathClauses_augmented_f1 =
                  ({-# LINE 261 "src/Transform.ag" #-}
                   extend (name_ : _lhsInonterm) ()
                   {-# LINE 13889 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2, _gathDeps_augmented_f3, _gathDeps_augmented_f4]
                   {-# LINE 13894 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   addDep _lhsIvisitEndDep _lhsIvisitEndReason [_scopeDep    ]
                   {-# LINE 13899 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   addDep _scopeDep     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 13904 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f3 =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   if _isDeepest
                   then (Seq.fromList [ Dep _lhsIvisitEndDep (ReasonAttrReq visIdent attr)
                                       [Map.findWithDefault (trace "Clause.Clause.unknown.loc" unknDepItem) (False,visIdent,attr) _distAttrSource    ]
                                     | attr <- Map.keys _lhsIlocalAttrs ] Seq.><)
                   else id
                   {-# LINE 13913 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f4 =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   if _isDeepest
                   then (Seq.fromList [ Dep _lhsIvisitEndDep (ReasonAttrReq lhsIdent attr)
                                       [Map.findWithDefault (trace ("Clause.Clause.unknown.syn: " ++ show (attr, _distAttrSource    ) ) unknDepItem) (False,lhsIdent,attr) _distAttrSource    ]
                                    | attr <- Map.keys _synAttrMap     ] Seq.><)
                   else id
                   {-# LINE 13922 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1994 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 13927 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1994 "src/Transform.ag" #-}
                   Map.insert _scopeDep     _lhsIvisitBeginDep
                   {-# LINE 13932 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 264, column 22)
              _lhsOgathClauseNames =
                  ({-# LINE 264 "src/Transform.ag" #-}
                   Set.singleton name_
                   {-# LINE 13937 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 601, column 26)
              _distRenames =
                  ({-# LINE 601 "src/Transform.ag" #-}
                   _stmtsIgathRenames `unionWithUnion` _lhsIdistRenames
                   {-# LINE 13942 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 622, column 23)
              _nextOclauseExtras =
                  ({-# LINE 622 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 13947 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 685, column 3)
              stmts_val_ =
                  ({-# LINE 685 "src/Transform.ag" #-}
                   \stmts -> foldr (\s r -> sem_Stmts_Cons (sem_Stmt s) r) stmts _extraStmts
                   {-# LINE 13952 "src/Transform.hs" #-})
              stmts_inst_ =
                  (stmts_val_ stmts_ )
              -- "src/Transform.ag"(line 687, column 3)
              _extraStmts =
                  ({-# LINE 687 "src/Transform.ag" #-}
                   Map.findWithDefault [] name_ _lhsIclauseExtras
                   {-# LINE 13959 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 767, column 32)
              _masterPos =
                  ({-# LINE 767 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 13964 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 851, column 3)
              _isDeepest =
                  ({-# LINE 851 "src/Transform.ag" #-}
                   not _nextIisInternal
                   {-# LINE 13969 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1079, column 3)
              _enterF =
                  ({-# LINE 1079 "src/Transform.ag" #-}
                   if _isDeepest     then enter else id
                   {-# LINE 13974 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1080, column 3)
              _leaveF =
                  ({-# LINE 1080 "src/Transform.ag" #-}
                   if _isDeepest     then leave else (\x -> (x, emptyEnv))
                   {-# LINE 13979 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1081, column 3)
              _enterWithF =
                  ({-# LINE 1081 "src/Transform.ag" #-}
                   if _isDeepest     then enterWith else (\_ x -> x)
                   {-# LINE 13984 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1083, column 3)
              _nextOgathDefs =
                  ({-# LINE 1083 "src/Transform.ag" #-}
                   _enterF     _stmtsIgathDefs
                   {-# LINE 13989 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1084, column 3)
              __tup1 =
                  ({-# LINE 1084 "src/Transform.ag" #-}
                   _leaveF     _nextIgathDefs
                   {-# LINE 13994 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1084, column 3)
              (_implsOgathDefs,_) =
                  ({-# LINE 1084 "src/Transform.ag" #-}
                   __tup1
                   {-# LINE 13999 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1084, column 3)
              (_,_nextVisitLocDefs) =
                  ({-# LINE 1084 "src/Transform.ag" #-}
                   __tup1
                   {-# LINE 14004 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1085, column 3)
              _nextOdistDefs =
                  ({-# LINE 1085 "src/Transform.ag" #-}
                   _enterWithF     _nextVisitLocDefs     _stmtsIdistDefs
                   {-# LINE 14009 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1086, column 3)
              __tup2 =
                  ({-# LINE 1086 "src/Transform.ag" #-}
                   _leaveF     _nextIdistDefs
                   {-# LINE 14014 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1086, column 3)
              (_implsOdistDefs,_) =
                  ({-# LINE 1086 "src/Transform.ag" #-}
                   __tup2
                   {-# LINE 14019 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1086, column 3)
              (_,_nextVisitLocDefs') =
                  ({-# LINE 1086 "src/Transform.ag" #-}
                   __tup2
                   {-# LINE 14024 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1091, column 3)
              _lhsOgathDefs =
                  ({-# LINE 1091 "src/Transform.ag" #-}
                   _implsIgathDefs
                   {-# LINE 14029 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1092, column 3)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 1092 "src/Transform.ag" #-}
                   _nextIgathVisLocalDefs
                   {-# LINE 14034 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1105, column 3)
              _missingLocalAttrMap =
                  ({-# LINE 1105 "src/Transform.ag" #-}
                   if _isDeepest
                   then Map.filterWithKey (\n _ -> not $
                          defined (replPos pos_ visIdent,replPos pos_ n,False) _nextIdistVisLocalDefs) _lhsIlocalAttrs
                   else Map.empty
                   {-# LINE 14042 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1109, column 3)
              _deflLocalAttrMap =
                  ({-# LINE 1109 "src/Transform.ag" #-}
                   _missingLocalAttrMap
                   {-# LINE 14047 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1110, column 3)
              _deflLocalAttrs =
                  ({-# LINE 1110 "src/Transform.ag" #-}
                   Map.keys _deflLocalAttrMap
                   {-# LINE 14052 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1121, column 3)
              _synAttrMap =
                  ({-# LINE 1121 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty _lhsIvisit (Map.findWithDefault Map.empty (head _lhsIitf) _lhsIdistVisitSynAttrs)
                   {-# LINE 14057 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1122, column 3)
              _missingAttrMap =
                  ({-# LINE 1122 "src/Transform.ag" #-}
                   if _isDeepest
                   then Map.filterWithKey (\n _ -> not $ defined (replPos pos_ lhsIdent,n,False) _lhsIdistDefs) _synAttrMap
                   else Map.empty
                   {-# LINE 14064 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1125, column 3)
              __tup3 =
                  ({-# LINE 1125 "src/Transform.ag" #-}
                   Map.partitionWithKey (\n _ -> Map.member n _distDeflStmts    ) _missingAttrMap
                   {-# LINE 14069 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1125, column 3)
              (_deflAttrMap,_) =
                  ({-# LINE 1125 "src/Transform.ag" #-}
                   __tup3
                   {-# LINE 14074 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1125, column 3)
              (_,_undefAttrMap) =
                  ({-# LINE 1125 "src/Transform.ag" #-}
                   __tup3
                   {-# LINE 14079 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1126, column 3)
              _lhsOdistDefs =
                  ({-# LINE 1126 "src/Transform.ag" #-}
                   Map.foldWithKey (\n _ -> snd . find (replPos pos_ lhsIdent,replPos pos_ n,False) Nothing) _implsIdistDefs _undefAttrMap
                   {-# LINE 14084 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1127, column 3)
              _deflAttrs =
                  ({-# LINE 1127 "src/Transform.ag" #-}
                   [ (a, Map.findWithDefault (False,Nothing) a _distDeflStmts    ) | a <- Map.keys _deflAttrMap     ]
                   {-# LINE 14089 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1187, column 3)
              impls_val_ =
                  ({-# LINE 1187 "src/Transform.ag" #-}
                   [ ImplStmt_Invoke pos_ nm s (findChild nm _lhsIdistChildDefs)
                   | (nm,vs) <- Map.assocs _implicitInvokes    , s <- Set.toList vs ]
                   {-# LINE 14095 "src/Transform.hs" #-})
              impls_inst_ =
                  (sem_ImplStmts impls_val_ )
              -- "src/Transform.ag"(line 1207, column 3)
              deflts_val_ =
                  ({-# LINE 1207 "src/Transform.ag" #-}
                   map (\(nm,(_,mbCode)) -> ImplStmt_DefaultSyn pos_ True nm mbCode) _deflAttrs
                   ++ map (ImplStmt_DefaultVisLocal pos_) _deflLocalAttrs
                   {-# LINE 14103 "src/Transform.hs" #-})
              deflts_inst_ =
                  (sem_ImplStmts deflts_val_ )
              -- "src/Transform.ag"(line 1314, column 32)
              _distChildOcc =
                  ({-# LINE 1314 "src/Transform.ag" #-}
                   _stmtsIgathChildOcc `unionWithMin` _lhsIdistChildOcc
                   {-# LINE 14110 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1350, column 32)
              _itfNm =
                  ({-# LINE 1350 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 14115 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1406, column 23)
              _basename =
                  ({-# LINE 1406 "src/Transform.ag" #-}
                   name_ : _lhsIbasename
                   {-# LINE 14120 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1563, column 3)
              _stmtsOgathNextVisits =
                  ({-# LINE 1563 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 14125 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1564, column 3)
              _nextOdistNextVisits =
                  ({-# LINE 1564 "src/Transform.ag" #-}
                   let ks = Map.keysSet _nextIallReqInvokes
                   in Map.filter (maybe False (`Set.member` ks))
                                 (_implsIgathNextVisits `Map.union` _lhsIdistNextVisits)
                   {-# LINE 14132 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1619, column 3)
              _distChildMinRanges =
                  ({-# LINE 1619 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `unionWithPlusplus` _lhsIdistChildMinRanges
                   {-# LINE 14137 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1620, column 3)
              _distAllChildMinRanges =
                  ({-# LINE 1620 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `Map.union` _lhsIdistAllChildMinRanges
                   {-# LINE 14142 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1621, column 3)
              _distChildEffRanges =
                  ({-# LINE 1621 "src/Transform.ag" #-}
                   _stmtsIgathChildEffRanges `unionWithUnion` _lhsIdistChildEffRanges
                   {-# LINE 14147 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1622, column 3)
              _nextOdistChildEffRanges =
                  ({-# LINE 1622 "src/Transform.ag" #-}
                   _distChildEffRanges     `diffInside` _availInvokes
                   {-# LINE 14152 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1623, column 3)
              _introChildren =
                  ({-# LINE 1623 "src/Transform.ag" #-}
                   Map.keysSet (Map.difference _stmtsIgathChildMinRanges _lhsIdistChildMinRanges)
                   {-# LINE 14157 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1672, column 3)
              _minReqInvokes1 =
                  ({-# LINE 1672 "src/Transform.ag" #-}
                   _stmtsIminReqInvokes `unionWithUnion` _nextIminReqInvokes
                   {-# LINE 14162 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1673, column 3)
              _allReqInvokes1 =
                  ({-# LINE 1673 "src/Transform.ag" #-}
                   _stmtsIallReqInvokes `unionWithUnion` _nextIallReqInvokes
                   {-# LINE 14167 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1674, column 3)
              _minReqInvokes =
                  ({-# LINE 1674 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _minReqInvokes1
                   {-# LINE 14172 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1675, column 3)
              _allReqInvokes =
                  ({-# LINE 1675 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _allReqInvokes1
                   {-# LINE 14177 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1767, column 3)
              _implicitInvokes =
                  ({-# LINE 1767 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _lhsIavailInvokes
                                       `diffInside` _stmtsIexplInvokes
                                       `diffInside` _nextIbannedInvokes
                   {-# LINE 14184 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1770, column 3)
              _additionalInvokes =
                  ({-# LINE 1770 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _nextIbannedInvokes `unionWithUnion` _stmtsIexplInvokes
                   {-# LINE 14189 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1771, column 3)
              _availInvokes =
                  ({-# LINE 1771 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` _lhsIavailInvokes
                   {-# LINE 14194 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1772, column 3)
              _allAvailInvokes =
                  ({-# LINE 1772 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` (
                     Map.filterWithKey (notIn _introChildren    ) _lhsIallAvailInvokes )
                   {-# LINE 14200 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1805, column 3)
              _missingInvokes =
                  ({-# LINE 1805 "src/Transform.ag" #-}
                   Set.toList (_stmtsIgathMissingInvokes `Set.difference` _nextIgathMissingInvokes)
                   {-# LINE 14205 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1823, column 32)
              _distDeflStmts =
                  ({-# LINE 1823 "src/Transform.ag" #-}
                   _stmtsIgathDeflStmts `Map.union` _lhsIdistDeflStmts
                   {-# LINE 14210 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2064, column 25)
              _distAttrSource =
                  ({-# LINE 2064 "src/Transform.ag" #-}
                   Map.unions [ _stmtsIgathAttrSource
                              , _defltsIgathAttrSource
                              , _implsIgathAttrSource
                              , _lhsIdistAttrSource ]
                   {-# LINE 14218 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2119, column 3)
              _distChildSource =
                  ({-# LINE 2119 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathChildSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistChildSource ]
                   {-# LINE 14224 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2139, column 3)
              _distVisitSource =
                  ({-# LINE 2139 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathVisitSource
                                          , _implsIgathVisitSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistVisitSource ]
                   {-# LINE 14231 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2173, column 3)
              _scopeReason =
                  ({-# LINE 2173 "src/Transform.ag" #-}
                   ReasonScopeClause name_
                   {-# LINE 14236 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2174, column 3)
              _scopeDep =
                  ({-# LINE 2174 "src/Transform.ag" #-}
                   DepClause _basename
                   {-# LINE 14241 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2391, column 3)
              __tup4 =
                  ({-# LINE 2391 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _scopeDep     _lhsIdistRanks
                   {-# LINE 14246 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2391, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2391 "src/Transform.ag" #-}
                   __tup4
                   {-# LINE 14251 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2391, column 3)
              (_,_rank) =
                  ({-# LINE 2391 "src/Transform.ag" #-}
                   __tup4
                   {-# LINE 14256 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2392, column 3)
              _isCyclic =
                  ({-# LINE 2392 "src/Transform.ag" #-}
                   _lhsIfullCyclic || _isOnCycle
                   {-# LINE 14261 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2397, column 32)
              _lhsOminRank =
                  ({-# LINE 2397 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 14266 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2530, column 18)
              _lhsOpp =
                  ({-# LINE 2530 "src/Transform.ag" #-}
                   "clause" >#< name_
                   >-< indent 2 (   vlist _stmtsIpps
                                >-< vlist _implsIpps
                                >-< vlist _defltsIpps
                                >-< _nextIpp
                                )
                   {-# LINE 14276 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 321, column 18)
              _hChildren =
                  ({-# LINE 321 "src/TargetHaskell.ag" #-}
                   hlist_sp [ hSemNm k v | (k, Just v) <- Map.assocs _lhsImyNextVisits ]
                   {-# LINE 14281 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 322, column 18)
              _hChns =
                  ({-# LINE 322 "src/TargetHaskell.ag" #-}
                   hlist_sp [ hParensWithPos _lhsIopts pos_ $ hInp visIdent nm
                            | (nm,_) <- Map.assocs _lhsIdirectVisitLocalAttrs ]
                   {-# LINE 14287 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 324, column 18)
              _hNext =
                  ({-# LINE 324 "src/TargetHaskell.ag" #-}
                   maybe [] (\nm -> [ hSynFldNmFull nextIdent _itfNm     _lhsIvisit >#< "= _visNext" ]) _nextImbNextVisit
                   {-# LINE 14292 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 325, column 18)
              _hVisLocs =
                  ({-# LINE 325 "src/TargetHaskell.ag" #-}
                   [ hInp visIdent _lhsIvisit >#< "=" >#< hParensWithPos _lhsIopts pos_ (hOutp visIdent nm)
                   | (nm,_) <- Map.assocs _lhsIdirectVisitLocalAttrs ]
                   {-# LINE 14298 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 327, column 18)
              _hRestart =
                  ({-# LINE 327 "src/TargetHaskell.ag" #-}
                   "_visRestart =" >#< hItfVsNm _itfNm     _lhsIvisit
                   >#< pp_parens (hVis _lhsIvisit >#< _hChildren     >#< _hChns    )
                   {-# LINE 14304 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 329, column 18)
              _hResVal =
                  ({-# LINE 329 "src/TargetHaskell.ag" #-}
                   pp_parens ( hSynDt _itfNm     _lhsIvisit
                     >#< pp_block "{" "}" "," ( [hSynFldNmFull repIdent _itfNm     _lhsIvisit >#< "= _visRestart" ] ++
                                                 _hNext     ++
                                                 [ hSynFldNm nm _itfNm     _lhsIvisit >#< "=" >#<
                                                   hParensWithPos _lhsIopts pos_ (hOutp lhsIdent nm)
                                                   | (nm,_) <- Map.assocs _synAttrMap     ] ))
                   {-# LINE 14314 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 335, column 18)
              _lhsOhpp =
                  ({-# LINE 335 "src/TargetHaskell.ag" #-}
                   if _lhsIfullCyclic
                   then "let" >#< (
                          vlist (concat _hGroupedStmts    )
                          >-< vlist _hVisLocs
                          >-< _hRestart
                          >-< case _nextImbNextVisit of
                                Nothing -> _nextIhpp
                                Just _  -> "_visNext" >#< "=" >#< _nextIhpp
                        )
                        >-< "in" >#< _hResVal
                   else "do" >#< (
                         hppStmtBlock _hGroupedStmts
                         >-< if _isDeepest
                             then vlist (map ("let" >#<) _hVisLocs    )
                                   >-< "let" >#< ( "!" >|< _hRestart
                                         >-< case _nextImbNextVisit of
                                               Nothing -> empty
                                               Just _  -> "!" >|< "_visNext" >#< "=" >#< _nextIhpp
                                       )
                                   >-< case _nextImbNextVisit of
                                         Nothing -> _nextIhpp
                                         Just _  -> empty
                                   >-< "return" >#< _hResVal
                             else _nextIhpp
                       )
                   {-# LINE 14343 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 602, column 3)
              __tup5 =
                  ({-# LINE 602 "src/TargetHaskell.ag" #-}
                   partition (rankIsLower _nextIminRank)
                     (_lhsIhSpilledStmts ++ _defltsIhopps ++ _implsIhopps ++ _stmtsIhopps)
                   {-# LINE 14349 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 602, column 3)
              (_hoStmts,_) =
                  ({-# LINE 602 "src/TargetHaskell.ag" #-}
                   __tup5
                   {-# LINE 14354 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 602, column 3)
              (_,_nextOhSpilledStmts) =
                  ({-# LINE 602 "src/TargetHaskell.ag" #-}
                   __tup5
                   {-# LINE 14359 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 605, column 3)
              _hGroupedStmts =
                  ({-# LINE 605 "src/TargetHaskell.ag" #-}
                   groupPairs _hoStmts
                   {-# LINE 14364 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 207, column 18)
              _lhsOjspp =
                  ({-# LINE 207 "src/TargetJs.ag" #-}
                   jsppStmtBlock _jsGroupedStmts
                   >-< if _isDeepest
                       then "var _outs = new Syn_" >|< jsConNm (head _lhsIitf) _lhsIvisit >|< "();"
                            >-< case _nextImbNextVisit of
                                  Just _  -> "_outs._next = " >#< _nextIjspp >|< ";"
                                  Nothing -> _nextIjspp
                            >-< vlist [ "_outs." >|< show nm >#< "=" >#< jsOutp lhsIdent nm >|< ";"
                                      | (nm,_) <- Map.assocs _synAttrMap     ]
                            >-< "return _outs;"
                       else _nextIjspp
                   {-# LINE 14378 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 397, column 3)
              __tup6 =
                  ({-# LINE 397 "src/TargetJs.ag" #-}
                   partition (rankIsLower _nextIminRank)
                     (_lhsIjsSpilledStmts ++ _defltsIjsopps ++ _implsIjsopps ++ _stmtsIjsopps)
                   {-# LINE 14384 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 397, column 3)
              (_jsoStmts,_) =
                  ({-# LINE 397 "src/TargetJs.ag" #-}
                   __tup6
                   {-# LINE 14389 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 397, column 3)
              (_,_nextOjsSpilledStmts) =
                  ({-# LINE 397 "src/TargetJs.ag" #-}
                   __tup6
                   {-# LINE 14394 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 400, column 3)
              _jsGroupedStmts =
                  ({-# LINE 400 "src/TargetJs.ag" #-}
                   groupPairs _jsoStmts
                   {-# LINE 14399 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup7 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_stmtsOlexCounter,_) =
                  ({-# LINE 1287 "src/Transform.ag" #-}
                   __tup7
                   {-# LINE 14407 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1287 "src/Transform.ag" #-}
                   __tup7
                   {-# LINE 14412 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _allReqInvokes
                   {-# LINE 14417 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _stmtsIbannedInvokes `unionWithUnion` _nextIbannedInvokes
                   {-# LINE 14422 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs0 Seq.>< _nextIerrs0
                   {-# LINE 14427 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs1 Seq.>< _nextIerrs1
                   {-# LINE 14432 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 1806 "src/Transform.ag" #-}
                   _stmtsIerrs2 Seq.>< _nextIerrs2 Seq.>< _implsIerrs2 Seq.>< _defltsIerrs2
                   {-# LINE 14437 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1089 "src/Transform.ag" #-}
                   _stmtsIerrs3 Seq.>< _nextIerrs3 Seq.>< _implsIerrs3 Seq.>< _defltsIerrs3
                   {-# LINE 14442 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs4 Seq.>< _nextIerrs4 Seq.>< _implsIerrs4 Seq.>< _defltsIerrs4
                   {-# LINE 14447 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs5 Seq.>< _nextIerrs5 Seq.>< _implsIerrs5 Seq.>< _defltsIerrs5
                   {-# LINE 14452 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   _stmtsIexplInvokes
                   {-# LINE 14457 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _nextIgathAllowCycVisits
                   {-# LINE 14462 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _stmtsIgathAttrSource `Map.union` _nextIgathAttrSource `Map.union` _implsIgathAttrSource `Map.union` _defltsIgathAttrSource
                   {-# LINE 14467 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _stmtsIgathAvoidVisits `Set.union` _nextIgathAvoidVisits
                   {-# LINE 14472 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _stmtsIgathChildSource `unionWithUnion` _nextIgathChildSource `unionWithUnion` _implsIgathChildSource `unionWithUnion` _defltsIgathChildSource
                   {-# LINE 14477 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2308 "src/Transform.ag" #-}
                   _stmtsIgathDeps Seq.>< _nextIgathDeps Seq.>< _implsIgathDeps Seq.>< _defltsIgathDeps
                   {-# LINE 14482 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1994 "src/Transform.ag" #-}
                   _stmtsIgathItemVisits `Map.union` _nextIgathItemVisits `Map.union` _implsIgathItemVisits `Map.union` _defltsIgathItemVisits
                   {-# LINE 14487 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _stmtsIgathLegalCycStmts `Set.union` _nextIgathLegalCycStmts `Set.union` _implsIgathLegalCycStmts `Set.union` _defltsIgathLegalCycStmts
                   {-# LINE 14492 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _stmtsIgathMissingInvokes `Set.union` _nextIgathMissingInvokes
                   {-# LINE 14497 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _nextIgathSemAttrSource
                   {-# LINE 14502 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _stmtsIgathSemStarts Seq.>< _nextIgathSemStarts
                   {-# LINE 14507 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _stmtsIgathStmtPosMap `Map.union` _nextIgathStmtPosMap `Map.union` _implsIgathStmtPosMap `Map.union` _defltsIgathStmtPosMap
                   {-# LINE 14512 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _nextIgathVisRankMap
                   {-# LINE 14517 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _nextIgathVisitAttrs
                   {-# LINE 14522 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _stmtsIgathVisitEnds Seq.>< _nextIgathVisitEnds
                   {-# LINE 14527 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _stmtsIgathVisitSource `unionWithUnion` _nextIgathVisitSource `unionWithUnion` _implsIgathVisitSource `unionWithUnion` _defltsIgathVisitSource
                   {-# LINE 14532 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _stmtsIgathVisitStarts Seq.>< _nextIgathVisitStarts
                   {-# LINE 14537 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _minReqInvokes
                   {-# LINE 14542 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _nextIcodeIdCounter
                   {-# LINE 14547 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _nextIdistChildDefs
                   {-# LINE 14552 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _nextIdistDataCons
                   {-# LINE 14557 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _nextIdistDataSems
                   {-# LINE 14562 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _nextIdistDatas
                   {-# LINE 14567 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _nextIdistItfs
                   {-# LINE 14572 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _defltsIdistVisLocalDefs
                   {-# LINE 14577 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _nextIdistVisits
                   {-# LINE 14582 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _nextIgathChildDefs
                   {-# LINE 14587 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathClauses_augmented_syn =
                  ({-# LINE 261 "src/Transform.ag" #-}
                   _nextIgathClauses
                   {-# LINE 14592 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _nextIgathDataSems
                   {-# LINE 14597 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _nextIgathNonterms
                   {-# LINE 14602 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _nextIgathVisitNames
                   {-# LINE 14607 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _defltsIlexCounter
                   {-# LINE 14612 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 14617 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 14622 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 14627 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 14632 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 14637 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 14642 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 14647 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 14652 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 14657 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 14662 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 14667 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 14672 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 14677 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 14682 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 14687 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 14692 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 14697 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 14702 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 14707 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 14712 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 14717 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 14722 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 14727 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 14732 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 14737 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 14742 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 14747 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 14752 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 14757 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 14762 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 14767 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 14772 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 14777 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 14782 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 14787 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 14792 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 14797 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 14802 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 14807 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 14812 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 14817 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 14822 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 14827 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 14832 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 14837 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 14842 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 14847 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 14852 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 14857 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 14862 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 14867 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 14872 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 14877 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 14882 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 14887 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 14892 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 14897 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 14902 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 14907 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 14912 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 14917 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 14922 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 14927 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _stmtsIcodeIdCounter
                   {-# LINE 14932 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 14937 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 14942 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 14947 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 14952 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 14957 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 14962 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _stmtsIdistChildDefs
                   {-# LINE 14967 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 14972 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 14977 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 14982 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 14987 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _stmtsIdistDataCons
                   {-# LINE 14992 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 14997 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _stmtsIdistDataSems
                   {-# LINE 15002 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _stmtsIdistDatas
                   {-# LINE 15007 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 15012 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 15017 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _stmtsIdistItfs
                   {-# LINE 15022 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 15027 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 15032 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 15037 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIdistVisLocalDefs
                   {-# LINE 15042 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 15047 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 15052 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 15057 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 15062 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 15067 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _stmtsIdistVisits
                   {-# LINE 15072 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 15077 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 15082 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 15087 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _stmtsIgathChildDefs
                   {-# LINE 15092 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathClauses
                   {-# LINE 15097 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _stmtsIgathDataSems
                   {-# LINE 15102 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathNonterms
                   {-# LINE 15107 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIgathVisLocalDefs
                   {-# LINE 15112 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 15117 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 15122 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 15127 "src/Transform.hs" #-})
              -- copy rule (chain)
              _nextOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _stmtsIlexCounter
                   {-# LINE 15132 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 15137 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _masterPos
                   {-# LINE 15142 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 15147 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 15152 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 15157 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 15162 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 15167 "src/Transform.hs" #-})
              -- copy rule (from local)
              _nextOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 15172 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 15177 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 15182 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 15187 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 15192 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 15197 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 15202 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 15207 "src/Transform.hs" #-})
              -- copy rule (down)
              _nextOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 15212 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 15217 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 15222 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 15227 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 15232 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 15237 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 15242 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 15247 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 15252 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 15257 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 15262 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 15267 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 15272 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _nextIdistChildDefs
                   {-# LINE 15277 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 15282 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 15287 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 15292 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 15297 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 15302 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _nextIdistDataCons
                   {-# LINE 15307 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 15312 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _nextIdistDataSems
                   {-# LINE 15317 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _nextIdistDatas
                   {-# LINE 15322 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 15327 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 15332 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _nextIdistItfs
                   {-# LINE 15337 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 15342 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 15347 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 15352 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _nextIdistVisLocalDefs
                   {-# LINE 15357 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 15362 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 15367 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 15372 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 15377 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 15382 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _nextIdistVisits
                   {-# LINE 15387 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 15392 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 15397 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _nextIgathChildDefs
                   {-# LINE 15402 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _nextIgathClauses
                   {-# LINE 15407 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _stmtsIgathNextVisits
                   {-# LINE 15412 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _nextIgathNonterms
                   {-# LINE 15417 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _nextIgathVisLocalDefs
                   {-# LINE 15422 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 15427 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 15432 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 15437 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _nextIlexCounter
                   {-# LINE 15442 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 15447 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 15452 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 15457 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 15462 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 15467 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 15472 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 15477 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 15482 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 15487 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 15492 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 15497 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 15502 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 15507 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 15512 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 15517 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 15522 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 15527 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 15532 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 15537 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 15542 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _nextIdistChildDefs
                   {-# LINE 15547 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 15552 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 15557 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 15562 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 15567 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 15572 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _nextIdistDataCons
                   {-# LINE 15577 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 15582 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _nextIdistDataSems
                   {-# LINE 15587 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _nextIdistDatas
                   {-# LINE 15592 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 15597 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIdistDefs
                   {-# LINE 15602 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 15607 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _nextIdistItfs
                   {-# LINE 15612 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 15617 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 15622 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 15627 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIdistVisLocalDefs
                   {-# LINE 15632 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 15637 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 15642 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 15647 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 15652 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 15657 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _nextIdistVisits
                   {-# LINE 15662 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 15667 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 15672 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _nextIgathChildDefs
                   {-# LINE 15677 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _nextIgathClauses
                   {-# LINE 15682 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIgathDefs
                   {-# LINE 15687 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _implsIgathNextVisits
                   {-# LINE 15692 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _nextIgathNonterms
                   {-# LINE 15697 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIgathVisLocalDefs
                   {-# LINE 15702 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 15707 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 15712 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 15717 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _implsIlexCounter
                   {-# LINE 15722 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 15727 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 15732 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 15737 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 15742 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 15747 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 15752 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 15757 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 15762 "src/Transform.hs" #-})
              ( _stmtsIallReqInvokes,_stmtsIbannedInvokes,_stmtsIcodeIdCounter,_stmtsIdistChildDefs,_stmtsIdistDataCons,_stmtsIdistDataSems,_stmtsIdistDatas,_stmtsIdistDefs,_stmtsIdistItfs,_stmtsIdistVisLocalDefs,_stmtsIdistVisits,_stmtsIerrs0,_stmtsIerrs1,_stmtsIerrs2,_stmtsIerrs3,_stmtsIerrs4,_stmtsIerrs5,_stmtsIexplInvokes,_stmtsIgathAttrSource,_stmtsIgathAvoidVisits,_stmtsIgathChildDefs,_stmtsIgathChildEffRanges,_stmtsIgathChildMinRanges,_stmtsIgathChildOcc,_stmtsIgathChildSource,_stmtsIgathClauses,_stmtsIgathDataSems,_stmtsIgathDeflStmts,_stmtsIgathDefs,_stmtsIgathDeps,_stmtsIgathItemVisits,_stmtsIgathLegalCycStmts,_stmtsIgathMissingInvokes,_stmtsIgathNextVisits,_stmtsIgathNonterms,_stmtsIgathRenames,_stmtsIgathSemStarts,_stmtsIgathStmtPosMap,_stmtsIgathVisLocalDefs,_stmtsIgathVisitEnds,_stmtsIgathVisitSource,_stmtsIgathVisitStarts,_stmtsIhopps,_stmtsIjsopps,_stmtsIlexCounter,_stmtsIminReqInvokes,_stmtsIpps) =
                  stmts_inst_ _stmtsOallAvailInvokes _stmtsOallVisits _stmtsOallowCycVisits _stmtsOavailInvokes _stmtsObasename _stmtsOcoItf _stmtsOcodeIdCounter _stmtsOdirectVisitAttrs _stmtsOdirectVisitLocalAttrs _stmtsOdistAliasses _stmtsOdistAllChildMinRanges _stmtsOdistAttrSource _stmtsOdistAttrVisMap _stmtsOdistChildDefs _stmtsOdistChildEffRanges _stmtsOdistChildMinRanges _stmtsOdistChildOcc _stmtsOdistChildSource _stmtsOdistCycVisMap _stmtsOdistDataCons _stmtsOdistDataMap _stmtsOdistDataSems _stmtsOdistDatas _stmtsOdistDeflStmts _stmtsOdistDefs _stmtsOdistInhAttrs _stmtsOdistItfs _stmtsOdistRanks _stmtsOdistRenames _stmtsOdistSynAttrs _stmtsOdistVisLocalDefs _stmtsOdistVisRankMap _stmtsOdistVisitInhAttrs _stmtsOdistVisitOrder _stmtsOdistVisitSource _stmtsOdistVisitSynAttrs _stmtsOdistVisits _stmtsOdoneVisits _stmtsOfullCyclicVisits _stmtsOgathChildDefs _stmtsOgathClauses _stmtsOgathDataSems _stmtsOgathDefs _stmtsOgathNextVisits _stmtsOgathNonterms _stmtsOgathVisLocalDefs _stmtsOhSpilledStmts _stmtsOindent _stmtsOitf _stmtsOjsSpilledStmts _stmtsOlexCounter _stmtsOnonterm _stmtsOopts _stmtsOscopeDep _stmtsOscopeReason _stmtsOstmtSource _stmtsOvisitBeginDep _stmtsOvisitEndDep _stmtsOvisitEndReason 
              ( _nextIallReqInvokes,_nextIbannedInvokes,_nextIcodeIdCounter,_nextIdistChildDefs,_nextIdistDataCons,_nextIdistDataSems,_nextIdistDatas,_nextIdistDefs,_nextIdistItfs,_nextIdistVisLocalDefs,_nextIdistVisits,_nextIerrs0,_nextIerrs1,_nextIerrs2,_nextIerrs3,_nextIerrs4,_nextIerrs5,_nextIgathAllowCycVisits,_nextIgathAttrSource,_nextIgathAvoidVisits,_nextIgathChildDefs,_nextIgathChildSource,_nextIgathClauses,_nextIgathDataSems,_nextIgathDefs,_nextIgathDeps,_nextIgathItemVisits,_nextIgathLegalCycStmts,_nextIgathMissingInvokes,_nextIgathNonterms,_nextIgathSemAttrSource,_nextIgathSemStarts,_nextIgathStmtPosMap,_nextIgathVisLocalDefs,_nextIgathVisRankMap,_nextIgathVisitAttrs,_nextIgathVisitEnds,_nextIgathVisitNames,_nextIgathVisitSource,_nextIgathVisitStarts,_nextIhpp,_nextIisInternal,_nextIjspp,_nextIlexCounter,_nextImbNextVisit,_nextIminRank,_nextIminReqInvokes,_nextIpp) =
                  next_ _nextOallAvailInvokes _nextOallVisits _nextOallowCycVisits _nextOavailInvokes _nextObasename _nextOclauseExtras _nextOcoItf _nextOcodeIdCounter _nextOdirectVisitAttrs _nextOdirectVisitLocalAttrs _nextOdistAliasses _nextOdistAllChildMinRanges _nextOdistAttrSource _nextOdistAttrVisMap _nextOdistChildDefs _nextOdistChildEffRanges _nextOdistChildMinRanges _nextOdistChildOcc _nextOdistChildSource _nextOdistCycVisMap _nextOdistDataCons _nextOdistDataMap _nextOdistDataSems _nextOdistDatas _nextOdistDeflStmts _nextOdistDefs _nextOdistInhAttrs _nextOdistItfs _nextOdistNextVisits _nextOdistRanks _nextOdistRenames _nextOdistSynAttrs _nextOdistVisLocalDefs _nextOdistVisRankMap _nextOdistVisitInhAttrs _nextOdistVisitOrder _nextOdistVisitSource _nextOdistVisitSynAttrs _nextOdistVisits _nextOdoneVisits _nextOfullCyclic _nextOfullCyclicVisits _nextOgathChildDefs _nextOgathClauses _nextOgathDataSems _nextOgathDefs _nextOgathNonterms _nextOgathVisLocalDefs _nextOgathVisitNames _nextOhSpilledStmts _nextOindent _nextOitf _nextOjsSpilledStmts _nextOlexCounter _nextOlocalAttrs _nextOmasterPos _nextOmyNextVisits _nextOnextVisits _nextOnonterm _nextOopts _nextOscopeDep _nextOscopeReason _nextOsemBasename _nextOstmtSource _nextOvisit _nextOvisitBeginDep _nextOvisitEndDep _nextOvisitEndReason _nextOvisitNr _nextOwithinCoSem 
              ( _implsIdistDefs,_implsIdistVisLocalDefs,_implsIerrs2,_implsIerrs3,_implsIerrs4,_implsIerrs5,_implsIgathAttrSource,_implsIgathChildSource,_implsIgathDefs,_implsIgathDeps,_implsIgathItemVisits,_implsIgathLegalCycStmts,_implsIgathNextVisits,_implsIgathStmtPosMap,_implsIgathVisLocalDefs,_implsIgathVisitSource,_implsIhopps,_implsIjsopps,_implsIlexCounter,_implsIpps) =
                  impls_inst_ _implsOallAvailInvokes _implsOallVisits _implsOallowCycVisits _implsOavailInvokes _implsObasename _implsOcoItf _implsOdirectVisitAttrs _implsOdirectVisitLocalAttrs _implsOdistAliasses _implsOdistAllChildMinRanges _implsOdistAttrSource _implsOdistAttrVisMap _implsOdistChildDefs _implsOdistChildEffRanges _implsOdistChildMinRanges _implsOdistChildOcc _implsOdistChildSource _implsOdistCycVisMap _implsOdistDataCons _implsOdistDataMap _implsOdistDataSems _implsOdistDatas _implsOdistDeflStmts _implsOdistDefs _implsOdistInhAttrs _implsOdistItfs _implsOdistRanks _implsOdistRenames _implsOdistSynAttrs _implsOdistVisLocalDefs _implsOdistVisRankMap _implsOdistVisitInhAttrs _implsOdistVisitOrder _implsOdistVisitSource _implsOdistVisitSynAttrs _implsOdistVisits _implsOdoneVisits _implsOfullCyclicVisits _implsOgathChildDefs _implsOgathClauses _implsOgathDefs _implsOgathNextVisits _implsOgathNonterms _implsOgathVisLocalDefs _implsOhSpilledStmts _implsOitf _implsOjsSpilledStmts _implsOlexCounter _implsOnonterm _implsOopts _implsOscopeDep _implsOscopeReason _implsOstmtSource _implsOvisitBeginDep _implsOvisitEndDep _implsOvisitEndReason 
              ( _defltsIdistDefs,_defltsIdistVisLocalDefs,_defltsIerrs2,_defltsIerrs3,_defltsIerrs4,_defltsIerrs5,_defltsIgathAttrSource,_defltsIgathChildSource,_defltsIgathDefs,_defltsIgathDeps,_defltsIgathItemVisits,_defltsIgathLegalCycStmts,_defltsIgathNextVisits,_defltsIgathStmtPosMap,_defltsIgathVisLocalDefs,_defltsIgathVisitSource,_defltsIhopps,_defltsIjsopps,_defltsIlexCounter,_defltsIpps) =
                  deflts_inst_ _defltsOallAvailInvokes _defltsOallVisits _defltsOallowCycVisits _defltsOavailInvokes _defltsObasename _defltsOcoItf _defltsOdirectVisitAttrs _defltsOdirectVisitLocalAttrs _defltsOdistAliasses _defltsOdistAllChildMinRanges _defltsOdistAttrSource _defltsOdistAttrVisMap _defltsOdistChildDefs _defltsOdistChildEffRanges _defltsOdistChildMinRanges _defltsOdistChildOcc _defltsOdistChildSource _defltsOdistCycVisMap _defltsOdistDataCons _defltsOdistDataMap _defltsOdistDataSems _defltsOdistDatas _defltsOdistDeflStmts _defltsOdistDefs _defltsOdistInhAttrs _defltsOdistItfs _defltsOdistRanks _defltsOdistRenames _defltsOdistSynAttrs _defltsOdistVisLocalDefs _defltsOdistVisRankMap _defltsOdistVisitInhAttrs _defltsOdistVisitOrder _defltsOdistVisitSource _defltsOdistVisitSynAttrs _defltsOdistVisits _defltsOdoneVisits _defltsOfullCyclicVisits _defltsOgathChildDefs _defltsOgathClauses _defltsOgathDefs _defltsOgathNextVisits _defltsOgathNonterms _defltsOgathVisLocalDefs _defltsOhSpilledStmts _defltsOitf _defltsOjsSpilledStmts _defltsOlexCounter _defltsOnonterm _defltsOopts _defltsOscopeDep _defltsOscopeReason _defltsOstmtSource _defltsOvisitBeginDep _defltsOvisitEndDep _defltsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauseNames,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
-- Clauses -----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         clauseExtras         : Map Ident Stmts
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distNextVisits       : Map Ident (Maybe Ident)
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclic           : Bool
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         localAttrs           : Map Ident String
         masterPos            : Pos
         myNextVisits         : Map Ident (Maybe Ident)
         nextVisits           : [Ident]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         semBasename          : QIdent
         stmtSource           : DepItem
         visit                : Ident
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
         visitNr              : Int
         withinCoSem          : Bool
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         gathVisitNames       : Env Ident ()
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         commonInvokes        : [Map Ident (Set Ident)]
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         explInvokes          : Map Ident (Set Ident)
         gathAllowCycVisits   : Set Ident
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathClauseNames      : Set Ident
         gathDefsAdds         : [DefsEnv]
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemAttrSource    : AttrSourceMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisLocalDefsAdds : [DefsEnv]
         gathVisRankMap       : IntMap Ident
         gathVisitAttrs       : Map Ident (Map Ident String)
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minRank              : Int
         minReqInvokes        : Map Ident (Set Ident)
         nClauses             : Int
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Clause 
         child tl             : Clauses 
         visit 0:
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local errs3_augmented_f3 : _
            local errs3_augmented_f4 : _
            local nClauses_augmented_f1 : _
            local _tup8       : {(Env QIdent (QIdent, QIdent),Env QIdent (QIdent, QIdent))}
            local _tup9       : _
            local gathLChildDefs : _
            local _tup10      : {(Env QIdent (QIdent,QIdent),Env QIdent (QIdent,QIdent))}
            local _tup11      : _
            local distLChildDefs : _
            local _tup12      : {(Env Ident (),Env Ident ())}
            local _tup13      : _
            local gathLVisitNames : _
            local _tup14      : {(DefsEnv,DefsEnv)}
            local _tup15      : {(DefsEnv,DefsEnv)}
            local _tup16      : _
            local gathLDefs   : _
            local _tup17      : _
            local gathVisLocalLDefs : _
            local _tup18      : _
            local localDistDefs : _
            local _tup19      : _
            local localDistVisLocalDefs : _
            local errs1_augmented_syn : _
            local errs3_augmented_syn : _
            local nClauses_augmented_syn : _
      alternative Nil:
-}
-- cata
sem_Clauses :: Clauses  ->
               T_Clauses 
sem_Clauses list  =
    (Prelude.foldr sem_Clauses_Cons sem_Clauses_Nil (Prelude.map sem_Clause list) )
-- semantic domain
type T_Clauses  = (Map Ident (Set Ident)) ->
                  (Set Ident) ->
                  (Set Ident) ->
                  (Map Ident (Set Ident)) ->
                  QIdent ->
                  (Map Ident Stmts) ->
                  Ident ->
                  Int ->
                  (Map Ident (Map Ident String)) ->
                  (Map Ident String) ->
                  (Map Ident AliasType) ->
                  (Map Ident [Ident]) ->
                  AttrSourceMap ->
                  AttrVisMap ->
                  (Env QIdent (QIdent,QIdent)) ->
                  (Map Ident (Set Ident)) ->
                  (Map Ident [Ident]) ->
                  (Map Ident Int) ->
                  ChildSourceMap ->
                  CycVisMap ->
                  ConEnv ->
                  DataMap ->
                  DataSemEnv ->
                  DataEnv ->
                  (Map Ident (Bool,Maybe Int)) ->
                  DefsEnv ->
                  AttrMap ->
                  ItfEnv ->
                  (Map Ident (Maybe Ident)) ->
                  (Map DepItem (Bool,Int)) ->
                  RenameMap ->
                  AttrMap ->
                  DefsEnv ->
                  (IntMap Ident) ->
                  VisitAttrMap ->
                  (Map Ident [Ident]) ->
                  VisitSourceMap ->
                  VisitAttrMap ->
                  VisitEnv ->
                  ([Ident]) ->
                  Bool ->
                  (Set Ident) ->
                  (Env QIdent (QIdent, QIdent)) ->
                  ClausesEnv ->
                  DataSemEnv ->
                  DefsEnv ->
                  NontermEnv ->
                  DefsEnv ->
                  (Env Ident ()) ->
                  ([(Int,PP_Doc)]) ->
                  Int ->
                  QIdent ->
                  ([(Int,PP_Doc)]) ->
                  Int ->
                  (Map Ident String) ->
                  Pos ->
                  (Map Ident (Maybe Ident)) ->
                  ([Ident]) ->
                  QIdent ->
                  Opts ->
                  DepItem ->
                  Reason ->
                  QIdent ->
                  DepItem ->
                  Ident ->
                  DepItem ->
                  DepItem ->
                  Reason ->
                  Int ->
                  Bool ->
                  ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,([Map Ident (Set Ident)]),(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident (Set Ident)),(Set Ident),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,(Set Ident),ClausesEnv,DataSemEnv,DefsEnv,([DefsEnv]),Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,AttrSourceMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,([DefsEnv]),(IntMap Ident),(Map Ident (Map Ident String)),(Seq DepItem),(Env Ident ()),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,Int,(Map Ident (Set Ident)),Int,([PP_Doc]))
sem_Clauses_Cons :: T_Clause  ->
                    T_Clauses  ->
                    T_Clauses 
sem_Clauses_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOnClauses :: Int
              __tup8 :: ((Env QIdent (QIdent, QIdent),Env QIdent (QIdent, QIdent)))
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              __tup10 :: ((Env QIdent (QIdent,QIdent),Env QIdent (QIdent,QIdent)))
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              __tup12 :: ((Env Ident (),Env Ident ()))
              _hdOgathVisitNames :: (Env Ident ())
              _tlOgathVisitNames :: (Env Ident ())
              _lhsOgathVisitNames :: (Env Ident ())
              __tup14 :: ((DefsEnv,DefsEnv))
              _hdOgathDefs :: DefsEnv
              _tlOgathDefs :: DefsEnv
              __tup15 :: ((DefsEnv,DefsEnv))
              _hdOgathVisLocalDefs :: DefsEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _hdOdistDefs :: DefsEnv
              _hdOdistVisLocalDefs :: DefsEnv
              _tlOdistDefs :: DefsEnv
              _tlOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefsAdds :: ([DefsEnv])
              _lhsOgathVisLocalDefsAdds :: ([DefsEnv])
              _lhsOcommonInvokes :: ([Map Ident (Set Ident)])
              _lhsOpps :: ([PP_Doc])
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathClauseNames :: (Set Ident)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOallowCycVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOclauseExtras :: (Map Ident Stmts)
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistNextVisits :: (Map Ident (Maybe Ident))
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisRankMap :: (IntMap Ident)
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOfullCyclic :: Bool
              _hdOfullCyclicVisits :: (Set Ident)
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathNonterms :: NontermEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOindent :: Int
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOlocalAttrs :: (Map Ident String)
              _hdOmasterPos :: Pos
              _hdOmyNextVisits :: (Map Ident (Maybe Ident))
              _hdOnextVisits :: ([Ident])
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOsemBasename :: QIdent
              _hdOstmtSource :: DepItem
              _hdOvisit :: Ident
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _hdOvisitNr :: Int
              _hdOwithinCoSem :: Bool
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOallowCycVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOclauseExtras :: (Map Ident Stmts)
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistNextVisits :: (Map Ident (Maybe Ident))
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisRankMap :: (IntMap Ident)
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOfullCyclic :: Bool
              _tlOfullCyclicVisits :: (Set Ident)
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathNonterms :: NontermEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOindent :: Int
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOlocalAttrs :: (Map Ident String)
              _tlOmasterPos :: Pos
              _tlOmyNextVisits :: (Map Ident (Maybe Ident))
              _tlOnextVisits :: ([Ident])
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOsemBasename :: QIdent
              _tlOstmtSource :: DepItem
              _tlOvisit :: Ident
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _tlOvisitNr :: Int
              _tlOwithinCoSem :: Bool
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIbannedInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIexplInvokes :: (Map Ident (Set Ident))
              _hdIgathAllowCycVisits :: (Set Ident)
              _hdIgathAttrSource :: AttrSourceMap
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathChildSource :: ChildSourceMap
              _hdIgathClauseNames :: (Set Ident)
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathMissingInvokes :: (Set (Ident,Ident))
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemAttrSource :: AttrSourceMap
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisRankMap :: (IntMap Ident)
              _hdIgathVisitAttrs :: (Map Ident (Map Ident String))
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitNames :: (Env Ident ())
              _hdIgathVisitSource :: VisitSourceMap
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminRank :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIbannedInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIcommonInvokes :: ([Map Ident (Set Ident)])
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIexplInvokes :: (Map Ident (Set Ident))
              _tlIgathAllowCycVisits :: (Set Ident)
              _tlIgathAttrSource :: AttrSourceMap
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathChildSource :: ChildSourceMap
              _tlIgathClauseNames :: (Set Ident)
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDefsAdds :: ([DefsEnv])
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathMissingInvokes :: (Set (Ident,Ident))
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemAttrSource :: AttrSourceMap
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisLocalDefsAdds :: ([DefsEnv])
              _tlIgathVisRankMap :: (IntMap Ident)
              _tlIgathVisitAttrs :: (Map Ident (Map Ident String))
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitNames :: (Env Ident ())
              _tlIgathVisitSource :: VisitSourceMap
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhpp :: PP_Doc
              _tlIjspp :: PP_Doc
              _tlIlexCounter :: Int
              _tlIminRank :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlInClauses :: Int
              _tlIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 842 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2]
                   {-# LINE 16371 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 842 "src/Transform.ag" #-}
                   addDefErrs' _gathLVisitNames
                   {-# LINE 16376 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 842 "src/Transform.ag" #-}
                   addUseErrs _distLChildDefs
                   {-# LINE 16381 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2, _errs3_augmented_f3, _errs3_augmented_f4]
                   {-# LINE 16386 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   addUseErrs'' _localDistVisLocalDefs
                   {-# LINE 16391 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   addUseErrs'' _localDistDefs
                   {-# LINE 16396 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f3 =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   addDefErrs'' _gathVisLocalLDefs
                   {-# LINE 16401 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f4 =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   addDefErrs'' _gathLDefs
                   {-# LINE 16406 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOnClauses =
                  ({-# LINE 1974 "src/Transform.ag" #-}
                   foldr ($) _nClauses_augmented_syn [_nClauses_augmented_f1]
                   {-# LINE 16411 "src/Transform.hs" #-})
              -- augment function
              _nClauses_augmented_f1 =
                  ({-# LINE 1974 "src/Transform.ag" #-}
                   (+1)
                   {-# LINE 16416 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 535, column 11)
              __tup8 =
                  ({-# LINE 535 "src/Transform.ag" #-}
                   split _lhsIgathChildDefs
                   {-# LINE 16421 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 535, column 11)
              (_hdOgathChildDefs,_) =
                  ({-# LINE 535 "src/Transform.ag" #-}
                   __tup8
                   {-# LINE 16426 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 535, column 11)
              (_,_tlOgathChildDefs) =
                  ({-# LINE 535 "src/Transform.ag" #-}
                   __tup8
                   {-# LINE 16431 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 536, column 11)
              __tup9 =
                  ({-# LINE 536 "src/Transform.ag" #-}
                   merge _hdIgathChildDefs _tlIgathChildDefs
                   {-# LINE 16436 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 536, column 11)
              (_lhsOgathChildDefs,_) =
                  ({-# LINE 536 "src/Transform.ag" #-}
                   __tup9
                   {-# LINE 16441 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 536, column 11)
              (_,_gathLChildDefs) =
                  ({-# LINE 536 "src/Transform.ag" #-}
                   __tup9
                   {-# LINE 16446 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 538, column 11)
              __tup10 =
                  ({-# LINE 538 "src/Transform.ag" #-}
                   splitWith _gathLChildDefs     _lhsIdistChildDefs
                   {-# LINE 16451 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 538, column 11)
              (_hdOdistChildDefs,_) =
                  ({-# LINE 538 "src/Transform.ag" #-}
                   __tup10
                   {-# LINE 16456 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 538, column 11)
              (_,_tlOdistChildDefs) =
                  ({-# LINE 538 "src/Transform.ag" #-}
                   __tup10
                   {-# LINE 16461 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 539, column 11)
              __tup11 =
                  ({-# LINE 539 "src/Transform.ag" #-}
                   merge _hdIdistChildDefs _tlIdistChildDefs
                   {-# LINE 16466 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 539, column 11)
              (_lhsOdistChildDefs,_) =
                  ({-# LINE 539 "src/Transform.ag" #-}
                   __tup11
                   {-# LINE 16471 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 539, column 11)
              (_,_distLChildDefs) =
                  ({-# LINE 539 "src/Transform.ag" #-}
                   __tup11
                   {-# LINE 16476 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 840, column 7)
              __tup12 =
                  ({-# LINE 840 "src/Transform.ag" #-}
                   split _lhsIgathVisitNames
                   {-# LINE 16481 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 840, column 7)
              (_hdOgathVisitNames,_) =
                  ({-# LINE 840 "src/Transform.ag" #-}
                   __tup12
                   {-# LINE 16486 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 840, column 7)
              (_,_tlOgathVisitNames) =
                  ({-# LINE 840 "src/Transform.ag" #-}
                   __tup12
                   {-# LINE 16491 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 841, column 7)
              __tup13 =
                  ({-# LINE 841 "src/Transform.ag" #-}
                   merge _hdIgathVisitNames _tlIgathVisitNames
                   {-# LINE 16496 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 841, column 7)
              (_lhsOgathVisitNames,_) =
                  ({-# LINE 841 "src/Transform.ag" #-}
                   __tup13
                   {-# LINE 16501 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 841, column 7)
              (_,_gathLVisitNames) =
                  ({-# LINE 841 "src/Transform.ag" #-}
                   __tup13
                   {-# LINE 16506 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1040, column 7)
              __tup14 =
                  ({-# LINE 1040 "src/Transform.ag" #-}
                   split _lhsIgathDefs
                   {-# LINE 16511 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1040, column 7)
              (_hdOgathDefs,_) =
                  ({-# LINE 1040 "src/Transform.ag" #-}
                   __tup14
                   {-# LINE 16516 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1040, column 7)
              (_,_tlOgathDefs) =
                  ({-# LINE 1040 "src/Transform.ag" #-}
                   __tup14
                   {-# LINE 16521 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1041, column 7)
              __tup15 =
                  ({-# LINE 1041 "src/Transform.ag" #-}
                   split _lhsIgathVisLocalDefs
                   {-# LINE 16526 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1041, column 7)
              (_hdOgathVisLocalDefs,_) =
                  ({-# LINE 1041 "src/Transform.ag" #-}
                   __tup15
                   {-# LINE 16531 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1041, column 7)
              (_,_tlOgathVisLocalDefs) =
                  ({-# LINE 1041 "src/Transform.ag" #-}
                   __tup15
                   {-# LINE 16536 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1042, column 7)
              __tup16 =
                  ({-# LINE 1042 "src/Transform.ag" #-}
                   merge _hdIgathDefs _tlIgathDefs
                   {-# LINE 16541 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1042, column 7)
              (_lhsOgathDefs,_) =
                  ({-# LINE 1042 "src/Transform.ag" #-}
                   __tup16
                   {-# LINE 16546 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1042, column 7)
              (_,_gathLDefs) =
                  ({-# LINE 1042 "src/Transform.ag" #-}
                   __tup16
                   {-# LINE 16551 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1043, column 7)
              __tup17 =
                  ({-# LINE 1043 "src/Transform.ag" #-}
                   merge _hdIgathVisLocalDefs _tlIgathVisLocalDefs
                   {-# LINE 16556 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1043, column 7)
              (_lhsOgathVisLocalDefs,_) =
                  ({-# LINE 1043 "src/Transform.ag" #-}
                   __tup17
                   {-# LINE 16561 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1043, column 7)
              (_,_gathVisLocalLDefs) =
                  ({-# LINE 1043 "src/Transform.ag" #-}
                   __tup17
                   {-# LINE 16566 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1044, column 7)
              _hdOdistDefs =
                  ({-# LINE 1044 "src/Transform.ag" #-}
                   enterWith _gathLDefs     _lhsIdistDefs
                   {-# LINE 16571 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1045, column 7)
              _hdOdistVisLocalDefs =
                  ({-# LINE 1045 "src/Transform.ag" #-}
                   enterWith _gathVisLocalLDefs     _lhsIdistVisLocalDefs
                   {-# LINE 16576 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1046, column 7)
              __tup18 =
                  ({-# LINE 1046 "src/Transform.ag" #-}
                   leave _hdIdistDefs
                   {-# LINE 16581 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1046, column 7)
              (_tlOdistDefs,_) =
                  ({-# LINE 1046 "src/Transform.ag" #-}
                   __tup18
                   {-# LINE 16586 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1046, column 7)
              (_,_localDistDefs) =
                  ({-# LINE 1046 "src/Transform.ag" #-}
                   __tup18
                   {-# LINE 16591 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1047, column 7)
              __tup19 =
                  ({-# LINE 1047 "src/Transform.ag" #-}
                   leave _hdIdistVisLocalDefs
                   {-# LINE 16596 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1047, column 7)
              (_tlOdistVisLocalDefs,_) =
                  ({-# LINE 1047 "src/Transform.ag" #-}
                   __tup19
                   {-# LINE 16601 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1047, column 7)
              (_,_localDistVisLocalDefs) =
                  ({-# LINE 1047 "src/Transform.ag" #-}
                   __tup19
                   {-# LINE 16606 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1069, column 11)
              _lhsOgathDefsAdds =
                  ({-# LINE 1069 "src/Transform.ag" #-}
                   _gathLDefs             : _tlIgathDefsAdds
                   {-# LINE 16611 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1070, column 11)
              _lhsOgathVisLocalDefsAdds =
                  ({-# LINE 1070 "src/Transform.ag" #-}
                   _gathVisLocalLDefs     : _tlIgathVisLocalDefsAdds
                   {-# LINE 16616 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1659, column 11)
              _lhsOcommonInvokes =
                  ({-# LINE 1659 "src/Transform.ag" #-}
                   _hdIallReqInvokes : _tlIcommonInvokes
                   {-# LINE 16621 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2653, column 11)
              _lhsOpps =
                  ({-# LINE 2653 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 16626 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 313, column 18)
              _lhsOhpp =
                  ({-# LINE 313 "src/TargetHaskell.ag" #-}
                   if _lhsIfullCyclic
                   then _hdIhpp
                   else pp_parens (hCatch _hdIhpp ("\\_ -> " >#< _tlIhpp))
                   {-# LINE 16633 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 192, column 18)
              _lhsOjspp =
                  ({-# LINE 192 "src/TargetJs.ag" #-}
                   if _lhsIfullCyclic
                   then _hdIjspp
                   else "try" >#< pp_braces (
                           _hdIjspp
                        ) >-< "catch (err)" >#< pp_braces (
                          "if (err == eEval)"
                          >-< pp_braces (
                            _tlIjspp
                          ) >-< "else" >#< pp_braces (
                            text "throw err;"
                          )
                        )
                   {-# LINE 16649 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 16654 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _hdIbannedInvokes `unionWithUnion` _tlIbannedInvokes
                   {-# LINE 16659 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 16664 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 842 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 16669 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 16674 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1052 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 16679 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 16684 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 16689 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   _hdIexplInvokes `unionWithUnion` _tlIexplInvokes
                   {-# LINE 16694 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _hdIgathAllowCycVisits `mappend` _tlIgathAllowCycVisits
                   {-# LINE 16699 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _hdIgathAttrSource `Map.union` _tlIgathAttrSource
                   {-# LINE 16704 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 16709 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _hdIgathChildSource `unionWithUnion` _tlIgathChildSource
                   {-# LINE 16714 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 263, column 54)
              _lhsOgathClauseNames =
                  ({-# LINE 263 "src/Transform.ag" #-}
                   _hdIgathClauseNames `Set.union` _tlIgathClauseNames
                   {-# LINE 16719 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 16724 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 16729 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 16734 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _hdIgathMissingInvokes `Set.union` _tlIgathMissingInvokes
                   {-# LINE 16739 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _hdIgathSemAttrSource `Map.union` _tlIgathSemAttrSource
                   {-# LINE 16744 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 16749 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 16754 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _hdIgathVisRankMap `mappend` _tlIgathVisRankMap
                   {-# LINE 16759 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _hdIgathVisitAttrs `mappend` _tlIgathVisitAttrs
                   {-# LINE 16764 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 16769 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _hdIgathVisitSource `unionWithUnion` _tlIgathVisitSource
                   {-# LINE 16774 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 16779 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   _hdIminRank `min` _tlIminRank
                   {-# LINE 16784 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 16789 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 16794 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 16799 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 16804 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 16809 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 16814 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 16819 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 16824 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 16829 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 16834 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 16839 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 16844 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 16849 "src/Transform.hs" #-})
              -- copy rule (up)
              _nClauses_augmented_syn =
                  ({-# LINE 1974 "src/Transform.ag" #-}
                   _tlInClauses
                   {-# LINE 16854 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 16859 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 16864 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 16869 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 16874 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 16879 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 16884 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 16889 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 16894 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 16899 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 16904 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 16909 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 16914 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 16919 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 16924 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 16929 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 16934 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 16939 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 16944 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 16949 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 16954 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 16959 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 16964 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 16969 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 16974 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 16979 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 16984 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 16989 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 16994 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 16999 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 17004 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 17009 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 17014 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 17019 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 17024 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 17029 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 17034 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 17039 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 17044 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 17049 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 17054 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 17059 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 17064 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 17069 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 17074 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 17079 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 17084 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 17089 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 17094 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 17099 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 17104 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 17109 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 17114 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 17119 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 17124 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 17129 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 17134 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 17139 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 17144 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 17149 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 17154 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 17159 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 17164 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 17169 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 17174 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 17179 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 17184 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 17189 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 17194 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 17199 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 17204 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 17209 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 17214 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 17219 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 17224 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 17229 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 17234 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 17239 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 17244 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 17249 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 17254 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 17259 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 17264 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 17269 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 17274 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 17279 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 17284 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 17289 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 17294 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 17299 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 17304 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 17309 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 17314 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 17319 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 17324 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 17329 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 17334 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 17339 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 17344 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 17349 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 17354 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 17359 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 17364 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 17369 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 17374 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 17379 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 17384 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 17389 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 17394 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 17399 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 17404 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 17409 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 17414 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 17419 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 17424 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 17429 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 17434 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 17439 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 17444 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 17449 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 17454 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 17459 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 17464 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 17469 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 17474 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 17479 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 17484 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIbannedInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIexplInvokes,_hdIgathAllowCycVisits,_hdIgathAttrSource,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathChildSource,_hdIgathClauseNames,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathMissingInvokes,_hdIgathNonterms,_hdIgathSemAttrSource,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisRankMap,_hdIgathVisitAttrs,_hdIgathVisitEnds,_hdIgathVisitNames,_hdIgathVisitSource,_hdIgathVisitStarts,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIminRank,_hdIminReqInvokes,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOallowCycVisits _hdOavailInvokes _hdObasename _hdOclauseExtras _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistNextVisits _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisRankMap _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOfullCyclic _hdOfullCyclicVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOgathVisitNames _hdOhSpilledStmts _hdOindent _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOlocalAttrs _hdOmasterPos _hdOmyNextVisits _hdOnextVisits _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOsemBasename _hdOstmtSource _hdOvisit _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason _hdOvisitNr _hdOwithinCoSem 
              ( _tlIallReqInvokes,_tlIbannedInvokes,_tlIcodeIdCounter,_tlIcommonInvokes,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIexplInvokes,_tlIgathAllowCycVisits,_tlIgathAttrSource,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathChildSource,_tlIgathClauseNames,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDefsAdds,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathMissingInvokes,_tlIgathNonterms,_tlIgathSemAttrSource,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisLocalDefsAdds,_tlIgathVisRankMap,_tlIgathVisitAttrs,_tlIgathVisitEnds,_tlIgathVisitNames,_tlIgathVisitSource,_tlIgathVisitStarts,_tlIhpp,_tlIjspp,_tlIlexCounter,_tlIminRank,_tlIminReqInvokes,_tlInClauses,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOallowCycVisits _tlOavailInvokes _tlObasename _tlOclauseExtras _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistNextVisits _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisRankMap _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOfullCyclic _tlOfullCyclicVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOgathVisitNames _tlOhSpilledStmts _tlOindent _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOlocalAttrs _tlOmasterPos _tlOmyNextVisits _tlOnextVisits _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOsemBasename _tlOstmtSource _tlOvisit _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason _tlOvisitNr _tlOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOcommonInvokes,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauseNames,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDefsAdds,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisLocalDefsAdds,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminRank,_lhsOminReqInvokes,_lhsOnClauses,_lhsOpps)))
sem_Clauses_Nil :: T_Clauses 
sem_Clauses_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsOgathDefsAdds :: ([DefsEnv])
              _lhsOgathVisLocalDefsAdds :: ([DefsEnv])
              _lhsOcommonInvokes :: ([Map Ident (Set Ident)])
              _lhsOnClauses :: Int
              _lhsOpps :: ([PP_Doc])
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathClauseNames :: (Set Ident)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 1071, column 11)
              _lhsOgathDefsAdds =
                  ({-# LINE 1071 "src/Transform.ag" #-}
                   []
                   {-# LINE 17618 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1072, column 11)
              _lhsOgathVisLocalDefsAdds =
                  ({-# LINE 1072 "src/Transform.ag" #-}
                   []
                   {-# LINE 17623 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1660, column 11)
              _lhsOcommonInvokes =
                  ({-# LINE 1660 "src/Transform.ag" #-}
                   []
                   {-# LINE 17628 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1975, column 11)
              _lhsOnClauses =
                  ({-# LINE 1975 "src/Transform.ag" #-}
                   0
                   {-# LINE 17633 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2654, column 11)
              _lhsOpps =
                  ({-# LINE 2654 "src/Transform.ag" #-}
                   []
                   {-# LINE 17638 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 316, column 18)
              _lhsOhpp =
                  ({-# LINE 316 "src/TargetHaskell.ag" #-}
                   if _lhsIfullCyclic
                   then text "undefined"
                   else pp_parens (hThrow ("no applicable clause for " ++ show (head _lhsIitf) ++ "." ++ show _lhsIvisit))
                   {-# LINE 17645 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 204, column 18)
              _lhsOjspp =
                  ({-# LINE 204 "src/TargetJs.ag" #-}
                   text "throw eEval;"
                   {-# LINE 17650 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17655 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17660 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17665 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17670 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17675 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17680 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17685 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17690 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17695 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 17700 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17705 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 17710 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17715 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 263, column 54)
              _lhsOgathClauseNames =
                  ({-# LINE 263 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 17720 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17725 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17730 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 17735 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 17740 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17745 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17750 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17755 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 17760 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 17765 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17770 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17775 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 17780 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   maxBound
                   {-# LINE 17785 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 17790 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 17795 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 17800 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 17805 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 17810 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 17815 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 17820 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 17825 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 17830 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 17835 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 17840 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 17845 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 17850 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 17855 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 17860 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 17865 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 17870 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 17875 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOcommonInvokes,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauseNames,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDefsAdds,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisLocalDefsAdds,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminRank,_lhsOminReqInvokes,_lhsOnClauses,_lhsOpps)))
-- ClausesTop --------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         clauseExtras         : Map Ident Stmts
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distNextVisits       : Map Ident (Maybe Ident)
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclic           : Bool
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         localAttrs           : Map Ident String
         masterPos            : Pos
         myNextVisits         : Map Ident (Maybe Ident)
         nextVisits           : [Ident]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         semBasename          : QIdent
         stmtSource           : DepItem
         visit                : Ident
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
         visitNr              : Int
         withinCoSem          : Bool
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         gathVisitNames       : Env Ident ()
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAllowCycVisits   : Set Ident
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathClauseNames      : Set Ident
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemAttrSource    : AttrSourceMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisRankMap       : IntMap Ident
         gathVisitAttrs       : Map Ident (Map Ident String)
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minRank              : Int
         minReqInvokes        : Map Ident (Set Ident)
         nClauses             : Int
         pps                  : [PP_Doc]
   alternatives:
      alternative Impl:
         child clauses        : {Clauses}
         visit 0:
            local pos         : _
            local name        : _
            inst  actual      : ClausesTop 
      alternative Top:
         child clauses        : Clauses 
         visit 0:
            local bannedInvokes_augmented_f1 : _
            local errs0_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local gathVisLocalDefs_augmented_f1 : _
            local bannedInvokes_augmented_syn : _
            local errs0_augmented_syn : _
            local gathDefs_augmented_syn : _
            local gathVisLocalDefs_augmented_syn : _
-}
-- cata
sem_ClausesTop :: ClausesTop  ->
                  T_ClausesTop 
sem_ClausesTop (ClausesTop_Impl _clauses )  =
    (sem_ClausesTop_Impl _clauses )
sem_ClausesTop (ClausesTop_Top _clauses )  =
    (sem_ClausesTop_Top (sem_Clauses _clauses ) )
-- semantic domain
type T_ClausesTop  = (Map Ident (Set Ident)) ->
                     (Set Ident) ->
                     (Set Ident) ->
                     (Map Ident (Set Ident)) ->
                     QIdent ->
                     (Map Ident Stmts) ->
                     Ident ->
                     Int ->
                     (Map Ident (Map Ident String)) ->
                     (Map Ident String) ->
                     (Map Ident AliasType) ->
                     (Map Ident [Ident]) ->
                     AttrSourceMap ->
                     AttrVisMap ->
                     (Env QIdent (QIdent,QIdent)) ->
                     (Map Ident (Set Ident)) ->
                     (Map Ident [Ident]) ->
                     (Map Ident Int) ->
                     ChildSourceMap ->
                     CycVisMap ->
                     ConEnv ->
                     DataMap ->
                     DataSemEnv ->
                     DataEnv ->
                     (Map Ident (Bool,Maybe Int)) ->
                     DefsEnv ->
                     AttrMap ->
                     ItfEnv ->
                     (Map Ident (Maybe Ident)) ->
                     (Map DepItem (Bool,Int)) ->
                     RenameMap ->
                     AttrMap ->
                     DefsEnv ->
                     (IntMap Ident) ->
                     VisitAttrMap ->
                     (Map Ident [Ident]) ->
                     VisitSourceMap ->
                     VisitAttrMap ->
                     VisitEnv ->
                     ([Ident]) ->
                     Bool ->
                     (Set Ident) ->
                     (Env QIdent (QIdent, QIdent)) ->
                     ClausesEnv ->
                     DataSemEnv ->
                     DefsEnv ->
                     NontermEnv ->
                     DefsEnv ->
                     (Env Ident ()) ->
                     ([(Int,PP_Doc)]) ->
                     Int ->
                     QIdent ->
                     ([(Int,PP_Doc)]) ->
                     Int ->
                     (Map Ident String) ->
                     Pos ->
                     (Map Ident (Maybe Ident)) ->
                     ([Ident]) ->
                     QIdent ->
                     Opts ->
                     DepItem ->
                     Reason ->
                     QIdent ->
                     DepItem ->
                     Ident ->
                     DepItem ->
                     DepItem ->
                     Reason ->
                     Int ->
                     Bool ->
                     ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set Ident),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,(Set Ident),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,AttrSourceMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,(IntMap Ident),(Map Ident (Map Ident String)),(Seq DepItem),(Env Ident ()),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,Int,(Map Ident (Set Ident)),Int,([PP_Doc]))
sem_ClausesTop_Impl :: Clauses ->
                       T_ClausesTop 
sem_ClausesTop_Impl clauses_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let actual_val_ :: ClausesTop 
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathClauseNames :: (Set Ident)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOnClauses :: Int
              _lhsOpps :: ([PP_Doc])
              _actualOallAvailInvokes :: (Map Ident (Set Ident))
              _actualOallVisits :: (Set Ident)
              _actualOallowCycVisits :: (Set Ident)
              _actualOavailInvokes :: (Map Ident (Set Ident))
              _actualObasename :: QIdent
              _actualOclauseExtras :: (Map Ident Stmts)
              _actualOcoItf :: Ident
              _actualOcodeIdCounter :: Int
              _actualOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _actualOdirectVisitLocalAttrs :: (Map Ident String)
              _actualOdistAliasses :: (Map Ident AliasType)
              _actualOdistAllChildMinRanges :: (Map Ident [Ident])
              _actualOdistAttrSource :: AttrSourceMap
              _actualOdistAttrVisMap :: AttrVisMap
              _actualOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _actualOdistChildEffRanges :: (Map Ident (Set Ident))
              _actualOdistChildMinRanges :: (Map Ident [Ident])
              _actualOdistChildOcc :: (Map Ident Int)
              _actualOdistChildSource :: ChildSourceMap
              _actualOdistCycVisMap :: CycVisMap
              _actualOdistDataCons :: ConEnv
              _actualOdistDataMap :: DataMap
              _actualOdistDataSems :: DataSemEnv
              _actualOdistDatas :: DataEnv
              _actualOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _actualOdistDefs :: DefsEnv
              _actualOdistInhAttrs :: AttrMap
              _actualOdistItfs :: ItfEnv
              _actualOdistNextVisits :: (Map Ident (Maybe Ident))
              _actualOdistRanks :: (Map DepItem (Bool,Int))
              _actualOdistRenames :: RenameMap
              _actualOdistSynAttrs :: AttrMap
              _actualOdistVisLocalDefs :: DefsEnv
              _actualOdistVisRankMap :: (IntMap Ident)
              _actualOdistVisitInhAttrs :: VisitAttrMap
              _actualOdistVisitOrder :: (Map Ident [Ident])
              _actualOdistVisitSource :: VisitSourceMap
              _actualOdistVisitSynAttrs :: VisitAttrMap
              _actualOdistVisits :: VisitEnv
              _actualOdoneVisits :: ([Ident])
              _actualOfullCyclic :: Bool
              _actualOfullCyclicVisits :: (Set Ident)
              _actualOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _actualOgathClauses :: ClausesEnv
              _actualOgathDataSems :: DataSemEnv
              _actualOgathDefs :: DefsEnv
              _actualOgathNonterms :: NontermEnv
              _actualOgathVisLocalDefs :: DefsEnv
              _actualOgathVisitNames :: (Env Ident ())
              _actualOhSpilledStmts :: ([(Int,PP_Doc)])
              _actualOindent :: Int
              _actualOitf :: QIdent
              _actualOjsSpilledStmts :: ([(Int,PP_Doc)])
              _actualOlexCounter :: Int
              _actualOlocalAttrs :: (Map Ident String)
              _actualOmasterPos :: Pos
              _actualOmyNextVisits :: (Map Ident (Maybe Ident))
              _actualOnextVisits :: ([Ident])
              _actualOnonterm :: QIdent
              _actualOopts :: Opts
              _actualOscopeDep :: DepItem
              _actualOscopeReason :: Reason
              _actualOsemBasename :: QIdent
              _actualOstmtSource :: DepItem
              _actualOvisit :: Ident
              _actualOvisitBeginDep :: DepItem
              _actualOvisitEndDep :: DepItem
              _actualOvisitEndReason :: Reason
              _actualOvisitNr :: Int
              _actualOwithinCoSem :: Bool
              _actualIallReqInvokes :: (Map Ident (Set Ident))
              _actualIbannedInvokes :: (Map Ident (Set Ident))
              _actualIcodeIdCounter :: Int
              _actualIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _actualIdistDataCons :: ConEnv
              _actualIdistDataSems :: DataSemEnv
              _actualIdistDatas :: DataEnv
              _actualIdistDefs :: DefsEnv
              _actualIdistItfs :: ItfEnv
              _actualIdistVisLocalDefs :: DefsEnv
              _actualIdistVisits :: VisitEnv
              _actualIerrs0 :: Errs
              _actualIerrs1 :: Errs
              _actualIerrs2 :: Errs
              _actualIerrs3 :: Errs
              _actualIerrs4 :: Errs
              _actualIerrs5 :: Errs
              _actualIgathAllowCycVisits :: (Set Ident)
              _actualIgathAttrSource :: AttrSourceMap
              _actualIgathAvoidVisits :: (Set DepItem)
              _actualIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _actualIgathChildSource :: ChildSourceMap
              _actualIgathClauseNames :: (Set Ident)
              _actualIgathClauses :: ClausesEnv
              _actualIgathDataSems :: DataSemEnv
              _actualIgathDefs :: DefsEnv
              _actualIgathDeps :: Deps
              _actualIgathItemVisits :: (Map DepItem DepItem)
              _actualIgathLegalCycStmts :: (Set DepItem)
              _actualIgathMissingInvokes :: (Set (Ident,Ident))
              _actualIgathNonterms :: NontermEnv
              _actualIgathSemAttrSource :: AttrSourceMap
              _actualIgathSemStarts :: (Seq DepItem)
              _actualIgathStmtPosMap :: (Map DepItem Pos)
              _actualIgathVisLocalDefs :: DefsEnv
              _actualIgathVisRankMap :: (IntMap Ident)
              _actualIgathVisitAttrs :: (Map Ident (Map Ident String))
              _actualIgathVisitEnds :: (Seq DepItem)
              _actualIgathVisitNames :: (Env Ident ())
              _actualIgathVisitSource :: VisitSourceMap
              _actualIgathVisitStarts :: (Seq DepItem)
              _actualIhpp :: PP_Doc
              _actualIjspp :: PP_Doc
              _actualIlexCounter :: Int
              _actualIminRank :: Int
              _actualIminReqInvokes :: (Map Ident (Set Ident))
              _actualInClauses :: Int
              _actualIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 789, column 7)
              _pos =
                  ({-# LINE 789 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 18326 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 790, column 7)
              _name =
                  ({-# LINE 790 "src/Transform.ag" #-}
                   mkClauseName _pos     (Ident "impl" _pos    ) _lhsIbasename
                   {-# LINE 18331 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 793, column 7)
              actual_val_ =
                  ({-# LINE 793 "src/Transform.ag" #-}
                   if null clauses_
                   then ClausesTop_Top [Clause_Clause _pos     _name     [] SemVisit_Impl ]
                   else ClausesTop_Top clauses_
                   {-# LINE 18338 "src/Transform.hs" #-})
              actual_inst_ =
                  (sem_ClausesTop actual_val_ )
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _actualIallReqInvokes
                   {-# LINE 18345 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _actualIbannedInvokes
                   {-# LINE 18350 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs0
                   {-# LINE 18355 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs1
                   {-# LINE 18360 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs2
                   {-# LINE 18365 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs3
                   {-# LINE 18370 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs4
                   {-# LINE 18375 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs5
                   {-# LINE 18380 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _actualIgathAllowCycVisits
                   {-# LINE 18385 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _actualIgathAttrSource
                   {-# LINE 18390 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _actualIgathAvoidVisits
                   {-# LINE 18395 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _actualIgathChildSource
                   {-# LINE 18400 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 263, column 54)
              _lhsOgathClauseNames =
                  ({-# LINE 263 "src/Transform.ag" #-}
                   _actualIgathClauseNames
                   {-# LINE 18405 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _actualIgathDeps
                   {-# LINE 18410 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _actualIgathItemVisits
                   {-# LINE 18415 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _actualIgathLegalCycStmts
                   {-# LINE 18420 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _actualIgathMissingInvokes
                   {-# LINE 18425 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _actualIgathSemAttrSource
                   {-# LINE 18430 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _actualIgathSemStarts
                   {-# LINE 18435 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _actualIgathStmtPosMap
                   {-# LINE 18440 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _actualIgathVisRankMap
                   {-# LINE 18445 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _actualIgathVisitAttrs
                   {-# LINE 18450 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _actualIgathVisitEnds
                   {-# LINE 18455 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _actualIgathVisitSource
                   {-# LINE 18460 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _actualIgathVisitStarts
                   {-# LINE 18465 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   _actualIminRank
                   {-# LINE 18470 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _actualIminReqInvokes
                   {-# LINE 18475 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _actualIcodeIdCounter
                   {-# LINE 18480 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _actualIdistChildDefs
                   {-# LINE 18485 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _actualIdistDataCons
                   {-# LINE 18490 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _actualIdistDataSems
                   {-# LINE 18495 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _actualIdistDatas
                   {-# LINE 18500 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIdistDefs
                   {-# LINE 18505 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _actualIdistItfs
                   {-# LINE 18510 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIdistVisLocalDefs
                   {-# LINE 18515 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _actualIdistVisits
                   {-# LINE 18520 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _actualIgathChildDefs
                   {-# LINE 18525 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _actualIgathClauses
                   {-# LINE 18530 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _actualIgathDataSems
                   {-# LINE 18535 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIgathDefs
                   {-# LINE 18540 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _actualIgathNonterms
                   {-# LINE 18545 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIgathVisLocalDefs
                   {-# LINE 18550 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _actualIgathVisitNames
                   {-# LINE 18555 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOhpp =
                  ({-# LINE 75 "src/TargetHaskell.ag" #-}
                   _actualIhpp
                   {-# LINE 18560 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOjspp =
                  ({-# LINE 35 "src/TargetJs.ag" #-}
                   _actualIjspp
                   {-# LINE 18565 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _actualIlexCounter
                   {-# LINE 18570 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOnClauses =
                  ({-# LINE 1972 "src/Transform.ag" #-}
                   _actualInClauses
                   {-# LINE 18575 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpps =
                  ({-# LINE 2618 "src/Transform.ag" #-}
                   _actualIpps
                   {-# LINE 18580 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 18585 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 18590 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 18595 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 18600 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 18605 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 18610 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 18615 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 18620 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 18625 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 18630 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 18635 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 18640 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 18645 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 18650 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 18655 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 18660 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 18665 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 18670 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 18675 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 18680 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 18685 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 18690 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 18695 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 18700 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 18705 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 18710 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 18715 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 18720 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 18725 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 18730 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 18735 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 18740 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 18745 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 18750 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 18755 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 18760 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 18765 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 18770 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 18775 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 18780 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 18785 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 18790 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 18795 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 18800 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 18805 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 18810 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 18815 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 18820 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 18825 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 18830 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 18835 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 18840 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 18845 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 18850 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 18855 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 18860 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 18865 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 18870 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 18875 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 18880 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 18885 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 18890 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 18895 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 18900 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 18905 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 18910 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 18915 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 18920 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 18925 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 18930 "src/Transform.hs" #-})
              ( _actualIallReqInvokes,_actualIbannedInvokes,_actualIcodeIdCounter,_actualIdistChildDefs,_actualIdistDataCons,_actualIdistDataSems,_actualIdistDatas,_actualIdistDefs,_actualIdistItfs,_actualIdistVisLocalDefs,_actualIdistVisits,_actualIerrs0,_actualIerrs1,_actualIerrs2,_actualIerrs3,_actualIerrs4,_actualIerrs5,_actualIgathAllowCycVisits,_actualIgathAttrSource,_actualIgathAvoidVisits,_actualIgathChildDefs,_actualIgathChildSource,_actualIgathClauseNames,_actualIgathClauses,_actualIgathDataSems,_actualIgathDefs,_actualIgathDeps,_actualIgathItemVisits,_actualIgathLegalCycStmts,_actualIgathMissingInvokes,_actualIgathNonterms,_actualIgathSemAttrSource,_actualIgathSemStarts,_actualIgathStmtPosMap,_actualIgathVisLocalDefs,_actualIgathVisRankMap,_actualIgathVisitAttrs,_actualIgathVisitEnds,_actualIgathVisitNames,_actualIgathVisitSource,_actualIgathVisitStarts,_actualIhpp,_actualIjspp,_actualIlexCounter,_actualIminRank,_actualIminReqInvokes,_actualInClauses,_actualIpps) =
                  actual_inst_ _actualOallAvailInvokes _actualOallVisits _actualOallowCycVisits _actualOavailInvokes _actualObasename _actualOclauseExtras _actualOcoItf _actualOcodeIdCounter _actualOdirectVisitAttrs _actualOdirectVisitLocalAttrs _actualOdistAliasses _actualOdistAllChildMinRanges _actualOdistAttrSource _actualOdistAttrVisMap _actualOdistChildDefs _actualOdistChildEffRanges _actualOdistChildMinRanges _actualOdistChildOcc _actualOdistChildSource _actualOdistCycVisMap _actualOdistDataCons _actualOdistDataMap _actualOdistDataSems _actualOdistDatas _actualOdistDeflStmts _actualOdistDefs _actualOdistInhAttrs _actualOdistItfs _actualOdistNextVisits _actualOdistRanks _actualOdistRenames _actualOdistSynAttrs _actualOdistVisLocalDefs _actualOdistVisRankMap _actualOdistVisitInhAttrs _actualOdistVisitOrder _actualOdistVisitSource _actualOdistVisitSynAttrs _actualOdistVisits _actualOdoneVisits _actualOfullCyclic _actualOfullCyclicVisits _actualOgathChildDefs _actualOgathClauses _actualOgathDataSems _actualOgathDefs _actualOgathNonterms _actualOgathVisLocalDefs _actualOgathVisitNames _actualOhSpilledStmts _actualOindent _actualOitf _actualOjsSpilledStmts _actualOlexCounter _actualOlocalAttrs _actualOmasterPos _actualOmyNextVisits _actualOnextVisits _actualOnonterm _actualOopts _actualOscopeDep _actualOscopeReason _actualOsemBasename _actualOstmtSource _actualOvisit _actualOvisitBeginDep _actualOvisitEndDep _actualOvisitEndReason _actualOvisitNr _actualOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauseNames,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminRank,_lhsOminReqInvokes,_lhsOnClauses,_lhsOpps)))
sem_ClausesTop_Top :: T_Clauses  ->
                      T_ClausesTop 
sem_ClausesTop_Top clauses_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathClauseNames :: (Set Ident)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOnClauses :: Int
              _lhsOpps :: ([PP_Doc])
              _clausesOallAvailInvokes :: (Map Ident (Set Ident))
              _clausesOallVisits :: (Set Ident)
              _clausesOallowCycVisits :: (Set Ident)
              _clausesOavailInvokes :: (Map Ident (Set Ident))
              _clausesObasename :: QIdent
              _clausesOclauseExtras :: (Map Ident Stmts)
              _clausesOcoItf :: Ident
              _clausesOcodeIdCounter :: Int
              _clausesOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _clausesOdirectVisitLocalAttrs :: (Map Ident String)
              _clausesOdistAliasses :: (Map Ident AliasType)
              _clausesOdistAllChildMinRanges :: (Map Ident [Ident])
              _clausesOdistAttrSource :: AttrSourceMap
              _clausesOdistAttrVisMap :: AttrVisMap
              _clausesOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesOdistChildEffRanges :: (Map Ident (Set Ident))
              _clausesOdistChildMinRanges :: (Map Ident [Ident])
              _clausesOdistChildOcc :: (Map Ident Int)
              _clausesOdistChildSource :: ChildSourceMap
              _clausesOdistCycVisMap :: CycVisMap
              _clausesOdistDataCons :: ConEnv
              _clausesOdistDataMap :: DataMap
              _clausesOdistDataSems :: DataSemEnv
              _clausesOdistDatas :: DataEnv
              _clausesOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _clausesOdistDefs :: DefsEnv
              _clausesOdistInhAttrs :: AttrMap
              _clausesOdistItfs :: ItfEnv
              _clausesOdistNextVisits :: (Map Ident (Maybe Ident))
              _clausesOdistRanks :: (Map DepItem (Bool,Int))
              _clausesOdistRenames :: RenameMap
              _clausesOdistSynAttrs :: AttrMap
              _clausesOdistVisLocalDefs :: DefsEnv
              _clausesOdistVisRankMap :: (IntMap Ident)
              _clausesOdistVisitInhAttrs :: VisitAttrMap
              _clausesOdistVisitOrder :: (Map Ident [Ident])
              _clausesOdistVisitSource :: VisitSourceMap
              _clausesOdistVisitSynAttrs :: VisitAttrMap
              _clausesOdistVisits :: VisitEnv
              _clausesOdoneVisits :: ([Ident])
              _clausesOfullCyclic :: Bool
              _clausesOfullCyclicVisits :: (Set Ident)
              _clausesOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesOgathClauses :: ClausesEnv
              _clausesOgathDataSems :: DataSemEnv
              _clausesOgathDefs :: DefsEnv
              _clausesOgathNonterms :: NontermEnv
              _clausesOgathVisLocalDefs :: DefsEnv
              _clausesOgathVisitNames :: (Env Ident ())
              _clausesOhSpilledStmts :: ([(Int,PP_Doc)])
              _clausesOindent :: Int
              _clausesOitf :: QIdent
              _clausesOjsSpilledStmts :: ([(Int,PP_Doc)])
              _clausesOlexCounter :: Int
              _clausesOlocalAttrs :: (Map Ident String)
              _clausesOmasterPos :: Pos
              _clausesOmyNextVisits :: (Map Ident (Maybe Ident))
              _clausesOnextVisits :: ([Ident])
              _clausesOnonterm :: QIdent
              _clausesOopts :: Opts
              _clausesOscopeDep :: DepItem
              _clausesOscopeReason :: Reason
              _clausesOsemBasename :: QIdent
              _clausesOstmtSource :: DepItem
              _clausesOvisit :: Ident
              _clausesOvisitBeginDep :: DepItem
              _clausesOvisitEndDep :: DepItem
              _clausesOvisitEndReason :: Reason
              _clausesOvisitNr :: Int
              _clausesOwithinCoSem :: Bool
              _clausesIallReqInvokes :: (Map Ident (Set Ident))
              _clausesIbannedInvokes :: (Map Ident (Set Ident))
              _clausesIcodeIdCounter :: Int
              _clausesIcommonInvokes :: ([Map Ident (Set Ident)])
              _clausesIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesIdistDataCons :: ConEnv
              _clausesIdistDataSems :: DataSemEnv
              _clausesIdistDatas :: DataEnv
              _clausesIdistDefs :: DefsEnv
              _clausesIdistItfs :: ItfEnv
              _clausesIdistVisLocalDefs :: DefsEnv
              _clausesIdistVisits :: VisitEnv
              _clausesIerrs0 :: Errs
              _clausesIerrs1 :: Errs
              _clausesIerrs2 :: Errs
              _clausesIerrs3 :: Errs
              _clausesIerrs4 :: Errs
              _clausesIerrs5 :: Errs
              _clausesIexplInvokes :: (Map Ident (Set Ident))
              _clausesIgathAllowCycVisits :: (Set Ident)
              _clausesIgathAttrSource :: AttrSourceMap
              _clausesIgathAvoidVisits :: (Set DepItem)
              _clausesIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesIgathChildSource :: ChildSourceMap
              _clausesIgathClauseNames :: (Set Ident)
              _clausesIgathClauses :: ClausesEnv
              _clausesIgathDataSems :: DataSemEnv
              _clausesIgathDefs :: DefsEnv
              _clausesIgathDefsAdds :: ([DefsEnv])
              _clausesIgathDeps :: Deps
              _clausesIgathItemVisits :: (Map DepItem DepItem)
              _clausesIgathLegalCycStmts :: (Set DepItem)
              _clausesIgathMissingInvokes :: (Set (Ident,Ident))
              _clausesIgathNonterms :: NontermEnv
              _clausesIgathSemAttrSource :: AttrSourceMap
              _clausesIgathSemStarts :: (Seq DepItem)
              _clausesIgathStmtPosMap :: (Map DepItem Pos)
              _clausesIgathVisLocalDefs :: DefsEnv
              _clausesIgathVisLocalDefsAdds :: ([DefsEnv])
              _clausesIgathVisRankMap :: (IntMap Ident)
              _clausesIgathVisitAttrs :: (Map Ident (Map Ident String))
              _clausesIgathVisitEnds :: (Seq DepItem)
              _clausesIgathVisitNames :: (Env Ident ())
              _clausesIgathVisitSource :: VisitSourceMap
              _clausesIgathVisitStarts :: (Seq DepItem)
              _clausesIhpp :: PP_Doc
              _clausesIjspp :: PP_Doc
              _clausesIlexCounter :: Int
              _clausesIminRank :: Int
              _clausesIminReqInvokes :: (Map Ident (Set Ident))
              _clausesInClauses :: Int
              _clausesIpps :: ([PP_Doc])
              -- augmented rule
              _lhsObannedInvokes =
                  ({-# LINE 1651 "src/Transform.ag" #-}
                   foldr ($) _bannedInvokes_augmented_syn [_bannedInvokes_augmented_f1]
                   {-# LINE 19181 "src/Transform.hs" #-})
              -- augment function
              _bannedInvokes_augmented_f1 =
                  ({-# LINE 1651 "src/Transform.ag" #-}
                   _clausesIexplInvokes `unionWithUnion`
                   {-# LINE 19186 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 673 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 19191 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 673 "src/Transform.ag" #-}
                   if Map.null _lhsIclauseExtras
                   then id
                   else let reqKeys = Map.keysSet _lhsIclauseExtras
                            impKeys = _clausesIgathClauseNames
                            diffSet = (impKeys `Set.difference` reqKeys) `Set.union` (reqKeys `Set.difference` impKeys)
                            diff = Set.elems diffSet
                            errs = map (\nm -> Err_MissingClause (head _lhsIitf) nm) diff
                        in (Seq.fromList errs Seq.><)
                   {-# LINE 19203 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1075 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 19208 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1075 "src/Transform.ag" #-}
                   push (strip $ intersection _clausesIgathDefsAdds)
                   {-# LINE 19213 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisLocalDefs =
                  ({-# LINE 1076 "src/Transform.ag" #-}
                   foldr ($) _gathVisLocalDefs_augmented_syn [_gathVisLocalDefs_augmented_f1]
                   {-# LINE 19218 "src/Transform.hs" #-})
              -- augment function
              _gathVisLocalDefs_augmented_f1 =
                  ({-# LINE 1076 "src/Transform.ag" #-}
                   push (strip $ intersection _clausesIgathVisLocalDefsAdds)
                   {-# LINE 19223 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1663, column 3)
              _lhsOminReqInvokes =
                  ({-# LINE 1663 "src/Transform.ag" #-}
                   intersectionsInvoke (_clausesIminReqInvokes : _clausesIcommonInvokes)
                   {-# LINE 19228 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _clausesIallReqInvokes
                   {-# LINE 19233 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _bannedInvokes_augmented_syn =
                  ({-# LINE 1651 "src/Transform.ag" #-}
                   _clausesIbannedInvokes
                   {-# LINE 19238 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 673 "src/Transform.ag" #-}
                   _clausesIerrs0
                   {-# LINE 19243 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs1
                   {-# LINE 19248 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs2
                   {-# LINE 19253 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs3
                   {-# LINE 19258 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs4
                   {-# LINE 19263 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs5
                   {-# LINE 19268 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _clausesIgathAllowCycVisits
                   {-# LINE 19273 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _clausesIgathAttrSource
                   {-# LINE 19278 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _clausesIgathAvoidVisits
                   {-# LINE 19283 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _clausesIgathChildSource
                   {-# LINE 19288 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 263, column 54)
              _lhsOgathClauseNames =
                  ({-# LINE 263 "src/Transform.ag" #-}
                   _clausesIgathClauseNames
                   {-# LINE 19293 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _clausesIgathDeps
                   {-# LINE 19298 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _clausesIgathItemVisits
                   {-# LINE 19303 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _clausesIgathLegalCycStmts
                   {-# LINE 19308 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _clausesIgathMissingInvokes
                   {-# LINE 19313 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _clausesIgathSemAttrSource
                   {-# LINE 19318 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _clausesIgathSemStarts
                   {-# LINE 19323 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _clausesIgathStmtPosMap
                   {-# LINE 19328 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _clausesIgathVisRankMap
                   {-# LINE 19333 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _clausesIgathVisitAttrs
                   {-# LINE 19338 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _clausesIgathVisitEnds
                   {-# LINE 19343 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _clausesIgathVisitSource
                   {-# LINE 19348 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _clausesIgathVisitStarts
                   {-# LINE 19353 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   _clausesIminRank
                   {-# LINE 19358 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _clausesIcodeIdCounter
                   {-# LINE 19363 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 19368 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 19373 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 19378 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 19383 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistDefs
                   {-# LINE 19388 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 19393 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistVisLocalDefs
                   {-# LINE 19398 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 19403 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 19408 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 19413 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _clausesIgathDataSems
                   {-# LINE 19418 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathDefs_augmented_syn =
                  ({-# LINE 1075 "src/Transform.ag" #-}
                   _clausesIgathDefs
                   {-# LINE 19423 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 19428 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathVisLocalDefs_augmented_syn =
                  ({-# LINE 1076 "src/Transform.ag" #-}
                   _clausesIgathVisLocalDefs
                   {-# LINE 19433 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _clausesIgathVisitNames
                   {-# LINE 19438 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOhpp =
                  ({-# LINE 75 "src/TargetHaskell.ag" #-}
                   _clausesIhpp
                   {-# LINE 19443 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOjspp =
                  ({-# LINE 35 "src/TargetJs.ag" #-}
                   _clausesIjspp
                   {-# LINE 19448 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _clausesIlexCounter
                   {-# LINE 19453 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOnClauses =
                  ({-# LINE 1972 "src/Transform.ag" #-}
                   _clausesInClauses
                   {-# LINE 19458 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpps =
                  ({-# LINE 2618 "src/Transform.ag" #-}
                   _clausesIpps
                   {-# LINE 19463 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 19468 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 19473 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 19478 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 19483 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 19488 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 19493 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 19498 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 19503 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 19508 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 19513 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 19518 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 19523 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 19528 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 19533 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 19538 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 19543 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 19548 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 19553 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 19558 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 19563 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 19568 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 19573 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 19578 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 19583 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 19588 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 19593 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 19598 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 19603 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 19608 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 19613 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 19618 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 19623 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 19628 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 19633 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 19638 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 19643 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 19648 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 19653 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 19658 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 19663 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 19668 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 19673 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 19678 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 19683 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 19688 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 19693 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 19698 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 19703 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 19708 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 19713 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 19718 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 19723 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 19728 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 19733 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 19738 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 19743 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 19748 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 19753 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 19758 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 19763 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 19768 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 19773 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 19778 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 19783 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 19788 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 19793 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 19798 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 19803 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 19808 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 19813 "src/Transform.hs" #-})
              ( _clausesIallReqInvokes,_clausesIbannedInvokes,_clausesIcodeIdCounter,_clausesIcommonInvokes,_clausesIdistChildDefs,_clausesIdistDataCons,_clausesIdistDataSems,_clausesIdistDatas,_clausesIdistDefs,_clausesIdistItfs,_clausesIdistVisLocalDefs,_clausesIdistVisits,_clausesIerrs0,_clausesIerrs1,_clausesIerrs2,_clausesIerrs3,_clausesIerrs4,_clausesIerrs5,_clausesIexplInvokes,_clausesIgathAllowCycVisits,_clausesIgathAttrSource,_clausesIgathAvoidVisits,_clausesIgathChildDefs,_clausesIgathChildSource,_clausesIgathClauseNames,_clausesIgathClauses,_clausesIgathDataSems,_clausesIgathDefs,_clausesIgathDefsAdds,_clausesIgathDeps,_clausesIgathItemVisits,_clausesIgathLegalCycStmts,_clausesIgathMissingInvokes,_clausesIgathNonterms,_clausesIgathSemAttrSource,_clausesIgathSemStarts,_clausesIgathStmtPosMap,_clausesIgathVisLocalDefs,_clausesIgathVisLocalDefsAdds,_clausesIgathVisRankMap,_clausesIgathVisitAttrs,_clausesIgathVisitEnds,_clausesIgathVisitNames,_clausesIgathVisitSource,_clausesIgathVisitStarts,_clausesIhpp,_clausesIjspp,_clausesIlexCounter,_clausesIminRank,_clausesIminReqInvokes,_clausesInClauses,_clausesIpps) =
                  clauses_ _clausesOallAvailInvokes _clausesOallVisits _clausesOallowCycVisits _clausesOavailInvokes _clausesObasename _clausesOclauseExtras _clausesOcoItf _clausesOcodeIdCounter _clausesOdirectVisitAttrs _clausesOdirectVisitLocalAttrs _clausesOdistAliasses _clausesOdistAllChildMinRanges _clausesOdistAttrSource _clausesOdistAttrVisMap _clausesOdistChildDefs _clausesOdistChildEffRanges _clausesOdistChildMinRanges _clausesOdistChildOcc _clausesOdistChildSource _clausesOdistCycVisMap _clausesOdistDataCons _clausesOdistDataMap _clausesOdistDataSems _clausesOdistDatas _clausesOdistDeflStmts _clausesOdistDefs _clausesOdistInhAttrs _clausesOdistItfs _clausesOdistNextVisits _clausesOdistRanks _clausesOdistRenames _clausesOdistSynAttrs _clausesOdistVisLocalDefs _clausesOdistVisRankMap _clausesOdistVisitInhAttrs _clausesOdistVisitOrder _clausesOdistVisitSource _clausesOdistVisitSynAttrs _clausesOdistVisits _clausesOdoneVisits _clausesOfullCyclic _clausesOfullCyclicVisits _clausesOgathChildDefs _clausesOgathClauses _clausesOgathDataSems _clausesOgathDefs _clausesOgathNonterms _clausesOgathVisLocalDefs _clausesOgathVisitNames _clausesOhSpilledStmts _clausesOindent _clausesOitf _clausesOjsSpilledStmts _clausesOlexCounter _clausesOlocalAttrs _clausesOmasterPos _clausesOmyNextVisits _clausesOnextVisits _clausesOnonterm _clausesOopts _clausesOscopeDep _clausesOscopeReason _clausesOsemBasename _clausesOstmtSource _clausesOvisit _clausesOvisitBeginDep _clausesOvisitEndDep _clausesOvisitEndReason _clausesOvisitNr _clausesOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauseNames,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminRank,_lhsOminReqInvokes,_lhsOnClauses,_lhsOpps)))
-- Code --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Code:
         child items          : Items 
-}
-- cata
sem_Code :: Code  ->
            T_Code 
sem_Code (Code_Code _items )  =
    (sem_Code_Code (sem_Items _items ) )
-- semantic domain
type T_Code  = (Map Ident (Set Ident)) ->
               (Set Ident) ->
               (Map Ident (Set Ident)) ->
               QIdent ->
               Ident ->
               Int ->
               (Map Ident (Map Ident String)) ->
               (Map Ident String) ->
               (Map Ident AliasType) ->
               (Map Ident [Ident]) ->
               AttrSourceMap ->
               AttrVisMap ->
               (Env QIdent (QIdent,QIdent)) ->
               (Map Ident (Set Ident)) ->
               (Map Ident [Ident]) ->
               (Map Ident Int) ->
               ChildSourceMap ->
               CycVisMap ->
               ConEnv ->
               DataMap ->
               DataSemEnv ->
               DataEnv ->
               (Map Ident (Bool,Maybe Int)) ->
               DefsEnv ->
               AttrMap ->
               ItfEnv ->
               (Map DepItem (Bool,Int)) ->
               RenameMap ->
               AttrMap ->
               DefsEnv ->
               VisitAttrMap ->
               (Map Ident [Ident]) ->
               VisitSourceMap ->
               VisitAttrMap ->
               VisitEnv ->
               ([Ident]) ->
               (Env QIdent (QIdent, QIdent)) ->
               ClausesEnv ->
               DataSemEnv ->
               DefsEnv ->
               NontermEnv ->
               DefsEnv ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               Opts ->
               DepItem ->
               Reason ->
               DepItem ->
               DepItem ->
               DepItem ->
               Reason ->
               ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),PP_Doc)
sem_Code_Code :: T_Items  ->
                 T_Code 
sem_Code_Code items_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _itemsOallAvailInvokes :: (Map Ident (Set Ident))
              _itemsOallVisits :: (Set Ident)
              _itemsOavailInvokes :: (Map Ident (Set Ident))
              _itemsObasename :: QIdent
              _itemsOcoItf :: Ident
              _itemsOcodeIdCounter :: Int
              _itemsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _itemsOdirectVisitLocalAttrs :: (Map Ident String)
              _itemsOdistAliasses :: (Map Ident AliasType)
              _itemsOdistAllChildMinRanges :: (Map Ident [Ident])
              _itemsOdistAttrSource :: AttrSourceMap
              _itemsOdistAttrVisMap :: AttrVisMap
              _itemsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemsOdistChildEffRanges :: (Map Ident (Set Ident))
              _itemsOdistChildMinRanges :: (Map Ident [Ident])
              _itemsOdistChildOcc :: (Map Ident Int)
              _itemsOdistChildSource :: ChildSourceMap
              _itemsOdistCycVisMap :: CycVisMap
              _itemsOdistDataCons :: ConEnv
              _itemsOdistDataMap :: DataMap
              _itemsOdistDataSems :: DataSemEnv
              _itemsOdistDatas :: DataEnv
              _itemsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _itemsOdistDefs :: DefsEnv
              _itemsOdistInhAttrs :: AttrMap
              _itemsOdistItfs :: ItfEnv
              _itemsOdistRanks :: (Map DepItem (Bool,Int))
              _itemsOdistRenames :: RenameMap
              _itemsOdistSynAttrs :: AttrMap
              _itemsOdistVisLocalDefs :: DefsEnv
              _itemsOdistVisitInhAttrs :: VisitAttrMap
              _itemsOdistVisitOrder :: (Map Ident [Ident])
              _itemsOdistVisitSource :: VisitSourceMap
              _itemsOdistVisitSynAttrs :: VisitAttrMap
              _itemsOdistVisits :: VisitEnv
              _itemsOdoneVisits :: ([Ident])
              _itemsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemsOgathClauses :: ClausesEnv
              _itemsOgathDataSems :: DataSemEnv
              _itemsOgathDefs :: DefsEnv
              _itemsOgathNonterms :: NontermEnv
              _itemsOgathVisLocalDefs :: DefsEnv
              _itemsOhSpilledStmts :: ([(Int,PP_Doc)])
              _itemsOindent :: Int
              _itemsOitf :: QIdent
              _itemsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _itemsOlexCounter :: Int
              _itemsOnonterm :: QIdent
              _itemsOopts :: Opts
              _itemsOscopeDep :: DepItem
              _itemsOscopeReason :: Reason
              _itemsOstmtSource :: DepItem
              _itemsOvisitBeginDep :: DepItem
              _itemsOvisitEndDep :: DepItem
              _itemsOvisitEndReason :: Reason
              _itemsIallReqInvokes :: (Map Ident (Set Ident))
              _itemsIcodeIdCounter :: Int
              _itemsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemsIdistDataCons :: ConEnv
              _itemsIdistDataSems :: DataSemEnv
              _itemsIdistDatas :: DataEnv
              _itemsIdistDefs :: DefsEnv
              _itemsIdistItfs :: ItfEnv
              _itemsIdistVisLocalDefs :: DefsEnv
              _itemsIdistVisits :: VisitEnv
              _itemsIerrs0 :: Errs
              _itemsIerrs1 :: Errs
              _itemsIerrs2 :: Errs
              _itemsIerrs3 :: Errs
              _itemsIerrs4 :: Errs
              _itemsIerrs5 :: Errs
              _itemsIgathAvoidVisits :: (Set DepItem)
              _itemsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemsIgathClauses :: ClausesEnv
              _itemsIgathDataSems :: DataSemEnv
              _itemsIgathDefs :: DefsEnv
              _itemsIgathDeps :: Deps
              _itemsIgathItemVisits :: (Map DepItem DepItem)
              _itemsIgathLegalCycStmts :: (Set DepItem)
              _itemsIgathMissingInvokes :: (Set (Ident,Ident))
              _itemsIgathNonterms :: NontermEnv
              _itemsIgathSemStarts :: (Seq DepItem)
              _itemsIgathStmtPosMap :: (Map DepItem Pos)
              _itemsIgathVisLocalDefs :: DefsEnv
              _itemsIgathVisitEnds :: (Seq DepItem)
              _itemsIgathVisitStarts :: (Seq DepItem)
              _itemsIhpps :: ([PP_Doc])
              _itemsIjspps :: ([PP_Doc])
              _itemsIlexCounter :: Int
              _itemsIminReqInvokes :: (Map Ident (Set Ident))
              _itemsIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2467, column 18)
              _lhsOpp =
                  ({-# LINE 2467 "src/Transform.ag" #-}
                   vlist _itemsIpps
                   {-# LINE 20153 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 211, column 18)
              _lhsOhpp =
                  ({-# LINE 211 "src/TargetHaskell.ag" #-}
                   vlist _itemsIhpps
                   {-# LINE 20158 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 141, column 18)
              _lhsOjspp =
                  ({-# LINE 141 "src/TargetJs.ag" #-}
                   vlist _itemsIjspps
                   {-# LINE 20163 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemsIallReqInvokes
                   {-# LINE 20168 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs0
                   {-# LINE 20173 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs1
                   {-# LINE 20178 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs2
                   {-# LINE 20183 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs3
                   {-# LINE 20188 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs4
                   {-# LINE 20193 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs5
                   {-# LINE 20198 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _itemsIgathAvoidVisits
                   {-# LINE 20203 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _itemsIgathDeps
                   {-# LINE 20208 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _itemsIgathItemVisits
                   {-# LINE 20213 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _itemsIgathLegalCycStmts
                   {-# LINE 20218 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _itemsIgathMissingInvokes
                   {-# LINE 20223 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _itemsIgathSemStarts
                   {-# LINE 20228 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _itemsIgathStmtPosMap
                   {-# LINE 20233 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemsIgathVisitEnds
                   {-# LINE 20238 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemsIgathVisitStarts
                   {-# LINE 20243 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemsIminReqInvokes
                   {-# LINE 20248 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _itemsIcodeIdCounter
                   {-# LINE 20253 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _itemsIdistChildDefs
                   {-# LINE 20258 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _itemsIdistDataCons
                   {-# LINE 20263 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _itemsIdistDataSems
                   {-# LINE 20268 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _itemsIdistDatas
                   {-# LINE 20273 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIdistDefs
                   {-# LINE 20278 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _itemsIdistItfs
                   {-# LINE 20283 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIdistVisLocalDefs
                   {-# LINE 20288 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _itemsIdistVisits
                   {-# LINE 20293 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _itemsIgathChildDefs
                   {-# LINE 20298 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemsIgathClauses
                   {-# LINE 20303 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _itemsIgathDataSems
                   {-# LINE 20308 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIgathDefs
                   {-# LINE 20313 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemsIgathNonterms
                   {-# LINE 20318 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIgathVisLocalDefs
                   {-# LINE 20323 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _itemsIlexCounter
                   {-# LINE 20328 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 20333 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 20338 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 20343 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 20348 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 20353 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 20358 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 20363 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 20368 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 20373 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 20378 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 20383 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 20388 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 20393 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 20398 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 20403 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 20408 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 20413 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 20418 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 20423 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 20428 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 20433 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 20438 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 20443 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 20448 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 20453 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 20458 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 20463 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 20468 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 20473 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 20478 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 20483 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 20488 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 20493 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 20498 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 20503 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 20508 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 20513 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 20518 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 20523 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 20528 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 20533 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 20538 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 20543 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 20548 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 20553 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 20558 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 20563 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 20568 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 20573 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 20578 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 20583 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 20588 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 20593 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 20598 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 20603 "src/Transform.hs" #-})
              ( _itemsIallReqInvokes,_itemsIcodeIdCounter,_itemsIdistChildDefs,_itemsIdistDataCons,_itemsIdistDataSems,_itemsIdistDatas,_itemsIdistDefs,_itemsIdistItfs,_itemsIdistVisLocalDefs,_itemsIdistVisits,_itemsIerrs0,_itemsIerrs1,_itemsIerrs2,_itemsIerrs3,_itemsIerrs4,_itemsIerrs5,_itemsIgathAvoidVisits,_itemsIgathChildDefs,_itemsIgathClauses,_itemsIgathDataSems,_itemsIgathDefs,_itemsIgathDeps,_itemsIgathItemVisits,_itemsIgathLegalCycStmts,_itemsIgathMissingInvokes,_itemsIgathNonterms,_itemsIgathSemStarts,_itemsIgathStmtPosMap,_itemsIgathVisLocalDefs,_itemsIgathVisitEnds,_itemsIgathVisitStarts,_itemsIhpps,_itemsIjspps,_itemsIlexCounter,_itemsIminReqInvokes,_itemsIpps) =
                  items_ _itemsOallAvailInvokes _itemsOallVisits _itemsOavailInvokes _itemsObasename _itemsOcoItf _itemsOcodeIdCounter _itemsOdirectVisitAttrs _itemsOdirectVisitLocalAttrs _itemsOdistAliasses _itemsOdistAllChildMinRanges _itemsOdistAttrSource _itemsOdistAttrVisMap _itemsOdistChildDefs _itemsOdistChildEffRanges _itemsOdistChildMinRanges _itemsOdistChildOcc _itemsOdistChildSource _itemsOdistCycVisMap _itemsOdistDataCons _itemsOdistDataMap _itemsOdistDataSems _itemsOdistDatas _itemsOdistDeflStmts _itemsOdistDefs _itemsOdistInhAttrs _itemsOdistItfs _itemsOdistRanks _itemsOdistRenames _itemsOdistSynAttrs _itemsOdistVisLocalDefs _itemsOdistVisitInhAttrs _itemsOdistVisitOrder _itemsOdistVisitSource _itemsOdistVisitSynAttrs _itemsOdistVisits _itemsOdoneVisits _itemsOgathChildDefs _itemsOgathClauses _itemsOgathDataSems _itemsOgathDefs _itemsOgathNonterms _itemsOgathVisLocalDefs _itemsOhSpilledStmts _itemsOindent _itemsOitf _itemsOjsSpilledStmts _itemsOlexCounter _itemsOnonterm _itemsOopts _itemsOscopeDep _itemsOscopeReason _itemsOstmtSource _itemsOvisitBeginDep _itemsOvisitEndDep _itemsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
-- Con ---------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         data                 : Ident
         distAliasses         : Map Ident AliasType
         isFirst              : Bool
         opts                 : Opts
         vars                 : [Ident]
      chained attributes:
         distDatas            : DataEnv
         gathDataCons         : ConEnv
         gathVarsEnv          : VarsEnv
         nr                   : Int
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathConMap           : ConMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Con:
         child pos            : {Pos}
         child name           : {Ident}
         child vars           : Vars 
         child fields         : Fields 
         visit 0:
            local errs0_augmented_f1 : _
            local gathDataCons_augmented_f1 : _
            local conItfNm    : _
            local deconItfNm  : _
            local allVarNms   : _
            local allVars     : _
            local constr      : _
            local deconstr    : _
            local constrSem   : _
            local deconstrSem : _
            local prefix      : _
            local hVarsPP     : _
            local errs0_augmented_syn : _
            local gathDataCons_augmented_syn : _
-}
-- cata
sem_Con :: Con  ->
           T_Con 
sem_Con (Con_Con _pos _name _vars _fields )  =
    (sem_Con_Con _pos _name (sem_Vars _vars ) (sem_Fields _fields ) )
-- semantic domain
type T_Con  = Ident ->
              (Map Ident AliasType) ->
              DataEnv ->
              ConEnv ->
              VarsEnv ->
              Bool ->
              Int ->
              Opts ->
              ([Ident]) ->
              ( DataEnv,Errs,Errs,Errs,Errs,Errs,Errs,Blocks,ConMap,ConEnv,VarsEnv,PP_Doc,PP_Doc,Int,PP_Doc)
sem_Con_Con :: Pos ->
               Ident ->
               T_Vars  ->
               T_Fields  ->
               T_Con 
sem_Con_Con pos_ name_ vars_ fields_  =
    (\ _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathDataCons
       _lhsIgathVarsEnv
       _lhsIisFirst
       _lhsInr
       _lhsIopts
       _lhsIvars ->
         (let _lhsOerrs0 :: Errs
              _lhsOgathDataCons :: ConEnv
              _fieldsOcon :: Ident
              _fieldsOgathFields :: FieldEnv
              _fieldsOnr :: Int
              _lhsOgathConMap :: ConMap
              _lhsOextraBlocks :: Blocks
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOdistDatas :: DataEnv
              _lhsOgathVarsEnv :: VarsEnv
              _lhsOnr :: Int
              _varsOgathVarsEnv :: VarsEnv
              _fieldsOdata :: Ident
              _fieldsOdistAliasses :: (Map Ident AliasType)
              _fieldsOdistDatas :: DataEnv
              _fieldsOopts :: Opts
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _fieldsIdistDatas :: DataEnv
              _fieldsIgathFieldMap :: FieldMap
              _fieldsIgathFields :: FieldEnv
              _fieldsIhpps :: ([PP_Doc])
              _fieldsIjsChecksPPs :: ([PP_Doc])
              _fieldsIjspps :: ([PP_Doc])
              _fieldsInr :: Int
              _fieldsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 325 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 20726 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 325 "src/Transform.ag" #-}
                   addDefErrs' _fieldsIgathFields
                   {-# LINE 20731 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDataCons =
                  ({-# LINE 316 "src/Transform.ag" #-}
                   foldr ($) _gathDataCons_augmented_syn [_gathDataCons_augmented_f1]
                   {-# LINE 20736 "src/Transform.hs" #-})
              -- augment function
              _gathDataCons_augmented_f1 =
                  ({-# LINE 316 "src/Transform.ag" #-}
                   extend [name_, _lhsIdata] _fieldsIgathFields
                   {-# LINE 20741 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 297, column 18)
              _fieldsOcon =
                  ({-# LINE 297 "src/Transform.ag" #-}
                   name_
                   {-# LINE 20746 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 324, column 3)
              _fieldsOgathFields =
                  ({-# LINE 324 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 20751 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 332, column 20)
              _fieldsOnr =
                  ({-# LINE 332 "src/Transform.ag" #-}
                   1 + _lhsInr
                   {-# LINE 20756 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1390, column 20)
              _lhsOgathConMap =
                  ({-# LINE 1390 "src/Transform.ag" #-}
                   Map.singleton name_ (_lhsInr, _fieldsIgathFieldMap)
                   {-# LINE 20761 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1492, column 3)
              _lhsOextraBlocks =
                  ({-# LINE 1492 "src/Transform.ag" #-}
                   if genConNonterms _lhsIopts
                   then [_constr    , _deconstr    , _constrSem    , _deconstrSem    ]
                   else []
                   {-# LINE 20768 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1495, column 3)
              _conItfNm =
                  ({-# LINE 1495 "src/Transform.ag" #-}
                   conItf _lhsIdata name_
                   {-# LINE 20773 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1496, column 3)
              _deconItfNm =
                  ({-# LINE 1496 "src/Transform.ag" #-}
                   deconItf _lhsIdata name_
                   {-# LINE 20778 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1497, column 3)
              _allVarNms =
                  ({-# LINE 1497 "src/Transform.ag" #-}
                   sort (_lhsIvars ++ _varsIvars)
                   {-# LINE 20783 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1498, column 3)
              _allVars =
                  ({-# LINE 1498 "src/Transform.ag" #-}
                   map Var_Var _allVarNms
                   {-# LINE 20788 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1499, column 3)
              _constr =
                  ({-# LINE 1499 "src/Transform.ag" #-}
                   Block_Itf $
                   Itf_Itf pos_ _conItfNm     _allVars     [ItfVisit_Visit pos_ (Ident "construct" pos_) False []
                     ( Attr_Syn (Ident "data" pos_) (show _lhsIdata)
                     : [ Attr_Inh k (either show id t) | (k,t) <- sortAssocs $ assocs _fieldsIgathFields ] )]
                   {-# LINE 20796 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1503, column 3)
              _deconstr =
                  ({-# LINE 1503 "src/Transform.ag" #-}
                   Block_Itf $
                   Itf_Itf pos_ _deconItfNm     _allVars     [ItfVisit_Visit pos_ (Ident "deconstruct" pos_) False []
                     ( Attr_Inh (Ident "data" pos_) (show _lhsIdata)
                     : [ Attr_Syn k (either show id t) | (k,t) <- sortAssocs $ assocs _fieldsIgathFields ] )]
                   {-# LINE 20804 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1507, column 3)
              _constrSem =
                  ({-# LINE 1507 "src/Transform.ag" #-}
                   Block_Item _conItfNm     $
                     Item_Sem pos_ _conItfNm     _conItfNm     [] Nothing $
                       SemVisit_Visit pos_ (Ident "construct" pos_) False [] [] $ ClausesTop_Top [
                         Clause_Clause pos_ (Ident "dispatch" pos_) [
                           Stmt_Eval Mode_Assert
                             (Pat_Attr (Ident "lhs" pos_) (Ident "data" pos_))
                             (BoundCode_Code Bind_Fun pos_ $ Code_Code [
                               Item_Construct pos_ _lhsIdata name_
                                 [ ExprField_Field k $ Code_Code [
                                       Item_Attr pos_ (Ident "lhs" pos_) k
                                     ]
                                 | (k,_) <- assocs _fieldsIgathFields ]
                             ] ) ] SemVisit_End ]
                   {-# LINE 20821 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1520, column 3)
              _deconstrSem =
                  ({-# LINE 1520 "src/Transform.ag" #-}
                   Block_Item _deconItfNm     $
                     Item_Sem pos_ _deconItfNm     _deconItfNm     [] Nothing $
                       SemVisit_Visit pos_ (Ident "deconstruct" pos_) False [] [] $ ClausesTop_Top [
                         Clause_Clause pos_ (Ident "dispatch" pos_) [
                           Stmt_Eval Mode_Match
                             (Pat_AttrCon name_ (Ident "lhs" pos_) _lhsIdata)
                             (BoundCode_Code Bind_Fun pos_ $ Code_Code [
                                Item_Attr pos_ (Ident "lhs" pos_) (Ident "data" pos_)])
                           ] SemVisit_End ]
                   {-# LINE 20834 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2440, column 3)
              _lhsOpp =
                  ({-# LINE 2440 "src/Transform.ag" #-}
                   "con" >#< name_ >-< indent 2 (vlist _fieldsIpps)
                   {-# LINE 20839 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 174, column 3)
              _prefix =
                  ({-# LINE 174 "src/TargetHaskell.ag" #-}
                   if _lhsIisFirst then "=" else "|"
                   {-# LINE 20844 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 175, column 3)
              _lhsOhpp =
                  ({-# LINE 175 "src/TargetHaskell.ag" #-}
                   _prefix     >#< _hVarsPP     >#< hConNm _lhsIdata name_ >#< pp_block "{" "}" "," _fieldsIhpps
                   {-# LINE 20849 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 176, column 3)
              _hVarsPP =
                  ({-# LINE 176 "src/TargetHaskell.ag" #-}
                   if null _varsIvars
                   then empty
                   else "forall" >#< hlist_sp (map (text .show) _varsIvars) >#< "."
                   {-# LINE 20856 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 83, column 3)
              _lhsOjspp =
                  ({-# LINE 83 "src/TargetJs.ag" #-}
                   "function" >#<  jsConNm _lhsIdata name_
                       >#< pp_block "(" ")" "," _fieldsIjspps
                   >-< pp_braces (
                         vlist [ "this." >|< nmPP >#< "=" >#< nmPP >|< ";" | nmPP <- _fieldsIjspps ]
                         >-< vlist _fieldsIjsChecksPPs
                       )
                   >-< jsConNm _lhsIdata name_ >|< ".prototype = new " >#< show _lhsIdata >|< "();"
                   >-< jsConNm _lhsIdata name_ >|< ".prototype.constructor =" >#< jsConNm _lhsIdata name_ >|< ";"
                   {-# LINE 20868 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 325 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20873 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20878 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20883 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20888 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20893 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 20898 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _fieldsIdistDatas
                   {-# LINE 20903 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDataCons_augmented_syn =
                  ({-# LINE 316 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 20908 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _varsIgathVarsEnv
                   {-# LINE 20913 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _fieldsInr
                   {-# LINE 20918 "src/Transform.hs" #-})
              -- copy rule (down)
              _varsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 20923 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 20928 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 20933 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 20938 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 20943 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _fieldsIdistDatas,_fieldsIgathFieldMap,_fieldsIgathFields,_fieldsIhpps,_fieldsIjsChecksPPs,_fieldsIjspps,_fieldsInr,_fieldsIpps) =
                  fields_ _fieldsOcon _fieldsOdata _fieldsOdistAliasses _fieldsOdistDatas _fieldsOgathFields _fieldsOnr _fieldsOopts 
          in  ( _lhsOdistDatas,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathConMap,_lhsOgathDataCons,_lhsOgathVarsEnv,_lhsOhpp,_lhsOjspp,_lhsOnr,_lhsOpp)))
-- Cons --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         data                 : Ident
         distAliasses         : Map Ident AliasType
         isFirst              : Bool
         opts                 : Opts
         vars                 : [Ident]
      chained attributes:
         distDatas            : DataEnv
         gathDataCons         : ConEnv
         gathVarsEnv          : VarsEnv
         nr                   : Int
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathConMap           : ConMap
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Con 
         child tl             : Cons 
         visit 0:
            local errs1_augmented_f1 : _
            local _tup20      : {(VarsEnv,VarsEnv)}
            local _tup21      : _
            local locGathVarsEnv : _
            local errs1_augmented_syn : _
      alternative Nil:
-}
-- cata
sem_Cons :: Cons  ->
            T_Cons 
sem_Cons list  =
    (Prelude.foldr sem_Cons_Cons sem_Cons_Nil (Prelude.map sem_Con list) )
-- semantic domain
type T_Cons  = Ident ->
               (Map Ident AliasType) ->
               DataEnv ->
               ConEnv ->
               VarsEnv ->
               Bool ->
               Int ->
               Opts ->
               ([Ident]) ->
               ( DataEnv,Errs,Errs,Errs,Errs,Errs,Errs,Blocks,ConMap,ConEnv,VarsEnv,([PP_Doc]),([PP_Doc]),Int,([PP_Doc]))
sem_Cons_Cons :: T_Con  ->
                 T_Cons  ->
                 T_Cons 
sem_Cons_Cons hd_ tl_  =
    (\ _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathDataCons
       _lhsIgathVarsEnv
       _lhsIisFirst
       _lhsInr
       _lhsIopts
       _lhsIvars ->
         (let _lhsOerrs1 :: Errs
              __tup20 :: ((VarsEnv,VarsEnv))
              _hdOgathVarsEnv :: VarsEnv
              _tlOgathVarsEnv :: VarsEnv
              _lhsOgathVarsEnv :: VarsEnv
              _lhsOpps :: ([PP_Doc])
              _tlOisFirst :: Bool
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathConMap :: ConMap
              _lhsOdistDatas :: DataEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOnr :: Int
              _hdOdata :: Ident
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistDatas :: DataEnv
              _hdOgathDataCons :: ConEnv
              _hdOisFirst :: Bool
              _hdOnr :: Int
              _hdOopts :: Opts
              _hdOvars :: ([Ident])
              _tlOdata :: Ident
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistDatas :: DataEnv
              _tlOgathDataCons :: ConEnv
              _tlOnr :: Int
              _tlOopts :: Opts
              _tlOvars :: ([Ident])
              _hdIdistDatas :: DataEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIextraBlocks :: Blocks
              _hdIgathConMap :: ConMap
              _hdIgathDataCons :: ConEnv
              _hdIgathVarsEnv :: VarsEnv
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdInr :: Int
              _hdIpp :: PP_Doc
              _tlIdistDatas :: DataEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIextraBlocks :: Blocks
              _tlIgathConMap :: ConMap
              _tlIgathDataCons :: ConEnv
              _tlIgathVarsEnv :: VarsEnv
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlInr :: Int
              _tlIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 371 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 21084 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 371 "src/Transform.ag" #-}
                   addDefErrs' _locGathVarsEnv
                   {-# LINE 21089 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 369, column 3)
              __tup20 =
                  ({-# LINE 369 "src/Transform.ag" #-}
                   split _lhsIgathVarsEnv
                   {-# LINE 21094 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 369, column 3)
              (_hdOgathVarsEnv,_) =
                  ({-# LINE 369 "src/Transform.ag" #-}
                   __tup20
                   {-# LINE 21099 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 369, column 3)
              (_,_tlOgathVarsEnv) =
                  ({-# LINE 369 "src/Transform.ag" #-}
                   __tup20
                   {-# LINE 21104 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 370, column 3)
              __tup21 =
                  ({-# LINE 370 "src/Transform.ag" #-}
                   merge _hdIgathVarsEnv _tlIgathVarsEnv
                   {-# LINE 21109 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 370, column 3)
              (_lhsOgathVarsEnv,_) =
                  ({-# LINE 370 "src/Transform.ag" #-}
                   __tup21
                   {-# LINE 21114 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 370, column 3)
              (_,_locGathVarsEnv) =
                  ({-# LINE 370 "src/Transform.ag" #-}
                   __tup21
                   {-# LINE 21119 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2637, column 11)
              _lhsOpps =
                  ({-# LINE 2637 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 21124 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 186, column 18)
              _tlOisFirst =
                  ({-# LINE 186 "src/TargetHaskell.ag" #-}
                   False
                   {-# LINE 21129 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 566, column 11)
              _lhsOhpps =
                  ({-# LINE 566 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 21134 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 361, column 11)
              _lhsOjspps =
                  ({-# LINE 361 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 21139 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 21144 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 371 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 21149 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 21154 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 21159 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 21164 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 21169 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _hdIextraBlocks ++ _tlIextraBlocks
                   {-# LINE 21174 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1386, column 32)
              _lhsOgathConMap =
                  ({-# LINE 1386 "src/Transform.ag" #-}
                   _hdIgathConMap `Map.union` _tlIgathConMap
                   {-# LINE 21179 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 21184 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _tlIgathDataCons
                   {-# LINE 21189 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _tlInr
                   {-# LINE 21194 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 21199 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 21204 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 21209 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 21214 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOisFirst =
                  ({-# LINE 184 "src/TargetHaskell.ag" #-}
                   _lhsIisFirst
                   {-# LINE 21219 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _lhsInr
                   {-# LINE 21224 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 21229 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _lhsIvars
                   {-# LINE 21234 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 21239 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 21244 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 21249 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _hdIgathDataCons
                   {-# LINE 21254 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _hdInr
                   {-# LINE 21259 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 21264 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _lhsIvars
                   {-# LINE 21269 "src/Transform.hs" #-})
              ( _hdIdistDatas,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIextraBlocks,_hdIgathConMap,_hdIgathDataCons,_hdIgathVarsEnv,_hdIhpp,_hdIjspp,_hdInr,_hdIpp) =
                  hd_ _hdOdata _hdOdistAliasses _hdOdistDatas _hdOgathDataCons _hdOgathVarsEnv _hdOisFirst _hdOnr _hdOopts _hdOvars 
              ( _tlIdistDatas,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIextraBlocks,_tlIgathConMap,_tlIgathDataCons,_tlIgathVarsEnv,_tlIhpps,_tlIjspps,_tlInr,_tlIpps) =
                  tl_ _tlOdata _tlOdistAliasses _tlOdistDatas _tlOgathDataCons _tlOgathVarsEnv _tlOisFirst _tlOnr _tlOopts _tlOvars 
          in  ( _lhsOdistDatas,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathConMap,_lhsOgathDataCons,_lhsOgathVarsEnv,_lhsOhpps,_lhsOjspps,_lhsOnr,_lhsOpps)))
sem_Cons_Nil :: T_Cons 
sem_Cons_Nil  =
    (\ _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathDataCons
       _lhsIgathVarsEnv
       _lhsIisFirst
       _lhsInr
       _lhsIopts
       _lhsIvars ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathConMap :: ConMap
              _lhsOdistDatas :: DataEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathVarsEnv :: VarsEnv
              _lhsOnr :: Int
              -- "src/Transform.ag"(line 2638, column 11)
              _lhsOpps =
                  ({-# LINE 2638 "src/Transform.ag" #-}
                   []
                   {-# LINE 21305 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 567, column 11)
              _lhsOhpps =
                  ({-# LINE 567 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 21310 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 362, column 11)
              _lhsOjspps =
                  ({-# LINE 362 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 21315 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21320 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21325 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21330 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21335 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21340 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 21345 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 21350 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1386, column 32)
              _lhsOgathConMap =
                  ({-# LINE 1386 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 21355 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 21360 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 21365 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 21370 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _lhsInr
                   {-# LINE 21375 "src/Transform.hs" #-})
          in  ( _lhsOdistDatas,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathConMap,_lhsOgathDataCons,_lhsOgathVarsEnv,_lhsOhpps,_lhsOjspps,_lhsOnr,_lhsOpps)))
-- Data --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         distAliasses         : Map Ident AliasType
         opts                 : Opts
      chained attributes:
         distDatas            : DataEnv
         gathDataCons         : ConEnv
         gathDatas            : DataEnv
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathDataMap          : DataMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Data:
         child pos            : {Pos}
         child name           : {Ident}
         child vars           : Vars 
         child cons           : Cons 
         child exts           : Exts 
         visit 0:
            local errs1_augmented_f1 : _
            local gathDatas_augmented_f1 : _
            local hExts       : _
            local errs1_augmented_syn : _
            local gathDatas_augmented_syn : _
-}
-- cata
sem_Data :: Data  ->
            T_Data 
sem_Data (Data_Data _pos _name _vars _cons _exts )  =
    (sem_Data_Data _pos _name (sem_Vars _vars ) (sem_Cons _cons ) (sem_Exts _exts ) )
-- semantic domain
type T_Data  = (Map Ident AliasType) ->
               DataEnv ->
               ConEnv ->
               DataEnv ->
               Opts ->
               ( DataEnv,Errs,Errs,Errs,Errs,Errs,Errs,Blocks,ConEnv,DataMap,DataEnv,PP_Doc,PP_Doc,PP_Doc)
sem_Data_Data :: Pos ->
                 Ident ->
                 T_Vars  ->
                 T_Cons  ->
                 T_Exts  ->
                 T_Data 
sem_Data_Data pos_ name_ vars_ cons_ exts_  =
    (\ _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathDataCons
       _lhsIgathDatas
       _lhsIopts ->
         (let _lhsOerrs1 :: Errs
              _lhsOgathDatas :: DataEnv
              _consOdata :: Ident
              _consOnr :: Int
              _varsOgathVarsEnv :: VarsEnv
              _lhsOgathDataMap :: DataMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _consOisFirst :: Bool
              _lhsOjspp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOdistDatas :: DataEnv
              _lhsOgathDataCons :: ConEnv
              _consOdistAliasses :: (Map Ident AliasType)
              _consOdistDatas :: DataEnv
              _consOgathDataCons :: ConEnv
              _consOgathVarsEnv :: VarsEnv
              _consOopts :: Opts
              _consOvars :: ([Ident])
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _consIdistDatas :: DataEnv
              _consIerrs0 :: Errs
              _consIerrs1 :: Errs
              _consIerrs2 :: Errs
              _consIerrs3 :: Errs
              _consIerrs4 :: Errs
              _consIerrs5 :: Errs
              _consIextraBlocks :: Blocks
              _consIgathConMap :: ConMap
              _consIgathDataCons :: ConEnv
              _consIgathVarsEnv :: VarsEnv
              _consIhpps :: ([PP_Doc])
              _consIjspps :: ([PP_Doc])
              _consInr :: Int
              _consIpps :: ([PP_Doc])
              _extsIgathExts :: (Set Ident)
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 366 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 21486 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 366 "src/Transform.ag" #-}
                   addDefErrs' _consIgathVarsEnv
                   {-# LINE 21491 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDatas =
                  ({-# LINE 320 "src/Transform.ag" #-}
                   foldr ($) _gathDatas_augmented_syn [_gathDatas_augmented_f1]
                   {-# LINE 21496 "src/Transform.hs" #-})
              -- augment function
              _gathDatas_augmented_f1 =
                  ({-# LINE 320 "src/Transform.ag" #-}
                   extend name_ ()
                   {-# LINE 21501 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 296, column 18)
              _consOdata =
                  ({-# LINE 296 "src/Transform.ag" #-}
                   name_
                   {-# LINE 21506 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 331, column 20)
              _consOnr =
                  ({-# LINE 331 "src/Transform.ag" #-}
                   0
                   {-# LINE 21511 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 365, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 365 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 21516 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1389, column 20)
              _lhsOgathDataMap =
                  ({-# LINE 1389 "src/Transform.ag" #-}
                   Map.singleton name_ _consIgathConMap
                   {-# LINE 21521 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2437, column 3)
              _lhsOpp =
                  ({-# LINE 2437 "src/Transform.ag" #-}
                   "data" >#< name_ >-< indent 2 ( vlist _consIpps )
                   {-# LINE 21526 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 168, column 3)
              _lhsOhpp =
                  ({-# LINE 168 "src/TargetHaskell.ag" #-}
                   "data" >#< hDtNm name_ >#< hlist_sp _varsIhpps >-< indent 2 (vlist _consIhpps) >-< indent 2 _hExts
                   {-# LINE 21531 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 169, column 3)
              _hExts =
                  ({-# LINE 169 "src/TargetHaskell.ag" #-}
                   if Set.null _extsIgathExts
                   then empty
                   else "deriving" >#< pp_block "(" ")" "," [ text (show i) | i <- Set.toList _extsIgathExts ]
                   {-# LINE 21538 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 185, column 18)
              _consOisFirst =
                  ({-# LINE 185 "src/TargetHaskell.ag" #-}
                   True
                   {-# LINE 21543 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 79, column 3)
              _lhsOjspp =
                  ({-# LINE 79 "src/TargetJs.ag" #-}
                   "function" >#< show name_ >#< "() {}"
                   >-< vlist _consIjspps
                   {-# LINE 21549 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _consIerrs0
                   {-# LINE 21554 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 366 "src/Transform.ag" #-}
                   _consIerrs1
                   {-# LINE 21559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _consIerrs2
                   {-# LINE 21564 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _consIerrs3
                   {-# LINE 21569 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _consIerrs4
                   {-# LINE 21574 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _consIerrs5
                   {-# LINE 21579 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _consIextraBlocks
                   {-# LINE 21584 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _consIdistDatas
                   {-# LINE 21589 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _consIgathDataCons
                   {-# LINE 21594 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDatas_augmented_syn =
                  ({-# LINE 320 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 21599 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 21604 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 21609 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 21614 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _varsIgathVarsEnv
                   {-# LINE 21619 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 21624 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _varsIvars
                   {-# LINE 21629 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _consIdistDatas,_consIerrs0,_consIerrs1,_consIerrs2,_consIerrs3,_consIerrs4,_consIerrs5,_consIextraBlocks,_consIgathConMap,_consIgathDataCons,_consIgathVarsEnv,_consIhpps,_consIjspps,_consInr,_consIpps) =
                  cons_ _consOdata _consOdistAliasses _consOdistDatas _consOgathDataCons _consOgathVarsEnv _consOisFirst _consOnr _consOopts _consOvars 
              ( _extsIgathExts) =
                  exts_ 
          in  ( _lhsOdistDatas,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDatas,_lhsOhpp,_lhsOjspp,_lhsOpp)))
-- DataSem -----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pos                  : Pos
         pp                   : PP_Doc
   alternatives:
      alternative Sem:
         child pos            : {Pos}
         child tp             : {Ident}
         child vars           : Vars 
         child mbMonad        : {Maybe String}
         child cyclic         : {Bool}
         child stmts          : {Stmts}
         child clauses        : ClausesTop 
         visit 0:
            local distDatas_augmented_f1 : _
            local distItfs_augmented_f1 : _
            local errs0_augmented_f1 : _
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local errs3_augmented_f3 : _
            local errs3_augmented_f4 : _
            local gathDataSems_augmented_f1 : _
            local _tup22      : _
            local localChildDefs : _
            local _tup23      : _
            local localChildDefs' : _
            local consMap     : _
            inst  cons        : SemCons 
            local visits      : _
            local nextVisits  : _
            local firstVisit  : _
            local doneVisits  : _
            local gathDefsIn  : _
            local gathDefsInh : _
            local _tup24      : _
            local localDefs   : _
            local _tup25      : _
            local localVisLocalDefs : _
            local _tup26      : _
            local localDefs'  : _
            local _tup27      : _
            local localVisLocalDefs' : _
            inst  clauses     : T_SemVisit 
            local basename    : _
            local semBasename : _
            local myNextVisits : _
            local inhAttrMap  : _
            local inhAttrSource : _
            local hppType     : _
            local errs0_augmented_syn : _
            local errs1_augmented_syn : _
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local distDatas_augmented_syn : _
            local distItfs_augmented_syn : _
            local gathDataSems_augmented_syn : _
-}
-- cata
sem_DataSem :: DataSem  ->
               T_DataSem 
sem_DataSem (DataSem_Sem _pos _tp _vars _mbMonad _cyclic _stmts _clauses )  =
    (sem_DataSem_Sem _pos _tp (sem_Vars _vars ) _mbMonad _cyclic _stmts (sem_ClausesTop _clauses ) )
-- semantic domain
type T_DataSem  = (Map Ident (Set Ident)) ->
                  (Set Ident) ->
                  (Map Ident (Set Ident)) ->
                  QIdent ->
                  Ident ->
                  Int ->
                  (Map Ident (Map Ident String)) ->
                  (Map Ident String) ->
                  (Map Ident AliasType) ->
                  (Map Ident [Ident]) ->
                  AttrSourceMap ->
                  AttrVisMap ->
                  (Env QIdent (QIdent,QIdent)) ->
                  (Map Ident (Set Ident)) ->
                  (Map Ident [Ident]) ->
                  (Map Ident Int) ->
                  ChildSourceMap ->
                  CycVisMap ->
                  ConEnv ->
                  DataMap ->
                  DataSemEnv ->
                  DataEnv ->
                  (Map Ident (Bool,Maybe Int)) ->
                  DefsEnv ->
                  AttrMap ->
                  ItfEnv ->
                  (Map DepItem (Bool,Int)) ->
                  RenameMap ->
                  AttrMap ->
                  DefsEnv ->
                  VisitAttrMap ->
                  (Map Ident [Ident]) ->
                  VisitSourceMap ->
                  VisitAttrMap ->
                  VisitEnv ->
                  ([Ident]) ->
                  (Env QIdent (QIdent, QIdent)) ->
                  ClausesEnv ->
                  DataSemEnv ->
                  DefsEnv ->
                  NontermEnv ->
                  DefsEnv ->
                  ([(Int,PP_Doc)]) ->
                  Int ->
                  QIdent ->
                  ([(Int,PP_Doc)]) ->
                  Int ->
                  QIdent ->
                  Opts ->
                  DepItem ->
                  Reason ->
                  DepItem ->
                  DepItem ->
                  DepItem ->
                  Reason ->
                  ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),Pos,PP_Doc)
sem_DataSem_Sem :: Pos ->
                   Ident ->
                   T_Vars  ->
                   (Maybe String) ->
                   Bool ->
                   Stmts ->
                   T_ClausesTop  ->
                   T_DataSem 
sem_DataSem_Sem pos_ tp_ vars_ mbMonad_ cyclic_ stmts_ clauses_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathDataSems :: DataSemEnv
              _clausesOnonterm :: QIdent
              _clausesOallVisits :: (Set Ident)
              _varsOgathVarsEnv :: VarsEnv
              _clausesOitf :: QIdent
              _clausesOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesOdistRenames :: RenameMap
              _clausesOclauseExtras :: (Map Ident Stmts)
              cons_val_ :: SemCons 
              _consOitf :: QIdent
              _clausesOvisitNr :: Int
              _clausesOmasterPos :: Pos
              _clausesOgathVisitNames :: (Env Ident ())
              _clausesOgathDefs :: DefsEnv
              _clausesOgathVisLocalDefs :: DefsEnv
              _clausesOdistDefs :: DefsEnv
              _clausesOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _clausesOlocalAttrs :: (Map Ident String)
              _clausesOvisit :: Ident
              _clausesOdistChildOcc :: (Map Ident Int)
              clauses_val_ :: T_ClausesTop  ->
                              T_SemVisit 
              _clausesOwithinCoSem :: Bool
              _lhsOpos :: Pos
              _clausesOdistNextVisits :: (Map Ident (Maybe Ident))
              _clausesOdistChildMinRanges :: (Map Ident [Ident])
              _clausesOdistChildEffRanges :: (Map Ident (Set Ident))
              _clausesOavailInvokes :: (Map Ident (Set Ident))
              _clausesOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _clausesOdistVisRankMap :: (IntMap Ident)
              _clausesOfullCyclicVisits :: (Set Ident)
              _clausesOfullCyclic :: Bool
              _clausesOallowCycVisits :: (Set Ident)
              _clausesOdistAttrSource :: AttrSourceMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOlexCounter :: Int
              _clausesOallAvailInvokes :: (Map Ident (Set Ident))
              _clausesObasename :: QIdent
              _clausesOcoItf :: Ident
              _clausesOcodeIdCounter :: Int
              _clausesOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _clausesOdirectVisitLocalAttrs :: (Map Ident String)
              _clausesOdistAliasses :: (Map Ident AliasType)
              _clausesOdistAllChildMinRanges :: (Map Ident [Ident])
              _clausesOdistAttrVisMap :: AttrVisMap
              _clausesOdistChildSource :: ChildSourceMap
              _clausesOdistCycVisMap :: CycVisMap
              _clausesOdistDataCons :: ConEnv
              _clausesOdistDataMap :: DataMap
              _clausesOdistDataSems :: DataSemEnv
              _clausesOdistDatas :: DataEnv
              _clausesOdistInhAttrs :: AttrMap
              _clausesOdistItfs :: ItfEnv
              _clausesOdistRanks :: (Map DepItem (Bool,Int))
              _clausesOdistSynAttrs :: AttrMap
              _clausesOdistVisitInhAttrs :: VisitAttrMap
              _clausesOdistVisitOrder :: (Map Ident [Ident])
              _clausesOdistVisitSource :: VisitSourceMap
              _clausesOdistVisitSynAttrs :: VisitAttrMap
              _clausesOdistVisits :: VisitEnv
              _clausesOdoneVisits :: ([Ident])
              _clausesOgathClauses :: ClausesEnv
              _clausesOgathDataSems :: DataSemEnv
              _clausesOgathNonterms :: NontermEnv
              _clausesOhSpilledStmts :: ([(Int,PP_Doc)])
              _clausesOindent :: Int
              _clausesOjsSpilledStmts :: ([(Int,PP_Doc)])
              _clausesOlexCounter :: Int
              _clausesOmyNextVisits :: (Map Ident (Maybe Ident))
              _clausesOnextVisits :: ([Ident])
              _clausesOopts :: Opts
              _clausesOscopeDep :: DepItem
              _clausesOscopeReason :: Reason
              _clausesOsemBasename :: QIdent
              _clausesOstmtSource :: DepItem
              _clausesOvisitBeginDep :: DepItem
              _clausesOvisitEndDep :: DepItem
              _clausesOvisitEndReason :: Reason
              _consOallAvailInvokes :: (Map Ident (Set Ident))
              _consOallVisits :: (Set Ident)
              _consOavailInvokes :: (Map Ident (Set Ident))
              _consObasename :: QIdent
              _consOcoItf :: Ident
              _consOcodeIdCounter :: Int
              _consOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _consOdirectVisitLocalAttrs :: (Map Ident String)
              _consOdistAliasses :: (Map Ident AliasType)
              _consOdistAllChildMinRanges :: (Map Ident [Ident])
              _consOdistAttrSource :: AttrSourceMap
              _consOdistAttrVisMap :: AttrVisMap
              _consOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _consOdistChildEffRanges :: (Map Ident (Set Ident))
              _consOdistChildMinRanges :: (Map Ident [Ident])
              _consOdistChildOcc :: (Map Ident Int)
              _consOdistChildSource :: ChildSourceMap
              _consOdistCycVisMap :: CycVisMap
              _consOdistDataCons :: ConEnv
              _consOdistDataMap :: DataMap
              _consOdistDataSems :: DataSemEnv
              _consOdistDatas :: DataEnv
              _consOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _consOdistDefs :: DefsEnv
              _consOdistInhAttrs :: AttrMap
              _consOdistItfs :: ItfEnv
              _consOdistRanks :: (Map DepItem (Bool,Int))
              _consOdistRenames :: RenameMap
              _consOdistSynAttrs :: AttrMap
              _consOdistVisLocalDefs :: DefsEnv
              _consOdistVisitInhAttrs :: VisitAttrMap
              _consOdistVisitOrder :: (Map Ident [Ident])
              _consOdistVisitSource :: VisitSourceMap
              _consOdistVisitSynAttrs :: VisitAttrMap
              _consOdistVisits :: VisitEnv
              _consOdoneVisits :: ([Ident])
              _consOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _consOgathClauses :: ClausesEnv
              _consOgathDataSems :: DataSemEnv
              _consOgathDefs :: DefsEnv
              _consOgathNonterms :: NontermEnv
              _consOgathVisLocalDefs :: DefsEnv
              _consOhSpilledStmts :: ([(Int,PP_Doc)])
              _consOjsSpilledStmts :: ([(Int,PP_Doc)])
              _consOlexCounter :: Int
              _consOnonterm :: QIdent
              _consOopts :: Opts
              _consOscopeDep :: DepItem
              _consOscopeReason :: Reason
              _consOstmtSource :: DepItem
              _consOvisitBeginDep :: DepItem
              _consOvisitEndDep :: DepItem
              _consOvisitEndReason :: Reason
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _clausesIallReqInvokes :: (Map Ident (Set Ident))
              _clausesIbannedInvokes :: (Map Ident (Set Ident))
              _clausesIcodeIdCounter :: Int
              _clausesIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesIdistDataCons :: ConEnv
              _clausesIdistDataSems :: DataSemEnv
              _clausesIdistDatas :: DataEnv
              _clausesIdistDefs :: DefsEnv
              _clausesIdistItfs :: ItfEnv
              _clausesIdistVisLocalDefs :: DefsEnv
              _clausesIdistVisits :: VisitEnv
              _clausesIerrs0 :: Errs
              _clausesIerrs1 :: Errs
              _clausesIerrs2 :: Errs
              _clausesIerrs3 :: Errs
              _clausesIerrs4 :: Errs
              _clausesIerrs5 :: Errs
              _clausesIgathAllowCycVisits :: (Set Ident)
              _clausesIgathAttrSource :: AttrSourceMap
              _clausesIgathAvoidVisits :: (Set DepItem)
              _clausesIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesIgathChildSource :: ChildSourceMap
              _clausesIgathClauses :: ClausesEnv
              _clausesIgathDataSems :: DataSemEnv
              _clausesIgathDefs :: DefsEnv
              _clausesIgathDeps :: Deps
              _clausesIgathItemVisits :: (Map DepItem DepItem)
              _clausesIgathLegalCycStmts :: (Set DepItem)
              _clausesIgathMissingInvokes :: (Set (Ident,Ident))
              _clausesIgathNonterms :: NontermEnv
              _clausesIgathSemAttrSource :: AttrSourceMap
              _clausesIgathSemStarts :: (Seq DepItem)
              _clausesIgathStmtPosMap :: (Map DepItem Pos)
              _clausesIgathVisLocalDefs :: DefsEnv
              _clausesIgathVisRankMap :: (IntMap Ident)
              _clausesIgathVisitAttrs :: (Map Ident (Map Ident String))
              _clausesIgathVisitEnds :: (Seq DepItem)
              _clausesIgathVisitNames :: (Env Ident ())
              _clausesIgathVisitSource :: VisitSourceMap
              _clausesIgathVisitStarts :: (Seq DepItem)
              _clausesIhpp :: PP_Doc
              _clausesIisInternal :: Bool
              _clausesIjspp :: PP_Doc
              _clausesIlexCounter :: Int
              _clausesImbNextVisit :: (Maybe Ident)
              _clausesIminRank :: Int
              _clausesIminReqInvokes :: (Map Ident (Set Ident))
              _clausesIpp :: PP_Doc
              _consIallReqInvokes :: (Map Ident (Set Ident))
              _consIclauseExtras :: (Map Ident Stmts)
              _consIcodeIdCounter :: Int
              _consIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _consIdistDataCons :: ConEnv
              _consIdistDataSems :: DataSemEnv
              _consIdistDatas :: DataEnv
              _consIdistDefs :: DefsEnv
              _consIdistItfs :: ItfEnv
              _consIdistVisLocalDefs :: DefsEnv
              _consIdistVisits :: VisitEnv
              _consIerrs0 :: Errs
              _consIerrs1 :: Errs
              _consIerrs2 :: Errs
              _consIerrs3 :: Errs
              _consIerrs4 :: Errs
              _consIerrs5 :: Errs
              _consIgathAvoidVisits :: (Set DepItem)
              _consIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _consIgathClauses :: ClausesEnv
              _consIgathDataSems :: DataSemEnv
              _consIgathDefs :: DefsEnv
              _consIgathDeps :: Deps
              _consIgathItemVisits :: (Map DepItem DepItem)
              _consIgathLegalCycStmts :: (Set DepItem)
              _consIgathNonterms :: NontermEnv
              _consIgathSemStarts :: (Seq DepItem)
              _consIgathStmtPosMap :: (Map DepItem Pos)
              _consIgathVisLocalDefs :: DefsEnv
              _consIgathVisitEnds :: (Seq DepItem)
              _consIgathVisitStarts :: (Seq DepItem)
              _consIlexCounter :: Int
              _consIminReqInvokes :: (Map Ident (Set Ident))
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 472 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 22154 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 472 "src/Transform.ag" #-}
                   snd . find tp_ ()
                   {-# LINE 22159 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOdistItfs =
                  ({-# LINE 407 "src/Transform.ag" #-}
                   foldr ($) _distItfs_augmented_syn [_distItfs_augmented_f1]
                   {-# LINE 22164 "src/Transform.hs" #-})
              -- augment function
              _distItfs_augmented_f1 =
                  ({-# LINE 407 "src/Transform.ag" #-}
                   snd . find [tp_] ()
                   {-# LINE 22169 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 837 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 22174 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 837 "src/Transform.ag" #-}
                   addDefErrs' _clausesIgathVisitNames
                   {-# LINE 22179 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 532 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2]
                   {-# LINE 22184 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 532 "src/Transform.ag" #-}
                   addUseErrs _localChildDefs'
                   {-# LINE 22189 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 532 "src/Transform.ag" #-}
                   addDefErrs' _varsIgathVarsEnv
                   {-# LINE 22194 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 474 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 22199 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 474 "src/Transform.ag" #-}
                   if Map.member astIdent $ Map.findWithDefault Map.empty _firstVisit
                                          $ Map.findWithDefault Map.empty tp_ _lhsIdistVisitInhAttrs
                   then id
                   else (Seq.singleton (Err_Missing [replPos pos_ astIdent]) Seq.><)
                   {-# LINE 22207 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2, _errs3_augmented_f3, _errs3_augmented_f4]
                   {-# LINE 22212 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   addUseErrs'' _localVisLocalDefs'
                   {-# LINE 22217 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   addUseErrs'' _localDefs'
                   {-# LINE 22222 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f3 =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   addDefErrs'' _localVisLocalDefs
                   {-# LINE 22227 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f4 =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   addDefErrs'' _localDefs
                   {-# LINE 22232 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDataSems =
                  ({-# LINE 275 "src/Transform.ag" #-}
                   foldr ($) _gathDataSems_augmented_syn [_gathDataSems_augmented_f1]
                   {-# LINE 22237 "src/Transform.hs" #-})
              -- augment function
              _gathDataSems_augmented_f1 =
                  ({-# LINE 275 "src/Transform.ag" #-}
                   extend tp_ ()
                   {-# LINE 22242 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 248, column 22)
              _clausesOnonterm =
                  ({-# LINE 248 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 22247 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 286, column 3)
              _clausesOallVisits =
                  ({-# LINE 286 "src/Transform.ag" #-}
                   Set.union (Set.fromList _nextVisits    ) _lhsIallVisits
                   {-# LINE 22252 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 387, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 387 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 22257 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 415, column 3)
              _clausesOitf =
                  ({-# LINE 415 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 22262 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 522, column 3)
              _clausesOgathChildDefs =
                  ({-# LINE 522 "src/Transform.ag" #-}
                   extend locQIdent (locQIdent, locQIdent)
                   $ extend visQIdent (visQIdent, visQIdent)
                   $ extend lhsQIdent ([tp_], [_firstVisit    , tp_])
                   $ enter _lhsIgathChildDefs
                   {-# LINE 22270 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 526, column 3)
              __tup22 =
                  ({-# LINE 526 "src/Transform.ag" #-}
                   leave _clausesIgathChildDefs
                   {-# LINE 22275 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 526, column 3)
              (_lhsOgathChildDefs,_) =
                  ({-# LINE 526 "src/Transform.ag" #-}
                   __tup22
                   {-# LINE 22280 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 526, column 3)
              (_,_localChildDefs) =
                  ({-# LINE 526 "src/Transform.ag" #-}
                   __tup22
                   {-# LINE 22285 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 529, column 3)
              _clausesOdistChildDefs =
                  ({-# LINE 529 "src/Transform.ag" #-}
                   enterWith _localChildDefs     _lhsIdistChildDefs
                   {-# LINE 22290 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 530, column 3)
              __tup23 =
                  ({-# LINE 530 "src/Transform.ag" #-}
                   leave _clausesIdistChildDefs
                   {-# LINE 22295 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 530, column 3)
              (_lhsOdistChildDefs,_) =
                  ({-# LINE 530 "src/Transform.ag" #-}
                   __tup23
                   {-# LINE 22300 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 530, column 3)
              (_,_localChildDefs') =
                  ({-# LINE 530 "src/Transform.ag" #-}
                   __tup23
                   {-# LINE 22305 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 598, column 24)
              _clausesOdistRenames =
                  ({-# LINE 598 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22310 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 626, column 3)
              _clausesOclauseExtras =
                  ({-# LINE 626 "src/Transform.ag" #-}
                   _consIclauseExtras
                   {-# LINE 22315 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 628, column 3)
              _consMap =
                  ({-# LINE 628 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty tp_ _lhsIdistDataMap
                   {-# LINE 22320 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 631, column 3)
              cons_val_ =
                  ({-# LINE 631 "src/Transform.ag" #-}
                   [ SemCon_Con pos_ (replPos pos_ c)
                       [ SemField_Field pos_ (replPos pos_ nm) tp | (nm,tp) <- sortAssocs $ Map.assocs fs ]
                   | (c,fs) <- sortAssocs $ Map.assocs _consMap     ]
                   {-# LINE 22327 "src/Transform.hs" #-})
              cons_inst_ =
                  (sem_SemCons cons_val_ )
              -- "src/Transform.ag"(line 635, column 3)
              _consOitf =
                  ({-# LINE 635 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 22334 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 695, column 32)
              _clausesOvisitNr =
                  ({-# LINE 695 "src/Transform.ag" #-}
                   1
                   {-# LINE 22339 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 721, column 24)
              _visits =
                  ({-# LINE 721 "src/Transform.ag" #-}
                   Map.findWithDefault [] tp_ _lhsIdistVisitOrder
                   {-# LINE 22344 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 722, column 24)
              _nextVisits =
                  ({-# LINE 722 "src/Transform.ag" #-}
                   _visits
                   {-# LINE 22349 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 723, column 24)
              _firstVisit =
                  ({-# LINE 723 "src/Transform.ag" #-}
                   case _visits     of
                     []    -> Ident "unknown" pos_
                     (x:_) -> x
                   {-# LINE 22356 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 730, column 24)
              _doneVisits =
                  ({-# LINE 730 "src/Transform.ag" #-}
                   []
                   {-# LINE 22361 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 765, column 32)
              _clausesOmasterPos =
                  ({-# LINE 765 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 22366 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 836, column 23)
              _clausesOgathVisitNames =
                  ({-# LINE 836 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 22371 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1021, column 7)
              _gathDefsIn =
                  ({-# LINE 1021 "src/Transform.ag" #-}
                   enter _lhsIgathDefs
                   {-# LINE 22376 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1022, column 7)
              _clausesOgathDefs =
                  ({-# LINE 1022 "src/Transform.ag" #-}
                   _gathDefsInh
                   {-# LINE 22381 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1023, column 7)
              _clausesOgathVisLocalDefs =
                  ({-# LINE 1023 "src/Transform.ag" #-}
                   enter _lhsIgathVisLocalDefs
                   {-# LINE 22386 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1024, column 7)
              _clausesOdistDefs =
                  ({-# LINE 1024 "src/Transform.ag" #-}
                   enterWith _localDefs     _lhsIdistDefs
                   {-# LINE 22391 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1025, column 7)
              _clausesOdistVisLocalDefs =
                  ({-# LINE 1025 "src/Transform.ag" #-}
                   enterWith _localVisLocalDefs     _lhsIdistVisLocalDefs
                   {-# LINE 22396 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1027, column 7)
              _gathDefsInh =
                  ({-# LINE 1027 "src/Transform.ag" #-}
                   Map.fold (flip (Map.foldWithKey (\n t -> extend (replPos pos_ lhsIdent,replPos pos_ n,True) (Just t)))) _gathDefsIn     _inhAttrMap
                   {-# LINE 22401 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1029, column 7)
              __tup24 =
                  ({-# LINE 1029 "src/Transform.ag" #-}
                   leave _clausesIgathDefs
                   {-# LINE 22406 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1029, column 7)
              (_lhsOgathDefs,_) =
                  ({-# LINE 1029 "src/Transform.ag" #-}
                   __tup24
                   {-# LINE 22411 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1029, column 7)
              (_,_localDefs) =
                  ({-# LINE 1029 "src/Transform.ag" #-}
                   __tup24
                   {-# LINE 22416 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1030, column 7)
              __tup25 =
                  ({-# LINE 1030 "src/Transform.ag" #-}
                   leave _clausesIgathVisLocalDefs
                   {-# LINE 22421 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1030, column 7)
              (_lhsOgathVisLocalDefs,_) =
                  ({-# LINE 1030 "src/Transform.ag" #-}
                   __tup25
                   {-# LINE 22426 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1030, column 7)
              (_,_localVisLocalDefs) =
                  ({-# LINE 1030 "src/Transform.ag" #-}
                   __tup25
                   {-# LINE 22431 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1031, column 7)
              __tup26 =
                  ({-# LINE 1031 "src/Transform.ag" #-}
                   leave _clausesIdistDefs
                   {-# LINE 22436 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1031, column 7)
              (_lhsOdistDefs,_) =
                  ({-# LINE 1031 "src/Transform.ag" #-}
                   __tup26
                   {-# LINE 22441 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1031, column 7)
              (_,_localDefs') =
                  ({-# LINE 1031 "src/Transform.ag" #-}
                   __tup26
                   {-# LINE 22446 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1032, column 7)
              __tup27 =
                  ({-# LINE 1032 "src/Transform.ag" #-}
                   leave _clausesIdistVisLocalDefs
                   {-# LINE 22451 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1032, column 7)
              (_lhsOdistVisLocalDefs,_) =
                  ({-# LINE 1032 "src/Transform.ag" #-}
                   __tup27
                   {-# LINE 22456 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1032, column 7)
              (_,_localVisLocalDefs') =
                  ({-# LINE 1032 "src/Transform.ag" #-}
                   __tup27
                   {-# LINE 22461 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1100, column 23)
              _clausesOlocalAttrs =
                  ({-# LINE 1100 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22466 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1117, column 23)
              _clausesOvisit =
                  ({-# LINE 1117 "src/Transform.ag" #-}
                   tp_
                   {-# LINE 22471 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1311, column 24)
              _clausesOdistChildOcc =
                  ({-# LINE 1311 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22476 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1322, column 3)
              clauses_val_ =
                  ({-# LINE 1322 "src/Transform.ag" #-}
                   sem_SemVisit_Visit pos_ _firstVisit     cyclic_ (sem_VisitAttrs_Nil) (sem_Stmts stmts_)
                   {-# LINE 22481 "src/Transform.hs" #-})
              clauses_inst_ =
                  (clauses_val_ clauses_ )
              -- "src/Transform.ag"(line 1404, column 23)
              _basename =
                  ({-# LINE 1404 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 22488 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1405, column 23)
              _semBasename =
                  ({-# LINE 1405 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 22493 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1413, column 20)
              _clausesOwithinCoSem =
                  ({-# LINE 1413 "src/Transform.ag" #-}
                   False
                   {-# LINE 22498 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1423, column 20)
              _lhsOpos =
                  ({-# LINE 1423 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 22503 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1554, column 23)
              _clausesOdistNextVisits =
                  ({-# LINE 1554 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22508 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1593, column 23)
              _myNextVisits =
                  ({-# LINE 1593 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22513 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1613, column 24)
              _clausesOdistChildMinRanges =
                  ({-# LINE 1613 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22518 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1614, column 24)
              _clausesOdistChildEffRanges =
                  ({-# LINE 1614 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22523 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1753, column 23)
              _clausesOavailInvokes =
                  ({-# LINE 1753 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22528 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1817, column 24)
              _clausesOdistDeflStmts =
                  ({-# LINE 1817 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 22533 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1864, column 23)
              _clausesOdistVisRankMap =
                  ({-# LINE 1864 "src/Transform.ag" #-}
                   _clausesIgathVisRankMap
                   {-# LINE 22538 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1900, column 23)
              _clausesOfullCyclicVisits =
                  ({-# LINE 1900 "src/Transform.ag" #-}
                   Map.findWithDefault Set.empty tp_ _lhsIdistCycVisMap
                   {-# LINE 22543 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1901, column 23)
              _clausesOfullCyclic =
                  ({-# LINE 1901 "src/Transform.ag" #-}
                   False
                   {-# LINE 22548 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1918, column 25)
              _clausesOallowCycVisits =
                  ({-# LINE 1918 "src/Transform.ag" #-}
                   _clausesIgathAllowCycVisits
                   {-# LINE 22553 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2081, column 3)
              _inhAttrMap =
                  ({-# LINE 2081 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty tp_ _lhsIdistVisitInhAttrs
                   {-# LINE 22558 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2082, column 3)
              _inhAttrSource =
                  ({-# LINE 2082 "src/Transform.ag" #-}
                   Map.fromList [ ((True,lhsIdent,attr), DepVisStart (visit : _semBasename    ))
                                | (visit,mp) <- Map.assocs _inhAttrMap    , attr <- Map.keys mp ]
                   {-# LINE 22564 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2084, column 3)
              _clausesOdistAttrSource =
                  ({-# LINE 2084 "src/Transform.ag" #-}
                   Map.union _inhAttrSource     _lhsIdistAttrSource
                   {-# LINE 22569 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2458, column 3)
              _lhsOpp =
                  ({-# LINE 2458 "src/Transform.ag" #-}
                   "datasem" >#< show tp_ >-< indent 2 _clausesIpp
                   {-# LINE 22574 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 197, column 3)
              _lhsOhpp =
                  ({-# LINE 197 "src/TargetHaskell.ag" #-}
                   hDtSemNm tp_ >#< "::" >#< _hppType
                   >-< hDtSemNm tp_ >#< "="
                   >-< indent 4 _clausesIhpp
                   {-# LINE 22581 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 200, column 3)
              _hppType =
                  ({-# LINE 200 "src/TargetHaskell.ag" #-}
                   case mbMonad_ of
                     Nothing -> "(Monad m, MonadError e m, Error e) => " >#< hItfNm tp_ >#< "m"
                     Just t  -> hItfNm tp_ >#< pp_parens (stripSpacing t)
                   {-# LINE 22588 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 127, column 3)
              _lhsOjspp =
                  ({-# LINE 127 "src/TargetJs.ag" #-}
                   "var dnt_" >|< show tp_ >#< "="
                   >#< pp_parens ( "function ()"
                               >-< pp_braces (
                                     "var" >#< "nt" >|< show tp_ >#< "=" >#< _clausesIjspp >|< ";"
                                      >-< "return" >#< "nt" >|< show tp_ >|< ";"
                               )) >|< ";"
                   {-# LINE 22598 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _clausesIallReqInvokes `unionWithUnion` _consIallReqInvokes
                   {-# LINE 22603 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 837 "src/Transform.ag" #-}
                   _clausesIerrs0 Seq.>< _consIerrs0
                   {-# LINE 22608 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 532 "src/Transform.ag" #-}
                   _clausesIerrs1 Seq.>< _consIerrs1
                   {-# LINE 22613 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 474 "src/Transform.ag" #-}
                   _clausesIerrs2 Seq.>< _consIerrs2
                   {-# LINE 22618 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1037 "src/Transform.ag" #-}
                   _clausesIerrs3 Seq.>< _consIerrs3
                   {-# LINE 22623 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs4 Seq.>< _consIerrs4
                   {-# LINE 22628 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _clausesIerrs5 Seq.>< _consIerrs5
                   {-# LINE 22633 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _clausesIgathAvoidVisits `Set.union` _consIgathAvoidVisits
                   {-# LINE 22638 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _clausesIgathDeps Seq.>< _consIgathDeps
                   {-# LINE 22643 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _clausesIgathItemVisits `Map.union` _consIgathItemVisits
                   {-# LINE 22648 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _clausesIgathLegalCycStmts `Set.union` _consIgathLegalCycStmts
                   {-# LINE 22653 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _clausesIgathSemStarts Seq.>< _consIgathSemStarts
                   {-# LINE 22658 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _clausesIgathStmtPosMap `Map.union` _consIgathStmtPosMap
                   {-# LINE 22663 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _clausesIgathVisitEnds Seq.>< _consIgathVisitEnds
                   {-# LINE 22668 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _clausesIgathVisitStarts Seq.>< _consIgathVisitStarts
                   {-# LINE 22673 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _clausesIminReqInvokes `unionWithUnion` _consIminReqInvokes
                   {-# LINE 22678 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _consIcodeIdCounter
                   {-# LINE 22683 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _consIdistDataCons
                   {-# LINE 22688 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _consIdistDataSems
                   {-# LINE 22693 "src/Transform.hs" #-})
              -- copy rule (up)
              _distDatas_augmented_syn =
                  ({-# LINE 472 "src/Transform.ag" #-}
                   _consIdistDatas
                   {-# LINE 22698 "src/Transform.hs" #-})
              -- copy rule (up)
              _distItfs_augmented_syn =
                  ({-# LINE 407 "src/Transform.ag" #-}
                   _consIdistItfs
                   {-# LINE 22703 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _consIdistVisits
                   {-# LINE 22708 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _consIgathClauses
                   {-# LINE 22713 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathDataSems_augmented_syn =
                  ({-# LINE 275 "src/Transform.ag" #-}
                   _consIgathDataSems
                   {-# LINE 22718 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _consIgathNonterms
                   {-# LINE 22723 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _consIlexCounter
                   {-# LINE 22728 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 22733 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 22738 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 22743 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 22748 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 22753 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 22758 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 22763 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 22768 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 22773 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 22778 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 22783 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 22788 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 22793 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 22798 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 22803 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 22808 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 22813 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 22818 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 22823 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 22828 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 22833 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 22838 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 22843 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 22848 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 22853 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 22858 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 22863 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 22868 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 22873 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 22878 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 22883 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 22888 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _myNextVisits
                   {-# LINE 22893 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _nextVisits
                   {-# LINE 22898 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 22903 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 22908 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 22913 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _semBasename
                   {-# LINE 22918 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 22923 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 22928 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 22933 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 22938 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 22943 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 22948 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 22953 "src/Transform.hs" #-})
              -- copy rule (from local)
              _consObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 22958 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 22963 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _clausesIcodeIdCounter
                   {-# LINE 22968 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 22973 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 22978 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 22983 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 22988 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 22993 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 22998 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 23003 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 23008 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 23013 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 23018 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 23023 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 23028 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 23033 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 23038 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 23043 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 23048 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 23053 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistDefs
                   {-# LINE 23058 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 23063 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 23068 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 23073 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 23078 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 23083 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistVisLocalDefs
                   {-# LINE 23088 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 23093 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 23098 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 23103 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 23108 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 23113 "src/Transform.hs" #-})
              -- copy rule (from local)
              _consOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 23118 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 23123 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 23128 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _clausesIgathDataSems
                   {-# LINE 23133 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathDefs
                   {-# LINE 23138 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 23143 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathVisLocalDefs
                   {-# LINE 23148 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 23153 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 23158 "src/Transform.hs" #-})
              -- copy rule (chain)
              _consOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _clausesIlexCounter
                   {-# LINE 23163 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 23168 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 23173 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 23178 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 23183 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 23188 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 23193 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 23198 "src/Transform.hs" #-})
              -- copy rule (down)
              _consOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 23203 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _clausesIallReqInvokes,_clausesIbannedInvokes,_clausesIcodeIdCounter,_clausesIdistChildDefs,_clausesIdistDataCons,_clausesIdistDataSems,_clausesIdistDatas,_clausesIdistDefs,_clausesIdistItfs,_clausesIdistVisLocalDefs,_clausesIdistVisits,_clausesIerrs0,_clausesIerrs1,_clausesIerrs2,_clausesIerrs3,_clausesIerrs4,_clausesIerrs5,_clausesIgathAllowCycVisits,_clausesIgathAttrSource,_clausesIgathAvoidVisits,_clausesIgathChildDefs,_clausesIgathChildSource,_clausesIgathClauses,_clausesIgathDataSems,_clausesIgathDefs,_clausesIgathDeps,_clausesIgathItemVisits,_clausesIgathLegalCycStmts,_clausesIgathMissingInvokes,_clausesIgathNonterms,_clausesIgathSemAttrSource,_clausesIgathSemStarts,_clausesIgathStmtPosMap,_clausesIgathVisLocalDefs,_clausesIgathVisRankMap,_clausesIgathVisitAttrs,_clausesIgathVisitEnds,_clausesIgathVisitNames,_clausesIgathVisitSource,_clausesIgathVisitStarts,_clausesIhpp,_clausesIisInternal,_clausesIjspp,_clausesIlexCounter,_clausesImbNextVisit,_clausesIminRank,_clausesIminReqInvokes,_clausesIpp) =
                  clauses_inst_ _clausesOallAvailInvokes _clausesOallVisits _clausesOallowCycVisits _clausesOavailInvokes _clausesObasename _clausesOclauseExtras _clausesOcoItf _clausesOcodeIdCounter _clausesOdirectVisitAttrs _clausesOdirectVisitLocalAttrs _clausesOdistAliasses _clausesOdistAllChildMinRanges _clausesOdistAttrSource _clausesOdistAttrVisMap _clausesOdistChildDefs _clausesOdistChildEffRanges _clausesOdistChildMinRanges _clausesOdistChildOcc _clausesOdistChildSource _clausesOdistCycVisMap _clausesOdistDataCons _clausesOdistDataMap _clausesOdistDataSems _clausesOdistDatas _clausesOdistDeflStmts _clausesOdistDefs _clausesOdistInhAttrs _clausesOdistItfs _clausesOdistNextVisits _clausesOdistRanks _clausesOdistRenames _clausesOdistSynAttrs _clausesOdistVisLocalDefs _clausesOdistVisRankMap _clausesOdistVisitInhAttrs _clausesOdistVisitOrder _clausesOdistVisitSource _clausesOdistVisitSynAttrs _clausesOdistVisits _clausesOdoneVisits _clausesOfullCyclic _clausesOfullCyclicVisits _clausesOgathChildDefs _clausesOgathClauses _clausesOgathDataSems _clausesOgathDefs _clausesOgathNonterms _clausesOgathVisLocalDefs _clausesOgathVisitNames _clausesOhSpilledStmts _clausesOindent _clausesOitf _clausesOjsSpilledStmts _clausesOlexCounter _clausesOlocalAttrs _clausesOmasterPos _clausesOmyNextVisits _clausesOnextVisits _clausesOnonterm _clausesOopts _clausesOscopeDep _clausesOscopeReason _clausesOsemBasename _clausesOstmtSource _clausesOvisit _clausesOvisitBeginDep _clausesOvisitEndDep _clausesOvisitEndReason _clausesOvisitNr _clausesOwithinCoSem 
              ( _consIallReqInvokes,_consIclauseExtras,_consIcodeIdCounter,_consIdistChildDefs,_consIdistDataCons,_consIdistDataSems,_consIdistDatas,_consIdistDefs,_consIdistItfs,_consIdistVisLocalDefs,_consIdistVisits,_consIerrs0,_consIerrs1,_consIerrs2,_consIerrs3,_consIerrs4,_consIerrs5,_consIgathAvoidVisits,_consIgathChildDefs,_consIgathClauses,_consIgathDataSems,_consIgathDefs,_consIgathDeps,_consIgathItemVisits,_consIgathLegalCycStmts,_consIgathNonterms,_consIgathSemStarts,_consIgathStmtPosMap,_consIgathVisLocalDefs,_consIgathVisitEnds,_consIgathVisitStarts,_consIlexCounter,_consIminReqInvokes) =
                  cons_inst_ _consOallAvailInvokes _consOallVisits _consOavailInvokes _consObasename _consOcoItf _consOcodeIdCounter _consOdirectVisitAttrs _consOdirectVisitLocalAttrs _consOdistAliasses _consOdistAllChildMinRanges _consOdistAttrSource _consOdistAttrVisMap _consOdistChildDefs _consOdistChildEffRanges _consOdistChildMinRanges _consOdistChildOcc _consOdistChildSource _consOdistCycVisMap _consOdistDataCons _consOdistDataMap _consOdistDataSems _consOdistDatas _consOdistDeflStmts _consOdistDefs _consOdistInhAttrs _consOdistItfs _consOdistRanks _consOdistRenames _consOdistSynAttrs _consOdistVisLocalDefs _consOdistVisitInhAttrs _consOdistVisitOrder _consOdistVisitSource _consOdistVisitSynAttrs _consOdistVisits _consOdoneVisits _consOgathChildDefs _consOgathClauses _consOgathDataSems _consOgathDefs _consOgathNonterms _consOgathVisLocalDefs _consOhSpilledStmts _consOitf _consOjsSpilledStmts _consOlexCounter _consOnonterm _consOopts _consOscopeDep _consOscopeReason _consOstmtSource _consOvisitBeginDep _consOvisitEndDep _consOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
-- ExprField ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         con                  : Ident
         data                 : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fieldOrder           : Map Ident Int
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathFields           : FieldEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hopp                 : (Int,PP_Doc)
         jsopp                : (Int,PP_Doc)
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Field:
         child name           : {Ident}
         child code           : Code 
         visit 0:
            local gathFields_augmented_f1 : _
            local fieldIndex  : _
            local gathFields_augmented_syn : _
-}
-- cata
sem_ExprField :: ExprField  ->
                 T_ExprField 
sem_ExprField (ExprField_Field _name _code )  =
    (sem_ExprField_Field _name (sem_Code _code ) )
-- semantic domain
type T_ExprField  = (Map Ident (Set Ident)) ->
                    (Set Ident) ->
                    (Map Ident (Set Ident)) ->
                    QIdent ->
                    Ident ->
                    Int ->
                    Ident ->
                    Ident ->
                    (Map Ident (Map Ident String)) ->
                    (Map Ident String) ->
                    (Map Ident AliasType) ->
                    (Map Ident [Ident]) ->
                    AttrSourceMap ->
                    AttrVisMap ->
                    (Env QIdent (QIdent,QIdent)) ->
                    (Map Ident (Set Ident)) ->
                    (Map Ident [Ident]) ->
                    (Map Ident Int) ->
                    ChildSourceMap ->
                    CycVisMap ->
                    ConEnv ->
                    DataMap ->
                    DataSemEnv ->
                    DataEnv ->
                    (Map Ident (Bool,Maybe Int)) ->
                    DefsEnv ->
                    AttrMap ->
                    ItfEnv ->
                    (Map DepItem (Bool,Int)) ->
                    RenameMap ->
                    AttrMap ->
                    DefsEnv ->
                    VisitAttrMap ->
                    (Map Ident [Ident]) ->
                    VisitSourceMap ->
                    VisitAttrMap ->
                    VisitEnv ->
                    ([Ident]) ->
                    (Map Ident Int) ->
                    (Env QIdent (QIdent, QIdent)) ->
                    ClausesEnv ->
                    DataSemEnv ->
                    DefsEnv ->
                    FieldEnv ->
                    NontermEnv ->
                    DefsEnv ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    QIdent ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    QIdent ->
                    Opts ->
                    DepItem ->
                    Reason ->
                    DepItem ->
                    DepItem ->
                    DepItem ->
                    Reason ->
                    ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,FieldEnv,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),((Int,PP_Doc)),((Int,PP_Doc)),Int,(Map Ident (Set Ident)),PP_Doc)
sem_ExprField_Field :: Ident ->
                       T_Code  ->
                       T_ExprField 
sem_ExprField_Field name_ code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIcon
       _lhsIdata
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfieldOrder
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathFields
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOgathFields :: FieldEnv
              _lhsOpp :: PP_Doc
              _lhsOhopp :: ((Int,PP_Doc))
              _lhsOjsopp :: ((Int,PP_Doc))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOindent :: Int
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOlexCounter :: Int
              _codeOnonterm :: QIdent
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpp :: PP_Doc
              -- augmented rule
              _lhsOgathFields =
                  ({-# LINE 349 "src/Transform.ag" #-}
                   foldr ($) _gathFields_augmented_syn [_gathFields_augmented_f1]
                   {-# LINE 23564 "src/Transform.hs" #-})
              -- augment function
              _gathFields_augmented_f1 =
                  ({-# LINE 349 "src/Transform.ag" #-}
                   extend name_ (0,Right "")
                   {-# LINE 23569 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 350, column 3)
              _fieldIndex =
                  ({-# LINE 350 "src/Transform.ag" #-}
                   Map.findWithDefault 0 name_ _lhsIfieldOrder
                   {-# LINE 23574 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2615, column 3)
              _lhsOpp =
                  ({-# LINE 2615 "src/Transform.ag" #-}
                   name_ >-< indent 2 ("=" >#< pp_parens _codeIpp)
                   {-# LINE 23579 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 533, column 3)
              _lhsOhopp =
                  ({-# LINE 533 "src/TargetHaskell.ag" #-}
                   (_fieldIndex    , pp_parens _codeIhpp)
                   {-# LINE 23584 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 337, column 3)
              _lhsOjsopp =
                  ({-# LINE 337 "src/TargetJs.ag" #-}
                   (_fieldIndex    , pp_parens _codeIjspp)
                   {-# LINE 23589 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIallReqInvokes
                   {-# LINE 23594 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs0
                   {-# LINE 23599 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs1
                   {-# LINE 23604 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs2
                   {-# LINE 23609 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs3
                   {-# LINE 23614 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs4
                   {-# LINE 23619 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs5
                   {-# LINE 23624 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _codeIgathAvoidVisits
                   {-# LINE 23629 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _codeIgathDeps
                   {-# LINE 23634 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _codeIgathItemVisits
                   {-# LINE 23639 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _codeIgathLegalCycStmts
                   {-# LINE 23644 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _codeIgathSemStarts
                   {-# LINE 23649 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _codeIgathStmtPosMap
                   {-# LINE 23654 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitEnds
                   {-# LINE 23659 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitStarts
                   {-# LINE 23664 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIminReqInvokes
                   {-# LINE 23669 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 23674 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 23679 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 23684 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 23689 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 23694 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 23699 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 23704 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 23709 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 23714 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 23719 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 23724 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 23729 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 23734 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathFields_augmented_syn =
                  ({-# LINE 349 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 23739 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 23744 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 23749 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 23754 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 23759 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 23764 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 23769 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 23774 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 23779 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 23784 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 23789 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 23794 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 23799 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 23804 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 23809 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 23814 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 23819 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 23824 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 23829 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 23834 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 23839 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 23844 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 23849 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 23854 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 23859 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 23864 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 23869 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 23874 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 23879 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 23884 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 23889 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 23894 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 23899 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 23904 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 23909 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 23914 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 23919 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 23924 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 23929 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 23934 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 23939 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 23944 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 23949 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 23954 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 23959 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 23964 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 23969 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 23974 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 23979 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 23984 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 23989 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 23994 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 23999 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 24004 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 24009 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 24014 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 24019 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 24024 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 24029 "src/Transform.hs" #-})
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOindent _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathFields,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhopp,_lhsOjsopp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
-- ExprFields --------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         con                  : Ident
         data                 : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fieldOrder           : Map Ident Int
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathFields           : FieldEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hopps                : [(Int,PP_Doc)]
         jsopps               : [(Int,PP_Doc)]
         minReqInvokes        : Map Ident (Set Ident)
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : ExprField 
         child tl             : ExprFields 
      alternative Nil:
-}
-- cata
sem_ExprFields :: ExprFields  ->
                  T_ExprFields 
sem_ExprFields list  =
    (Prelude.foldr sem_ExprFields_Cons sem_ExprFields_Nil (Prelude.map sem_ExprField list) )
-- semantic domain
type T_ExprFields  = (Map Ident (Set Ident)) ->
                     (Set Ident) ->
                     (Map Ident (Set Ident)) ->
                     QIdent ->
                     Ident ->
                     Int ->
                     Ident ->
                     Ident ->
                     (Map Ident (Map Ident String)) ->
                     (Map Ident String) ->
                     (Map Ident AliasType) ->
                     (Map Ident [Ident]) ->
                     AttrSourceMap ->
                     AttrVisMap ->
                     (Env QIdent (QIdent,QIdent)) ->
                     (Map Ident (Set Ident)) ->
                     (Map Ident [Ident]) ->
                     (Map Ident Int) ->
                     ChildSourceMap ->
                     CycVisMap ->
                     ConEnv ->
                     DataMap ->
                     DataSemEnv ->
                     DataEnv ->
                     (Map Ident (Bool,Maybe Int)) ->
                     DefsEnv ->
                     AttrMap ->
                     ItfEnv ->
                     (Map DepItem (Bool,Int)) ->
                     RenameMap ->
                     AttrMap ->
                     DefsEnv ->
                     VisitAttrMap ->
                     (Map Ident [Ident]) ->
                     VisitSourceMap ->
                     VisitAttrMap ->
                     VisitEnv ->
                     ([Ident]) ->
                     (Map Ident Int) ->
                     (Env QIdent (QIdent, QIdent)) ->
                     ClausesEnv ->
                     DataSemEnv ->
                     DefsEnv ->
                     FieldEnv ->
                     NontermEnv ->
                     DefsEnv ->
                     ([(Int,PP_Doc)]) ->
                     Int ->
                     QIdent ->
                     ([(Int,PP_Doc)]) ->
                     Int ->
                     QIdent ->
                     Opts ->
                     DepItem ->
                     Reason ->
                     DepItem ->
                     DepItem ->
                     DepItem ->
                     Reason ->
                     ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,FieldEnv,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),([(Int,PP_Doc)]),([(Int,PP_Doc)]),Int,(Map Ident (Set Ident)),([PP_Doc]))
sem_ExprFields_Cons :: T_ExprField  ->
                       T_ExprFields  ->
                       T_ExprFields 
sem_ExprFields_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIcon
       _lhsIdata
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfieldOrder
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathFields
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int,PP_Doc)])
              _lhsOjsopps :: ([(Int,PP_Doc)])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathFields :: FieldEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOcon :: Ident
              _hdOdata :: Ident
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOfieldOrder :: (Map Ident Int)
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathFields :: FieldEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOindent :: Int
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOcon :: Ident
              _tlOdata :: Ident
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOfieldOrder :: (Map Ident Int)
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathFields :: FieldEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOindent :: Int
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathFields :: FieldEnv
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhopp :: ((Int,PP_Doc))
              _hdIjsopp :: ((Int,PP_Doc))
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathFields :: FieldEnv
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhopps :: ([(Int,PP_Doc)])
              _tlIjsopps :: ([(Int,PP_Doc)])
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2669, column 11)
              _lhsOpps =
                  ({-# LINE 2669 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 24482 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 635, column 11)
              _lhsOhopps =
                  ({-# LINE 635 "src/TargetHaskell.ag" #-}
                   _hdIhopp : _tlIhopps
                   {-# LINE 24487 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 424, column 11)
              _lhsOjsopps =
                  ({-# LINE 424 "src/TargetJs.ag" #-}
                   _hdIjsopp : _tlIjsopps
                   {-# LINE 24492 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 24497 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 24502 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 24507 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 24512 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 24517 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 24522 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 24527 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 24532 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 24537 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 24542 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 24547 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 24552 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 24557 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 24562 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 24567 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 24572 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 24577 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 24582 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 24587 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 24592 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 24597 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 24602 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 24607 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 24612 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 24617 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 24622 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 24627 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 24632 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 24637 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathFields =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _tlIgathFields
                   {-# LINE 24642 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 24647 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 24652 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 24657 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 24662 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 24667 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 24672 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 24677 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 24682 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 24687 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcon =
                  ({-# LINE 295 "src/Transform.ag" #-}
                   _lhsIcon
                   {-# LINE 24692 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 24697 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 24702 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 24707 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 24712 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 24717 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 24722 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 24727 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 24732 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 24737 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 24742 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 24747 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 24752 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 24757 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 24762 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 24767 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 24772 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 24777 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 24782 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 24787 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 24792 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 24797 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 24802 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 24807 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 24812 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 24817 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 24822 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 24827 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 24832 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 24837 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 24842 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 24847 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOfieldOrder =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _lhsIfieldOrder
                   {-# LINE 24852 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 24857 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 24862 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 24867 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 24872 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathFields =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 24877 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 24882 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 24887 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 24892 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 24897 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 24902 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 24907 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 24912 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 24917 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 24922 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 24927 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 24932 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 24937 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 24942 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 24947 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 24952 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 24957 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 24962 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 24967 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 24972 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 24977 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 24982 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcon =
                  ({-# LINE 295 "src/Transform.ag" #-}
                   _lhsIcon
                   {-# LINE 24987 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 24992 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 24997 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 25002 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 25007 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 25012 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 25017 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 25022 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 25027 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 25032 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 25037 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 25042 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 25047 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 25052 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 25057 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 25062 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 25067 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 25072 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 25077 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 25082 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 25087 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 25092 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 25097 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 25102 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 25107 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 25112 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 25117 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 25122 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 25127 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 25132 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 25137 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 25142 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOfieldOrder =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _lhsIfieldOrder
                   {-# LINE 25147 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 25152 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 25157 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 25162 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 25167 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathFields =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _hdIgathFields
                   {-# LINE 25172 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 25177 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 25182 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 25187 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 25192 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 25197 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 25202 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 25207 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 25212 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 25217 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 25222 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 25227 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 25232 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 25237 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 25242 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 25247 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathFields,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitStarts,_hdIhopp,_hdIjsopp,_hdIlexCounter,_hdIminReqInvokes,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOcon _hdOdata _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOfieldOrder _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathFields _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOindent _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathFields,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitStarts,_tlIhopps,_tlIjsopps,_tlIlexCounter,_tlIminReqInvokes,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOcon _tlOdata _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOfieldOrder _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathFields _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOindent _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathFields,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
sem_ExprFields_Nil :: T_ExprFields 
sem_ExprFields_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIcon
       _lhsIdata
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfieldOrder
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathFields
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int,PP_Doc)])
              _lhsOjsopps :: ([(Int,PP_Doc)])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathFields :: FieldEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2670, column 11)
              _lhsOpps =
                  ({-# LINE 2670 "src/Transform.ag" #-}
                   []
                   {-# LINE 25354 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 636, column 11)
              _lhsOhopps =
                  ({-# LINE 636 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 25359 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 425, column 11)
              _lhsOjsopps =
                  ({-# LINE 425 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 25364 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 25369 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25374 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25379 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25384 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25389 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25394 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25399 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 25404 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25409 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 25414 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 25419 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25424 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 25429 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25434 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 25439 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 25444 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 25449 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 25454 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 25459 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 25464 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 25469 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 25474 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 25479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 25484 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 25489 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 25494 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 25499 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 25504 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 25509 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathFields =
                  ({-# LINE 340 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 25514 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 25519 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 25524 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 25529 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathFields,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
-- Ext ---------------------------------------------------------
{-
   visit 0:
      synthesized attribute:
         gathExts             : Set Ident
   alternatives:
      alternative Ext:
         child name           : {Ident}
-}
-- cata
sem_Ext :: Ext  ->
           T_Ext 
sem_Ext (Ext_Ext _name )  =
    (sem_Ext_Ext _name )
-- semantic domain
type T_Ext  = ( (Set Ident))
sem_Ext_Ext :: Ident ->
               T_Ext 
sem_Ext_Ext name_  =
    (let _lhsOgathExts :: (Set Ident)
         -- "src/Transform.ag"(line 1363, column 16)
         _lhsOgathExts =
             ({-# LINE 1363 "src/Transform.ag" #-}
              Set.singleton name_
              {-# LINE 25555 "src/Transform.hs" #-})
     in  ( _lhsOgathExts))
-- Exts --------------------------------------------------------
{-
   visit 0:
      synthesized attribute:
         gathExts             : Set Ident
   alternatives:
      alternative Cons:
         child hd             : Ext 
         child tl             : Exts 
      alternative Nil:
-}
-- cata
sem_Exts :: Exts  ->
            T_Exts 
sem_Exts list  =
    (Prelude.foldr sem_Exts_Cons sem_Exts_Nil (Prelude.map sem_Ext list) )
-- semantic domain
type T_Exts  = ( (Set Ident))
sem_Exts_Cons :: T_Ext  ->
                 T_Exts  ->
                 T_Exts 
sem_Exts_Cons hd_ tl_  =
    (let _lhsOgathExts :: (Set Ident)
         _hdIgathExts :: (Set Ident)
         _tlIgathExts :: (Set Ident)
         -- use rule "src/Transform.ag"(line 1362, column 30)
         _lhsOgathExts =
             ({-# LINE 1362 "src/Transform.ag" #-}
              _hdIgathExts `Set.union` _tlIgathExts
              {-# LINE 25586 "src/Transform.hs" #-})
         ( _hdIgathExts) =
             hd_ 
         ( _tlIgathExts) =
             tl_ 
     in  ( _lhsOgathExts))
sem_Exts_Nil :: T_Exts 
sem_Exts_Nil  =
    (let _lhsOgathExts :: (Set Ident)
         -- use rule "src/Transform.ag"(line 1362, column 30)
         _lhsOgathExts =
             ({-# LINE 1362 "src/Transform.ag" #-}
              Set.empty
              {-# LINE 25599 "src/Transform.hs" #-})
     in  ( _lhsOgathExts))
-- Field -------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         con                  : Ident
         data                 : Ident
         distAliasses         : Map Ident AliasType
         opts                 : Opts
      chained attributes:
         distDatas            : DataEnv
         gathFields           : FieldEnv
         nr                   : Int
      synthesized attributes:
         gathFieldMap         : FieldMap
         hpp                  : PP_Doc
         jsChecksPPs          : [PP_Doc]
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Field:
         child name           : {Ident}
         child type           : FieldType 
         visit 0:
            local gathFields_augmented_f1 : _
            local txtTp       : _
            local gathFields_augmented_syn : _
-}
-- cata
sem_Field :: Field  ->
             T_Field 
sem_Field (Field_Field _name _type )  =
    (sem_Field_Field _name (sem_FieldType _type ) )
-- semantic domain
type T_Field  = Ident ->
                Ident ->
                (Map Ident AliasType) ->
                DataEnv ->
                FieldEnv ->
                Int ->
                Opts ->
                ( DataEnv,FieldMap,FieldEnv,PP_Doc,([PP_Doc]),PP_Doc,Int,PP_Doc)
sem_Field_Field :: Ident ->
                   T_FieldType  ->
                   T_Field 
sem_Field_Field name_ type_  =
    (\ _lhsIcon
       _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathFields
       _lhsInr
       _lhsIopts ->
         (let _lhsOgathFields :: FieldEnv
              _lhsOnr :: Int
              _lhsOgathFieldMap :: FieldMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOjsChecksPPs :: ([PP_Doc])
              _lhsOdistDatas :: DataEnv
              _typeOdistAliasses :: (Map Ident AliasType)
              _typeOdistDatas :: DataEnv
              _typeOopts :: Opts
              _typeIdistDatas :: DataEnv
              _typeIfldType :: (Either Ident String)
              _typeIjsCheckPP :: (Maybe PP_Doc)
              _typeIpp :: PP_Doc
              -- augmented rule
              _lhsOgathFields =
                  ({-# LINE 328 "src/Transform.ag" #-}
                   foldr ($) _gathFields_augmented_syn [_gathFields_augmented_f1]
                   {-# LINE 25672 "src/Transform.hs" #-})
              -- augment function
              _gathFields_augmented_f1 =
                  ({-# LINE 328 "src/Transform.ag" #-}
                   extend name_ (_lhsInr, _typeIfldType)
                   {-# LINE 25677 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 333, column 20)
              _lhsOnr =
                  ({-# LINE 333 "src/Transform.ag" #-}
                   1 + _lhsInr
                   {-# LINE 25682 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1391, column 20)
              _lhsOgathFieldMap =
                  ({-# LINE 1391 "src/Transform.ag" #-}
                   Map.singleton name_ (_lhsInr, _typeIfldType)
                   {-# LINE 25687 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2443, column 3)
              _lhsOpp =
                  ({-# LINE 2443 "src/Transform.ag" #-}
                   name_ >#< _typeIpp
                   {-# LINE 25692 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 181, column 3)
              _txtTp =
                  ({-# LINE 181 "src/TargetHaskell.ag" #-}
                   either show id _typeIfldType
                   {-# LINE 25697 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 182, column 3)
              _lhsOhpp =
                  ({-# LINE 182 "src/TargetHaskell.ag" #-}
                   hFldNm _lhsIdata _lhsIcon name_ >#< "::" >#< "!" >|< hParensWithPos _lhsIopts (identPos name_) (stripSpacing _txtTp    )
                   {-# LINE 25702 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 96, column 3)
              _lhsOjspp =
                  ({-# LINE 96 "src/TargetJs.ag" #-}
                   text $ show name_
                   {-# LINE 25707 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 97, column 3)
              _lhsOjsChecksPPs =
                  ({-# LINE 97 "src/TargetJs.ag" #-}
                   [ "var _val = " >#< show name_ >|< ";"
                     >-< "if (_val === undefined) { throw \"Field undefined: " >|< show name_ >|< "\";}"
                     >-< case _typeIjsCheckPP of
                           Nothing -> text "_outcome = true;"
                           Just p  -> p
                     >-< "if" >#< pp_parens ("!_outcome")
                     >#< pp_braces ("throw \"Field fails predicate: " >|< show name_ >|< "\";") ]
                   {-# LINE 25718 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _typeIdistDatas
                   {-# LINE 25723 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathFields_augmented_syn =
                  ({-# LINE 328 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 25728 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 25733 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 25738 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 25743 "src/Transform.hs" #-})
              ( _typeIdistDatas,_typeIfldType,_typeIjsCheckPP,_typeIpp) =
                  type_ _typeOdistAliasses _typeOdistDatas _typeOopts 
          in  ( _lhsOdistDatas,_lhsOgathFieldMap,_lhsOgathFields,_lhsOhpp,_lhsOjsChecksPPs,_lhsOjspp,_lhsOnr,_lhsOpp)))
-- FieldType ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         distAliasses         : Map Ident AliasType
         opts                 : Opts
      chained attribute:
         distDatas            : DataEnv
      synthesized attributes:
         fldType              : Either Ident String
         jsCheckPP            : Maybe PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Nonterm:
         child name           : {Ident}
         visit 0:
            local distDatas_augmented_f1 : _
            local mbAlias     : _
            local distDatas_augmented_syn : _
      alternative Term:
         child type           : {String}
-}
-- cata
sem_FieldType :: FieldType  ->
                 T_FieldType 
sem_FieldType (FieldType_Nonterm _name )  =
    (sem_FieldType_Nonterm _name )
sem_FieldType (FieldType_Term _type )  =
    (sem_FieldType_Term _type )
-- semantic domain
type T_FieldType  = (Map Ident AliasType) ->
                    DataEnv ->
                    Opts ->
                    ( DataEnv,(Either Ident String),(Maybe PP_Doc),PP_Doc)
sem_FieldType_Nonterm :: Ident ->
                         T_FieldType 
sem_FieldType_Nonterm name_  =
    (\ _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIopts ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOfldType :: (Either Ident String)
              _lhsOpp :: PP_Doc
              _lhsOjsCheckPP :: (Maybe PP_Doc)
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 484 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 25795 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 484 "src/Transform.ag" #-}
                   snd . find name_ ()
                   {-# LINE 25800 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 338, column 14)
              _lhsOfldType =
                  ({-# LINE 338 "src/Transform.ag" #-}
                   Left name_
                   {-# LINE 25805 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1440, column 26)
              _mbAlias =
                  ({-# LINE 1440 "src/Transform.ag" #-}
                   Map.lookup name_ _lhsIdistAliasses
                   {-# LINE 25810 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2447, column 14)
              _lhsOpp =
                  ({-# LINE 2447 "src/Transform.ag" #-}
                   ":" >#< show name_
                   {-# LINE 25815 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 111, column 14)
              _lhsOjsCheckPP =
                  ({-# LINE 111 "src/TargetJs.ag" #-}
                   case _mbAlias     of
                     Nothing -> Just ("var _outcome = _val instanceof" >#< show name_ >|< ";")
                     Just alias -> case alias of
                                      AliasType_Prod _  -> Just $ text ("var _outcome = _val instanceof Tuple;")
                                      AliasType_List _  -> Just $ text ("var _outcome = _val instanceof Array;")
                                      AliasType_Maybe _ -> Just $ text ("var _outcome = _val instanceof Maybe;")
                   {-# LINE 25825 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDatas_augmented_syn =
                  ({-# LINE 484 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 25830 "src/Transform.hs" #-})
          in  ( _lhsOdistDatas,_lhsOfldType,_lhsOjsCheckPP,_lhsOpp)))
sem_FieldType_Term :: String ->
                      T_FieldType 
sem_FieldType_Term type_  =
    (\ _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIopts ->
         (let _lhsOfldType :: (Either Ident String)
              _lhsOpp :: PP_Doc
              _lhsOjsCheckPP :: (Maybe PP_Doc)
              _lhsOdistDatas :: DataEnv
              -- "src/Transform.ag"(line 337, column 14)
              _lhsOfldType =
                  ({-# LINE 337 "src/Transform.ag" #-}
                   Right type_
                   {-# LINE 25846 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2446, column 14)
              _lhsOpp =
                  ({-# LINE 2446 "src/Transform.ag" #-}
                   "::" >#< type_
                   {-# LINE 25851 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 106, column 14)
              _lhsOjsCheckPP =
                  ({-# LINE 106 "src/TargetJs.ag" #-}
                   if all isSpace type_
                   then Nothing
                   else Just ("var _assert =" >#< type_ >|< ";"
                        >-< "if (!_assert) { throw \"assert function undefined\"; }"
                        >-< "var _outcome = _assert(_val);")
                   {-# LINE 25860 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 25865 "src/Transform.hs" #-})
          in  ( _lhsOdistDatas,_lhsOfldType,_lhsOjsCheckPP,_lhsOpp)))
-- Fields ------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         con                  : Ident
         data                 : Ident
         distAliasses         : Map Ident AliasType
         opts                 : Opts
      chained attributes:
         distDatas            : DataEnv
         gathFields           : FieldEnv
         nr                   : Int
      synthesized attributes:
         gathFieldMap         : FieldMap
         hpps                 : [PP_Doc]
         jsChecksPPs          : [PP_Doc]
         jspps                : [PP_Doc]
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Field 
         child tl             : Fields 
      alternative Nil:
-}
-- cata
sem_Fields :: Fields  ->
              T_Fields 
sem_Fields list  =
    (Prelude.foldr sem_Fields_Cons sem_Fields_Nil (Prelude.map sem_Field list) )
-- semantic domain
type T_Fields  = Ident ->
                 Ident ->
                 (Map Ident AliasType) ->
                 DataEnv ->
                 FieldEnv ->
                 Int ->
                 Opts ->
                 ( DataEnv,FieldMap,FieldEnv,([PP_Doc]),([PP_Doc]),([PP_Doc]),Int,([PP_Doc]))
sem_Fields_Cons :: T_Field  ->
                   T_Fields  ->
                   T_Fields 
sem_Fields_Cons hd_ tl_  =
    (\ _lhsIcon
       _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathFields
       _lhsInr
       _lhsIopts ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOgathFieldMap :: FieldMap
              _lhsOjsChecksPPs :: ([PP_Doc])
              _lhsOdistDatas :: DataEnv
              _lhsOgathFields :: FieldEnv
              _lhsOnr :: Int
              _hdOcon :: Ident
              _hdOdata :: Ident
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistDatas :: DataEnv
              _hdOgathFields :: FieldEnv
              _hdOnr :: Int
              _hdOopts :: Opts
              _tlOcon :: Ident
              _tlOdata :: Ident
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistDatas :: DataEnv
              _tlOgathFields :: FieldEnv
              _tlOnr :: Int
              _tlOopts :: Opts
              _hdIdistDatas :: DataEnv
              _hdIgathFieldMap :: FieldMap
              _hdIgathFields :: FieldEnv
              _hdIhpp :: PP_Doc
              _hdIjsChecksPPs :: ([PP_Doc])
              _hdIjspp :: PP_Doc
              _hdInr :: Int
              _hdIpp :: PP_Doc
              _tlIdistDatas :: DataEnv
              _tlIgathFieldMap :: FieldMap
              _tlIgathFields :: FieldEnv
              _tlIhpps :: ([PP_Doc])
              _tlIjsChecksPPs :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlInr :: Int
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2641, column 11)
              _lhsOpps =
                  ({-# LINE 2641 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 25958 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 570, column 11)
              _lhsOhpps =
                  ({-# LINE 570 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 25963 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 365, column 11)
              _lhsOjspps =
                  ({-# LINE 365 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 25968 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1387, column 38)
              _lhsOgathFieldMap =
                  ({-# LINE 1387 "src/Transform.ag" #-}
                   _hdIgathFieldMap `Map.union` _tlIgathFieldMap
                   {-# LINE 25973 "src/Transform.hs" #-})
              -- use rule "src/TargetJs.ag"(line 92, column 37)
              _lhsOjsChecksPPs =
                  ({-# LINE 92 "src/TargetJs.ag" #-}
                   _hdIjsChecksPPs ++ _tlIjsChecksPPs
                   {-# LINE 25978 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 25983 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathFields =
                  ({-# LINE 322 "src/Transform.ag" #-}
                   _tlIgathFields
                   {-# LINE 25988 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _tlInr
                   {-# LINE 25993 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcon =
                  ({-# LINE 295 "src/Transform.ag" #-}
                   _lhsIcon
                   {-# LINE 25998 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 26003 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 26008 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 26013 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathFields =
                  ({-# LINE 322 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 26018 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _lhsInr
                   {-# LINE 26023 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 26028 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcon =
                  ({-# LINE 295 "src/Transform.ag" #-}
                   _lhsIcon
                   {-# LINE 26033 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdata =
                  ({-# LINE 294 "src/Transform.ag" #-}
                   _lhsIdata
                   {-# LINE 26038 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 26043 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 26048 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathFields =
                  ({-# LINE 322 "src/Transform.ag" #-}
                   _hdIgathFields
                   {-# LINE 26053 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _hdInr
                   {-# LINE 26058 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 26063 "src/Transform.hs" #-})
              ( _hdIdistDatas,_hdIgathFieldMap,_hdIgathFields,_hdIhpp,_hdIjsChecksPPs,_hdIjspp,_hdInr,_hdIpp) =
                  hd_ _hdOcon _hdOdata _hdOdistAliasses _hdOdistDatas _hdOgathFields _hdOnr _hdOopts 
              ( _tlIdistDatas,_tlIgathFieldMap,_tlIgathFields,_tlIhpps,_tlIjsChecksPPs,_tlIjspps,_tlInr,_tlIpps) =
                  tl_ _tlOcon _tlOdata _tlOdistAliasses _tlOdistDatas _tlOgathFields _tlOnr _tlOopts 
          in  ( _lhsOdistDatas,_lhsOgathFieldMap,_lhsOgathFields,_lhsOhpps,_lhsOjsChecksPPs,_lhsOjspps,_lhsOnr,_lhsOpps)))
sem_Fields_Nil :: T_Fields 
sem_Fields_Nil  =
    (\ _lhsIcon
       _lhsIdata
       _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathFields
       _lhsInr
       _lhsIopts ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOgathFieldMap :: FieldMap
              _lhsOjsChecksPPs :: ([PP_Doc])
              _lhsOdistDatas :: DataEnv
              _lhsOgathFields :: FieldEnv
              _lhsOnr :: Int
              -- "src/Transform.ag"(line 2642, column 11)
              _lhsOpps =
                  ({-# LINE 2642 "src/Transform.ag" #-}
                   []
                   {-# LINE 26090 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 571, column 11)
              _lhsOhpps =
                  ({-# LINE 571 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 26095 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 366, column 11)
              _lhsOjspps =
                  ({-# LINE 366 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 26100 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1387, column 38)
              _lhsOgathFieldMap =
                  ({-# LINE 1387 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26105 "src/Transform.hs" #-})
              -- use rule "src/TargetJs.ag"(line 92, column 37)
              _lhsOjsChecksPPs =
                  ({-# LINE 92 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 26110 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 26115 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathFields =
                  ({-# LINE 322 "src/Transform.ag" #-}
                   _lhsIgathFields
                   {-# LINE 26120 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOnr =
                  ({-# LINE 330 "src/Transform.ag" #-}
                   _lhsInr
                   {-# LINE 26125 "src/Transform.hs" #-})
          in  ( _lhsOdistDatas,_lhsOgathFieldMap,_lhsOgathFields,_lhsOhpps,_lhsOjsChecksPPs,_lhsOjspps,_lhsOnr,_lhsOpps)))
-- ImplStmt ----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataCons         : ConEnv
         distDataMap          : DataMap
         distDataSems         : DataEnv
         distDatas            : DataEnv
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distItfs             : ItfEnv
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         distVisits           : VisitEnv
         doneVisits           : [Ident]
         fullCyclicVisits     : Set Ident
         gathChildDefs        : Env QIdent (QIdent,QIdent)
         gathClauses          : ClausesEnv
         gathNonterms         : NontermEnv
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         distDefs             : DefsEnv
         distVisLocalDefs     : DefsEnv
         gathDefs             : DefsEnv
         gathNextVisits       : Map Ident (Maybe Ident)
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitSource      : VisitSourceMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
         rank                 : Int
   alternatives:
      alternative DefaultChild:
         child pos            : {Pos}
         child allowEmpty     : {Bool}
         child child          : {Ident}
         child name           : {Ident}
         child mbCodeRef      : {Maybe Int}
         visit 0:
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathDeps_augmented_f3 : _
            local gathDeps_augmented_f4 : _
            local gathDeps_augmented_f5 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local childrenOrdered : _
            local availChildren : _
            local candidateChildren : _
            local _tup28      : _
            local children    : _
            local errChildren : _
            local childAttrs  : _
            local unqualChildItf : _
            local lhsHasAttr  : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local _tup29      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local ppInps      : _
            local hApp        : _
            local hInps       : _
            local hFun        : _
            local hPrefix     : _
            local jsApp       : _
            local jsArr       : _
            local jsInps      : _
            local _tup30      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
      alternative DefaultSyn:
         child pos            : {Pos}
         child allowEmpty     : {Bool}
         child name           : {Ident}
         child mbCodeRef      : {Maybe Int}
         visit 0:
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathDeps_augmented_f3 : _
            local gathDeps_augmented_f4 : _
            local gathDeps_augmented_f5 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local childrenOrdered : _
            local availChildren : _
            local candidateChildren : _
            local _tup31      : _
            local children    : _
            local errChildren : _
            local childAttrs  : _
            local unqualChildItf : _
            local lhsHasAttr  : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local _tup32      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local ppInps      : _
            local hApp        : _
            local hInps       : _
            local hFun        : _
            local hPrefix     : _
            local jsApp       : _
            local jsArr       : _
            local jsInps      : _
            local _tup33      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
      alternative DefaultVisLocal:
         child pos            : {Pos}
         child name           : {Ident}
         visit 0:
            local gathAttrSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local _tup34      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local hPrefix     : _
            local _tup35      : {(Int,Int)}
            local lexOrder    : {Int}
            local gathAttrSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
      alternative Invoke:
         child pos            : {Pos}
         child child          : {Ident}
         child visit          : {Ident}
         child itf            : {Ident}
         visit 0:
            local errs5_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathDeps_augmented_f3 : _
            local gathDeps_augmented_f4 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathNextVisits_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local gathVisitSource_augmented_f1 : _
            local childVisits : _
            local inhAttrMap  : _
            local synAttrMap  : _
            local missingAttrMap : _
            local _tup36      : _
            local deflAttrMap : _
            local undefAttrMap : _
            local deflAttrs   : _
            inst  deflts      : ImplStmts 
            local mbNextVisit : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local visitCyclic : _
            local behaveCyclic : _
            local stmtSource  : _
            local mbVisitSource : _
            local mbChildSource : _
            local _tup37      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local hBang       : _
            local hfInps      : _
            local hPat        : _
            local hGroupedStmts : _
            local jsGroupedStmts : _
            local _tup38      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs5_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
            local gathVisitSource_augmented_syn : _
            local gathNextVisits_augmented_syn : _
-}
-- cata
sem_ImplStmt :: ImplStmt  ->
                T_ImplStmt 
sem_ImplStmt (ImplStmt_DefaultChild _pos _allowEmpty _child _name _mbCodeRef )  =
    (sem_ImplStmt_DefaultChild _pos _allowEmpty _child _name _mbCodeRef )
sem_ImplStmt (ImplStmt_DefaultSyn _pos _allowEmpty _name _mbCodeRef )  =
    (sem_ImplStmt_DefaultSyn _pos _allowEmpty _name _mbCodeRef )
sem_ImplStmt (ImplStmt_DefaultVisLocal _pos _name )  =
    (sem_ImplStmt_DefaultVisLocal _pos _name )
sem_ImplStmt (ImplStmt_Invoke _pos _child _visit _itf )  =
    (sem_ImplStmt_Invoke _pos _child _visit _itf )
-- semantic domain
type T_ImplStmt  = (Map Ident (Set Ident)) ->
                   (Set Ident) ->
                   (Set Ident) ->
                   (Map Ident (Set Ident)) ->
                   QIdent ->
                   Ident ->
                   (Map Ident (Map Ident String)) ->
                   (Map Ident String) ->
                   (Map Ident AliasType) ->
                   (Map Ident [Ident]) ->
                   AttrSourceMap ->
                   AttrVisMap ->
                   (Env QIdent (QIdent,QIdent)) ->
                   (Map Ident (Set Ident)) ->
                   (Map Ident [Ident]) ->
                   (Map Ident Int) ->
                   ChildSourceMap ->
                   CycVisMap ->
                   ConEnv ->
                   DataMap ->
                   DataEnv ->
                   DataEnv ->
                   (Map Ident (Bool,Maybe Int)) ->
                   DefsEnv ->
                   AttrMap ->
                   ItfEnv ->
                   (Map DepItem (Bool,Int)) ->
                   RenameMap ->
                   AttrMap ->
                   DefsEnv ->
                   (IntMap Ident) ->
                   VisitAttrMap ->
                   (Map Ident [Ident]) ->
                   VisitSourceMap ->
                   VisitAttrMap ->
                   VisitEnv ->
                   ([Ident]) ->
                   (Set Ident) ->
                   (Env QIdent (QIdent,QIdent)) ->
                   ClausesEnv ->
                   DefsEnv ->
                   (Map Ident (Maybe Ident)) ->
                   NontermEnv ->
                   DefsEnv ->
                   ([(Int,PP_Doc)]) ->
                   QIdent ->
                   ([(Int,PP_Doc)]) ->
                   Int ->
                   QIdent ->
                   Opts ->
                   DepItem ->
                   Reason ->
                   DepItem ->
                   DepItem ->
                   DepItem ->
                   Reason ->
                   ( DefsEnv,DefsEnv,Errs,Errs,Errs,Errs,AttrSourceMap,ChildSourceMap,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Map Ident (Maybe Ident)),(Map DepItem Pos),DefsEnv,VisitSourceMap,PP_Doc,PP_Doc,Int,PP_Doc,Int)
sem_ImplStmt_DefaultChild :: Pos ->
                             Bool ->
                             Ident ->
                             Ident ->
                             (Maybe Int) ->
                             T_ImplStmt 
sem_ImplStmt_DefaultChild pos_ allowEmpty_ child_ name_ mbCodeRef_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup30 :: ((Int,Int))
              _lhsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOrank :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 26548 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   \es -> foldr (\(c,itf,vis) -> (Err_ChildSynUnav pos_ c itf vis name_ Seq.<|)) es _errChildren
                   {-# LINE 26553 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1244 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1]
                   {-# LINE 26558 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1244 "src/Transform.ag" #-}
                   if not allowEmpty_ && null _children     && not _lhsHasAttr
                   then (Err_MissingAttr True child_ (replPos pos_ name_) Seq.<|)
                   else id
                   {-# LINE 26565 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2099 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 26570 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2099 "src/Transform.ag" #-}
                   Map.insert (True,child_,name_)    _stmtSource
                   {-# LINE 26575 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2, _gathDeps_augmented_f3, _gathDeps_augmented_f4, _gathDeps_augmented_f5]
                   {-# LINE 26580 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   Seq.fromList [ Dep _stmtSource     (ReasonAttrReq c a)
                                    [Map.findWithDefault (trace "ImplStmt.Default.childsyn" unknDepItem) (False,c,a) _lhsIdistAttrSource]
                                | (c,a) <- _childAttrs     ] Seq.><
                   {-# LINE 26587 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   if _lhsHasAttr
                   then addDep _stmtSource     (ReasonAttrReq lhsIdent name_)
                          [Map.findWithDefault (trace "ImplStmt.Default.lhsinh" unknDepItem) (True,lhsIdent,name_) _lhsIdistAttrSource]
                   else id
                   {-# LINE 26595 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f3 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> id
                     Just ref -> addDep _stmtSource     (ReasonDefault name_) [DepDefault ref]
                   {-# LINE 26602 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f4 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> id
                     Just ref -> addDep _stmtSource     (ReasonDefault name_) [DepDefault ref]
                   {-# LINE 26609 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f5 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 26614 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 26619 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 26624 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 26629 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 26634 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 26639 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 26644 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1223, column 3)
              _childrenOrdered =
                  ({-# LINE 1223 "src/Transform.ag" #-}
                   map fst $ sortBy (\(_,a) (_,b) -> a `compare` b) (Map.assocs _lhsIdistChildOcc)
                   {-# LINE 26649 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1224, column 3)
              _availChildren =
                  ({-# LINE 1224 "src/Transform.ag" #-}
                   [ (c,itf, findVisitOfAttr nm itf _lhsIdistAttrVisMap)
                   | c <- _childrenOrdered
                   , let ([itf], _) = fst $ find [c] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                         nm = renameAttrFwd _lhsIdistRenames c name_
                   , hasSynAttr nm itf _lhsIdistSynAttrs
                   ]
                   {-# LINE 26659 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1231, column 30)
              _candidateChildren =
                  ({-# LINE 1231 "src/Transform.ag" #-}
                   takeWhile (\(nm,_,_) -> nm /= child_) _availChildren
                   {-# LINE 26664 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              __tup28 =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   partition (\(c,itf,vis) -> visAvailable c itf vis _lhsIavailInvokes _lhsIdistVisitOrder)
                     _candidateChildren
                   {-# LINE 26670 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              (_children,_) =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   __tup28
                   {-# LINE 26675 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              (_,_errChildren) =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   __tup28
                   {-# LINE 26680 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1240, column 3)
              _childAttrs =
                  ({-# LINE 1240 "src/Transform.ag" #-}
                   map (\(c,_,_) -> (c, renameAttrFwd _lhsIdistRenames c name_)) _children
                   {-# LINE 26685 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1256, column 3)
              _unqualChildItf =
                  ({-# LINE 1256 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 26690 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1257, column 3)
              _lhsHasAttr =
                  ({-# LINE 1257 "src/Transform.ag" #-}
                   isJust $ Map.lookup (True,name_) $
                     Map.findWithDefault Map.empty _unqualChildItf     _lhsIdistAttrVisMap
                   {-# LINE 26696 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1867, column 19)
              _destVisit =
                  ({-# LINE 1867 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 26701 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1924, column 19)
              _fullCyclic =
                  ({-# LINE 1924 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 26706 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1925, column 19)
              _allowCycles =
                  ({-# LINE 1925 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 26711 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2027, column 14)
              _stmtSource =
                  ({-# LINE 2027 "src/Transform.ag" #-}
                   DepAssert _lexOrder
                   {-# LINE 26716 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              __tup29 =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 26721 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup29
                   {-# LINE 26726 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_,_rank) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup29
                   {-# LINE 26731 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2384, column 3)
              _isCyclic =
                  ({-# LINE 2384 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 26736 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2548, column 18)
              _lhsOpp =
                  ({-# LINE 2548 "src/Transform.ag" #-}
                   "default" >#< show child_ >|< "." >|< show name_ >#< pp_block "(" ")" "," (reverse _ppInps    )
                   {-# LINE 26741 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2554, column 7)
              _ppInps =
                  ({-# LINE 2554 "src/Transform.ag" #-}
                   (if _lhsHasAttr     then [text "lhs"] else []) ++ map (\(c,_,_) -> text $ show c) _children
                   {-# LINE 26746 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 475, column 7)
              _lhsOhpp =
                  ({-# LINE 475 "src/TargetHaskell.ag" #-}
                   _hPrefix     >|< hParensWithPos _lhsIopts pos_ (hOutp child_ name_)
                   >#< "=" >#< pp_parens _hApp     >#< "-- default rule for inh: " >#< show child_ >|< "." >|< show name_
                   {-# LINE 26752 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 482, column 7)
              _hApp =
                  ({-# LINE 482 "src/TargetHaskell.ag" #-}
                   _hFun     >#< pp_block "[" "]" "," (reverse _hInps    )
                   {-# LINE 26757 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 483, column 7)
              _hInps =
                  ({-# LINE 483 "src/TargetHaskell.ag" #-}
                   (if _lhsHasAttr     then [text $ hInp lhsIdent name_] else []) ++ map (\(c,a) -> text $ hInp c a) _childAttrs
                   {-# LINE 26762 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 484, column 7)
              _hFun =
                  ({-# LINE 484 "src/TargetHaskell.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> text "head"
                     Just ref -> hParensWithPos _lhsIopts pos_ $ hDfltNm name_ ref
                   {-# LINE 26769 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 493, column 7)
              _hPrefix =
                  ({-# LINE 493 "src/TargetHaskell.ag" #-}
                   if _isCyclic     then empty else text "let "
                   {-# LINE 26774 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 268, column 7)
              _lhsOjspp =
                  ({-# LINE 268 "src/TargetJs.ag" #-}
                   "var" >#< hOutp child_ name_ >#< "=" >#< _jsApp     >|< ";"
                   {-# LINE 26779 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 273, column 7)
              _jsApp =
                  ({-# LINE 273 "src/TargetJs.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> _jsArr     >|< "[0]"
                     Just ref -> "_def" >|< show ref >#< pp_parens _jsArr
                   {-# LINE 26786 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 276, column 7)
              _jsArr =
                  ({-# LINE 276 "src/TargetJs.ag" #-}
                   pp_block "[" "]" "," (reverse _jsInps    )
                   {-# LINE 26791 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 277, column 7)
              _jsInps =
                  ({-# LINE 277 "src/TargetJs.ag" #-}
                   (if _lhsHasAttr     then [text $ jsInp lhsIdent name_] else []) ++ map (\(c,a) -> text $ jsInp c a) _childAttrs
                   {-# LINE 26796 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup30 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_lhsOlexCounter,_) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup30
                   {-# LINE 26804 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup30
                   {-# LINE 26809 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _errs2_augmented_syn =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 26814 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _errs3_augmented_syn =
                  ({-# LINE 1244 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 26819 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 26824 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs5 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 26829 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2099 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26834 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26839 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 26844 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26849 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 26854 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26859 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 26864 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 26869 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 26874 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 26879 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 26884 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 26889 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 26894 "src/Transform.hs" #-})
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOpp,_lhsOrank)))
sem_ImplStmt_DefaultSyn :: Pos ->
                           Bool ->
                           Ident ->
                           (Maybe Int) ->
                           T_ImplStmt 
sem_ImplStmt_DefaultSyn pos_ allowEmpty_ name_ mbCodeRef_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup33 :: ((Int,Int))
              _lhsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOrank :: Int
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 26985 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   \es -> foldr (\(c,itf,vis) -> (Err_ChildSynUnav pos_ c itf vis name_ Seq.<|)) es _errChildren
                   {-# LINE 26990 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1249 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1]
                   {-# LINE 26995 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1249 "src/Transform.ag" #-}
                   if not allowEmpty_ && null _children     && not _lhsHasAttr
                   then (Err_MissingAttr False (replPos pos_ lhsIdent) name_ Seq.<|)
                   else id
                   {-# LINE 27002 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2098 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 27007 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2098 "src/Transform.ag" #-}
                   Map.insert (False,lhsIdent,name_) _stmtSource
                   {-# LINE 27012 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2, _gathDeps_augmented_f3, _gathDeps_augmented_f4, _gathDeps_augmented_f5]
                   {-# LINE 27017 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   Seq.fromList [ Dep _stmtSource     (ReasonAttrReq c a)
                                    [Map.findWithDefault (trace "ImplStmt.Default.childsyn" unknDepItem) (False,c,a) _lhsIdistAttrSource]
                                | (c,a) <- _childAttrs     ] Seq.><
                   {-# LINE 27024 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   if _lhsHasAttr
                   then addDep _stmtSource     (ReasonAttrReq lhsIdent name_)
                          [Map.findWithDefault (trace "ImplStmt.Default.lhsinh" unknDepItem) (True,lhsIdent,name_) _lhsIdistAttrSource]
                   else id
                   {-# LINE 27032 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f3 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> id
                     Just ref -> addDep _stmtSource     (ReasonDefault name_) [DepDefault ref]
                   {-# LINE 27039 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f4 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> id
                     Just ref -> addDep _stmtSource     (ReasonDefault name_) [DepDefault ref]
                   {-# LINE 27046 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f5 =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 27051 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 27056 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 27061 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 27066 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 27071 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 27076 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 27081 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1223, column 3)
              _childrenOrdered =
                  ({-# LINE 1223 "src/Transform.ag" #-}
                   map fst $ sortBy (\(_,a) (_,b) -> a `compare` b) (Map.assocs _lhsIdistChildOcc)
                   {-# LINE 27086 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1224, column 3)
              _availChildren =
                  ({-# LINE 1224 "src/Transform.ag" #-}
                   [ (c,itf, findVisitOfAttr nm itf _lhsIdistAttrVisMap)
                   | c <- _childrenOrdered
                   , let ([itf], _) = fst $ find [c] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                         nm = renameAttrFwd _lhsIdistRenames c name_
                   , hasSynAttr nm itf _lhsIdistSynAttrs
                   ]
                   {-# LINE 27096 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1232, column 30)
              _candidateChildren =
                  ({-# LINE 1232 "src/Transform.ag" #-}
                   _availChildren
                   {-# LINE 27101 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              __tup31 =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   partition (\(c,itf,vis) -> visAvailable c itf vis _lhsIavailInvokes _lhsIdistVisitOrder)
                     _candidateChildren
                   {-# LINE 27107 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              (_children,_) =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   __tup31
                   {-# LINE 27112 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1238, column 3)
              (_,_errChildren) =
                  ({-# LINE 1238 "src/Transform.ag" #-}
                   __tup31
                   {-# LINE 27117 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1240, column 3)
              _childAttrs =
                  ({-# LINE 1240 "src/Transform.ag" #-}
                   map (\(c,_,_) -> (c, renameAttrFwd _lhsIdistRenames c name_)) _children
                   {-# LINE 27122 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1256, column 3)
              _unqualChildItf =
                  ({-# LINE 1256 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 27127 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1257, column 3)
              _lhsHasAttr =
                  ({-# LINE 1257 "src/Transform.ag" #-}
                   isJust $ Map.lookup (True,name_) $
                     Map.findWithDefault Map.empty _unqualChildItf     _lhsIdistAttrVisMap
                   {-# LINE 27133 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1867, column 19)
              _destVisit =
                  ({-# LINE 1867 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 27138 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1924, column 19)
              _fullCyclic =
                  ({-# LINE 1924 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 27143 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1925, column 19)
              _allowCycles =
                  ({-# LINE 1925 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 27148 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2027, column 14)
              _stmtSource =
                  ({-# LINE 2027 "src/Transform.ag" #-}
                   DepAssert _lexOrder
                   {-# LINE 27153 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              __tup32 =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 27158 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup32
                   {-# LINE 27163 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_,_rank) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup32
                   {-# LINE 27168 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2384, column 3)
              _isCyclic =
                  ({-# LINE 2384 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 27173 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2549, column 18)
              _lhsOpp =
                  ({-# LINE 2549 "src/Transform.ag" #-}
                   "default lhs." >|< show name_ >#< pp_block "(" ")" "," (reverse _ppInps    )
                   {-# LINE 27178 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2554, column 7)
              _ppInps =
                  ({-# LINE 2554 "src/Transform.ag" #-}
                   (if _lhsHasAttr     then [text "lhs"] else []) ++ map (\(c,_,_) -> text $ show c) _children
                   {-# LINE 27183 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 478, column 7)
              _lhsOhpp =
                  ({-# LINE 478 "src/TargetHaskell.ag" #-}
                   _hPrefix     >|< hParensWithPos _lhsIopts pos_ (hOutp lhsIdent name_)
                   >#< "=" >#< pp_parens _hApp     >#< "-- default rule for syn: " >#< show lhsIdent >|< "." >|< show name_
                   {-# LINE 27189 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 482, column 7)
              _hApp =
                  ({-# LINE 482 "src/TargetHaskell.ag" #-}
                   _hFun     >#< pp_block "[" "]" "," (reverse _hInps    )
                   {-# LINE 27194 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 483, column 7)
              _hInps =
                  ({-# LINE 483 "src/TargetHaskell.ag" #-}
                   (if _lhsHasAttr     then [text $ hInp lhsIdent name_] else []) ++ map (\(c,a) -> text $ hInp c a) _childAttrs
                   {-# LINE 27199 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 484, column 7)
              _hFun =
                  ({-# LINE 484 "src/TargetHaskell.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> text "head"
                     Just ref -> hParensWithPos _lhsIopts pos_ $ hDfltNm name_ ref
                   {-# LINE 27206 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 493, column 7)
              _hPrefix =
                  ({-# LINE 493 "src/TargetHaskell.ag" #-}
                   if _isCyclic     then empty else text "let "
                   {-# LINE 27211 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 270, column 7)
              _lhsOjspp =
                  ({-# LINE 270 "src/TargetJs.ag" #-}
                   "var" >#< hOutp lhsIdent name_ >#< "=" >#< _jsApp     >|< ";"
                   {-# LINE 27216 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 273, column 7)
              _jsApp =
                  ({-# LINE 273 "src/TargetJs.ag" #-}
                   case mbCodeRef_ of
                     Nothing  -> _jsArr     >|< "[0]"
                     Just ref -> "_def" >|< show ref >#< pp_parens _jsArr
                   {-# LINE 27223 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 276, column 7)
              _jsArr =
                  ({-# LINE 276 "src/TargetJs.ag" #-}
                   pp_block "[" "]" "," (reverse _jsInps    )
                   {-# LINE 27228 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 277, column 7)
              _jsInps =
                  ({-# LINE 277 "src/TargetJs.ag" #-}
                   (if _lhsHasAttr     then [text $ jsInp lhsIdent name_] else []) ++ map (\(c,a) -> text $ jsInp c a) _childAttrs
                   {-# LINE 27233 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup33 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_lhsOlexCounter,_) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup33
                   {-# LINE 27241 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup33
                   {-# LINE 27246 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _errs2_augmented_syn =
                  ({-# LINE 1241 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27251 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _errs3_augmented_syn =
                  ({-# LINE 1249 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27256 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27261 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs5 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27266 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2098 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27271 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27276 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2324 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27281 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27286 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 27291 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27296 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27301 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 27306 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 27311 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 27316 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 27321 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 27326 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 27331 "src/Transform.hs" #-})
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOpp,_lhsOrank)))
sem_ImplStmt_DefaultVisLocal :: Pos ->
                                Ident ->
                                T_ImplStmt 
sem_ImplStmt_DefaultVisLocal pos_ name_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup35 :: ((Int,Int))
              _lhsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOrank :: Int
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2100 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 27420 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2100 "src/Transform.ag" #-}
                   Map.insert (False,visIdent,name_) _stmtSource
                   {-# LINE 27425 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2316 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 27430 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2316 "src/Transform.ag" #-}
                   addDep _lhsIvisitEndDep _lhsIvisitEndReason [_stmtSource    ]
                   {-# LINE 27435 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2316 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 27440 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 27445 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 27450 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 27455 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 27460 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 27465 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 27470 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1867, column 19)
              _destVisit =
                  ({-# LINE 1867 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 27475 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1924, column 19)
              _fullCyclic =
                  ({-# LINE 1924 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 27480 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1925, column 19)
              _allowCycles =
                  ({-# LINE 1925 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 27485 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2027, column 14)
              _stmtSource =
                  ({-# LINE 2027 "src/Transform.ag" #-}
                   DepAssert _lexOrder
                   {-# LINE 27490 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              __tup34 =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 27495 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup34
                   {-# LINE 27500 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_,_rank) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup34
                   {-# LINE 27505 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2384, column 3)
              _isCyclic =
                  ({-# LINE 2384 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 27510 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2551, column 18)
              _lhsOpp =
                  ({-# LINE 2551 "src/Transform.ag" #-}
                   "default local." >|< show name_
                   {-# LINE 27515 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 488, column 7)
              _lhsOhpp =
                  ({-# LINE 488 "src/TargetHaskell.ag" #-}
                   _hPrefix     >|< hParensWithPos _lhsIopts pos_ (hOutp visIdent name_) >#< "="
                   >#< hParensWithPos _lhsIopts pos_ (hInp visIdent name_)
                   >#< "-- default rule for vis-local: " >#< show name_
                   {-# LINE 27522 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 493, column 7)
              _hPrefix =
                  ({-# LINE 493 "src/TargetHaskell.ag" #-}
                   if _isCyclic     then empty else text "let "
                   {-# LINE 27527 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 280, column 7)
              _lhsOjspp =
                  ({-# LINE 280 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 27532 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup35 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_lhsOlexCounter,_) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup35
                   {-# LINE 27540 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup35
                   {-# LINE 27545 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs2 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27550 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs3 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27555 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27560 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs5 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27565 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2100 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27570 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27575 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2316 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 27580 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27585 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 27590 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27595 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 27600 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 27605 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 27610 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 27615 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 27620 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 27625 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 27630 "src/Transform.hs" #-})
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOpp,_lhsOrank)))
sem_ImplStmt_Invoke :: Pos ->
                       Ident ->
                       Ident ->
                       Ident ->
                       T_ImplStmt 
sem_ImplStmt_Invoke pos_ child_ visit_ itf_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              deflts_val_ :: ImplStmts 
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup38 :: ((Int,Int))
              _defltsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _lhsOrank :: Int
              _defltsOallAvailInvokes :: (Map Ident (Set Ident))
              _defltsOallVisits :: (Set Ident)
              _defltsOallowCycVisits :: (Set Ident)
              _defltsOavailInvokes :: (Map Ident (Set Ident))
              _defltsObasename :: QIdent
              _defltsOcoItf :: Ident
              _defltsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _defltsOdirectVisitLocalAttrs :: (Map Ident String)
              _defltsOdistAliasses :: (Map Ident AliasType)
              _defltsOdistAllChildMinRanges :: (Map Ident [Ident])
              _defltsOdistAttrSource :: AttrSourceMap
              _defltsOdistAttrVisMap :: AttrVisMap
              _defltsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOdistChildEffRanges :: (Map Ident (Set Ident))
              _defltsOdistChildMinRanges :: (Map Ident [Ident])
              _defltsOdistChildOcc :: (Map Ident Int)
              _defltsOdistChildSource :: ChildSourceMap
              _defltsOdistCycVisMap :: CycVisMap
              _defltsOdistDataCons :: ConEnv
              _defltsOdistDataMap :: DataMap
              _defltsOdistDataSems :: DataEnv
              _defltsOdistDatas :: DataEnv
              _defltsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _defltsOdistDefs :: DefsEnv
              _defltsOdistInhAttrs :: AttrMap
              _defltsOdistItfs :: ItfEnv
              _defltsOdistRanks :: (Map DepItem (Bool,Int))
              _defltsOdistRenames :: RenameMap
              _defltsOdistSynAttrs :: AttrMap
              _defltsOdistVisLocalDefs :: DefsEnv
              _defltsOdistVisRankMap :: (IntMap Ident)
              _defltsOdistVisitInhAttrs :: VisitAttrMap
              _defltsOdistVisitOrder :: (Map Ident [Ident])
              _defltsOdistVisitSource :: VisitSourceMap
              _defltsOdistVisitSynAttrs :: VisitAttrMap
              _defltsOdistVisits :: VisitEnv
              _defltsOdoneVisits :: ([Ident])
              _defltsOfullCyclicVisits :: (Set Ident)
              _defltsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOgathClauses :: ClausesEnv
              _defltsOgathDefs :: DefsEnv
              _defltsOgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsOgathNonterms :: NontermEnv
              _defltsOgathVisLocalDefs :: DefsEnv
              _defltsOhSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOitf :: QIdent
              _defltsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOnonterm :: QIdent
              _defltsOopts :: Opts
              _defltsOscopeDep :: DepItem
              _defltsOscopeReason :: Reason
              _defltsOstmtSource :: DepItem
              _defltsOvisitBeginDep :: DepItem
              _defltsOvisitEndDep :: DepItem
              _defltsOvisitEndReason :: Reason
              _defltsIdistDefs :: DefsEnv
              _defltsIdistVisLocalDefs :: DefsEnv
              _defltsIerrs2 :: Errs
              _defltsIerrs3 :: Errs
              _defltsIerrs4 :: Errs
              _defltsIerrs5 :: Errs
              _defltsIgathAttrSource :: AttrSourceMap
              _defltsIgathChildSource :: ChildSourceMap
              _defltsIgathDefs :: DefsEnv
              _defltsIgathDeps :: Deps
              _defltsIgathItemVisits :: (Map DepItem DepItem)
              _defltsIgathLegalCycStmts :: (Set DepItem)
              _defltsIgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsIgathStmtPosMap :: (Map DepItem Pos)
              _defltsIgathVisLocalDefs :: DefsEnv
              _defltsIgathVisitSource :: VisitSourceMap
              _defltsIhopps :: ([(Int, PP_Doc)])
              _defltsIjsopps :: ([(Int, PP_Doc)])
              _defltsIlexCounter :: Int
              _defltsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs5 =
                  ({-# LINE 1962 "src/Transform.ag" #-}
                   foldr ($) _errs5_augmented_syn [_errs5_augmented_f1]
                   {-# LINE 27798 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f1 =
                  ({-# LINE 1962 "src/Transform.ag" #-}
                   if _isCyclic     && not _visitCyclic
                   then (Err_VisExpCyclic visit_ child_ Seq.<|)
                   else id
                   {-# LINE 27805 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2090 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 27810 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2090 "src/Transform.ag" #-}
                   Map.union $ Map.fromList [ ((False,child_,attr), _stmtSource    ) | attr <- Map.keys _synAttrMap     ]
                   {-# LINE 27815 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2, _gathDeps_augmented_f3, _gathDeps_augmented_f4]
                   {-# LINE 27820 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   Seq.fromList [ Dep _stmtSource     (ReasonAttrReq child_ attr)
                                    [Map.findWithDefault (trace "ImplStmt.Invoke.unknown.inh" unknDepItem) (True,child_,attr) _lhsIdistAttrSource]
                                | attr <- Map.keys _inhAttrMap     ] Seq.><
                   {-# LINE 27827 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   case _mbChildSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _stmtSource     (ReasonChildReq child_) [d]
                   {-# LINE 27834 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f3 =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   case _mbVisitSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _stmtSource     (ReasonInvokeReq visit_) [d]
                   {-# LINE 27841 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f4 =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 27846 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 27851 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 27856 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 27861 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 27866 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathNextVisits =
                  ({-# LINE 1569 "src/Transform.ag" #-}
                   foldr ($) _gathNextVisits_augmented_syn [_gathNextVisits_augmented_f1]
                   {-# LINE 27871 "src/Transform.hs" #-})
              -- augment function
              _gathNextVisits_augmented_f1 =
                  ({-# LINE 1569 "src/Transform.ag" #-}
                   Map.insertWith (laterVisit _childVisits    ) child_ _mbNextVisit
                   {-# LINE 27876 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 27881 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 27886 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitSource =
                  ({-# LINE 2147 "src/Transform.ag" #-}
                   foldr ($) _gathVisitSource_augmented_syn [_gathVisitSource_augmented_f1]
                   {-# LINE 27891 "src/Transform.hs" #-})
              -- augment function
              _gathVisitSource_augmented_f1 =
                  ({-# LINE 2147 "src/Transform.ag" #-}
                   Map.insertWith mappend child_ (Map.singleton visit_ _stmtSource    )
                   {-# LINE 27896 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 445, column 13)
              _childVisits =
                  ({-# LINE 445 "src/Transform.ag" #-}
                   Map.findWithDefault [] itf_ _lhsIdistVisitOrder
                   {-# LINE 27901 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1168, column 3)
              _inhAttrMap =
                  ({-# LINE 1168 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty visit_ (Map.findWithDefault Map.empty itf_ _lhsIdistVisitInhAttrs)
                   {-# LINE 27906 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1169, column 3)
              _synAttrMap =
                  ({-# LINE 1169 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty visit_ (Map.findWithDefault Map.empty itf_ _lhsIdistVisitSynAttrs)
                   {-# LINE 27911 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1171, column 3)
              _missingAttrMap =
                  ({-# LINE 1171 "src/Transform.ag" #-}
                   Map.filterWithKey (\n _ -> not $ defined (child_,n,True) _lhsIdistDefs) _inhAttrMap
                   {-# LINE 27916 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1172, column 3)
              __tup36 =
                  ({-# LINE 1172 "src/Transform.ag" #-}
                   Map.partitionWithKey (\n _ -> Map.member n _lhsIdistDeflStmts) _missingAttrMap
                   {-# LINE 27921 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1172, column 3)
              (_deflAttrMap,_) =
                  ({-# LINE 1172 "src/Transform.ag" #-}
                   __tup36
                   {-# LINE 27926 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1172, column 3)
              (_,_undefAttrMap) =
                  ({-# LINE 1172 "src/Transform.ag" #-}
                   __tup36
                   {-# LINE 27931 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1173, column 3)
              _deflAttrs =
                  ({-# LINE 1173 "src/Transform.ag" #-}
                   [ (a, Map.findWithDefault (False,Nothing) a _lhsIdistDeflStmts) | a <- Map.keys _deflAttrMap     ]
                   {-# LINE 27936 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1176, column 3)
              _lhsOdistDefs =
                  ({-# LINE 1176 "src/Transform.ag" #-}
                   Map.foldWithKey (\n _ -> snd . find (child_,replPos pos_ n,True) Nothing) _lhsIdistDefs _undefAttrMap
                   {-# LINE 27941 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1177, column 3)
              _lhsOgathDefs =
                  ({-# LINE 1177 "src/Transform.ag" #-}
                   Map.foldWithKey (\n t -> extend (child_,replPos pos_ n,False) (Just t)) _lhsIgathDefs _synAttrMap
                   {-# LINE 27946 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1216, column 3)
              deflts_val_ =
                  ({-# LINE 1216 "src/Transform.ag" #-}
                   map (\(nm,(empty,mbCode)) -> ImplStmt_DefaultChild pos_ empty child_ nm mbCode) _deflAttrs
                   {-# LINE 27951 "src/Transform.hs" #-})
              deflts_inst_ =
                  (sem_ImplStmts deflts_val_ )
              -- "src/Transform.ag"(line 1557, column 24)
              _mbNextVisit =
                  ({-# LINE 1557 "src/Transform.ag" #-}
                   visitAfter visit_ _childVisits
                   {-# LINE 27958 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1867, column 19)
              _destVisit =
                  ({-# LINE 1867 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 27963 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1924, column 19)
              _fullCyclic =
                  ({-# LINE 1924 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 27968 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1925, column 19)
              _allowCycles =
                  ({-# LINE 1925 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 27973 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1932, column 3)
              _visitCyclic =
                  ({-# LINE 1932 "src/Transform.ag" #-}
                   Set.member visit_ (Map.findWithDefault Set.empty itf_ _lhsIdistCycVisMap)
                   {-# LINE 27978 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1933, column 3)
              _behaveCyclic =
                  ({-# LINE 1933 "src/Transform.ag" #-}
                   _fullCyclic     || _visitCyclic
                   {-# LINE 27983 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2025, column 14)
              _stmtSource =
                  ({-# LINE 2025 "src/Transform.ag" #-}
                   DepInvoke (visit_ : child_ : _lhsIbasename)
                   {-# LINE 27988 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2252, column 3)
              _mbVisitSource =
                  ({-# LINE 2252 "src/Transform.ag" #-}
                   nearestVisitEntry False visit_ _childVisits     $ Map.findWithDefault Map.empty child_ _lhsIdistVisitSource
                   {-# LINE 27993 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2253, column 3)
              _mbChildSource =
                  ({-# LINE 2253 "src/Transform.ag" #-}
                   nearestVisitEntry True  visit_ _childVisits     $ Map.findWithDefault Map.empty child_ _lhsIdistChildSource
                   {-# LINE 27998 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              __tup37 =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 28003 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup37
                   {-# LINE 28008 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2383, column 3)
              (_,_rank) =
                  ({-# LINE 2383 "src/Transform.ag" #-}
                   __tup37
                   {-# LINE 28013 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2384, column 3)
              _isCyclic =
                  ({-# LINE 2384 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 28018 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2546, column 18)
              _lhsOpp =
                  ({-# LINE 2546 "src/Transform.ag" #-}
                   vlist _defltsIpps
                   >-< "invoke" >#< show visit_ >#< "of" >#< show child_ >#< "-- implicit"
                   {-# LINE 28024 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 451, column 8)
              _hBang =
                  ({-# LINE 451 "src/TargetHaskell.ag" #-}
                   if _behaveCyclic     then empty else text "!"
                   {-# LINE 28029 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 452, column 8)
              _lhsOhpp =
                  ({-# LINE 452 "src/TargetHaskell.ag" #-}
                   (if _isCyclic
                     then vlist (concat _hGroupedStmts    )
                     else hppStmtBlock _hGroupedStmts    )
                   >-< ppBind _isCyclic
                              (_hBang     >|< _hPat    )
                              ((\p -> if not _isCyclic     && _behaveCyclic     then "return" >#< pp_parens p else p) (
                              "let" >#< _hBang     >|< pp_parens (hItfVsNm itf_ visit_ >#< "!" >|< "__f")
                                     >#< "=" >#< hSemNm child_ visit_
                               >-< "in" >#< "__f" >#< _hfInps    ))
                         >#< "-- implicit invoke: " >#< show child_ >|< "." >|< show visit_
                   {-# LINE 28043 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 462, column 8)
              _hfInps =
                  ({-# LINE 462 "src/TargetHaskell.ag" #-}
                   pp_parens (hInhDt itf_ visit_ >#< pp_block "{" "}" ","
                     [ hInhFldNm nm itf_ visit_ >#< "=" >#<
                         hParensWithPos _lhsIopts pos_ (hOutp child_ nm)
                     | (nm,_) <- Map.assocs _inhAttrMap     ] )
                   {-# LINE 28051 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 466, column 8)
              _hPat =
                  ({-# LINE 466 "src/TargetHaskell.ag" #-}
                   pp_parens (
                     hSynDt itf_ visit_ >#< pp_block "{" "}" "," (
                       ( maybe [] (\nm -> [ hSynFldNmFull nextIdent itf_ visit_ >#< "=" >#< hSemNm child_ nm ])
                         _mbNextVisit    ) ++
                       [ hSynFldNm nm itf_ visit_ >#< "=" >#< hParensWithPos _lhsIopts pos_ (hInp child_ nm)
                       | (nm,_) <- Map.assocs _synAttrMap     ]
                   ))
                   {-# LINE 28062 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 608, column 24)
              _hGroupedStmts =
                  ({-# LINE 608 "src/TargetHaskell.ag" #-}
                   groupPairs _defltsIhopps
                   {-# LINE 28067 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 252, column 8)
              _lhsOjspp =
                  ({-# LINE 252 "src/TargetJs.ag" #-}
                   jsppStmtBlock _jsGroupedStmts
                   >-< "var _args = new Inh_" >|< jsConNm itf_ visit_ >|< "();"
                   >-< vlist [ "_args." >|< show nm >#< "=" >#< jsOutp child_ nm >|< ";"
                             | (nm,_) <- Map.assocs _inhAttrMap     ]
                   >-< "if (!" >|< jsVis child_ visit_ >|< ") { throw \"uninitialized semantics: ">|< jsVis child_ visit_ >#< " (impl)\"; }"
                   >-< "var _res =" >#< jsVis child_ visit_ >#< pp_parens (text "_args") >|< ";"
                   >-< "_res.check();"
                   >-< vlist [ "var" >#< (jsInp child_ nm) >#< "=" >#< "_res." >|< show nm >|< ";"
                             | (nm,_) <- Map.assocs _synAttrMap     ]
                   >-< case _mbNextVisit     of
                         Nothing   -> empty
                         Just next -> "var" >#< jsVis child_ next >#< "= _res._next;"
                   {-# LINE 28083 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 403, column 24)
              _jsGroupedStmts =
                  ({-# LINE 403 "src/TargetJs.ag" #-}
                   groupPairs _defltsIjsopps
                   {-# LINE 28088 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup38 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_defltsOlexCounter,_) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup38
                   {-# LINE 28096 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1285 "src/Transform.ag" #-}
                   __tup38
                   {-# LINE 28101 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs2 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _defltsIerrs2
                   {-# LINE 28106 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs3 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _defltsIerrs3
                   {-# LINE 28111 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _defltsIerrs4
                   {-# LINE 28116 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _errs5_augmented_syn =
                  ({-# LINE 1962 "src/Transform.ag" #-}
                   _defltsIerrs5
                   {-# LINE 28121 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2090 "src/Transform.ag" #-}
                   _defltsIgathAttrSource
                   {-# LINE 28126 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _defltsIgathChildSource
                   {-# LINE 28131 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2260 "src/Transform.ag" #-}
                   _defltsIgathDeps
                   {-# LINE 28136 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1996 "src/Transform.ag" #-}
                   _defltsIgathItemVisits
                   {-# LINE 28141 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 2000 "src/Transform.ag" #-}
                   _defltsIgathLegalCycStmts
                   {-# LINE 28146 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2032 "src/Transform.ag" #-}
                   _defltsIgathStmtPosMap
                   {-# LINE 28151 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _gathVisitSource_augmented_syn =
                  ({-# LINE 2147 "src/Transform.ag" #-}
                   _defltsIgathVisitSource
                   {-# LINE 28156 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _defltsIdistVisLocalDefs
                   {-# LINE 28161 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathNextVisits_augmented_syn =
                  ({-# LINE 1569 "src/Transform.ag" #-}
                   _defltsIgathNextVisits
                   {-# LINE 28166 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _defltsIgathVisLocalDefs
                   {-# LINE 28171 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _defltsIlexCounter
                   {-# LINE 28176 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 28181 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 28186 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 28191 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 28196 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 28201 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 28206 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 28211 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 28216 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 28221 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 28226 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 28231 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 28236 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 28241 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 28246 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 28251 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 28256 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 28261 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 28266 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 28271 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 28276 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 28281 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 28286 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 28291 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 28296 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 28301 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 28306 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 28311 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 28316 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 28321 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 28326 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 28331 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 28336 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 28341 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 28346 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 28351 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 28356 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 28361 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 28366 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 28371 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 28376 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 28381 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 28386 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 28391 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 28396 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 28401 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 28406 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 28411 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 28416 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 28421 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 28426 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 28431 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 28436 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 28441 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 28446 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 28451 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 28456 "src/Transform.hs" #-})
              ( _defltsIdistDefs,_defltsIdistVisLocalDefs,_defltsIerrs2,_defltsIerrs3,_defltsIerrs4,_defltsIerrs5,_defltsIgathAttrSource,_defltsIgathChildSource,_defltsIgathDefs,_defltsIgathDeps,_defltsIgathItemVisits,_defltsIgathLegalCycStmts,_defltsIgathNextVisits,_defltsIgathStmtPosMap,_defltsIgathVisLocalDefs,_defltsIgathVisitSource,_defltsIhopps,_defltsIjsopps,_defltsIlexCounter,_defltsIpps) =
                  deflts_inst_ _defltsOallAvailInvokes _defltsOallVisits _defltsOallowCycVisits _defltsOavailInvokes _defltsObasename _defltsOcoItf _defltsOdirectVisitAttrs _defltsOdirectVisitLocalAttrs _defltsOdistAliasses _defltsOdistAllChildMinRanges _defltsOdistAttrSource _defltsOdistAttrVisMap _defltsOdistChildDefs _defltsOdistChildEffRanges _defltsOdistChildMinRanges _defltsOdistChildOcc _defltsOdistChildSource _defltsOdistCycVisMap _defltsOdistDataCons _defltsOdistDataMap _defltsOdistDataSems _defltsOdistDatas _defltsOdistDeflStmts _defltsOdistDefs _defltsOdistInhAttrs _defltsOdistItfs _defltsOdistRanks _defltsOdistRenames _defltsOdistSynAttrs _defltsOdistVisLocalDefs _defltsOdistVisRankMap _defltsOdistVisitInhAttrs _defltsOdistVisitOrder _defltsOdistVisitSource _defltsOdistVisitSynAttrs _defltsOdistVisits _defltsOdoneVisits _defltsOfullCyclicVisits _defltsOgathChildDefs _defltsOgathClauses _defltsOgathDefs _defltsOgathNextVisits _defltsOgathNonterms _defltsOgathVisLocalDefs _defltsOhSpilledStmts _defltsOitf _defltsOjsSpilledStmts _defltsOlexCounter _defltsOnonterm _defltsOopts _defltsOscopeDep _defltsOscopeReason _defltsOstmtSource _defltsOvisitBeginDep _defltsOvisitEndDep _defltsOvisitEndReason 
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOpp,_lhsOrank)))
-- ImplStmts ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataCons         : ConEnv
         distDataMap          : DataMap
         distDataSems         : DataEnv
         distDatas            : DataEnv
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distItfs             : ItfEnv
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         distVisits           : VisitEnv
         doneVisits           : [Ident]
         fullCyclicVisits     : Set Ident
         gathChildDefs        : Env QIdent (QIdent,QIdent)
         gathClauses          : ClausesEnv
         gathNonterms         : NontermEnv
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         distDefs             : DefsEnv
         distVisLocalDefs     : DefsEnv
         gathDefs             : DefsEnv
         gathNextVisits       : Map Ident (Maybe Ident)
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitSource      : VisitSourceMap
         hopps                : [(Int, PP_Doc)]
         jsopps               : [(Int, PP_Doc)]
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : ImplStmt 
         child tl             : ImplStmts 
      alternative Nil:
-}
-- cata
sem_ImplStmts :: ImplStmts  ->
                 T_ImplStmts 
sem_ImplStmts list  =
    (Prelude.foldr sem_ImplStmts_Cons sem_ImplStmts_Nil (Prelude.map sem_ImplStmt list) )
-- semantic domain
type T_ImplStmts  = (Map Ident (Set Ident)) ->
                    (Set Ident) ->
                    (Set Ident) ->
                    (Map Ident (Set Ident)) ->
                    QIdent ->
                    Ident ->
                    (Map Ident (Map Ident String)) ->
                    (Map Ident String) ->
                    (Map Ident AliasType) ->
                    (Map Ident [Ident]) ->
                    AttrSourceMap ->
                    AttrVisMap ->
                    (Env QIdent (QIdent,QIdent)) ->
                    (Map Ident (Set Ident)) ->
                    (Map Ident [Ident]) ->
                    (Map Ident Int) ->
                    ChildSourceMap ->
                    CycVisMap ->
                    ConEnv ->
                    DataMap ->
                    DataEnv ->
                    DataEnv ->
                    (Map Ident (Bool,Maybe Int)) ->
                    DefsEnv ->
                    AttrMap ->
                    ItfEnv ->
                    (Map DepItem (Bool,Int)) ->
                    RenameMap ->
                    AttrMap ->
                    DefsEnv ->
                    (IntMap Ident) ->
                    VisitAttrMap ->
                    (Map Ident [Ident]) ->
                    VisitSourceMap ->
                    VisitAttrMap ->
                    VisitEnv ->
                    ([Ident]) ->
                    (Set Ident) ->
                    (Env QIdent (QIdent,QIdent)) ->
                    ClausesEnv ->
                    DefsEnv ->
                    (Map Ident (Maybe Ident)) ->
                    NontermEnv ->
                    DefsEnv ->
                    ([(Int,PP_Doc)]) ->
                    QIdent ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    QIdent ->
                    Opts ->
                    DepItem ->
                    Reason ->
                    DepItem ->
                    DepItem ->
                    DepItem ->
                    Reason ->
                    ( DefsEnv,DefsEnv,Errs,Errs,Errs,Errs,AttrSourceMap,ChildSourceMap,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Map Ident (Maybe Ident)),(Map DepItem Pos),DefsEnv,VisitSourceMap,([(Int, PP_Doc)]),([(Int, PP_Doc)]),Int,([PP_Doc]))
sem_ImplStmts_Cons :: T_ImplStmt  ->
                      T_ImplStmts  ->
                      T_ImplStmts 
sem_ImplStmts_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int, PP_Doc)])
              _lhsOjsopps :: ([(Int, PP_Doc)])
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOallowCycVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisRankMap :: (IntMap Ident)
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOfullCyclicVisits :: (Set Ident)
              _hdOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNextVisits :: (Map Ident (Maybe Ident))
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOallowCycVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisRankMap :: (IntMap Ident)
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOfullCyclicVisits :: (Set Ident)
              _tlOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNextVisits :: (Map Ident (Maybe Ident))
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIdistDefs :: DefsEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAttrSource :: AttrSourceMap
              _hdIgathChildSource :: ChildSourceMap
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNextVisits :: (Map Ident (Maybe Ident))
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitSource :: VisitSourceMap
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIpp :: PP_Doc
              _hdIrank :: Int
              _tlIdistDefs :: DefsEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAttrSource :: AttrSourceMap
              _tlIgathChildSource :: ChildSourceMap
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNextVisits :: (Map Ident (Maybe Ident))
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitSource :: VisitSourceMap
              _tlIhopps :: ([(Int, PP_Doc)])
              _tlIjsopps :: ([(Int, PP_Doc)])
              _tlIlexCounter :: Int
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2661, column 11)
              _lhsOpps =
                  ({-# LINE 2661 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 28842 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 624, column 11)
              _lhsOhopps =
                  ({-# LINE 624 "src/TargetHaskell.ag" #-}
                   (_hdIrank, _hdIhpp) : _tlIhopps
                   {-# LINE 28847 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 413, column 11)
              _lhsOjsopps =
                  ({-# LINE 413 "src/TargetJs.ag" #-}
                   (_hdIrank, _hdIjspp) : _tlIjsopps
                   {-# LINE 28852 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs2 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 28857 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs3 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 28862 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 28867 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs5 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 28872 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _hdIgathAttrSource `Map.union` _tlIgathAttrSource
                   {-# LINE 28877 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _hdIgathChildSource `unionWithUnion` _tlIgathChildSource
                   {-# LINE 28882 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 28887 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 28892 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 28897 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 28902 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _hdIgathVisitSource `unionWithUnion` _tlIgathVisitSource
                   {-# LINE 28907 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 28912 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 28917 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 28922 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _tlIgathNextVisits
                   {-# LINE 28927 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 28932 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 28937 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 28942 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 28947 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 28952 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 28957 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 28962 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 28967 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 28972 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 28977 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 28982 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 28987 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 28992 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 28997 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 29002 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 29007 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 29012 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 29017 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 29022 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 29027 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 29032 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 29037 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 29042 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 29047 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 29052 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 29057 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 29062 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 29067 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 29072 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 29077 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 29082 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 29087 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 29092 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 29097 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 29102 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 29107 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 29112 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 29117 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 29122 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 29127 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 29132 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 29137 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 29142 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 29147 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 29152 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 29157 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 29162 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 29167 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 29172 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 29177 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 29182 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 29187 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 29192 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 29197 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 29202 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 29207 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 29212 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 29217 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 29222 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 29227 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 29232 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 29237 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 29242 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 29247 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 29252 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 29257 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 29262 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 29267 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 29272 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 29277 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 29282 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 29287 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 29292 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 29297 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 29302 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 29307 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 29312 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 29317 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 29322 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 29327 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 29332 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 29337 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 29342 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 29347 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 29352 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 29357 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 29362 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 29367 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 29372 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 29377 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 29382 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 29387 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 29392 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 29397 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 29402 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 29407 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 29412 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 29417 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 29422 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _hdIgathNextVisits
                   {-# LINE 29427 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 29432 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 29437 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 29442 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 29447 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 29452 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 29457 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 29462 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 29467 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 29472 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 29477 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 29482 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 29487 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 29492 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 29497 "src/Transform.hs" #-})
              ( _hdIdistDefs,_hdIdistVisLocalDefs,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAttrSource,_hdIgathChildSource,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNextVisits,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitSource,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIpp,_hdIrank) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOallowCycVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisRankMap _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOfullCyclicVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDefs _hdOgathNextVisits _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIdistDefs,_tlIdistVisLocalDefs,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAttrSource,_tlIgathChildSource,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNextVisits,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitSource,_tlIhopps,_tlIjsopps,_tlIlexCounter,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOallowCycVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisRankMap _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOfullCyclicVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDefs _tlOgathNextVisits _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOpps)))
sem_ImplStmts_Nil :: T_ImplStmts 
sem_ImplStmts_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int, PP_Doc)])
              _lhsOjsopps :: ([(Int, PP_Doc)])
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2662, column 11)
              _lhsOpps =
                  ({-# LINE 2662 "src/Transform.ag" #-}
                   []
                   {-# LINE 29585 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 625, column 11)
              _lhsOhopps =
                  ({-# LINE 625 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 29590 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 414, column 11)
              _lhsOjsopps =
                  ({-# LINE 414 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 29595 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs2 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 29600 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs3 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 29605 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs4 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 29610 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 107, column 55)
              _lhsOerrs5 =
                  ({-# LINE 107 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 29615 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 29620 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 29625 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 29630 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 29635 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 29640 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 29645 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 29650 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 29655 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 29660 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 29665 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 29670 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 29675 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 29680 "src/Transform.hs" #-})
          in  ( _lhsOdistDefs,_lhsOdistVisLocalDefs,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathChildSource,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNextVisits,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitSource,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOpps)))
-- Item --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         hppType              : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Attr:
         child pos            : {Pos}
         child child          : {Ident}
         child name           : {Ident}
         visit 0:
            local _tup39      : _
            local _tup40      : _
            local childItf    : _
            local startVisit  : _
            local origName    : _
            inst  tp          : AttrTypeCode 
            local diff        : _
            local hppType     : _
      alternative Brackets:
         child pos            : {Pos}
         child items          : Items 
         child posEnd         : {Pos}
         visit 0:
            local diff        : _
            local diff2       : _
            local hppType     : _
      alternative CoSem:
         child pos            : {Pos}
         child name           : {Ident}
         child tp             : {Ident}
         child visit          : {Ident}
         child vars           : Vars 
         child mbMonad        : {Maybe String}
         child first          : SemVisit 
         visit 0:
            local distItfs_augmented_f1 : _
            local errs0_augmented_f1 : _
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local errs3_augmented_f3 : _
            local errs3_augmented_f4 : _
            local gathNonterms_augmented_f1 : _
            local coItf       : _
            local firstVisit  : _
            local _tup41      : _
            local localChildDefs : _
            local _tup42      : _
            local localChildDefs' : _
            local nextVisits  : _
            local doneVisits  : _
            local gathDefsIn  : _
            local gathDefsInh : _
            local _tup43      : _
            local localDefs   : _
            local _tup44      : _
            local localVisLocalDefs : _
            local _tup45      : _
            local localDefs'  : _
            local _tup46      : _
            local localVisLocalDefs' : _
            local basename    : _
            local semBasename : _
            local myNextVisits : _
            local inhAttrMap  : _
            local inhAttrSource : _
            local diff        : _
            local hppType     : _
            local errs0_augmented_syn : _
            local errs1_augmented_syn : _
            local errs3_augmented_syn : _
            local distItfs_augmented_syn : _
            local gathNonterms_augmented_syn : _
      alternative Construct:
         child pos            : {Pos}
         child data           : {Ident}
         child con            : {Ident}
         child fields         : ExprFields 
         visit 0:
            local distDatas_augmented_f1 : _
            local errs0_augmented_f1 : _
            local errs0_augmented_f2 : _
            local gathFieldEnv : _
            local _tup47      : _
            local fieldEnv    : _
            local fields      : _
            local mbAlias     : _
            local diff        : _
            local hFldsPPs    : _
            local hpp         : _
            local hppType     : _
            local jspp        : _
            local errs0_augmented_syn : _
            local distDatas_augmented_syn : _
      alternative DataSem:
         child sem            : DataSem 
         visit 0:
            local pos         : _
            local diff        : _
            local hppType     : _
      alternative Detach:
         child pos            : {Pos}
         child visit          : {Ident}
         child name           : {Ident}
         visit 0:
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local _tup48      : _
            local _tup49      : _
            local childItf    : _
            local startVisit  : _
            local visitOrder  : _
            local unqualChildItf : _
            local childVisits : _
            local minRanges   : _
            local potentialReqs : _
            local actualReqs  : _
            local invokeReqs  : _
            local mbVisitSource : _
            local mbChildSource : _
            local diff        : _
            local hppType     : _
            local gathDeps_augmented_syn : _
      alternative Plain:
         child pos            : {Pos}
         child txt            : {String}
         visit 0:
            local pp          : _
            local diff        : _
            local hppType     : _
      alternative Sem:
         child pos            : {Pos}
         child name           : {Ident}
         child tp             : {Ident}
         child vars           : Vars 
         child mbMonad        : {Maybe String}
         child first          : SemVisit 
         visit 0:
            local distItfs_augmented_f1 : _
            local errs0_augmented_f1 : _
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local errs3_augmented_f3 : _
            local errs3_augmented_f4 : _
            local gathNonterms_augmented_f1 : _
            local firstVisit  : _
            local _tup50      : _
            local localChildDefs : _
            local _tup51      : _
            local localChildDefs' : _
            local nextVisits  : _
            local doneVisits  : _
            local gathDefsIn  : _
            local gathDefsInh : _
            local _tup52      : _
            local localDefs   : _
            local _tup53      : _
            local localVisLocalDefs : _
            local _tup54      : _
            local localDefs'  : _
            local _tup55      : _
            local localVisLocalDefs' : _
            local basename    : _
            local semBasename : _
            local myNextVisits : _
            local inhAttrMap  : _
            local inhAttrSource : _
            local diff        : _
            local hppType     : _
            local errs0_augmented_syn : _
            local errs1_augmented_syn : _
            local errs3_augmented_syn : _
            local distItfs_augmented_syn : _
            local gathNonterms_augmented_syn : _
-}
-- cata
sem_Item :: Item  ->
            T_Item 
sem_Item (Item_Attr _pos _child _name )  =
    (sem_Item_Attr _pos _child _name )
sem_Item (Item_Brackets _pos _items _posEnd )  =
    (sem_Item_Brackets _pos (sem_Items _items ) _posEnd )
sem_Item (Item_CoSem _pos _name _tp _visit _vars _mbMonad _first )  =
    (sem_Item_CoSem _pos _name _tp _visit (sem_Vars _vars ) _mbMonad (sem_SemVisit _first ) )
sem_Item (Item_Construct _pos _data _con _fields )  =
    (sem_Item_Construct _pos _data _con (sem_ExprFields _fields ) )
sem_Item (Item_DataSem _sem )  =
    (sem_Item_DataSem (sem_DataSem _sem ) )
sem_Item (Item_Detach _pos _visit _name )  =
    (sem_Item_Detach _pos _visit _name )
sem_Item (Item_Plain _pos _txt )  =
    (sem_Item_Plain _pos _txt )
sem_Item (Item_Sem _pos _name _tp _vars _mbMonad _first )  =
    (sem_Item_Sem _pos _name _tp (sem_Vars _vars ) _mbMonad (sem_SemVisit _first ) )
-- semantic domain
type T_Item  = (Map Ident (Set Ident)) ->
               (Set Ident) ->
               (Map Ident (Set Ident)) ->
               QIdent ->
               Ident ->
               Int ->
               (Map Ident (Map Ident String)) ->
               (Map Ident String) ->
               (Map Ident AliasType) ->
               (Map Ident [Ident]) ->
               AttrSourceMap ->
               AttrVisMap ->
               (Env QIdent (QIdent,QIdent)) ->
               (Map Ident (Set Ident)) ->
               (Map Ident [Ident]) ->
               (Map Ident Int) ->
               ChildSourceMap ->
               CycVisMap ->
               ConEnv ->
               DataMap ->
               DataSemEnv ->
               DataEnv ->
               (Map Ident (Bool,Maybe Int)) ->
               DefsEnv ->
               AttrMap ->
               ItfEnv ->
               (Map DepItem (Bool,Int)) ->
               RenameMap ->
               AttrMap ->
               DefsEnv ->
               VisitAttrMap ->
               (Map Ident [Ident]) ->
               VisitSourceMap ->
               VisitAttrMap ->
               VisitEnv ->
               ([Ident]) ->
               (Env QIdent (QIdent, QIdent)) ->
               ClausesEnv ->
               DataSemEnv ->
               DefsEnv ->
               NontermEnv ->
               DefsEnv ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               Opts ->
               DepItem ->
               Reason ->
               DepItem ->
               DepItem ->
               DepItem ->
               Reason ->
               ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),PP_Doc,PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),PP_Doc)
sem_Item_Attr :: Pos ->
                 Ident ->
                 Ident ->
                 T_Item 
sem_Item_Attr pos_ child_ name_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              tp_val_ :: AttrTypeCode 
              _tpOchild :: Ident
              _tpOname :: Ident
              _tpOchildItf :: Ident
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _tpOallAvailInvokes :: (Map Ident (Set Ident))
              _tpOallVisits :: (Set Ident)
              _tpOavailInvokes :: (Map Ident (Set Ident))
              _tpObasename :: QIdent
              _tpOcoItf :: Ident
              _tpOcodeIdCounter :: Int
              _tpOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tpOdirectVisitLocalAttrs :: (Map Ident String)
              _tpOdistAliasses :: (Map Ident AliasType)
              _tpOdistAllChildMinRanges :: (Map Ident [Ident])
              _tpOdistAttrSource :: AttrSourceMap
              _tpOdistAttrVisMap :: AttrVisMap
              _tpOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tpOdistChildEffRanges :: (Map Ident (Set Ident))
              _tpOdistChildMinRanges :: (Map Ident [Ident])
              _tpOdistChildOcc :: (Map Ident Int)
              _tpOdistChildSource :: ChildSourceMap
              _tpOdistCycVisMap :: CycVisMap
              _tpOdistDataCons :: ConEnv
              _tpOdistDataMap :: DataMap
              _tpOdistDataSems :: DataSemEnv
              _tpOdistDatas :: DataEnv
              _tpOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tpOdistDefs :: DefsEnv
              _tpOdistInhAttrs :: AttrMap
              _tpOdistItfs :: ItfEnv
              _tpOdistRanks :: (Map DepItem (Bool,Int))
              _tpOdistRenames :: RenameMap
              _tpOdistSynAttrs :: AttrMap
              _tpOdistVisLocalDefs :: DefsEnv
              _tpOdistVisitInhAttrs :: VisitAttrMap
              _tpOdistVisitOrder :: (Map Ident [Ident])
              _tpOdistVisitSource :: VisitSourceMap
              _tpOdistVisitSynAttrs :: VisitAttrMap
              _tpOdistVisits :: VisitEnv
              _tpOdoneVisits :: ([Ident])
              _tpOgathClauses :: ClausesEnv
              _tpOgathDataSems :: DataSemEnv
              _tpOgathDefs :: DefsEnv
              _tpOgathNonterms :: NontermEnv
              _tpOgathVisLocalDefs :: DefsEnv
              _tpOhSpilledStmts :: ([(Int,PP_Doc)])
              _tpOitf :: QIdent
              _tpOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tpOlexCounter :: Int
              _tpOnonterm :: QIdent
              _tpOopts :: Opts
              _tpOscopeDep :: DepItem
              _tpOscopeReason :: Reason
              _tpOstmtSource :: DepItem
              _tpOvisitBeginDep :: DepItem
              _tpOvisitEndDep :: DepItem
              _tpOvisitEndReason :: Reason
              _tpIallReqInvokes :: (Map Ident (Set Ident))
              _tpIcodeIdCounter :: Int
              _tpIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tpIdistDataCons :: ConEnv
              _tpIdistDataSems :: DataSemEnv
              _tpIdistDatas :: DataEnv
              _tpIdistDefs :: DefsEnv
              _tpIdistItfs :: ItfEnv
              _tpIdistVisLocalDefs :: DefsEnv
              _tpIdistVisits :: VisitEnv
              _tpIerrs0 :: Errs
              _tpIerrs1 :: Errs
              _tpIerrs2 :: Errs
              _tpIerrs3 :: Errs
              _tpIerrs4 :: Errs
              _tpIerrs5 :: Errs
              _tpIgathAttrSource :: AttrSourceMap
              _tpIgathAvoidVisits :: (Set DepItem)
              _tpIgathChildSource :: ChildSourceMap
              _tpIgathClauses :: ClausesEnv
              _tpIgathDataSems :: DataSemEnv
              _tpIgathDefs :: DefsEnv
              _tpIgathDeps :: Deps
              _tpIgathItemVisits :: (Map DepItem DepItem)
              _tpIgathLegalCycStmts :: (Set DepItem)
              _tpIgathMissingInvokes :: (Set (Ident,Ident))
              _tpIgathNonterms :: NontermEnv
              _tpIgathSemStarts :: (Seq DepItem)
              _tpIgathStmtPosMap :: (Map DepItem Pos)
              _tpIgathVisLocalDefs :: DefsEnv
              _tpIgathVisitEnds :: (Seq DepItem)
              _tpIgathVisitSource :: VisitSourceMap
              _tpIgathVisitStarts :: (Seq DepItem)
              _tpIhpp :: PP_Doc
              _tpIjspp :: PP_Doc
              _tpIlexCounter :: Int
              _tpIminReqInvokes :: (Map Ident (Set Ident))
              -- "src/Transform.ag"(line 518, column 13)
              __tup39 =
                  ({-# LINE 518 "src/Transform.ag" #-}
                   find [child_] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                   {-# LINE 30209 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 518, column 13)
              (__tup40,_) =
                  ({-# LINE 518 "src/Transform.ag" #-}
                   __tup39
                   {-# LINE 30214 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 518, column 13)
              (_childItf,_) =
                  ({-# LINE 518 "src/Transform.ag" #-}
                   __tup40
                   {-# LINE 30219 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 518, column 13)
              (_,_startVisit) =
                  ({-# LINE 518 "src/Transform.ag" #-}
                   __tup40
                   {-# LINE 30224 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 518, column 13)
              (_,_lhsOdistChildDefs) =
                  ({-# LINE 518 "src/Transform.ag" #-}
                   __tup39
                   {-# LINE 30229 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 612, column 18)
              _origName =
                  ({-# LINE 612 "src/Transform.ag" #-}
                   renameAttrBwd _lhsIdistRenames child_ name_
                   {-# LINE 30234 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 929, column 7)
              tp_val_ =
                  ({-# LINE 929 "src/Transform.ag" #-}
                   case identName child_ of
                     s | s == "loc"                         -> AttrTypeCode_ProdLocal
                       | s == "lhs"                         -> AttrTypeCode_Lhs
                       | s == "vis"                         -> AttrTypeCode_VisLocal
                       | child_ `Set.member` _lhsIallVisits -> AttrTypeCode_Visit
                       | _childItf     == locQIdent         -> AttrTypeCode_ProdLocal
                       | otherwise                          -> AttrTypeCode_Child
                   {-# LINE 30245 "src/Transform.hs" #-})
              tp_inst_ =
                  (sem_AttrTypeCode tp_val_ )
              -- "src/Transform.ag"(line 936, column 7)
              _tpOchild =
                  ({-# LINE 936 "src/Transform.ag" #-}
                   child_
                   {-# LINE 30252 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 937, column 7)
              _tpOname =
                  ({-# LINE 937 "src/Transform.ag" #-}
                   _origName
                   {-# LINE 30257 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 938, column 7)
              _tpOchildItf =
                  ({-# LINE 938 "src/Transform.ag" #-}
                   head _childItf
                   {-# LINE 30262 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2471, column 18)
              _lhsOpp =
                  ({-# LINE 2471 "src/Transform.ag" #-}
                   addSpaces _diff     (child_ >|< "." >|< name_)
                   {-# LINE 30267 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 30272 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 217, column 18)
              _lhsOhpp =
                  ({-# LINE 217 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     $ _tpIhpp
                   {-# LINE 30277 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 259, column 12)
              _hppType =
                  ({-# LINE 259 "src/TargetHaskell.ag" #-}
                   text "{- cannot be used toplevel -}"
                   {-# LINE 30282 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 147, column 18)
              _lhsOjspp =
                  ({-# LINE 147 "src/TargetJs.ag" #-}
                   addSpaces _diff     _tpIjspp
                   {-# LINE 30287 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _tpIallReqInvokes
                   {-# LINE 30292 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs0
                   {-# LINE 30297 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs1
                   {-# LINE 30302 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs2
                   {-# LINE 30307 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs3
                   {-# LINE 30312 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs4
                   {-# LINE 30317 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs5
                   {-# LINE 30322 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _tpIgathAvoidVisits
                   {-# LINE 30327 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _tpIgathDeps
                   {-# LINE 30332 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _tpIgathItemVisits
                   {-# LINE 30337 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _tpIgathLegalCycStmts
                   {-# LINE 30342 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _tpIgathMissingInvokes
                   {-# LINE 30347 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _tpIgathSemStarts
                   {-# LINE 30352 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _tpIgathStmtPosMap
                   {-# LINE 30357 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _tpIgathVisitEnds
                   {-# LINE 30362 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _tpIgathVisitStarts
                   {-# LINE 30367 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _tpIminReqInvokes
                   {-# LINE 30372 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tpIcodeIdCounter
                   {-# LINE 30377 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tpIdistDataCons
                   {-# LINE 30382 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tpIdistDataSems
                   {-# LINE 30387 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tpIdistDatas
                   {-# LINE 30392 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIdistDefs
                   {-# LINE 30397 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tpIdistItfs
                   {-# LINE 30402 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIdistVisLocalDefs
                   {-# LINE 30407 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tpIdistVisits
                   {-# LINE 30412 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 30417 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tpIgathClauses
                   {-# LINE 30422 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tpIgathDataSems
                   {-# LINE 30427 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIgathDefs
                   {-# LINE 30432 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tpIgathNonterms
                   {-# LINE 30437 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIgathVisLocalDefs
                   {-# LINE 30442 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 30447 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tpIlexCounter
                   {-# LINE 30452 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 30457 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 30462 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 30467 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 30472 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 30477 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 30482 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 30487 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 30492 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 30497 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 30502 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 30507 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 30512 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 30517 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 30522 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 30527 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 30532 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 30537 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 30542 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 30547 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 30552 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 30557 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 30562 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 30567 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 30572 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 30577 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 30582 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 30587 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 30592 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 30597 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 30602 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 30607 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 30612 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 30617 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 30622 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 30627 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 30632 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 30637 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 30642 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 30647 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 30652 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 30657 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 30662 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 30667 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 30672 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 30677 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 30682 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 30687 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 30692 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 30697 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 30702 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 30707 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 30712 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 30717 "src/Transform.hs" #-})
              ( _tpIallReqInvokes,_tpIcodeIdCounter,_tpIdistChildDefs,_tpIdistDataCons,_tpIdistDataSems,_tpIdistDatas,_tpIdistDefs,_tpIdistItfs,_tpIdistVisLocalDefs,_tpIdistVisits,_tpIerrs0,_tpIerrs1,_tpIerrs2,_tpIerrs3,_tpIerrs4,_tpIerrs5,_tpIgathAttrSource,_tpIgathAvoidVisits,_tpIgathChildSource,_tpIgathClauses,_tpIgathDataSems,_tpIgathDefs,_tpIgathDeps,_tpIgathItemVisits,_tpIgathLegalCycStmts,_tpIgathMissingInvokes,_tpIgathNonterms,_tpIgathSemStarts,_tpIgathStmtPosMap,_tpIgathVisLocalDefs,_tpIgathVisitEnds,_tpIgathVisitSource,_tpIgathVisitStarts,_tpIhpp,_tpIjspp,_tpIlexCounter,_tpIminReqInvokes) =
                  tp_inst_ _tpOallAvailInvokes _tpOallVisits _tpOavailInvokes _tpObasename _tpOchild _tpOchildItf _tpOcoItf _tpOcodeIdCounter _tpOdirectVisitAttrs _tpOdirectVisitLocalAttrs _tpOdistAliasses _tpOdistAllChildMinRanges _tpOdistAttrSource _tpOdistAttrVisMap _tpOdistChildDefs _tpOdistChildEffRanges _tpOdistChildMinRanges _tpOdistChildOcc _tpOdistChildSource _tpOdistCycVisMap _tpOdistDataCons _tpOdistDataMap _tpOdistDataSems _tpOdistDatas _tpOdistDeflStmts _tpOdistDefs _tpOdistInhAttrs _tpOdistItfs _tpOdistRanks _tpOdistRenames _tpOdistSynAttrs _tpOdistVisLocalDefs _tpOdistVisitInhAttrs _tpOdistVisitOrder _tpOdistVisitSource _tpOdistVisitSynAttrs _tpOdistVisits _tpOdoneVisits _tpOgathClauses _tpOgathDataSems _tpOgathDefs _tpOgathNonterms _tpOgathVisLocalDefs _tpOhSpilledStmts _tpOitf _tpOjsSpilledStmts _tpOlexCounter _tpOname _tpOnonterm _tpOopts _tpOscopeDep _tpOscopeReason _tpOstmtSource _tpOvisitBeginDep _tpOvisitEndDep _tpOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_Brackets :: Pos ->
                     T_Items  ->
                     Pos ->
                     T_Item 
sem_Item_Brackets pos_ items_ posEnd_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _itemsOallAvailInvokes :: (Map Ident (Set Ident))
              _itemsOallVisits :: (Set Ident)
              _itemsOavailInvokes :: (Map Ident (Set Ident))
              _itemsObasename :: QIdent
              _itemsOcoItf :: Ident
              _itemsOcodeIdCounter :: Int
              _itemsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _itemsOdirectVisitLocalAttrs :: (Map Ident String)
              _itemsOdistAliasses :: (Map Ident AliasType)
              _itemsOdistAllChildMinRanges :: (Map Ident [Ident])
              _itemsOdistAttrSource :: AttrSourceMap
              _itemsOdistAttrVisMap :: AttrVisMap
              _itemsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemsOdistChildEffRanges :: (Map Ident (Set Ident))
              _itemsOdistChildMinRanges :: (Map Ident [Ident])
              _itemsOdistChildOcc :: (Map Ident Int)
              _itemsOdistChildSource :: ChildSourceMap
              _itemsOdistCycVisMap :: CycVisMap
              _itemsOdistDataCons :: ConEnv
              _itemsOdistDataMap :: DataMap
              _itemsOdistDataSems :: DataSemEnv
              _itemsOdistDatas :: DataEnv
              _itemsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _itemsOdistDefs :: DefsEnv
              _itemsOdistInhAttrs :: AttrMap
              _itemsOdistItfs :: ItfEnv
              _itemsOdistRanks :: (Map DepItem (Bool,Int))
              _itemsOdistRenames :: RenameMap
              _itemsOdistSynAttrs :: AttrMap
              _itemsOdistVisLocalDefs :: DefsEnv
              _itemsOdistVisitInhAttrs :: VisitAttrMap
              _itemsOdistVisitOrder :: (Map Ident [Ident])
              _itemsOdistVisitSource :: VisitSourceMap
              _itemsOdistVisitSynAttrs :: VisitAttrMap
              _itemsOdistVisits :: VisitEnv
              _itemsOdoneVisits :: ([Ident])
              _itemsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemsOgathClauses :: ClausesEnv
              _itemsOgathDataSems :: DataSemEnv
              _itemsOgathDefs :: DefsEnv
              _itemsOgathNonterms :: NontermEnv
              _itemsOgathVisLocalDefs :: DefsEnv
              _itemsOhSpilledStmts :: ([(Int,PP_Doc)])
              _itemsOindent :: Int
              _itemsOitf :: QIdent
              _itemsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _itemsOlexCounter :: Int
              _itemsOnonterm :: QIdent
              _itemsOopts :: Opts
              _itemsOscopeDep :: DepItem
              _itemsOscopeReason :: Reason
              _itemsOstmtSource :: DepItem
              _itemsOvisitBeginDep :: DepItem
              _itemsOvisitEndDep :: DepItem
              _itemsOvisitEndReason :: Reason
              _itemsIallReqInvokes :: (Map Ident (Set Ident))
              _itemsIcodeIdCounter :: Int
              _itemsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _itemsIdistDataCons :: ConEnv
              _itemsIdistDataSems :: DataSemEnv
              _itemsIdistDatas :: DataEnv
              _itemsIdistDefs :: DefsEnv
              _itemsIdistItfs :: ItfEnv
              _itemsIdistVisLocalDefs :: DefsEnv
              _itemsIdistVisits :: VisitEnv
              _itemsIerrs0 :: Errs
              _itemsIerrs1 :: Errs
              _itemsIerrs2 :: Errs
              _itemsIerrs3 :: Errs
              _itemsIerrs4 :: Errs
              _itemsIerrs5 :: Errs
              _itemsIgathAvoidVisits :: (Set DepItem)
              _itemsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _itemsIgathClauses :: ClausesEnv
              _itemsIgathDataSems :: DataSemEnv
              _itemsIgathDefs :: DefsEnv
              _itemsIgathDeps :: Deps
              _itemsIgathItemVisits :: (Map DepItem DepItem)
              _itemsIgathLegalCycStmts :: (Set DepItem)
              _itemsIgathMissingInvokes :: (Set (Ident,Ident))
              _itemsIgathNonterms :: NontermEnv
              _itemsIgathSemStarts :: (Seq DepItem)
              _itemsIgathStmtPosMap :: (Map DepItem Pos)
              _itemsIgathVisLocalDefs :: DefsEnv
              _itemsIgathVisitEnds :: (Seq DepItem)
              _itemsIgathVisitStarts :: (Seq DepItem)
              _itemsIhpps :: ([PP_Doc])
              _itemsIjspps :: ([PP_Doc])
              _itemsIlexCounter :: Int
              _itemsIminReqInvokes :: (Map Ident (Set Ident))
              _itemsIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2477, column 18)
              _lhsOpp =
                  ({-# LINE 2477 "src/Transform.ag" #-}
                   addSpaces _diff     (text "{")
                   >-< vlist _itemsIpps
                   >-< addSpaces _diff2     (text "}")
                   {-# LINE 30915 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 30920 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2492, column 18)
              _diff2 =
                  ({-# LINE 2492 "src/Transform.ag" #-}
                   column posEnd_ - _lhsIindent
                   {-# LINE 30925 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 225, column 18)
              _lhsOhpp =
                  ({-# LINE 225 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     (text "{")
                   >-< vlist _itemsIhpps
                   >-< addSpaces _diff2     (text "}")
                   {-# LINE 30932 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 259, column 12)
              _hppType =
                  ({-# LINE 259 "src/TargetHaskell.ag" #-}
                   text "{- cannot be used toplevel -}"
                   {-# LINE 30937 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 157, column 18)
              _lhsOjspp =
                  ({-# LINE 157 "src/TargetJs.ag" #-}
                   addSpaces _diff     (text "{")
                   >-< vlist _itemsIjspps
                   >-< addSpaces _diff2     (text "}")
                   {-# LINE 30944 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemsIallReqInvokes
                   {-# LINE 30949 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs0
                   {-# LINE 30954 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs1
                   {-# LINE 30959 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs2
                   {-# LINE 30964 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs3
                   {-# LINE 30969 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs4
                   {-# LINE 30974 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _itemsIerrs5
                   {-# LINE 30979 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _itemsIgathAvoidVisits
                   {-# LINE 30984 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _itemsIgathDeps
                   {-# LINE 30989 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _itemsIgathItemVisits
                   {-# LINE 30994 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _itemsIgathLegalCycStmts
                   {-# LINE 30999 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _itemsIgathMissingInvokes
                   {-# LINE 31004 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _itemsIgathSemStarts
                   {-# LINE 31009 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _itemsIgathStmtPosMap
                   {-# LINE 31014 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemsIgathVisitEnds
                   {-# LINE 31019 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _itemsIgathVisitStarts
                   {-# LINE 31024 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _itemsIminReqInvokes
                   {-# LINE 31029 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _itemsIcodeIdCounter
                   {-# LINE 31034 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _itemsIdistChildDefs
                   {-# LINE 31039 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _itemsIdistDataCons
                   {-# LINE 31044 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _itemsIdistDataSems
                   {-# LINE 31049 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _itemsIdistDatas
                   {-# LINE 31054 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIdistDefs
                   {-# LINE 31059 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _itemsIdistItfs
                   {-# LINE 31064 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIdistVisLocalDefs
                   {-# LINE 31069 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _itemsIdistVisits
                   {-# LINE 31074 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _itemsIgathChildDefs
                   {-# LINE 31079 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemsIgathClauses
                   {-# LINE 31084 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _itemsIgathDataSems
                   {-# LINE 31089 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIgathDefs
                   {-# LINE 31094 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _itemsIgathNonterms
                   {-# LINE 31099 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _itemsIgathVisLocalDefs
                   {-# LINE 31104 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 31109 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _itemsIlexCounter
                   {-# LINE 31114 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 31119 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 31124 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 31129 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 31134 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 31139 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 31144 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 31149 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 31154 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 31159 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 31164 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 31169 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 31174 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 31179 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 31184 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 31189 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 31194 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 31199 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 31204 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 31209 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 31214 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 31219 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 31224 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 31229 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 31234 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 31239 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 31244 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 31249 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 31254 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 31259 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 31264 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 31269 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 31274 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 31279 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 31284 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 31289 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 31294 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 31299 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 31304 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 31309 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 31314 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 31319 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 31324 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 31329 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 31334 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 31339 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 31344 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 31349 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 31354 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 31359 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 31364 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 31369 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 31374 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 31379 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 31384 "src/Transform.hs" #-})
              -- copy rule (down)
              _itemsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 31389 "src/Transform.hs" #-})
              ( _itemsIallReqInvokes,_itemsIcodeIdCounter,_itemsIdistChildDefs,_itemsIdistDataCons,_itemsIdistDataSems,_itemsIdistDatas,_itemsIdistDefs,_itemsIdistItfs,_itemsIdistVisLocalDefs,_itemsIdistVisits,_itemsIerrs0,_itemsIerrs1,_itemsIerrs2,_itemsIerrs3,_itemsIerrs4,_itemsIerrs5,_itemsIgathAvoidVisits,_itemsIgathChildDefs,_itemsIgathClauses,_itemsIgathDataSems,_itemsIgathDefs,_itemsIgathDeps,_itemsIgathItemVisits,_itemsIgathLegalCycStmts,_itemsIgathMissingInvokes,_itemsIgathNonterms,_itemsIgathSemStarts,_itemsIgathStmtPosMap,_itemsIgathVisLocalDefs,_itemsIgathVisitEnds,_itemsIgathVisitStarts,_itemsIhpps,_itemsIjspps,_itemsIlexCounter,_itemsIminReqInvokes,_itemsIpps) =
                  items_ _itemsOallAvailInvokes _itemsOallVisits _itemsOavailInvokes _itemsObasename _itemsOcoItf _itemsOcodeIdCounter _itemsOdirectVisitAttrs _itemsOdirectVisitLocalAttrs _itemsOdistAliasses _itemsOdistAllChildMinRanges _itemsOdistAttrSource _itemsOdistAttrVisMap _itemsOdistChildDefs _itemsOdistChildEffRanges _itemsOdistChildMinRanges _itemsOdistChildOcc _itemsOdistChildSource _itemsOdistCycVisMap _itemsOdistDataCons _itemsOdistDataMap _itemsOdistDataSems _itemsOdistDatas _itemsOdistDeflStmts _itemsOdistDefs _itemsOdistInhAttrs _itemsOdistItfs _itemsOdistRanks _itemsOdistRenames _itemsOdistSynAttrs _itemsOdistVisLocalDefs _itemsOdistVisitInhAttrs _itemsOdistVisitOrder _itemsOdistVisitSource _itemsOdistVisitSynAttrs _itemsOdistVisits _itemsOdoneVisits _itemsOgathChildDefs _itemsOgathClauses _itemsOgathDataSems _itemsOgathDefs _itemsOgathNonterms _itemsOgathVisLocalDefs _itemsOhSpilledStmts _itemsOindent _itemsOitf _itemsOjsSpilledStmts _itemsOlexCounter _itemsOnonterm _itemsOopts _itemsOscopeDep _itemsOscopeReason _itemsOstmtSource _itemsOvisitBeginDep _itemsOvisitEndDep _itemsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_CoSem :: Pos ->
                  Ident ->
                  Ident ->
                  Ident ->
                  T_Vars  ->
                  (Maybe String) ->
                  T_SemVisit  ->
                  T_Item 
sem_Item_CoSem pos_ name_ tp_ visit_ vars_ mbMonad_ first_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistItfs :: ItfEnv
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathNonterms :: NontermEnv
              _firstOnonterm :: QIdent
              _firstOallVisits :: (Set Ident)
              _varsOgathVarsEnv :: VarsEnv
              _firstOitf :: QIdent
              _firstOcoItf :: Ident
              _firstOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _firstOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _firstOdistRenames :: RenameMap
              _firstOclauseExtras :: (Map Ident Stmts)
              _firstOvisitNr :: Int
              _firstOmasterPos :: Pos
              _firstOgathVisitNames :: (Env Ident ())
              _firstOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _firstOgathDefs :: DefsEnv
              _firstOgathVisLocalDefs :: DefsEnv
              _firstOdistDefs :: DefsEnv
              _firstOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _firstOlocalAttrs :: (Map Ident String)
              _firstOvisit :: Ident
              _firstOdistChildOcc :: (Map Ident Int)
              _firstOwithinCoSem :: Bool
              _firstOdistNextVisits :: (Map Ident (Maybe Ident))
              _firstOdistChildMinRanges :: (Map Ident [Ident])
              _firstOdistChildEffRanges :: (Map Ident (Set Ident))
              _firstOavailInvokes :: (Map Ident (Set Ident))
              _firstOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _firstOdistVisRankMap :: (IntMap Ident)
              _firstOfullCyclicVisits :: (Set Ident)
              _firstOfullCyclic :: Bool
              _firstOallowCycVisits :: (Set Ident)
              _firstOdistAttrSource :: AttrSourceMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs2 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _firstOallAvailInvokes :: (Map Ident (Set Ident))
              _firstObasename :: QIdent
              _firstOcodeIdCounter :: Int
              _firstOdirectVisitLocalAttrs :: (Map Ident String)
              _firstOdistAliasses :: (Map Ident AliasType)
              _firstOdistAllChildMinRanges :: (Map Ident [Ident])
              _firstOdistAttrVisMap :: AttrVisMap
              _firstOdistChildSource :: ChildSourceMap
              _firstOdistCycVisMap :: CycVisMap
              _firstOdistDataCons :: ConEnv
              _firstOdistDataMap :: DataMap
              _firstOdistDataSems :: DataSemEnv
              _firstOdistDatas :: DataEnv
              _firstOdistInhAttrs :: AttrMap
              _firstOdistItfs :: ItfEnv
              _firstOdistRanks :: (Map DepItem (Bool,Int))
              _firstOdistSynAttrs :: AttrMap
              _firstOdistVisitInhAttrs :: VisitAttrMap
              _firstOdistVisitOrder :: (Map Ident [Ident])
              _firstOdistVisitSource :: VisitSourceMap
              _firstOdistVisitSynAttrs :: VisitAttrMap
              _firstOdistVisits :: VisitEnv
              _firstOdoneVisits :: ([Ident])
              _firstOgathClauses :: ClausesEnv
              _firstOgathDataSems :: DataSemEnv
              _firstOgathNonterms :: NontermEnv
              _firstOhSpilledStmts :: ([(Int,PP_Doc)])
              _firstOindent :: Int
              _firstOjsSpilledStmts :: ([(Int,PP_Doc)])
              _firstOlexCounter :: Int
              _firstOmyNextVisits :: (Map Ident (Maybe Ident))
              _firstOnextVisits :: ([Ident])
              _firstOopts :: Opts
              _firstOscopeDep :: DepItem
              _firstOscopeReason :: Reason
              _firstOsemBasename :: QIdent
              _firstOstmtSource :: DepItem
              _firstOvisitBeginDep :: DepItem
              _firstOvisitEndDep :: DepItem
              _firstOvisitEndReason :: Reason
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _firstIallReqInvokes :: (Map Ident (Set Ident))
              _firstIbannedInvokes :: (Map Ident (Set Ident))
              _firstIcodeIdCounter :: Int
              _firstIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _firstIdistDataCons :: ConEnv
              _firstIdistDataSems :: DataSemEnv
              _firstIdistDatas :: DataEnv
              _firstIdistDefs :: DefsEnv
              _firstIdistItfs :: ItfEnv
              _firstIdistVisLocalDefs :: DefsEnv
              _firstIdistVisits :: VisitEnv
              _firstIerrs0 :: Errs
              _firstIerrs1 :: Errs
              _firstIerrs2 :: Errs
              _firstIerrs3 :: Errs
              _firstIerrs4 :: Errs
              _firstIerrs5 :: Errs
              _firstIgathAllowCycVisits :: (Set Ident)
              _firstIgathAttrSource :: AttrSourceMap
              _firstIgathAvoidVisits :: (Set DepItem)
              _firstIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _firstIgathChildSource :: ChildSourceMap
              _firstIgathClauses :: ClausesEnv
              _firstIgathDataSems :: DataSemEnv
              _firstIgathDefs :: DefsEnv
              _firstIgathDeps :: Deps
              _firstIgathItemVisits :: (Map DepItem DepItem)
              _firstIgathLegalCycStmts :: (Set DepItem)
              _firstIgathMissingInvokes :: (Set (Ident,Ident))
              _firstIgathNonterms :: NontermEnv
              _firstIgathSemAttrSource :: AttrSourceMap
              _firstIgathSemStarts :: (Seq DepItem)
              _firstIgathStmtPosMap :: (Map DepItem Pos)
              _firstIgathVisLocalDefs :: DefsEnv
              _firstIgathVisRankMap :: (IntMap Ident)
              _firstIgathVisitAttrs :: (Map Ident (Map Ident String))
              _firstIgathVisitEnds :: (Seq DepItem)
              _firstIgathVisitNames :: (Env Ident ())
              _firstIgathVisitSource :: VisitSourceMap
              _firstIgathVisitStarts :: (Seq DepItem)
              _firstIhpp :: PP_Doc
              _firstIisInternal :: Bool
              _firstIjspp :: PP_Doc
              _firstIlexCounter :: Int
              _firstImbNextVisit :: (Maybe Ident)
              _firstIminRank :: Int
              _firstIminReqInvokes :: (Map Ident (Set Ident))
              _firstIpp :: PP_Doc
              -- augmented rule
              _lhsOdistItfs =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   foldr ($) _distItfs_augmented_syn [_distItfs_augmented_f1]
                   {-# LINE 31622 "src/Transform.hs" #-})
              -- augment function
              _distItfs_augmented_f1 =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   snd . find [tp_] ()
                   {-# LINE 31627 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 31632 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   addDefErrs' _firstIgathVisitNames
                   {-# LINE 31637 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2]
                   {-# LINE 31642 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   addUseErrs _localChildDefs'
                   {-# LINE 31647 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   addDefErrs' _varsIgathVarsEnv
                   {-# LINE 31652 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2, _errs3_augmented_f3, _errs3_augmented_f4]
                   {-# LINE 31657 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addUseErrs'' _localVisLocalDefs'
                   {-# LINE 31662 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addUseErrs'' _localDefs'
                   {-# LINE 31667 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f3 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addDefErrs'' _localVisLocalDefs
                   {-# LINE 31672 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f4 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addDefErrs'' _localDefs
                   {-# LINE 31677 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathNonterms =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   foldr ($) _gathNonterms_augmented_syn [_gathNonterms_augmented_f1]
                   {-# LINE 31682 "src/Transform.hs" #-})
              -- augment function
              _gathNonterms_augmented_f1 =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   extend [name_] ()
                   {-# LINE 31687 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 251, column 3)
              _firstOnonterm =
                  ({-# LINE 251 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 31692 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 283, column 3)
              _firstOallVisits =
                  ({-# LINE 283 "src/Transform.ag" #-}
                   Set.union (Set.fromList _nextVisits    ) _lhsIallVisits
                   {-# LINE 31697 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 383, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 383 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 31702 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 419, column 14)
              _firstOitf =
                  ({-# LINE 419 "src/Transform.ag" #-}
                   [_coItf    ]
                   {-# LINE 31707 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 420, column 14)
              _coItf =
                  ({-# LINE 420 "src/Transform.ag" #-}
                   mkCoIdent tp_ visit_
                   {-# LINE 31712 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 421, column 14)
              _firstOcoItf =
                  ({-# LINE 421 "src/Transform.ag" #-}
                   tp_
                   {-# LINE 31717 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 506, column 10)
              _firstVisit =
                  ({-# LINE 506 "src/Transform.ag" #-}
                   if null _nextVisits     then unknIdent else head _nextVisits
                   {-# LINE 31722 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 507, column 10)
              _firstOgathChildDefs =
                  ({-# LINE 507 "src/Transform.ag" #-}
                   extend locQIdent (locQIdent, locQIdent)
                   $ extend visQIdent (visQIdent, visQIdent)
                   $ extend lhsQIdent ([tp_], [_firstVisit    , tp_])
                   $ enter _lhsIgathChildDefs
                   {-# LINE 31730 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              __tup41 =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   leave _firstIgathChildDefs
                   {-# LINE 31735 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              (_lhsOgathChildDefs,_) =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   __tup41
                   {-# LINE 31740 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              (_,_localChildDefs) =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   __tup41
                   {-# LINE 31745 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 514, column 10)
              _firstOdistChildDefs =
                  ({-# LINE 514 "src/Transform.ag" #-}
                   enterWith _localChildDefs     _lhsIdistChildDefs
                   {-# LINE 31750 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              __tup42 =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   leave _firstIdistChildDefs
                   {-# LINE 31755 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              (_lhsOdistChildDefs,_) =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   __tup42
                   {-# LINE 31760 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              (_,_localChildDefs') =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   __tup42
                   {-# LINE 31765 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 599, column 24)
              _firstOdistRenames =
                  ({-# LINE 599 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31770 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 623, column 23)
              _firstOclauseExtras =
                  ({-# LINE 623 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31775 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 694, column 32)
              _firstOvisitNr =
                  ({-# LINE 694 "src/Transform.ag" #-}
                   1
                   {-# LINE 31780 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 715, column 24)
              _nextVisits =
                  ({-# LINE 715 "src/Transform.ag" #-}
                   Map.findWithDefault [] _coItf     _lhsIdistVisitOrder
                   {-# LINE 31785 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 729, column 24)
              _doneVisits =
                  ({-# LINE 729 "src/Transform.ag" #-}
                   []
                   {-# LINE 31790 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 764, column 32)
              _firstOmasterPos =
                  ({-# LINE 764 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 31795 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 834, column 23)
              _firstOgathVisitNames =
                  ({-# LINE 834 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 31800 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 901, column 24)
              _firstOdirectVisitAttrs =
                  ({-# LINE 901 "src/Transform.ag" #-}
                   _firstIgathVisitAttrs
                   {-# LINE 31805 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1002, column 7)
              _gathDefsIn =
                  ({-# LINE 1002 "src/Transform.ag" #-}
                   enter _lhsIgathDefs
                   {-# LINE 31810 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1003, column 7)
              _firstOgathDefs =
                  ({-# LINE 1003 "src/Transform.ag" #-}
                   _gathDefsInh
                   {-# LINE 31815 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1004, column 7)
              _firstOgathVisLocalDefs =
                  ({-# LINE 1004 "src/Transform.ag" #-}
                   enter _lhsIgathVisLocalDefs
                   {-# LINE 31820 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1005, column 7)
              _firstOdistDefs =
                  ({-# LINE 1005 "src/Transform.ag" #-}
                   enterWith _localDefs     _lhsIdistDefs
                   {-# LINE 31825 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1006, column 7)
              _firstOdistVisLocalDefs =
                  ({-# LINE 1006 "src/Transform.ag" #-}
                   enterWith _localVisLocalDefs     _lhsIdistVisLocalDefs
                   {-# LINE 31830 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1008, column 7)
              _gathDefsInh =
                  ({-# LINE 1008 "src/Transform.ag" #-}
                   Map.fold (flip (Map.foldWithKey (\n t -> extend (replPos pos_ lhsIdent,replPos pos_ n,True) (Just t)))) _gathDefsIn     _inhAttrMap
                   {-# LINE 31835 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              __tup43 =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   leave _firstIgathDefs
                   {-# LINE 31840 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              (_lhsOgathDefs,_) =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   __tup43
                   {-# LINE 31845 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              (_,_localDefs) =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   __tup43
                   {-# LINE 31850 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              __tup44 =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   leave _firstIgathVisLocalDefs
                   {-# LINE 31855 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              (_lhsOgathVisLocalDefs,_) =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   __tup44
                   {-# LINE 31860 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              (_,_localVisLocalDefs) =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   __tup44
                   {-# LINE 31865 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              __tup45 =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   leave _firstIdistDefs
                   {-# LINE 31870 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              (_lhsOdistDefs,_) =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   __tup45
                   {-# LINE 31875 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              (_,_localDefs') =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   __tup45
                   {-# LINE 31880 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              __tup46 =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   leave _firstIdistVisLocalDefs
                   {-# LINE 31885 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              (_lhsOdistVisLocalDefs,_) =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   __tup46
                   {-# LINE 31890 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              (_,_localVisLocalDefs') =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   __tup46
                   {-# LINE 31895 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1099, column 23)
              _firstOlocalAttrs =
                  ({-# LINE 1099 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31900 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1116, column 23)
              _firstOvisit =
                  ({-# LINE 1116 "src/Transform.ag" #-}
                   name_
                   {-# LINE 31905 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1310, column 24)
              _firstOdistChildOcc =
                  ({-# LINE 1310 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31910 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1402, column 23)
              _basename =
                  ({-# LINE 1402 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 31915 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1403, column 23)
              _semBasename =
                  ({-# LINE 1403 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 31920 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1412, column 20)
              _firstOwithinCoSem =
                  ({-# LINE 1412 "src/Transform.ag" #-}
                   True
                   {-# LINE 31925 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1553, column 23)
              _firstOdistNextVisits =
                  ({-# LINE 1553 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31930 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1592, column 23)
              _myNextVisits =
                  ({-# LINE 1592 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31935 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1615, column 24)
              _firstOdistChildMinRanges =
                  ({-# LINE 1615 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31940 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1616, column 24)
              _firstOdistChildEffRanges =
                  ({-# LINE 1616 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31945 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1754, column 23)
              _firstOavailInvokes =
                  ({-# LINE 1754 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31950 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1816, column 24)
              _firstOdistDeflStmts =
                  ({-# LINE 1816 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 31955 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1863, column 23)
              _firstOdistVisRankMap =
                  ({-# LINE 1863 "src/Transform.ag" #-}
                   _firstIgathVisRankMap
                   {-# LINE 31960 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1898, column 23)
              _firstOfullCyclicVisits =
                  ({-# LINE 1898 "src/Transform.ag" #-}
                   Map.findWithDefault Set.empty tp_ _lhsIdistCycVisMap
                   {-# LINE 31965 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1899, column 23)
              _firstOfullCyclic =
                  ({-# LINE 1899 "src/Transform.ag" #-}
                   False
                   {-# LINE 31970 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1917, column 25)
              _firstOallowCycVisits =
                  ({-# LINE 1917 "src/Transform.ag" #-}
                   _firstIgathAllowCycVisits
                   {-# LINE 31975 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2075, column 3)
              _inhAttrMap =
                  ({-# LINE 2075 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty tp_ _lhsIdistVisitInhAttrs
                   {-# LINE 31980 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2076, column 3)
              _inhAttrSource =
                  ({-# LINE 2076 "src/Transform.ag" #-}
                   Map.fromList [ ((True,lhsIdent,attr), DepVisStart (visit : _semBasename    ))
                                | (visit,mp) <- Map.assocs _inhAttrMap    , attr <- Map.keys mp ]
                   {-# LINE 31986 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2078, column 3)
              _firstOdistAttrSource =
                  ({-# LINE 2078 "src/Transform.ag" #-}
                   Map.union _inhAttrSource     _lhsIdistAttrSource
                   {-# LINE 31991 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2474, column 18)
              _lhsOpp =
                  ({-# LINE 2474 "src/Transform.ag" #-}
                   addSpaces _diff     ("cosem" >#< name_ >#< ":" >#< tp_ >#< visit_
                                       >-< indent 2 _firstIpp)
                   {-# LINE 31997 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 32002 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 218, column 18)
              _lhsOhpp =
                  ({-# LINE 218 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     ( pp_parens (
                     "let" >#< (hNt name_ >#< "::" >#< _hppType    )
                     >-< indent 4 (hNt name_ >#< "=")
                     >-< indent 6 _firstIhpp
                     >-< "in" >#< hNt name_ ))
                   {-# LINE 32011 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 263, column 12)
              _hppType =
                  ({-# LINE 263 "src/TargetHaskell.ag" #-}
                   case mbMonad_ of
                     Nothing -> "(Monad m, MonadError e m, Error e) => " >#< hCoItfNm tp_ visit_ >#< "m"
                     Just t  -> hCoItfNm tp_ visit_ >#< pp_parens (stripSpacing t)
                   {-# LINE 32018 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 148, column 18)
              _lhsOjspp =
                  ({-# LINE 148 "src/TargetJs.ag" #-}
                   addSpaces _diff     (pp_parens (
                     "function ()"
                     >-< pp_braces (
                           "var" >#< "nt" >|< show name_ >#< "=" >#< _firstIjspp >|< ";"
                           >-< "return" >#< "nt" >|< show name_ >|< ";"
                         )
                   ))
                   {-# LINE 32029 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _firstIallReqInvokes
                   {-# LINE 32034 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   _firstIerrs0
                   {-# LINE 32039 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   _firstIerrs1
                   {-# LINE 32044 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs2
                   {-# LINE 32049 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   _firstIerrs3
                   {-# LINE 32054 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs4
                   {-# LINE 32059 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs5
                   {-# LINE 32064 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _firstIgathAvoidVisits
                   {-# LINE 32069 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _firstIgathDeps
                   {-# LINE 32074 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _firstIgathItemVisits
                   {-# LINE 32079 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _firstIgathLegalCycStmts
                   {-# LINE 32084 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _firstIgathMissingInvokes
                   {-# LINE 32089 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _firstIgathSemStarts
                   {-# LINE 32094 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _firstIgathStmtPosMap
                   {-# LINE 32099 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _firstIgathVisitEnds
                   {-# LINE 32104 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _firstIgathVisitStarts
                   {-# LINE 32109 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _firstIminReqInvokes
                   {-# LINE 32114 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _firstIcodeIdCounter
                   {-# LINE 32119 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _firstIdistDataCons
                   {-# LINE 32124 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _firstIdistDataSems
                   {-# LINE 32129 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _firstIdistDatas
                   {-# LINE 32134 "src/Transform.hs" #-})
              -- copy rule (up)
              _distItfs_augmented_syn =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   _firstIdistItfs
                   {-# LINE 32139 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _firstIdistVisits
                   {-# LINE 32144 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _firstIgathClauses
                   {-# LINE 32149 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _firstIgathDataSems
                   {-# LINE 32154 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathNonterms_augmented_syn =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   _firstIgathNonterms
                   {-# LINE 32159 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 32164 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _firstIlexCounter
                   {-# LINE 32169 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 32174 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 32179 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 32184 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 32189 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 32194 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 32199 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 32204 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 32209 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 32214 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 32219 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 32224 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 32229 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 32234 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 32239 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 32244 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 32249 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 32254 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 32259 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 32264 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 32269 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 32274 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 32279 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 32284 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 32289 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 32294 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 32299 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 32304 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 32309 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 32314 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 32319 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _myNextVisits
                   {-# LINE 32324 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _nextVisits
                   {-# LINE 32329 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 32334 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 32339 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 32344 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _semBasename
                   {-# LINE 32349 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 32354 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 32359 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 32364 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 32369 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _firstIallReqInvokes,_firstIbannedInvokes,_firstIcodeIdCounter,_firstIdistChildDefs,_firstIdistDataCons,_firstIdistDataSems,_firstIdistDatas,_firstIdistDefs,_firstIdistItfs,_firstIdistVisLocalDefs,_firstIdistVisits,_firstIerrs0,_firstIerrs1,_firstIerrs2,_firstIerrs3,_firstIerrs4,_firstIerrs5,_firstIgathAllowCycVisits,_firstIgathAttrSource,_firstIgathAvoidVisits,_firstIgathChildDefs,_firstIgathChildSource,_firstIgathClauses,_firstIgathDataSems,_firstIgathDefs,_firstIgathDeps,_firstIgathItemVisits,_firstIgathLegalCycStmts,_firstIgathMissingInvokes,_firstIgathNonterms,_firstIgathSemAttrSource,_firstIgathSemStarts,_firstIgathStmtPosMap,_firstIgathVisLocalDefs,_firstIgathVisRankMap,_firstIgathVisitAttrs,_firstIgathVisitEnds,_firstIgathVisitNames,_firstIgathVisitSource,_firstIgathVisitStarts,_firstIhpp,_firstIisInternal,_firstIjspp,_firstIlexCounter,_firstImbNextVisit,_firstIminRank,_firstIminReqInvokes,_firstIpp) =
                  first_ _firstOallAvailInvokes _firstOallVisits _firstOallowCycVisits _firstOavailInvokes _firstObasename _firstOclauseExtras _firstOcoItf _firstOcodeIdCounter _firstOdirectVisitAttrs _firstOdirectVisitLocalAttrs _firstOdistAliasses _firstOdistAllChildMinRanges _firstOdistAttrSource _firstOdistAttrVisMap _firstOdistChildDefs _firstOdistChildEffRanges _firstOdistChildMinRanges _firstOdistChildOcc _firstOdistChildSource _firstOdistCycVisMap _firstOdistDataCons _firstOdistDataMap _firstOdistDataSems _firstOdistDatas _firstOdistDeflStmts _firstOdistDefs _firstOdistInhAttrs _firstOdistItfs _firstOdistNextVisits _firstOdistRanks _firstOdistRenames _firstOdistSynAttrs _firstOdistVisLocalDefs _firstOdistVisRankMap _firstOdistVisitInhAttrs _firstOdistVisitOrder _firstOdistVisitSource _firstOdistVisitSynAttrs _firstOdistVisits _firstOdoneVisits _firstOfullCyclic _firstOfullCyclicVisits _firstOgathChildDefs _firstOgathClauses _firstOgathDataSems _firstOgathDefs _firstOgathNonterms _firstOgathVisLocalDefs _firstOgathVisitNames _firstOhSpilledStmts _firstOindent _firstOitf _firstOjsSpilledStmts _firstOlexCounter _firstOlocalAttrs _firstOmasterPos _firstOmyNextVisits _firstOnextVisits _firstOnonterm _firstOopts _firstOscopeDep _firstOscopeReason _firstOsemBasename _firstOstmtSource _firstOvisit _firstOvisitBeginDep _firstOvisitEndDep _firstOvisitEndReason _firstOvisitNr _firstOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_Construct :: Pos ->
                      Ident ->
                      Ident ->
                      T_ExprFields  ->
                      T_Item 
sem_Item_Construct pos_ data_ con_ fields_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOerrs0 :: Errs
              _fieldsOdata :: Ident
              _fieldsOcon :: Ident
              _fieldsOgathFields :: FieldEnv
              _fieldsOfieldOrder :: (Map Ident Int)
              _lhsOdistDataCons :: ConEnv
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _fieldsOallAvailInvokes :: (Map Ident (Set Ident))
              _fieldsOallVisits :: (Set Ident)
              _fieldsOavailInvokes :: (Map Ident (Set Ident))
              _fieldsObasename :: QIdent
              _fieldsOcoItf :: Ident
              _fieldsOcodeIdCounter :: Int
              _fieldsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _fieldsOdirectVisitLocalAttrs :: (Map Ident String)
              _fieldsOdistAliasses :: (Map Ident AliasType)
              _fieldsOdistAllChildMinRanges :: (Map Ident [Ident])
              _fieldsOdistAttrSource :: AttrSourceMap
              _fieldsOdistAttrVisMap :: AttrVisMap
              _fieldsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _fieldsOdistChildEffRanges :: (Map Ident (Set Ident))
              _fieldsOdistChildMinRanges :: (Map Ident [Ident])
              _fieldsOdistChildOcc :: (Map Ident Int)
              _fieldsOdistChildSource :: ChildSourceMap
              _fieldsOdistCycVisMap :: CycVisMap
              _fieldsOdistDataCons :: ConEnv
              _fieldsOdistDataMap :: DataMap
              _fieldsOdistDataSems :: DataSemEnv
              _fieldsOdistDatas :: DataEnv
              _fieldsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _fieldsOdistDefs :: DefsEnv
              _fieldsOdistInhAttrs :: AttrMap
              _fieldsOdistItfs :: ItfEnv
              _fieldsOdistRanks :: (Map DepItem (Bool,Int))
              _fieldsOdistRenames :: RenameMap
              _fieldsOdistSynAttrs :: AttrMap
              _fieldsOdistVisLocalDefs :: DefsEnv
              _fieldsOdistVisitInhAttrs :: VisitAttrMap
              _fieldsOdistVisitOrder :: (Map Ident [Ident])
              _fieldsOdistVisitSource :: VisitSourceMap
              _fieldsOdistVisitSynAttrs :: VisitAttrMap
              _fieldsOdistVisits :: VisitEnv
              _fieldsOdoneVisits :: ([Ident])
              _fieldsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _fieldsOgathClauses :: ClausesEnv
              _fieldsOgathDataSems :: DataSemEnv
              _fieldsOgathDefs :: DefsEnv
              _fieldsOgathNonterms :: NontermEnv
              _fieldsOgathVisLocalDefs :: DefsEnv
              _fieldsOhSpilledStmts :: ([(Int,PP_Doc)])
              _fieldsOindent :: Int
              _fieldsOitf :: QIdent
              _fieldsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _fieldsOlexCounter :: Int
              _fieldsOnonterm :: QIdent
              _fieldsOopts :: Opts
              _fieldsOscopeDep :: DepItem
              _fieldsOscopeReason :: Reason
              _fieldsOstmtSource :: DepItem
              _fieldsOvisitBeginDep :: DepItem
              _fieldsOvisitEndDep :: DepItem
              _fieldsOvisitEndReason :: Reason
              _fieldsIallReqInvokes :: (Map Ident (Set Ident))
              _fieldsIcodeIdCounter :: Int
              _fieldsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _fieldsIdistDataCons :: ConEnv
              _fieldsIdistDataSems :: DataSemEnv
              _fieldsIdistDatas :: DataEnv
              _fieldsIdistDefs :: DefsEnv
              _fieldsIdistItfs :: ItfEnv
              _fieldsIdistVisLocalDefs :: DefsEnv
              _fieldsIdistVisits :: VisitEnv
              _fieldsIerrs0 :: Errs
              _fieldsIerrs1 :: Errs
              _fieldsIerrs2 :: Errs
              _fieldsIerrs3 :: Errs
              _fieldsIerrs4 :: Errs
              _fieldsIerrs5 :: Errs
              _fieldsIgathAvoidVisits :: (Set DepItem)
              _fieldsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _fieldsIgathClauses :: ClausesEnv
              _fieldsIgathDataSems :: DataSemEnv
              _fieldsIgathDefs :: DefsEnv
              _fieldsIgathDeps :: Deps
              _fieldsIgathFields :: FieldEnv
              _fieldsIgathItemVisits :: (Map DepItem DepItem)
              _fieldsIgathLegalCycStmts :: (Set DepItem)
              _fieldsIgathNonterms :: NontermEnv
              _fieldsIgathSemStarts :: (Seq DepItem)
              _fieldsIgathStmtPosMap :: (Map DepItem Pos)
              _fieldsIgathVisLocalDefs :: DefsEnv
              _fieldsIgathVisitEnds :: (Seq DepItem)
              _fieldsIgathVisitStarts :: (Seq DepItem)
              _fieldsIhopps :: ([(Int,PP_Doc)])
              _fieldsIjsopps :: ([(Int,PP_Doc)])
              _fieldsIlexCounter :: Int
              _fieldsIminReqInvokes :: (Map Ident (Set Ident))
              _fieldsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 485 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 32572 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 485 "src/Transform.ag" #-}
                   snd . find data_ ()
                   {-# LINE 32577 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 345 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1, _errs0_augmented_f2]
                   {-# LINE 32582 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 345 "src/Transform.ag" #-}
                   addUseErrs' _gathFieldEnv
                   {-# LINE 32587 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f2 =
                  ({-# LINE 345 "src/Transform.ag" #-}
                   addDefErrs' _gathFieldEnv
                   {-# LINE 32592 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 298, column 22)
              _fieldsOdata =
                  ({-# LINE 298 "src/Transform.ag" #-}
                   data_
                   {-# LINE 32597 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 299, column 22)
              _fieldsOcon =
                  ({-# LINE 299 "src/Transform.ag" #-}
                   con_
                   {-# LINE 32602 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 342, column 3)
              _fieldsOgathFields =
                  ({-# LINE 342 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 32607 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 343, column 3)
              _gathFieldEnv =
                  ({-# LINE 343 "src/Transform.ag" #-}
                   foldr (\(nm,_) -> snd . find nm (0,Right "")) _fieldsIgathFields _fields
                   {-# LINE 32612 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 346, column 3)
              _fieldsOfieldOrder =
                  ({-# LINE 346 "src/Transform.ag" #-}
                   Map.fromList (zip (map fst _fields    ) [1..])
                   {-# LINE 32617 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 457, column 3)
              __tup47 =
                  ({-# LINE 457 "src/Transform.ag" #-}
                   find [con_, data_] emptyEnv _lhsIdistDataCons
                   {-# LINE 32622 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 457, column 3)
              (_fieldEnv,_) =
                  ({-# LINE 457 "src/Transform.ag" #-}
                   __tup47
                   {-# LINE 32627 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 457, column 3)
              (_,_lhsOdistDataCons) =
                  ({-# LINE 457 "src/Transform.ag" #-}
                   __tup47
                   {-# LINE 32632 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 458, column 3)
              _fields =
                  ({-# LINE 458 "src/Transform.ag" #-}
                   sortAssocs $ assocs _fieldEnv
                   {-# LINE 32637 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1439, column 26)
              _mbAlias =
                  ({-# LINE 1439 "src/Transform.ag" #-}
                   Map.lookup data_ _lhsIdistAliasses
                   {-# LINE 32642 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2480, column 18)
              _lhsOpp =
                  ({-# LINE 2480 "src/Transform.ag" #-}
                   addSpaces _diff     (show data_ >|< "." >|< show con_ >#< pp_block "{" "}" "," _fieldsIpps)
                   {-# LINE 32647 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 32652 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 228, column 18)
              _lhsOhpp =
                  ({-# LINE 228 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     (pp_parens _hpp    )
                   {-# LINE 32657 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 229, column 18)
              _hFldsPPs =
                  ({-# LINE 229 "src/TargetHaskell.ag" #-}
                   sortPairs _fieldsIhopps
                   {-# LINE 32662 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 230, column 18)
              _hpp =
                  ({-# LINE 230 "src/TargetHaskell.ag" #-}
                   case _mbAlias of
                     Nothing    -> hConNm data_ con_ >#< hlist_sp _hFldsPPs
                     Just alias -> case alias of
                                     AliasType_Prod _  -> pp_block "(" ")" "," _hFldsPPs
                                     AliasType_List _  -> if con_ == ident "Cons"
                                                          then "(:)" >#< hlist_sp _hFldsPPs
                                                          else text "[]"
                                     AliasType_Maybe _ -> if con_ == ident "Nothing"
                                                          then "Just" >#< hlist_sp _hFldsPPs
                                                          else text "Nothing"
                   {-# LINE 32676 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 259, column 12)
              _hppType =
                  ({-# LINE 259 "src/TargetHaskell.ag" #-}
                   text "{- cannot be used toplevel -}"
                   {-# LINE 32681 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 160, column 18)
              _lhsOjspp =
                  ({-# LINE 160 "src/TargetJs.ag" #-}
                   addSpaces _diff     (pp_parens _jspp    )
                   {-# LINE 32686 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 161, column 18)
              _jspp =
                  ({-# LINE 161 "src/TargetJs.ag" #-}
                   case _mbAlias of
                     Nothing    -> empty
                     Just alias -> case alias of
                                     AliasType_Prod _  -> empty
                                     AliasType_List _  -> empty
                                     AliasType_Maybe _ -> empty
                   {-# LINE 32696 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _fieldsIallReqInvokes
                   {-# LINE 32701 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 345 "src/Transform.ag" #-}
                   _fieldsIerrs0
                   {-# LINE 32706 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs1
                   {-# LINE 32711 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs2
                   {-# LINE 32716 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs3
                   {-# LINE 32721 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs4
                   {-# LINE 32726 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs5
                   {-# LINE 32731 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _fieldsIgathAvoidVisits
                   {-# LINE 32736 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _fieldsIgathDeps
                   {-# LINE 32741 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _fieldsIgathItemVisits
                   {-# LINE 32746 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _fieldsIgathLegalCycStmts
                   {-# LINE 32751 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 32756 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _fieldsIgathSemStarts
                   {-# LINE 32761 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _fieldsIgathStmtPosMap
                   {-# LINE 32766 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _fieldsIgathVisitEnds
                   {-# LINE 32771 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _fieldsIgathVisitStarts
                   {-# LINE 32776 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _fieldsIminReqInvokes
                   {-# LINE 32781 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _fieldsIcodeIdCounter
                   {-# LINE 32786 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _fieldsIdistChildDefs
                   {-# LINE 32791 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _fieldsIdistDataSems
                   {-# LINE 32796 "src/Transform.hs" #-})
              -- copy rule (up)
              _distDatas_augmented_syn =
                  ({-# LINE 485 "src/Transform.ag" #-}
                   _fieldsIdistDatas
                   {-# LINE 32801 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIdistDefs
                   {-# LINE 32806 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _fieldsIdistItfs
                   {-# LINE 32811 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIdistVisLocalDefs
                   {-# LINE 32816 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _fieldsIdistVisits
                   {-# LINE 32821 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _fieldsIgathChildDefs
                   {-# LINE 32826 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _fieldsIgathClauses
                   {-# LINE 32831 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _fieldsIgathDataSems
                   {-# LINE 32836 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIgathDefs
                   {-# LINE 32841 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _fieldsIgathNonterms
                   {-# LINE 32846 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIgathVisLocalDefs
                   {-# LINE 32851 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 32856 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _fieldsIlexCounter
                   {-# LINE 32861 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 32866 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 32871 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 32876 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 32881 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 32886 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 32891 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 32896 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 32901 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 32906 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 32911 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 32916 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 32921 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 32926 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 32931 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 32936 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 32941 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 32946 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 32951 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 32956 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 32961 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 32966 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 32971 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 32976 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 32981 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 32986 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 32991 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 32996 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 33001 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 33006 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 33011 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 33016 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 33021 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 33026 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 33031 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 33036 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 33041 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 33046 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 33051 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 33056 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 33061 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 33066 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 33071 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 33076 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 33081 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 33086 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 33091 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 33096 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 33101 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 33106 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 33111 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 33116 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 33121 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 33126 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 33131 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 33136 "src/Transform.hs" #-})
              ( _fieldsIallReqInvokes,_fieldsIcodeIdCounter,_fieldsIdistChildDefs,_fieldsIdistDataCons,_fieldsIdistDataSems,_fieldsIdistDatas,_fieldsIdistDefs,_fieldsIdistItfs,_fieldsIdistVisLocalDefs,_fieldsIdistVisits,_fieldsIerrs0,_fieldsIerrs1,_fieldsIerrs2,_fieldsIerrs3,_fieldsIerrs4,_fieldsIerrs5,_fieldsIgathAvoidVisits,_fieldsIgathChildDefs,_fieldsIgathClauses,_fieldsIgathDataSems,_fieldsIgathDefs,_fieldsIgathDeps,_fieldsIgathFields,_fieldsIgathItemVisits,_fieldsIgathLegalCycStmts,_fieldsIgathNonterms,_fieldsIgathSemStarts,_fieldsIgathStmtPosMap,_fieldsIgathVisLocalDefs,_fieldsIgathVisitEnds,_fieldsIgathVisitStarts,_fieldsIhopps,_fieldsIjsopps,_fieldsIlexCounter,_fieldsIminReqInvokes,_fieldsIpps) =
                  fields_ _fieldsOallAvailInvokes _fieldsOallVisits _fieldsOavailInvokes _fieldsObasename _fieldsOcoItf _fieldsOcodeIdCounter _fieldsOcon _fieldsOdata _fieldsOdirectVisitAttrs _fieldsOdirectVisitLocalAttrs _fieldsOdistAliasses _fieldsOdistAllChildMinRanges _fieldsOdistAttrSource _fieldsOdistAttrVisMap _fieldsOdistChildDefs _fieldsOdistChildEffRanges _fieldsOdistChildMinRanges _fieldsOdistChildOcc _fieldsOdistChildSource _fieldsOdistCycVisMap _fieldsOdistDataCons _fieldsOdistDataMap _fieldsOdistDataSems _fieldsOdistDatas _fieldsOdistDeflStmts _fieldsOdistDefs _fieldsOdistInhAttrs _fieldsOdistItfs _fieldsOdistRanks _fieldsOdistRenames _fieldsOdistSynAttrs _fieldsOdistVisLocalDefs _fieldsOdistVisitInhAttrs _fieldsOdistVisitOrder _fieldsOdistVisitSource _fieldsOdistVisitSynAttrs _fieldsOdistVisits _fieldsOdoneVisits _fieldsOfieldOrder _fieldsOgathChildDefs _fieldsOgathClauses _fieldsOgathDataSems _fieldsOgathDefs _fieldsOgathFields _fieldsOgathNonterms _fieldsOgathVisLocalDefs _fieldsOhSpilledStmts _fieldsOindent _fieldsOitf _fieldsOjsSpilledStmts _fieldsOlexCounter _fieldsOnonterm _fieldsOopts _fieldsOscopeDep _fieldsOscopeReason _fieldsOstmtSource _fieldsOvisitBeginDep _fieldsOvisitEndDep _fieldsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_DataSem :: T_DataSem  ->
                    T_Item 
sem_Item_DataSem sem_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOpp :: PP_Doc
              _semOallAvailInvokes :: (Map Ident (Set Ident))
              _semOallVisits :: (Set Ident)
              _semOavailInvokes :: (Map Ident (Set Ident))
              _semObasename :: QIdent
              _semOcoItf :: Ident
              _semOcodeIdCounter :: Int
              _semOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _semOdirectVisitLocalAttrs :: (Map Ident String)
              _semOdistAliasses :: (Map Ident AliasType)
              _semOdistAllChildMinRanges :: (Map Ident [Ident])
              _semOdistAttrSource :: AttrSourceMap
              _semOdistAttrVisMap :: AttrVisMap
              _semOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _semOdistChildEffRanges :: (Map Ident (Set Ident))
              _semOdistChildMinRanges :: (Map Ident [Ident])
              _semOdistChildOcc :: (Map Ident Int)
              _semOdistChildSource :: ChildSourceMap
              _semOdistCycVisMap :: CycVisMap
              _semOdistDataCons :: ConEnv
              _semOdistDataMap :: DataMap
              _semOdistDataSems :: DataSemEnv
              _semOdistDatas :: DataEnv
              _semOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _semOdistDefs :: DefsEnv
              _semOdistInhAttrs :: AttrMap
              _semOdistItfs :: ItfEnv
              _semOdistRanks :: (Map DepItem (Bool,Int))
              _semOdistRenames :: RenameMap
              _semOdistSynAttrs :: AttrMap
              _semOdistVisLocalDefs :: DefsEnv
              _semOdistVisitInhAttrs :: VisitAttrMap
              _semOdistVisitOrder :: (Map Ident [Ident])
              _semOdistVisitSource :: VisitSourceMap
              _semOdistVisitSynAttrs :: VisitAttrMap
              _semOdistVisits :: VisitEnv
              _semOdoneVisits :: ([Ident])
              _semOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _semOgathClauses :: ClausesEnv
              _semOgathDataSems :: DataSemEnv
              _semOgathDefs :: DefsEnv
              _semOgathNonterms :: NontermEnv
              _semOgathVisLocalDefs :: DefsEnv
              _semOhSpilledStmts :: ([(Int,PP_Doc)])
              _semOindent :: Int
              _semOitf :: QIdent
              _semOjsSpilledStmts :: ([(Int,PP_Doc)])
              _semOlexCounter :: Int
              _semOnonterm :: QIdent
              _semOopts :: Opts
              _semOscopeDep :: DepItem
              _semOscopeReason :: Reason
              _semOstmtSource :: DepItem
              _semOvisitBeginDep :: DepItem
              _semOvisitEndDep :: DepItem
              _semOvisitEndReason :: Reason
              _semIallReqInvokes :: (Map Ident (Set Ident))
              _semIcodeIdCounter :: Int
              _semIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _semIdistDataCons :: ConEnv
              _semIdistDataSems :: DataSemEnv
              _semIdistDatas :: DataEnv
              _semIdistDefs :: DefsEnv
              _semIdistItfs :: ItfEnv
              _semIdistVisLocalDefs :: DefsEnv
              _semIdistVisits :: VisitEnv
              _semIerrs0 :: Errs
              _semIerrs1 :: Errs
              _semIerrs2 :: Errs
              _semIerrs3 :: Errs
              _semIerrs4 :: Errs
              _semIerrs5 :: Errs
              _semIgathAvoidVisits :: (Set DepItem)
              _semIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _semIgathClauses :: ClausesEnv
              _semIgathDataSems :: DataSemEnv
              _semIgathDefs :: DefsEnv
              _semIgathDeps :: Deps
              _semIgathItemVisits :: (Map DepItem DepItem)
              _semIgathLegalCycStmts :: (Set DepItem)
              _semIgathNonterms :: NontermEnv
              _semIgathSemStarts :: (Seq DepItem)
              _semIgathStmtPosMap :: (Map DepItem Pos)
              _semIgathVisLocalDefs :: DefsEnv
              _semIgathVisitEnds :: (Seq DepItem)
              _semIgathVisitStarts :: (Seq DepItem)
              _semIhpp :: PP_Doc
              _semIjspp :: PP_Doc
              _semIlexCounter :: Int
              _semIminReqInvokes :: (Map Ident (Set Ident))
              _semIpos :: Pos
              _semIpp :: PP_Doc
              -- "src/Transform.ag"(line 1424, column 21)
              _pos =
                  ({-# LINE 1424 "src/Transform.ag" #-}
                   _semIpos
                   {-# LINE 33330 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column _pos - _lhsIindent
                   {-# LINE 33335 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 223, column 18)
              _lhsOhpp =
                  ({-# LINE 223 "src/TargetHaskell.ag" #-}
                   _semIhpp
                   {-# LINE 33340 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 267, column 12)
              _hppType =
                  ({-# LINE 267 "src/TargetHaskell.ag" #-}
                   text "{- no type signature for nested datatype semantics -}"
                   {-# LINE 33345 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 155, column 18)
              _lhsOjspp =
                  ({-# LINE 155 "src/TargetJs.ag" #-}
                   _semIjspp
                   {-# LINE 33350 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _semIallReqInvokes
                   {-# LINE 33355 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs0
                   {-# LINE 33360 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs1
                   {-# LINE 33365 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs2
                   {-# LINE 33370 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs3
                   {-# LINE 33375 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs4
                   {-# LINE 33380 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _semIerrs5
                   {-# LINE 33385 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _semIgathAvoidVisits
                   {-# LINE 33390 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _semIgathDeps
                   {-# LINE 33395 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _semIgathItemVisits
                   {-# LINE 33400 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _semIgathLegalCycStmts
                   {-# LINE 33405 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 33410 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _semIgathSemStarts
                   {-# LINE 33415 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _semIgathStmtPosMap
                   {-# LINE 33420 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _semIgathVisitEnds
                   {-# LINE 33425 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _semIgathVisitStarts
                   {-# LINE 33430 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _semIminReqInvokes
                   {-# LINE 33435 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _semIcodeIdCounter
                   {-# LINE 33440 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _semIdistChildDefs
                   {-# LINE 33445 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _semIdistDataCons
                   {-# LINE 33450 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _semIdistDataSems
                   {-# LINE 33455 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _semIdistDatas
                   {-# LINE 33460 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIdistDefs
                   {-# LINE 33465 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _semIdistItfs
                   {-# LINE 33470 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIdistVisLocalDefs
                   {-# LINE 33475 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _semIdistVisits
                   {-# LINE 33480 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _semIgathChildDefs
                   {-# LINE 33485 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _semIgathClauses
                   {-# LINE 33490 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _semIgathDataSems
                   {-# LINE 33495 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIgathDefs
                   {-# LINE 33500 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _semIgathNonterms
                   {-# LINE 33505 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _semIgathVisLocalDefs
                   {-# LINE 33510 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 33515 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _semIlexCounter
                   {-# LINE 33520 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpp =
                  ({-# LINE 2411 "src/Transform.ag" #-}
                   _semIpp
                   {-# LINE 33525 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 33530 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 33535 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 33540 "src/Transform.hs" #-})
              -- copy rule (down)
              _semObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 33545 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 33550 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 33555 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 33560 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 33565 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 33570 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 33575 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 33580 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 33585 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 33590 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 33595 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 33600 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 33605 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 33610 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 33615 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 33620 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 33625 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 33630 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 33635 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 33640 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 33645 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 33650 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 33655 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 33660 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 33665 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 33670 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 33675 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 33680 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 33685 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 33690 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 33695 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 33700 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 33705 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 33710 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 33715 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 33720 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 33725 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 33730 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 33735 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 33740 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 33745 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 33750 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 33755 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 33760 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 33765 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 33770 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 33775 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 33780 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 33785 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 33790 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 33795 "src/Transform.hs" #-})
              -- copy rule (down)
              _semOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 33800 "src/Transform.hs" #-})
              ( _semIallReqInvokes,_semIcodeIdCounter,_semIdistChildDefs,_semIdistDataCons,_semIdistDataSems,_semIdistDatas,_semIdistDefs,_semIdistItfs,_semIdistVisLocalDefs,_semIdistVisits,_semIerrs0,_semIerrs1,_semIerrs2,_semIerrs3,_semIerrs4,_semIerrs5,_semIgathAvoidVisits,_semIgathChildDefs,_semIgathClauses,_semIgathDataSems,_semIgathDefs,_semIgathDeps,_semIgathItemVisits,_semIgathLegalCycStmts,_semIgathNonterms,_semIgathSemStarts,_semIgathStmtPosMap,_semIgathVisLocalDefs,_semIgathVisitEnds,_semIgathVisitStarts,_semIhpp,_semIjspp,_semIlexCounter,_semIminReqInvokes,_semIpos,_semIpp) =
                  sem_ _semOallAvailInvokes _semOallVisits _semOavailInvokes _semObasename _semOcoItf _semOcodeIdCounter _semOdirectVisitAttrs _semOdirectVisitLocalAttrs _semOdistAliasses _semOdistAllChildMinRanges _semOdistAttrSource _semOdistAttrVisMap _semOdistChildDefs _semOdistChildEffRanges _semOdistChildMinRanges _semOdistChildOcc _semOdistChildSource _semOdistCycVisMap _semOdistDataCons _semOdistDataMap _semOdistDataSems _semOdistDatas _semOdistDeflStmts _semOdistDefs _semOdistInhAttrs _semOdistItfs _semOdistRanks _semOdistRenames _semOdistSynAttrs _semOdistVisLocalDefs _semOdistVisitInhAttrs _semOdistVisitOrder _semOdistVisitSource _semOdistVisitSynAttrs _semOdistVisits _semOdoneVisits _semOgathChildDefs _semOgathClauses _semOgathDataSems _semOgathDefs _semOgathNonterms _semOgathVisLocalDefs _semOhSpilledStmts _semOindent _semOitf _semOjsSpilledStmts _semOlexCounter _semOnonterm _semOopts _semOscopeDep _semOscopeReason _semOstmtSource _semOvisitBeginDep _semOvisitEndDep _semOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_Detach :: Pos ->
                   Ident ->
                   Ident ->
                   T_Item 
sem_Item_Detach pos_ visit_ name_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOgathDeps :: Deps
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2291 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 33905 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2291 "src/Transform.ag" #-}
                   case _mbChildSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _lhsIstmtSource (ReasonDetach name_ visit_) [d]
                   {-# LINE 33912 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2291 "src/Transform.ag" #-}
                   case _mbVisitSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _lhsIstmtSource (ReasonDetach name_ visit_) [d]
                   {-# LINE 33919 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 519, column 13)
              __tup48 =
                  ({-# LINE 519 "src/Transform.ag" #-}
                   find [name_] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                   {-# LINE 33924 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 519, column 13)
              (__tup49,_) =
                  ({-# LINE 519 "src/Transform.ag" #-}
                   __tup48
                   {-# LINE 33929 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 519, column 13)
              (_childItf,_) =
                  ({-# LINE 519 "src/Transform.ag" #-}
                   __tup49
                   {-# LINE 33934 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 519, column 13)
              (_,_startVisit) =
                  ({-# LINE 519 "src/Transform.ag" #-}
                   __tup49
                   {-# LINE 33939 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 519, column 13)
              (_,_lhsOdistChildDefs) =
                  ({-# LINE 519 "src/Transform.ag" #-}
                   __tup48
                   {-# LINE 33944 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 716, column 24)
              _visitOrder =
                  ({-# LINE 716 "src/Transform.ag" #-}
                   Map.findWithDefault [] _unqualChildItf     _lhsIdistVisitOrder
                   {-# LINE 33949 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 815, column 13)
              _unqualChildItf =
                  ({-# LINE 815 "src/Transform.ag" #-}
                   head _childItf
                   {-# LINE 33954 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 816, column 13)
              _childVisits =
                  ({-# LINE 816 "src/Transform.ag" #-}
                   Map.findWithDefault [] _unqualChildItf     _lhsIdistVisitOrder
                   {-# LINE 33959 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1685, column 3)
              _minRanges =
                  ({-# LINE 1685 "src/Transform.ag" #-}
                   Set.fromList $ Map.findWithDefault [] name_ _lhsIdistAllChildMinRanges
                   {-# LINE 33964 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1686, column 3)
              _potentialReqs =
                  ({-# LINE 1686 "src/Transform.ag" #-}
                   drop 1 $ dropWhile (/= visit_) $ reverse _visitOrder
                   {-# LINE 33969 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1687, column 3)
              _actualReqs =
                  ({-# LINE 1687 "src/Transform.ag" #-}
                   take (1 + length (takeWhile (\x -> not $ Set.member x _minRanges    ) _potentialReqs    )) _potentialReqs
                   {-# LINE 33974 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1689, column 3)
              _invokeReqs =
                  ({-# LINE 1689 "src/Transform.ag" #-}
                   Map.singleton name_ $ Set.fromList _actualReqs
                   {-# LINE 33979 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1690, column 3)
              _lhsOminReqInvokes =
                  ({-# LINE 1690 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 33984 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1691, column 3)
              _lhsOallReqInvokes =
                  ({-# LINE 1691 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 33989 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1793, column 3)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1793 "src/Transform.ag" #-}
                   Set.fromList [ (k, v) | (k,vs) <- Map.assocs (_invokeReqs     `diffInside` _lhsIallAvailInvokes)
                                , v <- Set.toList vs ]
                   {-# LINE 33995 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2286, column 3)
              _mbVisitSource =
                  ({-# LINE 2286 "src/Transform.ag" #-}
                   nearestVisitEntry False visit_ _childVisits     $ Map.findWithDefault Map.empty name_ _lhsIdistVisitSource
                   {-# LINE 34000 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2287, column 3)
              _mbChildSource =
                  ({-# LINE 2287 "src/Transform.ag" #-}
                   nearestVisitEntry False visit_ _childVisits     $ Map.findWithDefault Map.empty name_ _lhsIdistChildSource
                   {-# LINE 34005 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2476, column 18)
              _lhsOpp =
                  ({-# LINE 2476 "src/Transform.ag" #-}
                   addSpaces _diff     ("detach" >#< name_ >#< "of" >#< visit_)
                   {-# LINE 34010 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 34015 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 224, column 18)
              _lhsOhpp =
                  ({-# LINE 224 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     (text $ hSemNm name_ visit_)
                   {-# LINE 34020 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 259, column 12)
              _hppType =
                  ({-# LINE 259 "src/TargetHaskell.ag" #-}
                   text "{- cannot be used toplevel -}"
                   {-# LINE 34025 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 156, column 18)
              _lhsOjspp =
                  ({-# LINE 156 "src/TargetJs.ag" #-}
                   addSpaces _diff     empty
                   {-# LINE 34030 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34035 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34040 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34045 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34050 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34055 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34060 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 34065 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2291 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34070 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34075 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 34080 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34085 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34090 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34095 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34100 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 34105 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 34110 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 34115 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 34120 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 34125 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 34130 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 34135 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 34140 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 34145 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 34150 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 34155 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 34160 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 34165 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 34170 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 34175 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 34180 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_Plain :: Pos ->
                  String ->
                  T_Item 
sem_Item_Plain pos_ txt_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOpp :: PP_Doc
              -- "src/Transform.ag"(line 2470, column 18)
              _pp =
                  ({-# LINE 2470 "src/Transform.ag" #-}
                   vlist (modifySpacing _diff     _lhsIindent txt_)
                   {-# LINE 34282 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 34287 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 214, column 18)
              _lhsOhpp =
                  ({-# LINE 214 "src/TargetHaskell.ag" #-}
                   if all isSpace txt_
                   then empty
                   else vlist $ modifySpacing _diff     _lhsIindent txt_
                   {-# LINE 34294 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 259, column 12)
              _hppType =
                  ({-# LINE 259 "src/TargetHaskell.ag" #-}
                   text "{- cannot be used toplevel -}"
                   {-# LINE 34299 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 144, column 18)
              _lhsOjspp =
                  ({-# LINE 144 "src/TargetJs.ag" #-}
                   if all isSpace txt_
                   then empty
                   else vlist $ modifySpacing _diff     _lhsIindent txt_
                   {-# LINE 34306 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34311 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34316 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34321 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34326 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34331 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34336 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34341 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 34346 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34351 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34356 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 34361 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 34366 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34371 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34376 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34381 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 34386 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34391 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 34396 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 34401 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 34406 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 34411 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 34416 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 34421 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 34426 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 34431 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 34436 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 34441 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 34446 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 34451 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 34456 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 34461 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 34466 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 34471 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 34476 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOpp =
                  ({-# LINE 2411 "src/Transform.ag" #-}
                   _pp
                   {-# LINE 34481 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_Item_Sem :: Pos ->
                Ident ->
                Ident ->
                T_Vars  ->
                (Maybe String) ->
                T_SemVisit  ->
                T_Item 
sem_Item_Sem pos_ name_ tp_ vars_ mbMonad_ first_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistItfs :: ItfEnv
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathNonterms :: NontermEnv
              _firstOnonterm :: QIdent
              _firstOallVisits :: (Set Ident)
              _varsOgathVarsEnv :: VarsEnv
              _firstOitf :: QIdent
              _firstOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _firstOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _firstOdistRenames :: RenameMap
              _firstOclauseExtras :: (Map Ident Stmts)
              _firstOvisitNr :: Int
              _firstOmasterPos :: Pos
              _firstOgathVisitNames :: (Env Ident ())
              _firstOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _firstOgathDefs :: DefsEnv
              _firstOgathVisLocalDefs :: DefsEnv
              _firstOdistDefs :: DefsEnv
              _firstOdistVisLocalDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _firstOlocalAttrs :: (Map Ident String)
              _firstOvisit :: Ident
              _firstOdistChildOcc :: (Map Ident Int)
              _firstOwithinCoSem :: Bool
              _firstOdistNextVisits :: (Map Ident (Maybe Ident))
              _firstOdistChildMinRanges :: (Map Ident [Ident])
              _firstOdistChildEffRanges :: (Map Ident (Set Ident))
              _firstOavailInvokes :: (Map Ident (Set Ident))
              _firstOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _firstOdistVisRankMap :: (IntMap Ident)
              _firstOfullCyclicVisits :: (Set Ident)
              _firstOfullCyclic :: Bool
              _firstOallowCycVisits :: (Set Ident)
              _firstOdistAttrSource :: AttrSourceMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs2 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOhppType :: PP_Doc
              _lhsOlexCounter :: Int
              _firstOallAvailInvokes :: (Map Ident (Set Ident))
              _firstObasename :: QIdent
              _firstOcoItf :: Ident
              _firstOcodeIdCounter :: Int
              _firstOdirectVisitLocalAttrs :: (Map Ident String)
              _firstOdistAliasses :: (Map Ident AliasType)
              _firstOdistAllChildMinRanges :: (Map Ident [Ident])
              _firstOdistAttrVisMap :: AttrVisMap
              _firstOdistChildSource :: ChildSourceMap
              _firstOdistCycVisMap :: CycVisMap
              _firstOdistDataCons :: ConEnv
              _firstOdistDataMap :: DataMap
              _firstOdistDataSems :: DataSemEnv
              _firstOdistDatas :: DataEnv
              _firstOdistInhAttrs :: AttrMap
              _firstOdistItfs :: ItfEnv
              _firstOdistRanks :: (Map DepItem (Bool,Int))
              _firstOdistSynAttrs :: AttrMap
              _firstOdistVisitInhAttrs :: VisitAttrMap
              _firstOdistVisitOrder :: (Map Ident [Ident])
              _firstOdistVisitSource :: VisitSourceMap
              _firstOdistVisitSynAttrs :: VisitAttrMap
              _firstOdistVisits :: VisitEnv
              _firstOdoneVisits :: ([Ident])
              _firstOgathClauses :: ClausesEnv
              _firstOgathDataSems :: DataSemEnv
              _firstOgathNonterms :: NontermEnv
              _firstOhSpilledStmts :: ([(Int,PP_Doc)])
              _firstOindent :: Int
              _firstOjsSpilledStmts :: ([(Int,PP_Doc)])
              _firstOlexCounter :: Int
              _firstOmyNextVisits :: (Map Ident (Maybe Ident))
              _firstOnextVisits :: ([Ident])
              _firstOopts :: Opts
              _firstOscopeDep :: DepItem
              _firstOscopeReason :: Reason
              _firstOsemBasename :: QIdent
              _firstOstmtSource :: DepItem
              _firstOvisitBeginDep :: DepItem
              _firstOvisitEndDep :: DepItem
              _firstOvisitEndReason :: Reason
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _firstIallReqInvokes :: (Map Ident (Set Ident))
              _firstIbannedInvokes :: (Map Ident (Set Ident))
              _firstIcodeIdCounter :: Int
              _firstIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _firstIdistDataCons :: ConEnv
              _firstIdistDataSems :: DataSemEnv
              _firstIdistDatas :: DataEnv
              _firstIdistDefs :: DefsEnv
              _firstIdistItfs :: ItfEnv
              _firstIdistVisLocalDefs :: DefsEnv
              _firstIdistVisits :: VisitEnv
              _firstIerrs0 :: Errs
              _firstIerrs1 :: Errs
              _firstIerrs2 :: Errs
              _firstIerrs3 :: Errs
              _firstIerrs4 :: Errs
              _firstIerrs5 :: Errs
              _firstIgathAllowCycVisits :: (Set Ident)
              _firstIgathAttrSource :: AttrSourceMap
              _firstIgathAvoidVisits :: (Set DepItem)
              _firstIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _firstIgathChildSource :: ChildSourceMap
              _firstIgathClauses :: ClausesEnv
              _firstIgathDataSems :: DataSemEnv
              _firstIgathDefs :: DefsEnv
              _firstIgathDeps :: Deps
              _firstIgathItemVisits :: (Map DepItem DepItem)
              _firstIgathLegalCycStmts :: (Set DepItem)
              _firstIgathMissingInvokes :: (Set (Ident,Ident))
              _firstIgathNonterms :: NontermEnv
              _firstIgathSemAttrSource :: AttrSourceMap
              _firstIgathSemStarts :: (Seq DepItem)
              _firstIgathStmtPosMap :: (Map DepItem Pos)
              _firstIgathVisLocalDefs :: DefsEnv
              _firstIgathVisRankMap :: (IntMap Ident)
              _firstIgathVisitAttrs :: (Map Ident (Map Ident String))
              _firstIgathVisitEnds :: (Seq DepItem)
              _firstIgathVisitNames :: (Env Ident ())
              _firstIgathVisitSource :: VisitSourceMap
              _firstIgathVisitStarts :: (Seq DepItem)
              _firstIhpp :: PP_Doc
              _firstIisInternal :: Bool
              _firstIjspp :: PP_Doc
              _firstIlexCounter :: Int
              _firstImbNextVisit :: (Maybe Ident)
              _firstIminRank :: Int
              _firstIminReqInvokes :: (Map Ident (Set Ident))
              _firstIpp :: PP_Doc
              -- augmented rule
              _lhsOdistItfs =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   foldr ($) _distItfs_augmented_syn [_distItfs_augmented_f1]
                   {-# LINE 34711 "src/Transform.hs" #-})
              -- augment function
              _distItfs_augmented_f1 =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   snd . find [tp_] ()
                   {-# LINE 34716 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 34721 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   addDefErrs' _firstIgathVisitNames
                   {-# LINE 34726 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2]
                   {-# LINE 34731 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   addUseErrs _localChildDefs'
                   {-# LINE 34736 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   addDefErrs' _varsIgathVarsEnv
                   {-# LINE 34741 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2, _errs3_augmented_f3, _errs3_augmented_f4]
                   {-# LINE 34746 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addUseErrs'' _localVisLocalDefs'
                   {-# LINE 34751 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addUseErrs'' _localDefs'
                   {-# LINE 34756 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f3 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addDefErrs'' _localVisLocalDefs
                   {-# LINE 34761 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f4 =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   addDefErrs'' _localDefs
                   {-# LINE 34766 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathNonterms =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   foldr ($) _gathNonterms_augmented_syn [_gathNonterms_augmented_f1]
                   {-# LINE 34771 "src/Transform.hs" #-})
              -- augment function
              _gathNonterms_augmented_f1 =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   extend [name_] ()
                   {-# LINE 34776 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 251, column 3)
              _firstOnonterm =
                  ({-# LINE 251 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 34781 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 283, column 3)
              _firstOallVisits =
                  ({-# LINE 283 "src/Transform.ag" #-}
                   Set.union (Set.fromList _nextVisits    ) _lhsIallVisits
                   {-# LINE 34786 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 383, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 383 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 34791 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 418, column 14)
              _firstOitf =
                  ({-# LINE 418 "src/Transform.ag" #-}
                   [tp_]
                   {-# LINE 34796 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 506, column 10)
              _firstVisit =
                  ({-# LINE 506 "src/Transform.ag" #-}
                   if null _nextVisits     then unknIdent else head _nextVisits
                   {-# LINE 34801 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 507, column 10)
              _firstOgathChildDefs =
                  ({-# LINE 507 "src/Transform.ag" #-}
                   extend locQIdent (locQIdent, locQIdent)
                   $ extend visQIdent (visQIdent, visQIdent)
                   $ extend lhsQIdent ([tp_], [_firstVisit    , tp_])
                   $ enter _lhsIgathChildDefs
                   {-# LINE 34809 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              __tup50 =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   leave _firstIgathChildDefs
                   {-# LINE 34814 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              (_lhsOgathChildDefs,_) =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   __tup50
                   {-# LINE 34819 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 511, column 10)
              (_,_localChildDefs) =
                  ({-# LINE 511 "src/Transform.ag" #-}
                   __tup50
                   {-# LINE 34824 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 514, column 10)
              _firstOdistChildDefs =
                  ({-# LINE 514 "src/Transform.ag" #-}
                   enterWith _localChildDefs     _lhsIdistChildDefs
                   {-# LINE 34829 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              __tup51 =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   leave _firstIdistChildDefs
                   {-# LINE 34834 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              (_lhsOdistChildDefs,_) =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   __tup51
                   {-# LINE 34839 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 515, column 10)
              (_,_localChildDefs') =
                  ({-# LINE 515 "src/Transform.ag" #-}
                   __tup51
                   {-# LINE 34844 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 599, column 24)
              _firstOdistRenames =
                  ({-# LINE 599 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34849 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 623, column 23)
              _firstOclauseExtras =
                  ({-# LINE 623 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34854 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 694, column 32)
              _firstOvisitNr =
                  ({-# LINE 694 "src/Transform.ag" #-}
                   1
                   {-# LINE 34859 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 714, column 24)
              _nextVisits =
                  ({-# LINE 714 "src/Transform.ag" #-}
                   Map.findWithDefault [] tp_ _lhsIdistVisitOrder
                   {-# LINE 34864 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 728, column 24)
              _doneVisits =
                  ({-# LINE 728 "src/Transform.ag" #-}
                   []
                   {-# LINE 34869 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 764, column 32)
              _firstOmasterPos =
                  ({-# LINE 764 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 34874 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 834, column 23)
              _firstOgathVisitNames =
                  ({-# LINE 834 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 34879 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 901, column 24)
              _firstOdirectVisitAttrs =
                  ({-# LINE 901 "src/Transform.ag" #-}
                   _firstIgathVisitAttrs
                   {-# LINE 34884 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1002, column 7)
              _gathDefsIn =
                  ({-# LINE 1002 "src/Transform.ag" #-}
                   enter _lhsIgathDefs
                   {-# LINE 34889 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1003, column 7)
              _firstOgathDefs =
                  ({-# LINE 1003 "src/Transform.ag" #-}
                   _gathDefsInh
                   {-# LINE 34894 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1004, column 7)
              _firstOgathVisLocalDefs =
                  ({-# LINE 1004 "src/Transform.ag" #-}
                   enter _lhsIgathVisLocalDefs
                   {-# LINE 34899 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1005, column 7)
              _firstOdistDefs =
                  ({-# LINE 1005 "src/Transform.ag" #-}
                   enterWith _localDefs     _lhsIdistDefs
                   {-# LINE 34904 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1006, column 7)
              _firstOdistVisLocalDefs =
                  ({-# LINE 1006 "src/Transform.ag" #-}
                   enterWith _localVisLocalDefs     _lhsIdistVisLocalDefs
                   {-# LINE 34909 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1008, column 7)
              _gathDefsInh =
                  ({-# LINE 1008 "src/Transform.ag" #-}
                   Map.fold (flip (Map.foldWithKey (\n t -> extend (replPos pos_ lhsIdent,replPos pos_ n,True) (Just t)))) _gathDefsIn     _inhAttrMap
                   {-# LINE 34914 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              __tup52 =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   leave _firstIgathDefs
                   {-# LINE 34919 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              (_lhsOgathDefs,_) =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   __tup52
                   {-# LINE 34924 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1010, column 7)
              (_,_localDefs) =
                  ({-# LINE 1010 "src/Transform.ag" #-}
                   __tup52
                   {-# LINE 34929 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              __tup53 =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   leave _firstIgathVisLocalDefs
                   {-# LINE 34934 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              (_lhsOgathVisLocalDefs,_) =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   __tup53
                   {-# LINE 34939 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1011, column 7)
              (_,_localVisLocalDefs) =
                  ({-# LINE 1011 "src/Transform.ag" #-}
                   __tup53
                   {-# LINE 34944 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              __tup54 =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   leave _firstIdistDefs
                   {-# LINE 34949 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              (_lhsOdistDefs,_) =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   __tup54
                   {-# LINE 34954 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1012, column 7)
              (_,_localDefs') =
                  ({-# LINE 1012 "src/Transform.ag" #-}
                   __tup54
                   {-# LINE 34959 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              __tup55 =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   leave _firstIdistVisLocalDefs
                   {-# LINE 34964 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              (_lhsOdistVisLocalDefs,_) =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   __tup55
                   {-# LINE 34969 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1013, column 7)
              (_,_localVisLocalDefs') =
                  ({-# LINE 1013 "src/Transform.ag" #-}
                   __tup55
                   {-# LINE 34974 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1099, column 23)
              _firstOlocalAttrs =
                  ({-# LINE 1099 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34979 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1116, column 23)
              _firstOvisit =
                  ({-# LINE 1116 "src/Transform.ag" #-}
                   name_
                   {-# LINE 34984 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1310, column 24)
              _firstOdistChildOcc =
                  ({-# LINE 1310 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 34989 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1402, column 23)
              _basename =
                  ({-# LINE 1402 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 34994 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1403, column 23)
              _semBasename =
                  ({-# LINE 1403 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 34999 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1411, column 20)
              _firstOwithinCoSem =
                  ({-# LINE 1411 "src/Transform.ag" #-}
                   False
                   {-# LINE 35004 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1553, column 23)
              _firstOdistNextVisits =
                  ({-# LINE 1553 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35009 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1592, column 23)
              _myNextVisits =
                  ({-# LINE 1592 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35014 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1615, column 24)
              _firstOdistChildMinRanges =
                  ({-# LINE 1615 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35019 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1616, column 24)
              _firstOdistChildEffRanges =
                  ({-# LINE 1616 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35024 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1754, column 23)
              _firstOavailInvokes =
                  ({-# LINE 1754 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35029 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1816, column 24)
              _firstOdistDeflStmts =
                  ({-# LINE 1816 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 35034 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1863, column 23)
              _firstOdistVisRankMap =
                  ({-# LINE 1863 "src/Transform.ag" #-}
                   _firstIgathVisRankMap
                   {-# LINE 35039 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1898, column 23)
              _firstOfullCyclicVisits =
                  ({-# LINE 1898 "src/Transform.ag" #-}
                   Map.findWithDefault Set.empty tp_ _lhsIdistCycVisMap
                   {-# LINE 35044 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1899, column 23)
              _firstOfullCyclic =
                  ({-# LINE 1899 "src/Transform.ag" #-}
                   False
                   {-# LINE 35049 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1917, column 25)
              _firstOallowCycVisits =
                  ({-# LINE 1917 "src/Transform.ag" #-}
                   _firstIgathAllowCycVisits
                   {-# LINE 35054 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2075, column 3)
              _inhAttrMap =
                  ({-# LINE 2075 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty tp_ _lhsIdistVisitInhAttrs
                   {-# LINE 35059 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2076, column 3)
              _inhAttrSource =
                  ({-# LINE 2076 "src/Transform.ag" #-}
                   Map.fromList [ ((True,lhsIdent,attr), DepVisStart (visit : _semBasename    ))
                                | (visit,mp) <- Map.assocs _inhAttrMap    , attr <- Map.keys mp ]
                   {-# LINE 35065 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2078, column 3)
              _firstOdistAttrSource =
                  ({-# LINE 2078 "src/Transform.ag" #-}
                   Map.union _inhAttrSource     _lhsIdistAttrSource
                   {-# LINE 35070 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2472, column 18)
              _lhsOpp =
                  ({-# LINE 2472 "src/Transform.ag" #-}
                   addSpaces _diff     ("sem" >#< name_ >#< ":" >#< tp_
                                       >-< indent 2 _firstIpp)
                   {-# LINE 35076 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2491, column 18)
              _diff =
                  ({-# LINE 2491 "src/Transform.ag" #-}
                   column pos_ - _lhsIindent
                   {-# LINE 35081 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 218, column 18)
              _lhsOhpp =
                  ({-# LINE 218 "src/TargetHaskell.ag" #-}
                   addSpaces _diff     ( pp_parens (
                     "let" >#< (hNt name_ >#< "::" >#< _hppType    )
                     >-< indent 4 (hNt name_ >#< "=")
                     >-< indent 6 _firstIhpp
                     >-< "in" >#< hNt name_ ))
                   {-# LINE 35090 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 260, column 12)
              _hppType =
                  ({-# LINE 260 "src/TargetHaskell.ag" #-}
                   case mbMonad_ of
                     Nothing -> "(Monad m, MonadError e m, Error e) => " >#< hItfNm tp_ >#< "m"
                     Just t  -> hItfNm tp_ >#< pp_parens (stripSpacing t)
                   {-# LINE 35097 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 148, column 18)
              _lhsOjspp =
                  ({-# LINE 148 "src/TargetJs.ag" #-}
                   addSpaces _diff     (pp_parens (
                     "function ()"
                     >-< pp_braces (
                           "var" >#< "nt" >|< show name_ >#< "=" >#< _firstIjspp >|< ";"
                           >-< "return" >#< "nt" >|< show name_ >|< ";"
                         )
                   ))
                   {-# LINE 35108 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _firstIallReqInvokes
                   {-# LINE 35113 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 835 "src/Transform.ag" #-}
                   _firstIerrs0
                   {-# LINE 35118 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 517 "src/Transform.ag" #-}
                   _firstIerrs1
                   {-# LINE 35123 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs2
                   {-# LINE 35128 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1018 "src/Transform.ag" #-}
                   _firstIerrs3
                   {-# LINE 35133 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs4
                   {-# LINE 35138 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _firstIerrs5
                   {-# LINE 35143 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _firstIgathAvoidVisits
                   {-# LINE 35148 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _firstIgathDeps
                   {-# LINE 35153 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _firstIgathItemVisits
                   {-# LINE 35158 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _firstIgathLegalCycStmts
                   {-# LINE 35163 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _firstIgathMissingInvokes
                   {-# LINE 35168 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _firstIgathSemStarts
                   {-# LINE 35173 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _firstIgathStmtPosMap
                   {-# LINE 35178 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _firstIgathVisitEnds
                   {-# LINE 35183 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _firstIgathVisitStarts
                   {-# LINE 35188 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _firstIminReqInvokes
                   {-# LINE 35193 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _firstIcodeIdCounter
                   {-# LINE 35198 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _firstIdistDataCons
                   {-# LINE 35203 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _firstIdistDataSems
                   {-# LINE 35208 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _firstIdistDatas
                   {-# LINE 35213 "src/Transform.hs" #-})
              -- copy rule (up)
              _distItfs_augmented_syn =
                  ({-# LINE 401 "src/Transform.ag" #-}
                   _firstIdistItfs
                   {-# LINE 35218 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _firstIdistVisits
                   {-# LINE 35223 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _firstIgathClauses
                   {-# LINE 35228 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _firstIgathDataSems
                   {-# LINE 35233 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathNonterms_augmented_syn =
                  ({-# LINE 258 "src/Transform.ag" #-}
                   _firstIgathNonterms
                   {-# LINE 35238 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOhppType =
                  ({-# LINE 256 "src/TargetHaskell.ag" #-}
                   _hppType
                   {-# LINE 35243 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _firstIlexCounter
                   {-# LINE 35248 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 35253 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _basename
                   {-# LINE 35258 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 35263 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 35268 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 35273 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 35278 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 35283 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 35288 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 35293 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 35298 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 35303 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 35308 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 35313 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 35318 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 35323 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 35328 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 35333 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 35338 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 35343 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 35348 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 35353 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 35358 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 35363 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 35368 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 35373 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 35378 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 35383 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 35388 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 35393 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 35398 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 35403 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _myNextVisits
                   {-# LINE 35408 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _nextVisits
                   {-# LINE 35413 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 35418 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 35423 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 35428 "src/Transform.hs" #-})
              -- copy rule (from local)
              _firstOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _semBasename
                   {-# LINE 35433 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 35438 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 35443 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 35448 "src/Transform.hs" #-})
              -- copy rule (down)
              _firstOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 35453 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _firstIallReqInvokes,_firstIbannedInvokes,_firstIcodeIdCounter,_firstIdistChildDefs,_firstIdistDataCons,_firstIdistDataSems,_firstIdistDatas,_firstIdistDefs,_firstIdistItfs,_firstIdistVisLocalDefs,_firstIdistVisits,_firstIerrs0,_firstIerrs1,_firstIerrs2,_firstIerrs3,_firstIerrs4,_firstIerrs5,_firstIgathAllowCycVisits,_firstIgathAttrSource,_firstIgathAvoidVisits,_firstIgathChildDefs,_firstIgathChildSource,_firstIgathClauses,_firstIgathDataSems,_firstIgathDefs,_firstIgathDeps,_firstIgathItemVisits,_firstIgathLegalCycStmts,_firstIgathMissingInvokes,_firstIgathNonterms,_firstIgathSemAttrSource,_firstIgathSemStarts,_firstIgathStmtPosMap,_firstIgathVisLocalDefs,_firstIgathVisRankMap,_firstIgathVisitAttrs,_firstIgathVisitEnds,_firstIgathVisitNames,_firstIgathVisitSource,_firstIgathVisitStarts,_firstIhpp,_firstIisInternal,_firstIjspp,_firstIlexCounter,_firstImbNextVisit,_firstIminRank,_firstIminReqInvokes,_firstIpp) =
                  first_ _firstOallAvailInvokes _firstOallVisits _firstOallowCycVisits _firstOavailInvokes _firstObasename _firstOclauseExtras _firstOcoItf _firstOcodeIdCounter _firstOdirectVisitAttrs _firstOdirectVisitLocalAttrs _firstOdistAliasses _firstOdistAllChildMinRanges _firstOdistAttrSource _firstOdistAttrVisMap _firstOdistChildDefs _firstOdistChildEffRanges _firstOdistChildMinRanges _firstOdistChildOcc _firstOdistChildSource _firstOdistCycVisMap _firstOdistDataCons _firstOdistDataMap _firstOdistDataSems _firstOdistDatas _firstOdistDeflStmts _firstOdistDefs _firstOdistInhAttrs _firstOdistItfs _firstOdistNextVisits _firstOdistRanks _firstOdistRenames _firstOdistSynAttrs _firstOdistVisLocalDefs _firstOdistVisRankMap _firstOdistVisitInhAttrs _firstOdistVisitOrder _firstOdistVisitSource _firstOdistVisitSynAttrs _firstOdistVisits _firstOdoneVisits _firstOfullCyclic _firstOfullCyclicVisits _firstOgathChildDefs _firstOgathClauses _firstOgathDataSems _firstOgathDefs _firstOgathNonterms _firstOgathVisLocalDefs _firstOgathVisitNames _firstOhSpilledStmts _firstOindent _firstOitf _firstOjsSpilledStmts _firstOlexCounter _firstOlocalAttrs _firstOmasterPos _firstOmyNextVisits _firstOnextVisits _firstOnonterm _firstOopts _firstOscopeDep _firstOscopeReason _firstOsemBasename _firstOstmtSource _firstOvisit _firstOvisitBeginDep _firstOvisitEndDep _firstOvisitEndReason _firstOvisitNr _firstOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOhppType,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
-- Items -------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         minReqInvokes        : Map Ident (Set Ident)
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Item 
         child tl             : Items 
      alternative Nil:
-}
-- cata
sem_Items :: Items  ->
             T_Items 
sem_Items list  =
    (Prelude.foldr sem_Items_Cons sem_Items_Nil (Prelude.map sem_Item list) )
-- semantic domain
type T_Items  = (Map Ident (Set Ident)) ->
                (Set Ident) ->
                (Map Ident (Set Ident)) ->
                QIdent ->
                Ident ->
                Int ->
                (Map Ident (Map Ident String)) ->
                (Map Ident String) ->
                (Map Ident AliasType) ->
                (Map Ident [Ident]) ->
                AttrSourceMap ->
                AttrVisMap ->
                (Env QIdent (QIdent,QIdent)) ->
                (Map Ident (Set Ident)) ->
                (Map Ident [Ident]) ->
                (Map Ident Int) ->
                ChildSourceMap ->
                CycVisMap ->
                ConEnv ->
                DataMap ->
                DataSemEnv ->
                DataEnv ->
                (Map Ident (Bool,Maybe Int)) ->
                DefsEnv ->
                AttrMap ->
                ItfEnv ->
                (Map DepItem (Bool,Int)) ->
                RenameMap ->
                AttrMap ->
                DefsEnv ->
                VisitAttrMap ->
                (Map Ident [Ident]) ->
                VisitSourceMap ->
                VisitAttrMap ->
                VisitEnv ->
                ([Ident]) ->
                (Env QIdent (QIdent, QIdent)) ->
                ClausesEnv ->
                DataSemEnv ->
                DefsEnv ->
                NontermEnv ->
                DefsEnv ->
                ([(Int,PP_Doc)]) ->
                Int ->
                QIdent ->
                ([(Int,PP_Doc)]) ->
                Int ->
                QIdent ->
                Opts ->
                DepItem ->
                Reason ->
                DepItem ->
                DepItem ->
                DepItem ->
                Reason ->
                ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),([PP_Doc]),([PP_Doc]),Int,(Map Ident (Set Ident)),([PP_Doc]))
sem_Items_Cons :: T_Item  ->
                  T_Items  ->
                  T_Items 
sem_Items_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOindent :: Int
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOindent :: Int
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathMissingInvokes :: (Set (Ident,Ident))
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhpp :: PP_Doc
              _hdIhppType :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathMissingInvokes :: (Set (Ident,Ident))
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2645, column 11)
              _lhsOpps =
                  ({-# LINE 2645 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 35890 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 574, column 11)
              _lhsOhpps =
                  ({-# LINE 574 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 35895 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 369, column 11)
              _lhsOjspps =
                  ({-# LINE 369 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 35900 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 35905 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 35910 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 35915 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 35920 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 35925 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 35930 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 35935 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 35940 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 35945 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 35950 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 35955 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _hdIgathMissingInvokes `Set.union` _tlIgathMissingInvokes
                   {-# LINE 35960 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 35965 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 35970 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 35975 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 35980 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 35985 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 35990 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 35995 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 36000 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 36005 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 36010 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 36015 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 36020 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 36025 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 36030 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 36035 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 36040 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 36045 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 36050 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 36055 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 36060 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 36065 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 36070 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 36075 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 36080 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 36085 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 36090 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 36095 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 36100 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 36105 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 36110 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 36115 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 36120 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 36125 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 36130 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 36135 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 36140 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 36145 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 36150 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 36155 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 36160 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 36165 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 36170 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 36175 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 36180 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 36185 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 36190 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 36195 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 36200 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 36205 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 36210 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 36215 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 36220 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 36225 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 36230 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 36235 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 36240 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 36245 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 36250 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 36255 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 36260 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 36265 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 36270 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 36275 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 36280 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 36285 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 36290 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 36295 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 36300 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 36305 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 36310 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 36315 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 36320 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 36325 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 36330 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 36335 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 36340 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 36345 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 36350 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 36355 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 36360 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 36365 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 36370 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 36375 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 36380 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 36385 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 36390 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 36395 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 36400 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 36405 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 36410 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 36415 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 36420 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 36425 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 36430 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 36435 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 36440 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 36445 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 36450 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 36455 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 36460 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 36465 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 36470 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 36475 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 36480 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 36485 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 36490 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 36495 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 36500 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 36505 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 36510 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 36515 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 36520 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 36525 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 36530 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 36535 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 36540 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 36545 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 36550 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 36555 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 36560 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 36565 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 36570 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 36575 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 36580 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 36585 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 36590 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 36595 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 36600 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 36605 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 36610 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 36615 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathMissingInvokes,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitStarts,_hdIhpp,_hdIhppType,_hdIjspp,_hdIlexCounter,_hdIminReqInvokes,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOindent _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathMissingInvokes,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitStarts,_tlIhpps,_tlIjspps,_tlIlexCounter,_tlIminReqInvokes,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOindent _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
sem_Items_Nil :: T_Items 
sem_Items_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2646, column 11)
              _lhsOpps =
                  ({-# LINE 2646 "src/Transform.ag" #-}
                   []
                   {-# LINE 36718 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 575, column 11)
              _lhsOhpps =
                  ({-# LINE 575 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 36723 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 370, column 11)
              _lhsOjspps =
                  ({-# LINE 370 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 36728 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 36733 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36738 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36743 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36748 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36753 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36758 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36763 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 36768 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36773 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 36778 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 36783 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 36788 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36793 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 36798 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36803 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 36808 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 36813 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 36818 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 36823 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 36828 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 36833 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 36838 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 36843 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 36848 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 36853 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 36858 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 36863 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 36868 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 36873 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 36878 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 36883 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 36888 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 36893 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
-- Itf ---------------------------------------------------------
{-
   visit 0:
      inherited attribute:
         opts                 : Opts
      chained attributes:
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathSyns             : AttrEnv
         gathVisits           : VisitEnv
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         gathAttrVisMap       : AttrVisMap
         gathCycVisMap        : CycVisMap
         gathInhAttrs         : AttrMap
         gathSynAttrs         : AttrMap
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitSynAttrs    : VisitAttrMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Itf:
         child pos            : {Pos}
         child name           : {Ident}
         child vars           : Vars 
         child visits         : ItfVisits 
         visit 0:
            local errs1_augmented_f1 : _
            local gathInhAttrs_augmented_f1 : _
            local gathItfs_augmented_f1 : _
            local gathSynAttrs_augmented_f1 : _
            local gathVisitInhAttrs_augmented_f1 : _
            local gathVisitOrder_augmented_f1 : _
            local gathVisitSynAttrs_augmented_f1 : _
            local hpp_augmented_f1 : _
            local hpp_augmented_f2 : _
            local hpp_augmented_syn : _
            local errs1_augmented_syn : _
            local gathInhAttrs_augmented_syn : _
            local gathSynAttrs_augmented_syn : _
            local gathVisitInhAttrs_augmented_syn : _
            local gathVisitOrder_augmented_syn : _
            local gathVisitSynAttrs_augmented_syn : _
            local gathItfs_augmented_syn : _
-}
-- cata
sem_Itf :: Itf  ->
           T_Itf 
sem_Itf (Itf_Itf _pos _name _vars _visits )  =
    (sem_Itf_Itf _pos _name (sem_Vars _vars ) (sem_ItfVisits _visits ) )
-- semantic domain
type T_Itf  = AttrEnv ->
              ItfEnv ->
              AttrEnv ->
              VisitEnv ->
              Opts ->
              ( Errs,Errs,Errs,Errs,Errs,Errs,Blocks,AttrVisMap,CycVisMap,AttrMap,AttrEnv,ItfEnv,AttrMap,AttrEnv,VisitAttrMap,(Map Ident [Ident]),VisitAttrMap,VisitEnv,PP_Doc,PP_Doc,PP_Doc)
sem_Itf_Itf :: Pos ->
               Ident ->
               T_Vars  ->
               T_ItfVisits  ->
               T_Itf 
sem_Itf_Itf pos_ name_ vars_ visits_  =
    (\ _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathSyns
       _lhsIgathVisits
       _lhsIopts ->
         (let _lhsOerrs1 :: Errs
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathItfs :: ItfEnv
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOhpp :: PP_Doc
              _visitsOitf :: QIdent
              _varsOgathVarsEnv :: VarsEnv
              _lhsOgathAttrVisMap :: AttrVisMap
              _lhsOgathCycVisMap :: CycVisMap
              _lhsOpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisits :: VisitEnv
              _visitsOgathInhs :: AttrEnv
              _visitsOgathItfs :: ItfEnv
              _visitsOgathSyns :: AttrEnv
              _visitsOgathVarsEnv :: VarsEnv
              _visitsOgathVisits :: VisitEnv
              _visitsOopts :: Opts
              _visitsOvars :: ([Ident])
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _visitsIerrs0 :: Errs
              _visitsIerrs1 :: Errs
              _visitsIerrs2 :: Errs
              _visitsIerrs3 :: Errs
              _visitsIerrs4 :: Errs
              _visitsIerrs5 :: Errs
              _visitsIextraBlocks :: Blocks
              _visitsIfirstVisit :: Ident
              _visitsIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _visitsIgathCycVisits :: (Set Ident)
              _visitsIgathInhAttrs :: AttrMap
              _visitsIgathInhs :: AttrEnv
              _visitsIgathItfs :: ItfEnv
              _visitsIgathSynAttrs :: AttrMap
              _visitsIgathSyns :: AttrEnv
              _visitsIgathVarsEnv :: VarsEnv
              _visitsIgathVisitInhAttrs :: VisitAttrMap
              _visitsIgathVisitOrder :: (Map Ident [Ident])
              _visitsIgathVisitSynAttrs :: VisitAttrMap
              _visitsIgathVisits :: VisitEnv
              _visitsIgathVisitsInhAttrs :: AttrMap
              _visitsIgathVisitsOrder :: ([Ident])
              _visitsIgathVisitsSynAttrs :: AttrMap
              _visitsIhpps :: ([PP_Doc])
              _visitsIjspps :: ([PP_Doc])
              _visitsImbNextVisit :: (Maybe Ident)
              _visitsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 375 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 37037 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 375 "src/Transform.ag" #-}
                   addDefErrs' _visitsIgathVarsEnv
                   {-# LINE 37042 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathInhAttrs =
                  ({-# LINE 883 "src/Transform.ag" #-}
                   foldr ($) _gathInhAttrs_augmented_syn [_gathInhAttrs_augmented_f1]
                   {-# LINE 37047 "src/Transform.hs" #-})
              -- augment function
              _gathInhAttrs_augmented_f1 =
                  ({-# LINE 883 "src/Transform.ag" #-}
                   Map.insert name_ $ Map.unions $ Map.elems _visitsIgathVisitsInhAttrs
                   {-# LINE 37052 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItfs =
                  ({-# LINE 181 "src/Transform.ag" #-}
                   foldr ($) _gathItfs_augmented_syn [_gathItfs_augmented_f1]
                   {-# LINE 37057 "src/Transform.hs" #-})
              -- augment function
              _gathItfs_augmented_f1 =
                  ({-# LINE 181 "src/Transform.ag" #-}
                   extend [name_] ()
                   {-# LINE 37062 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathSynAttrs =
                  ({-# LINE 884 "src/Transform.ag" #-}
                   foldr ($) _gathSynAttrs_augmented_syn [_gathSynAttrs_augmented_f1]
                   {-# LINE 37067 "src/Transform.hs" #-})
              -- augment function
              _gathSynAttrs_augmented_f1 =
                  ({-# LINE 884 "src/Transform.ag" #-}
                   Map.insert name_ $ Map.unions $ Map.elems _visitsIgathVisitsSynAttrs
                   {-# LINE 37072 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 880 "src/Transform.ag" #-}
                   foldr ($) _gathVisitInhAttrs_augmented_syn [_gathVisitInhAttrs_augmented_f1]
                   {-# LINE 37077 "src/Transform.hs" #-})
              -- augment function
              _gathVisitInhAttrs_augmented_f1 =
                  ({-# LINE 880 "src/Transform.ag" #-}
                   Map.insert name_ _visitsIgathVisitsInhAttrs
                   {-# LINE 37082 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitOrder =
                  ({-# LINE 706 "src/Transform.ag" #-}
                   foldr ($) _gathVisitOrder_augmented_syn [_gathVisitOrder_augmented_f1]
                   {-# LINE 37087 "src/Transform.hs" #-})
              -- augment function
              _gathVisitOrder_augmented_f1 =
                  ({-# LINE 706 "src/Transform.ag" #-}
                   Map.insert name_ _visitsIgathVisitsOrder
                   {-# LINE 37092 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 881 "src/Transform.ag" #-}
                   foldr ($) _gathVisitSynAttrs_augmented_syn [_gathVisitSynAttrs_augmented_f1]
                   {-# LINE 37097 "src/Transform.hs" #-})
              -- augment function
              _gathVisitSynAttrs_augmented_f1 =
                  ({-# LINE 881 "src/Transform.ag" #-}
                   Map.insert name_ _visitsIgathVisitsSynAttrs
                   {-# LINE 37102 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOhpp =
                  ({-# LINE 93 "src/TargetHaskell.ag" #-}
                   foldr ($) _hpp_augmented_syn [_hpp_augmented_f1, _hpp_augmented_f2]
                   {-# LINE 37107 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f1 =
                  ({-# LINE 93 "src/TargetHaskell.ag" #-}
                   vlist _visitsIhpps >-<
                   {-# LINE 37112 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f2 =
                  ({-# LINE 93 "src/TargetHaskell.ag" #-}
                   ("type" >#< hItfNm name_ >#< "m" >#< "=" >#< hItfVsNm name_ _visitsIfirstVisit >#< "m") >-<
                   {-# LINE 37117 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 185, column 16)
              _visitsOitf =
                  ({-# LINE 185 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 37122 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 374, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 374 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 37127 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1371, column 16)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1371 "src/Transform.ag" #-}
                   Map.singleton name_ _visitsIgathAttrVisMap
                   {-# LINE 37132 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1892, column 24)
              _lhsOgathCycVisMap =
                  ({-# LINE 1892 "src/Transform.ag" #-}
                   Map.singleton name_ _visitsIgathCycVisits
                   {-# LINE 37137 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2425, column 18)
              _lhsOpp =
                  ({-# LINE 2425 "src/Transform.ag" #-}
                   "itf" >#< name_
                   >-< indent 2 (vlist _visitsIpps)
                   {-# LINE 37143 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 90, column 14)
              _hpp_augmented_syn =
                  ({-# LINE 93 "src/TargetHaskell.ag" #-}
                   empty
                   {-# LINE 37148 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 48, column 14)
              _lhsOjspp =
                  ({-# LINE 48 "src/TargetJs.ag" #-}
                   vlist _visitsIjspps
                   {-# LINE 37153 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs0
                   {-# LINE 37158 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 375 "src/Transform.ag" #-}
                   _visitsIerrs1
                   {-# LINE 37163 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs2
                   {-# LINE 37168 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs3
                   {-# LINE 37173 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs4
                   {-# LINE 37178 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs5
                   {-# LINE 37183 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _visitsIextraBlocks
                   {-# LINE 37188 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _gathInhAttrs_augmented_syn =
                  ({-# LINE 883 "src/Transform.ag" #-}
                   _visitsIgathInhAttrs
                   {-# LINE 37193 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _gathSynAttrs_augmented_syn =
                  ({-# LINE 884 "src/Transform.ag" #-}
                   _visitsIgathSynAttrs
                   {-# LINE 37198 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _gathVisitInhAttrs_augmented_syn =
                  ({-# LINE 880 "src/Transform.ag" #-}
                   _visitsIgathVisitInhAttrs
                   {-# LINE 37203 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _gathVisitOrder_augmented_syn =
                  ({-# LINE 706 "src/Transform.ag" #-}
                   _visitsIgathVisitOrder
                   {-# LINE 37208 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _gathVisitSynAttrs_augmented_syn =
                  ({-# LINE 881 "src/Transform.ag" #-}
                   _visitsIgathVisitSynAttrs
                   {-# LINE 37213 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _visitsIgathInhs
                   {-# LINE 37218 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathItfs_augmented_syn =
                  ({-# LINE 181 "src/Transform.ag" #-}
                   _visitsIgathItfs
                   {-# LINE 37223 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _visitsIgathSyns
                   {-# LINE 37228 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _visitsIgathVisits
                   {-# LINE 37233 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 37238 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 37243 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 37248 "src/Transform.hs" #-})
              -- copy rule (chain)
              _visitsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _varsIgathVarsEnv
                   {-# LINE 37253 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 37258 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 37263 "src/Transform.hs" #-})
              -- copy rule (chain)
              _visitsOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _varsIvars
                   {-# LINE 37268 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _visitsIerrs0,_visitsIerrs1,_visitsIerrs2,_visitsIerrs3,_visitsIerrs4,_visitsIerrs5,_visitsIextraBlocks,_visitsIfirstVisit,_visitsIgathAttrVisMap,_visitsIgathCycVisits,_visitsIgathInhAttrs,_visitsIgathInhs,_visitsIgathItfs,_visitsIgathSynAttrs,_visitsIgathSyns,_visitsIgathVarsEnv,_visitsIgathVisitInhAttrs,_visitsIgathVisitOrder,_visitsIgathVisitSynAttrs,_visitsIgathVisits,_visitsIgathVisitsInhAttrs,_visitsIgathVisitsOrder,_visitsIgathVisitsSynAttrs,_visitsIhpps,_visitsIjspps,_visitsImbNextVisit,_visitsIpps) =
                  visits_ _visitsOgathInhs _visitsOgathItfs _visitsOgathSyns _visitsOgathVarsEnv _visitsOgathVisits _visitsOitf _visitsOopts _visitsOvars 
          in  ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOgathAttrVisMap,_lhsOgathCycVisMap,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItfs,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOhpp,_lhsOjspp,_lhsOpp)))
-- ItfVisit ----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         itf                  : QIdent
         mbNextVisit          : Maybe Ident
         opts                 : Opts
         vars                 : [Ident]
      chained attributes:
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathSyns             : AttrEnv
         gathVarsEnv          : VarsEnv
         gathVisits           : VisitEnv
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         firstVisit           : Ident
         gathAttrVisMap       : Map (Bool,Ident) Ident
         gathCycVisits        : Set Ident
         gathInhAttrs         : AttrMap
         gathSynAttrs         : AttrMap
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitSynAttrs    : VisitAttrMap
         gathVisitsInhAttrs   : AttrMap
         gathVisitsOrder      : [Ident]
         gathVisitsSynAttrs   : AttrMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Visit:
         child pos            : {Pos}
         child name           : {Ident}
         child cyclic         : {Bool}
         child vars           : Vars 
         child attrs          : Attrs 
         visit 0:
            local gathItfs_augmented_f1 : _
            local gathVisits_augmented_f1 : _
            local gathVisits_augmented_f2 : _
            local hpp_augmented_f1 : _
            local hpp_augmented_f2 : _
            local hpp_augmented_f3 : _
            local hpp_augmented_f4 : _
            local hpp_augmented_f5 : _
            local hpp_augmented_f6 : _
            local hpp_augmented_f7 : _
            local hpp_augmented_f8 : _
            local hpp_augmented_f9 : _
            local hpp_augmented_f10 : _
            local hpp_augmented_f11 : _
            local jspp_augmented_f1 : _
            local coItf       : _
            local itfNm       : _
            local unqualItf   : _
            local noIterNm    : _
            local noIterSem   : _
            local visCyclic   : _
            local hpp_augmented_syn : _
            local hCtx        : _
            local hMonad      : _
            local hConNm      : _
            local hCoConNm    : _
            local hRepFld     : _
            local hNextFld    : _
            local hArrTp      : _
            local hCoArrTp    : _
            local jspp_augmented_syn : _
            local jsInhNm     : _
            local jsSynNm     : _
            local gathItfs_augmented_syn : _
            local gathVisits_augmented_syn : _
-}
-- cata
sem_ItfVisit :: ItfVisit  ->
                T_ItfVisit 
sem_ItfVisit (ItfVisit_Visit _pos _name _cyclic _vars _attrs )  =
    (sem_ItfVisit_Visit _pos _name _cyclic (sem_Vars _vars ) (sem_Attrs _attrs ) )
-- semantic domain
type T_ItfVisit  = AttrEnv ->
                   ItfEnv ->
                   AttrEnv ->
                   VarsEnv ->
                   VisitEnv ->
                   QIdent ->
                   (Maybe Ident) ->
                   Opts ->
                   ([Ident]) ->
                   ( Errs,Errs,Errs,Errs,Errs,Errs,Blocks,Ident,(Map (Bool,Ident) Ident),(Set Ident),AttrMap,AttrEnv,ItfEnv,AttrMap,AttrEnv,VarsEnv,VisitAttrMap,(Map Ident [Ident]),VisitAttrMap,VisitEnv,AttrMap,([Ident]),AttrMap,PP_Doc,PP_Doc,PP_Doc)
sem_ItfVisit_Visit :: Pos ->
                      Ident ->
                      Bool ->
                      T_Vars  ->
                      T_Attrs  ->
                      T_ItfVisit 
sem_ItfVisit_Visit pos_ name_ cyclic_ vars_ attrs_  =
    (\ _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathSyns
       _lhsIgathVarsEnv
       _lhsIgathVisits
       _lhsIitf
       _lhsImbNextVisit
       _lhsIopts
       _lhsIvars ->
         (let _lhsOgathItfs :: ItfEnv
              _lhsOgathVisits :: VisitEnv
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _attrsOvisit :: QIdent
              _lhsOgathVisitsOrder :: ([Ident])
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitsInhAttrs :: AttrMap
              _lhsOgathVisitsSynAttrs :: AttrMap
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathSynAttrs :: AttrMap
              _lhsOfirstVisit :: Ident
              _lhsOextraBlocks :: Blocks
              _lhsOgathCycVisits :: (Set Ident)
              _lhsOpp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOgathInhs :: AttrEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVarsEnv :: VarsEnv
              _varsOgathVarsEnv :: VarsEnv
              _attrsOcoItf :: QIdent
              _attrsOgathInhs :: AttrEnv
              _attrsOgathSyns :: AttrEnv
              _attrsOitf :: QIdent
              _attrsOopts :: Opts
              _attrsOvisCyclic :: Bool
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _attrsIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _attrsIgathInhs :: AttrEnv
              _attrsIgathSyns :: AttrEnv
              _attrsIgathVisitInhAttrs :: (Map Ident String)
              _attrsIgathVisitSynAttrs :: (Map Ident String)
              _attrsIhCoInhDeclPPs :: ([PP_Doc])
              _attrsIhCoSynDeclPPs :: ([PP_Doc])
              _attrsIhInhDeclPPs :: ([PP_Doc])
              _attrsIhSynDeclPPs :: ([PP_Doc])
              _attrsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOgathItfs =
                  ({-# LINE 182 "src/Transform.ag" #-}
                   foldr ($) _gathItfs_augmented_syn [_gathItfs_augmented_f1]
                   {-# LINE 37439 "src/Transform.hs" #-})
              -- augment function
              _gathItfs_augmented_f1 =
                  ({-# LINE 182 "src/Transform.ag" #-}
                   extend _coItf     ()
                   {-# LINE 37444 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisits =
                  ({-# LINE 197 "src/Transform.ag" #-}
                   foldr ($) _gathVisits_augmented_syn [_gathVisits_augmented_f1, _gathVisits_augmented_f2]
                   {-# LINE 37449 "src/Transform.hs" #-})
              -- augment function
              _gathVisits_augmented_f1 =
                  ({-# LINE 197 "src/Transform.ag" #-}
                   extend (name_ : _coItf    ) ()
                   {-# LINE 37454 "src/Transform.hs" #-})
              -- augment function
              _gathVisits_augmented_f2 =
                  ({-# LINE 197 "src/Transform.ag" #-}
                   extend (name_ : _lhsIitf) ()
                   {-# LINE 37459 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOhpp =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   foldr ($) _hpp_augmented_syn [_hpp_augmented_f1, _hpp_augmented_f2, _hpp_augmented_f3, _hpp_augmented_f4, _hpp_augmented_f5, _hpp_augmented_f6, _hpp_augmented_f7, _hpp_augmented_f8, _hpp_augmented_f9, _hpp_augmented_f10, _hpp_augmented_f11]
                   {-# LINE 37464 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f1 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ((hCurrentNm _itfNm     name_ >#< "!" >|< pp_parens (
                     hSynDt _itfNm     name_ >#< pp_braces (hSynFldNmFull repIdent _itfNm     name_ >#< "=" >#< "__f")
                   ) >#< "=" >#< "__f") >-<)
                   {-# LINE 37471 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f2 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   case _lhsImbNextVisit of
                      Nothing -> id
                      Just v  -> ((hNextNm _itfNm     name_ >#< "!" >|< pp_parens (
                                   hSynDt _itfNm     name_ >#< pp_braces (
                                     hSynFldNmFull nextIdent _itfNm     name_ >#< "=" >#< "__f")
                                 ) >#< "=" >#< "__f" >#< "--" >#< v) >-<)
                   {-# LINE 37481 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f3 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   (hCoInvNm _itfNm     name_ >#< "!" >|< pp_parens (_hCoConNm     >#< "!" >|< "__f") >#< "=" >#< "__f") >-<
                   {-# LINE 37486 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f4 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   (hInvNm _itfNm     name_ >#< "!" >|< pp_parens (_hConNm     >#< "!" >|< "__f") >#< "=" >#< "__f") >-<
                   {-# LINE 37491 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f5 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("type" >#< hCoItfNm _itfNm     name_ >#< "m" >#< "=" >#< hCoItfVsNm _itfNm     name_ >#< "m") >-<
                   {-# LINE 37496 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f6 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("data" >#< _hCtx
                           >#< hCoSynDt _itfNm     name_ >#< "m" >#< "=" >#< hCoSynDt _itfNm     name_
                           >#< pp_block "{" "}" "," (
                                 (hCoSynFldNmFull repIdent _itfNm     name_ >#< "::" >#< "!" >|< pp_parens (_hCoConNm     >#< "m"))
                                 : _attrsIhCoSynDeclPPs)
                            ) >-<
                   {-# LINE 37506 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f7 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("data" >#< _hCtx
                           >#< hCoInhDt _itfNm     name_ >#< "m" >#< "=" >#< hCoInhDt _itfNm     name_
                           >#< pp_block "{" "}" "," _attrsIhCoInhDeclPPs) >-<
                   {-# LINE 37513 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f8 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("data" >#< _hCtx
                           >#< hSynDt _itfNm     name_ >#< "m" >#< "=" >#< hSynDt _itfNm     name_
                           >#< pp_block "{" "}" "," (_hRepFld     ++ _hNextFld     ++ _attrsIhSynDeclPPs)
                           ) >-<
                   {-# LINE 37521 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f9 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("data" >#< _hCtx
                           >#< hInhDt _itfNm     name_ >#< "m" >#< "=" >#< hInhDt _itfNm     name_
                           >#< pp_block "{" "}" "," _attrsIhInhDeclPPs) >-<
                   {-# LINE 37528 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f10 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("newtype" >#< _hCtx     >#< _hCoConNm     >#< "m" >#< "=" >#< _hCoConNm     >#< pp_parens _hCoArrTp    ) >-<
                   {-# LINE 37533 "src/Transform.hs" #-})
              -- augment function
              _hpp_augmented_f11 =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   ("newtype" >#< _hCtx     >#< _hConNm     >#< "m" >#< "=" >#< _hConNm     >#< pp_parens _hArrTp    ) >-<
                   {-# LINE 37538 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOjspp =
                  ({-# LINE 54 "src/TargetJs.ag" #-}
                   foldr ($) _jspp_augmented_syn [_jspp_augmented_f1]
                   {-# LINE 37543 "src/Transform.hs" #-})
              -- augment function
              _jspp_augmented_f1 =
                  ({-# LINE 54 "src/TargetJs.ag" #-}
                   ("function" >#< _jsInhNm     >#< "() {}"
                   >-< _jsInhNm     >|< ".prototype.check = function()"
                   >-< indent 2 (pp_braces (
                         vlist [ jsTpCheck nm tp | (nm,tp) <- Map.assocs _attrsIgathVisitInhAttrs ]
                       ))
                   >-< "function" >#< _jsSynNm     >#< "() {}"
                    >-< _jsSynNm     >|< ".prototype.check = function()"
                    >-< indent 2 (pp_braces (
                          vlist [ jsTpCheck nm tp | (nm,tp) <- Map.assocs _attrsIgathVisitSynAttrs ]
                        ))
                   ) >-<
                   {-# LINE 37558 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 202, column 3)
              _attrsOvisit =
                  ({-# LINE 202 "src/Transform.ag" #-}
                   name_ : _lhsIitf
                   {-# LINE 37563 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 203, column 3)
              _coItf =
                  ({-# LINE 203 "src/Transform.ag" #-}
                   [mkCoIdent (head _lhsIitf) name_]
                   {-# LINE 37568 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 707, column 23)
              _lhsOgathVisitsOrder =
                  ({-# LINE 707 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 37573 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 708, column 23)
              _lhsOgathVisitOrder =
                  ({-# LINE 708 "src/Transform.ag" #-}
                   Map.singleton (head _coItf    ) [name_]
                   {-# LINE 37578 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 872, column 12)
              _lhsOgathVisitsInhAttrs =
                  ({-# LINE 872 "src/Transform.ag" #-}
                   Map.singleton name_ _attrsIgathVisitInhAttrs
                   {-# LINE 37583 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 873, column 12)
              _lhsOgathVisitsSynAttrs =
                  ({-# LINE 873 "src/Transform.ag" #-}
                   Map.singleton name_ _attrsIgathVisitSynAttrs
                   {-# LINE 37588 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 874, column 12)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 874 "src/Transform.ag" #-}
                   Map.singleton (head _coItf    ) (Map.singleton name_ _attrsIgathVisitSynAttrs)
                   {-# LINE 37593 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 875, column 12)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 875 "src/Transform.ag" #-}
                   Map.singleton (head _coItf    ) (Map.singleton name_ _attrsIgathVisitInhAttrs)
                   {-# LINE 37598 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 876, column 12)
              _lhsOgathInhAttrs =
                  ({-# LINE 876 "src/Transform.ag" #-}
                   Map.singleton (head _coItf    ) _attrsIgathVisitSynAttrs
                   {-# LINE 37603 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 877, column 12)
              _lhsOgathSynAttrs =
                  ({-# LINE 877 "src/Transform.ag" #-}
                   Map.singleton (head _coItf    ) _attrsIgathVisitInhAttrs
                   {-# LINE 37608 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1329, column 23)
              _lhsOfirstVisit =
                  ({-# LINE 1329 "src/Transform.ag" #-}
                   name_
                   {-# LINE 37613 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1335, column 12)
              _itfNm =
                  ({-# LINE 1335 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 37618 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1537, column 3)
              _lhsOextraBlocks =
                  ({-# LINE 1537 "src/Transform.ag" #-}
                   if genCoSems _lhsIopts
                    then [_noIterSem    ]
                    else []
                   {-# LINE 37625 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1540, column 3)
              _unqualItf =
                  ({-# LINE 1540 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 37630 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1541, column 3)
              _noIterNm =
                  ({-# LINE 1541 "src/Transform.ag" #-}
                   noIterNm _unqualItf     name_
                   {-# LINE 37635 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1542, column 3)
              _noIterSem =
                  ({-# LINE 1542 "src/Transform.ag" #-}
                   Block_Item _noIterNm     $
                     Item_CoSem pos_ _noIterNm     _unqualItf     name_ [] Nothing $
                       SemVisit_Visit pos_ name_ False [] [] $ ClausesTop_Top []
                   {-# LINE 37642 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1890, column 24)
              _lhsOgathCycVisits =
                  ({-# LINE 1890 "src/Transform.ag" #-}
                   if cyclic_ then Set.singleton name_ else Set.empty
                   {-# LINE 37647 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1891, column 24)
              _visCyclic =
                  ({-# LINE 1891 "src/Transform.ag" #-}
                   cyclic_
                   {-# LINE 37652 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2429, column 18)
              _lhsOpp =
                  ({-# LINE 2429 "src/Transform.ag" #-}
                   "visit" >#< name_ >#< (if cyclic_ then text "cyclic" else empty)
                   >-< indent 2 (vlist _attrsIpps)
                   {-# LINE 37658 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 96, column 14)
              _hpp_augmented_syn =
                  ({-# LINE 134 "src/TargetHaskell.ag" #-}
                   empty
                   {-# LINE 37663 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 97, column 14)
              _hCtx =
                  ({-# LINE 97 "src/TargetHaskell.ag" #-}
                   "(Monad m) => "
                   {-# LINE 37668 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 98, column 14)
              _hMonad =
                  ({-# LINE 98 "src/TargetHaskell.ag" #-}
                   if cyclic_ then empty else text "m"
                   {-# LINE 37673 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 99, column 14)
              _hConNm =
                  ({-# LINE 99 "src/TargetHaskell.ag" #-}
                   text $ hItfVsNm _itfNm     name_
                   {-# LINE 37678 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 100, column 14)
              _hCoConNm =
                  ({-# LINE 100 "src/TargetHaskell.ag" #-}
                   text $ hCoItfVsNm _itfNm     name_
                   {-# LINE 37683 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 101, column 14)
              _hRepFld =
                  ({-# LINE 101 "src/TargetHaskell.ag" #-}
                   [ hSynFldNmFull repIdent _itfNm     name_ >#< "::" >#< "!" >|< pp_parens (_hConNm     >#< "m") ]
                   {-# LINE 37688 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 102, column 14)
              _hNextFld =
                  ({-# LINE 102 "src/TargetHaskell.ag" #-}
                   maybe [] (\nm -> [ hSynFldNmFull nextIdent _itfNm     name_
                                      >#< "::" >#< "!" >|< pp_parens (hItfVsNm _itfNm     nm >#< "m")]) _lhsImbNextVisit
                   {-# LINE 37694 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 104, column 14)
              _hArrTp =
                  ({-# LINE 104 "src/TargetHaskell.ag" #-}
                   hInhDt _itfNm     name_ >#< "m" >#< "->" >#< _hMonad     >#< pp_parens (hSynDt _itfNm     name_ >#< "m")
                   {-# LINE 37699 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 105, column 14)
              _hCoArrTp =
                  ({-# LINE 105 "src/TargetHaskell.ag" #-}
                   hCoInhDt _itfNm     name_ >#< "m" >#< "->" >#< _hMonad     >#< pp_parens (hCoSynDt _itfNm     name_ >#< "m")
                   {-# LINE 37704 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 51, column 14)
              _jspp_augmented_syn =
                  ({-# LINE 54 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 37709 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 52, column 14)
              _jsInhNm =
                  ({-# LINE 52 "src/TargetJs.ag" #-}
                   "Inh_" >|< jsConNm _itfNm     name_
                   {-# LINE 37714 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 53, column 14)
              _jsSynNm =
                  ({-# LINE 53 "src/TargetJs.ag" #-}
                   "Syn_" >|< jsConNm _itfNm     name_
                   {-# LINE 37719 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37724 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37729 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37734 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37739 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37744 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 37749 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1370, column 57)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1370 "src/Transform.ag" #-}
                   _attrsIgathAttrVisMap
                   {-# LINE 37754 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _attrsIgathInhs
                   {-# LINE 37759 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathItfs_augmented_syn =
                  ({-# LINE 182 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 37764 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _attrsIgathSyns
                   {-# LINE 37769 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _varsIgathVarsEnv
                   {-# LINE 37774 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathVisits_augmented_syn =
                  ({-# LINE 197 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 37779 "src/Transform.hs" #-})
              -- copy rule (down)
              _varsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 37784 "src/Transform.hs" #-})
              -- copy rule (from local)
              _attrsOcoItf =
                  ({-# LINE 200 "src/Transform.ag" #-}
                   _coItf
                   {-# LINE 37789 "src/Transform.hs" #-})
              -- copy rule (down)
              _attrsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 37794 "src/Transform.hs" #-})
              -- copy rule (down)
              _attrsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 37799 "src/Transform.hs" #-})
              -- copy rule (down)
              _attrsOitf =
                  ({-# LINE 184 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 37804 "src/Transform.hs" #-})
              -- copy rule (down)
              _attrsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 37809 "src/Transform.hs" #-})
              -- copy rule (from local)
              _attrsOvisCyclic =
                  ({-# LINE 1887 "src/Transform.ag" #-}
                   _visCyclic
                   {-# LINE 37814 "src/Transform.hs" #-})
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _attrsIgathAttrVisMap,_attrsIgathInhs,_attrsIgathSyns,_attrsIgathVisitInhAttrs,_attrsIgathVisitSynAttrs,_attrsIhCoInhDeclPPs,_attrsIhCoSynDeclPPs,_attrsIhInhDeclPPs,_attrsIhSynDeclPPs,_attrsIpps) =
                  attrs_ _attrsOcoItf _attrsOgathInhs _attrsOgathSyns _attrsOitf _attrsOopts _attrsOvisCyclic _attrsOvisit 
          in  ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOfirstVisit,_lhsOgathAttrVisMap,_lhsOgathCycVisits,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItfs,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVarsEnv,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOgathVisitsInhAttrs,_lhsOgathVisitsOrder,_lhsOgathVisitsSynAttrs,_lhsOhpp,_lhsOjspp,_lhsOpp)))
-- ItfVisits ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         itf                  : QIdent
         opts                 : Opts
         vars                 : [Ident]
      chained attributes:
         gathInhs             : AttrEnv
         gathItfs             : ItfEnv
         gathSyns             : AttrEnv
         gathVarsEnv          : VarsEnv
         gathVisits           : VisitEnv
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         extraBlocks          : Blocks
         firstVisit           : Ident
         gathAttrVisMap       : Map (Bool,Ident) Ident
         gathCycVisits        : Set Ident
         gathInhAttrs         : AttrMap
         gathSynAttrs         : AttrMap
         gathVisitInhAttrs    : VisitAttrMap
         gathVisitOrder       : Map Ident [Ident]
         gathVisitSynAttrs    : VisitAttrMap
         gathVisitsInhAttrs   : AttrMap
         gathVisitsOrder      : [Ident]
         gathVisitsSynAttrs   : AttrMap
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         mbNextVisit          : Maybe Ident
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : ItfVisit 
         child tl             : ItfVisits 
         visit 0:
            local errs1_augmented_f1 : _
            local _tup56      : {(VarsEnv,VarsEnv)}
            local _tup57      : _
            local locGathVarsEnv : _
            local errs1_augmented_syn : _
      alternative Nil:
-}
-- cata
sem_ItfVisits :: ItfVisits  ->
                 T_ItfVisits 
sem_ItfVisits list  =
    (Prelude.foldr sem_ItfVisits_Cons sem_ItfVisits_Nil (Prelude.map sem_ItfVisit list) )
-- semantic domain
type T_ItfVisits  = AttrEnv ->
                    ItfEnv ->
                    AttrEnv ->
                    VarsEnv ->
                    VisitEnv ->
                    QIdent ->
                    Opts ->
                    ([Ident]) ->
                    ( Errs,Errs,Errs,Errs,Errs,Errs,Blocks,Ident,(Map (Bool,Ident) Ident),(Set Ident),AttrMap,AttrEnv,ItfEnv,AttrMap,AttrEnv,VarsEnv,VisitAttrMap,(Map Ident [Ident]),VisitAttrMap,VisitEnv,AttrMap,([Ident]),AttrMap,([PP_Doc]),([PP_Doc]),(Maybe Ident),([PP_Doc]))
sem_ItfVisits_Cons :: T_ItfVisit  ->
                      T_ItfVisits  ->
                      T_ItfVisits 
sem_ItfVisits_Cons hd_ tl_  =
    (\ _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathSyns
       _lhsIgathVarsEnv
       _lhsIgathVisits
       _lhsIitf
       _lhsIopts
       _lhsIvars ->
         (let _lhsOerrs1 :: Errs
              __tup56 :: ((VarsEnv,VarsEnv))
              _hdOgathVarsEnv :: VarsEnv
              _tlOgathVarsEnv :: VarsEnv
              _lhsOgathVarsEnv :: VarsEnv
              _lhsOfirstVisit :: Ident
              _hdOmbNextVisit :: (Maybe Ident)
              _lhsOmbNextVisit :: (Maybe Ident)
              _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOgathCycVisits :: (Set Ident)
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOgathVisitsInhAttrs :: AttrMap
              _lhsOgathVisitsOrder :: ([Ident])
              _lhsOgathVisitsSynAttrs :: AttrMap
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVisits :: VisitEnv
              _hdOgathInhs :: AttrEnv
              _hdOgathItfs :: ItfEnv
              _hdOgathSyns :: AttrEnv
              _hdOgathVisits :: VisitEnv
              _hdOitf :: QIdent
              _hdOopts :: Opts
              _hdOvars :: ([Ident])
              _tlOgathInhs :: AttrEnv
              _tlOgathItfs :: ItfEnv
              _tlOgathSyns :: AttrEnv
              _tlOgathVisits :: VisitEnv
              _tlOitf :: QIdent
              _tlOopts :: Opts
              _tlOvars :: ([Ident])
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIextraBlocks :: Blocks
              _hdIfirstVisit :: Ident
              _hdIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _hdIgathCycVisits :: (Set Ident)
              _hdIgathInhAttrs :: AttrMap
              _hdIgathInhs :: AttrEnv
              _hdIgathItfs :: ItfEnv
              _hdIgathSynAttrs :: AttrMap
              _hdIgathSyns :: AttrEnv
              _hdIgathVarsEnv :: VarsEnv
              _hdIgathVisitInhAttrs :: VisitAttrMap
              _hdIgathVisitOrder :: (Map Ident [Ident])
              _hdIgathVisitSynAttrs :: VisitAttrMap
              _hdIgathVisits :: VisitEnv
              _hdIgathVisitsInhAttrs :: AttrMap
              _hdIgathVisitsOrder :: ([Ident])
              _hdIgathVisitsSynAttrs :: AttrMap
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIpp :: PP_Doc
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIextraBlocks :: Blocks
              _tlIfirstVisit :: Ident
              _tlIgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _tlIgathCycVisits :: (Set Ident)
              _tlIgathInhAttrs :: AttrMap
              _tlIgathInhs :: AttrEnv
              _tlIgathItfs :: ItfEnv
              _tlIgathSynAttrs :: AttrMap
              _tlIgathSyns :: AttrEnv
              _tlIgathVarsEnv :: VarsEnv
              _tlIgathVisitInhAttrs :: VisitAttrMap
              _tlIgathVisitOrder :: (Map Ident [Ident])
              _tlIgathVisitSynAttrs :: VisitAttrMap
              _tlIgathVisits :: VisitEnv
              _tlIgathVisitsInhAttrs :: AttrMap
              _tlIgathVisitsOrder :: ([Ident])
              _tlIgathVisitsSynAttrs :: AttrMap
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlImbNextVisit :: (Maybe Ident)
              _tlIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 380 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 37997 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 380 "src/Transform.ag" #-}
                   addDefErrs' _locGathVarsEnv
                   {-# LINE 38002 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 378, column 3)
              __tup56 =
                  ({-# LINE 378 "src/Transform.ag" #-}
                   split _lhsIgathVarsEnv
                   {-# LINE 38007 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 378, column 3)
              (_hdOgathVarsEnv,_) =
                  ({-# LINE 378 "src/Transform.ag" #-}
                   __tup56
                   {-# LINE 38012 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 378, column 3)
              (_,_tlOgathVarsEnv) =
                  ({-# LINE 378 "src/Transform.ag" #-}
                   __tup56
                   {-# LINE 38017 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 379, column 3)
              __tup57 =
                  ({-# LINE 379 "src/Transform.ag" #-}
                   merge _hdIgathVarsEnv _tlIgathVarsEnv
                   {-# LINE 38022 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 379, column 3)
              (_lhsOgathVarsEnv,_) =
                  ({-# LINE 379 "src/Transform.ag" #-}
                   __tup57
                   {-# LINE 38027 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 379, column 3)
              (_,_locGathVarsEnv) =
                  ({-# LINE 379 "src/Transform.ag" #-}
                   __tup57
                   {-# LINE 38032 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1331, column 11)
              _lhsOfirstVisit =
                  ({-# LINE 1331 "src/Transform.ag" #-}
                   _hdIfirstVisit
                   {-# LINE 38037 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1345, column 11)
              _hdOmbNextVisit =
                  ({-# LINE 1345 "src/Transform.ag" #-}
                   _tlImbNextVisit
                   {-# LINE 38042 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1346, column 11)
              _lhsOmbNextVisit =
                  ({-# LINE 1346 "src/Transform.ag" #-}
                   Just _hdIfirstVisit
                   {-# LINE 38047 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2629, column 11)
              _lhsOpps =
                  ({-# LINE 2629 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 38052 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 562, column 11)
              _lhsOhpps =
                  ({-# LINE 562 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 38057 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 357, column 11)
              _lhsOjspps =
                  ({-# LINE 357 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 38062 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 38067 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 380 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 38072 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 38077 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 38082 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 38087 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 38092 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   _hdIextraBlocks ++ _tlIextraBlocks
                   {-# LINE 38097 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1370, column 57)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1370 "src/Transform.ag" #-}
                   _hdIgathAttrVisMap `Map.union` _tlIgathAttrVisMap
                   {-# LINE 38102 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1886, column 45)
              _lhsOgathCycVisits =
                  ({-# LINE 1886 "src/Transform.ag" #-}
                   _hdIgathCycVisits `Set.union` _tlIgathCycVisits
                   {-# LINE 38107 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _hdIgathInhAttrs `mappend` _tlIgathInhAttrs
                   {-# LINE 38112 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   _hdIgathSynAttrs `mappend` _tlIgathSynAttrs
                   {-# LINE 38117 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _hdIgathVisitInhAttrs `mappend` _tlIgathVisitInhAttrs
                   {-# LINE 38122 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   _hdIgathVisitOrder `mappend` _tlIgathVisitOrder
                   {-# LINE 38127 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   _hdIgathVisitSynAttrs `mappend` _tlIgathVisitSynAttrs
                   {-# LINE 38132 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 864, column 70)
              _lhsOgathVisitsInhAttrs =
                  ({-# LINE 864 "src/Transform.ag" #-}
                   _hdIgathVisitsInhAttrs `mappend` _tlIgathVisitsInhAttrs
                   {-# LINE 38137 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 704, column 47)
              _lhsOgathVisitsOrder =
                  ({-# LINE 704 "src/Transform.ag" #-}
                   _hdIgathVisitsOrder ++ _tlIgathVisitsOrder
                   {-# LINE 38142 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 864, column 70)
              _lhsOgathVisitsSynAttrs =
                  ({-# LINE 864 "src/Transform.ag" #-}
                   _hdIgathVisitsSynAttrs `mappend` _tlIgathVisitsSynAttrs
                   {-# LINE 38147 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathInhs
                   {-# LINE 38152 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _tlIgathItfs
                   {-# LINE 38157 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _tlIgathSyns
                   {-# LINE 38162 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _tlIgathVisits
                   {-# LINE 38167 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 38172 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 38177 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 38182 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 38187 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 184 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 38192 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 38197 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _lhsIvars
                   {-# LINE 38202 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathInhs
                   {-# LINE 38207 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _hdIgathItfs
                   {-# LINE 38212 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _hdIgathSyns
                   {-# LINE 38217 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _hdIgathVisits
                   {-# LINE 38222 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 184 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 38227 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 38232 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvars =
                  ({-# LINE 1477 "src/Transform.ag" #-}
                   _lhsIvars
                   {-# LINE 38237 "src/Transform.hs" #-})
              ( _hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIextraBlocks,_hdIfirstVisit,_hdIgathAttrVisMap,_hdIgathCycVisits,_hdIgathInhAttrs,_hdIgathInhs,_hdIgathItfs,_hdIgathSynAttrs,_hdIgathSyns,_hdIgathVarsEnv,_hdIgathVisitInhAttrs,_hdIgathVisitOrder,_hdIgathVisitSynAttrs,_hdIgathVisits,_hdIgathVisitsInhAttrs,_hdIgathVisitsOrder,_hdIgathVisitsSynAttrs,_hdIhpp,_hdIjspp,_hdIpp) =
                  hd_ _hdOgathInhs _hdOgathItfs _hdOgathSyns _hdOgathVarsEnv _hdOgathVisits _hdOitf _hdOmbNextVisit _hdOopts _hdOvars 
              ( _tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIextraBlocks,_tlIfirstVisit,_tlIgathAttrVisMap,_tlIgathCycVisits,_tlIgathInhAttrs,_tlIgathInhs,_tlIgathItfs,_tlIgathSynAttrs,_tlIgathSyns,_tlIgathVarsEnv,_tlIgathVisitInhAttrs,_tlIgathVisitOrder,_tlIgathVisitSynAttrs,_tlIgathVisits,_tlIgathVisitsInhAttrs,_tlIgathVisitsOrder,_tlIgathVisitsSynAttrs,_tlIhpps,_tlIjspps,_tlImbNextVisit,_tlIpps) =
                  tl_ _tlOgathInhs _tlOgathItfs _tlOgathSyns _tlOgathVarsEnv _tlOgathVisits _tlOitf _tlOopts _tlOvars 
          in  ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOfirstVisit,_lhsOgathAttrVisMap,_lhsOgathCycVisits,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItfs,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVarsEnv,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOgathVisitsInhAttrs,_lhsOgathVisitsOrder,_lhsOgathVisitsSynAttrs,_lhsOhpps,_lhsOjspps,_lhsOmbNextVisit,_lhsOpps)))
sem_ItfVisits_Nil :: T_ItfVisits 
sem_ItfVisits_Nil  =
    (\ _lhsIgathInhs
       _lhsIgathItfs
       _lhsIgathSyns
       _lhsIgathVarsEnv
       _lhsIgathVisits
       _lhsIitf
       _lhsIopts
       _lhsIvars ->
         (let _lhsOfirstVisit :: Ident
              _lhsOmbNextVisit :: (Maybe Ident)
              _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOextraBlocks :: Blocks
              _lhsOgathAttrVisMap :: (Map (Bool,Ident) Ident)
              _lhsOgathCycVisits :: (Set Ident)
              _lhsOgathInhAttrs :: AttrMap
              _lhsOgathSynAttrs :: AttrMap
              _lhsOgathVisitInhAttrs :: VisitAttrMap
              _lhsOgathVisitOrder :: (Map Ident [Ident])
              _lhsOgathVisitSynAttrs :: VisitAttrMap
              _lhsOgathVisitsInhAttrs :: AttrMap
              _lhsOgathVisitsOrder :: ([Ident])
              _lhsOgathVisitsSynAttrs :: AttrMap
              _lhsOgathInhs :: AttrEnv
              _lhsOgathItfs :: ItfEnv
              _lhsOgathSyns :: AttrEnv
              _lhsOgathVarsEnv :: VarsEnv
              _lhsOgathVisits :: VisitEnv
              -- "src/Transform.ag"(line 1332, column 11)
              _lhsOfirstVisit =
                  ({-# LINE 1332 "src/Transform.ag" #-}
                   ident "nofirstvisit"
                   {-# LINE 38284 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1347, column 11)
              _lhsOmbNextVisit =
                  ({-# LINE 1347 "src/Transform.ag" #-}
                   Nothing
                   {-# LINE 38289 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2630, column 11)
              _lhsOpps =
                  ({-# LINE 2630 "src/Transform.ag" #-}
                   []
                   {-# LINE 38294 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 563, column 11)
              _lhsOhpps =
                  ({-# LINE 563 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 38299 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 358, column 11)
              _lhsOjspps =
                  ({-# LINE 358 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 38304 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38309 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38314 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38319 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38324 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38329 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 38334 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1483, column 74)
              _lhsOextraBlocks =
                  ({-# LINE 1483 "src/Transform.ag" #-}
                   []
                   {-# LINE 38339 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1370, column 57)
              _lhsOgathAttrVisMap =
                  ({-# LINE 1370 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 38344 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1886, column 45)
              _lhsOgathCycVisits =
                  ({-# LINE 1886 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 38349 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathInhAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38354 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 862, column 85)
              _lhsOgathSynAttrs =
                  ({-# LINE 862 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38359 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitInhAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38364 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 703, column 73)
              _lhsOgathVisitOrder =
                  ({-# LINE 703 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38369 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 863, column 95)
              _lhsOgathVisitSynAttrs =
                  ({-# LINE 863 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38374 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 864, column 70)
              _lhsOgathVisitsInhAttrs =
                  ({-# LINE 864 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38379 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 704, column 47)
              _lhsOgathVisitsOrder =
                  ({-# LINE 704 "src/Transform.ag" #-}
                   []
                   {-# LINE 38384 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 864, column 70)
              _lhsOgathVisitsSynAttrs =
                  ({-# LINE 864 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 38389 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathInhs =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathInhs
                   {-# LINE 38394 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathItfs =
                  ({-# LINE 177 "src/Transform.ag" #-}
                   _lhsIgathItfs
                   {-# LINE 38399 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathSyns =
                  ({-# LINE 214 "src/Transform.ag" #-}
                   _lhsIgathSyns
                   {-# LINE 38404 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 38409 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisits =
                  ({-# LINE 191 "src/Transform.ag" #-}
                   _lhsIgathVisits
                   {-# LINE 38414 "src/Transform.hs" #-})
          in  ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOextraBlocks,_lhsOfirstVisit,_lhsOgathAttrVisMap,_lhsOgathCycVisits,_lhsOgathInhAttrs,_lhsOgathInhs,_lhsOgathItfs,_lhsOgathSynAttrs,_lhsOgathSyns,_lhsOgathVarsEnv,_lhsOgathVisitInhAttrs,_lhsOgathVisitOrder,_lhsOgathVisitSynAttrs,_lhsOgathVisits,_lhsOgathVisitsInhAttrs,_lhsOgathVisitsOrder,_lhsOgathVisitsSynAttrs,_lhsOhpps,_lhsOjspps,_lhsOmbNextVisit,_lhsOpps)))
-- MaybeBoundCode ----------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         isFun                : Bool
         isJust               : Bool
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative Just:
         child just           : BoundCode 
      alternative Nothing:
-}
-- cata
sem_MaybeBoundCode :: MaybeBoundCode  ->
                      T_MaybeBoundCode 
sem_MaybeBoundCode (Prelude.Just x )  =
    (sem_MaybeBoundCode_Just (sem_BoundCode x ) )
sem_MaybeBoundCode Prelude.Nothing  =
    sem_MaybeBoundCode_Nothing
-- semantic domain
type T_MaybeBoundCode  = (Map Ident (Set Ident)) ->
                         (Set Ident) ->
                         (Map Ident (Set Ident)) ->
                         QIdent ->
                         Ident ->
                         Int ->
                         (Map Ident (Map Ident String)) ->
                         (Map Ident String) ->
                         (Map Ident AliasType) ->
                         (Map Ident [Ident]) ->
                         AttrSourceMap ->
                         AttrVisMap ->
                         (Env QIdent (QIdent,QIdent)) ->
                         (Map Ident (Set Ident)) ->
                         (Map Ident [Ident]) ->
                         (Map Ident Int) ->
                         ChildSourceMap ->
                         CycVisMap ->
                         ConEnv ->
                         DataMap ->
                         DataSemEnv ->
                         DataEnv ->
                         (Map Ident (Bool,Maybe Int)) ->
                         DefsEnv ->
                         AttrMap ->
                         ItfEnv ->
                         (Map DepItem (Bool,Int)) ->
                         RenameMap ->
                         AttrMap ->
                         DefsEnv ->
                         VisitAttrMap ->
                         (Map Ident [Ident]) ->
                         VisitSourceMap ->
                         VisitAttrMap ->
                         VisitEnv ->
                         ([Ident]) ->
                         (Env QIdent (QIdent, QIdent)) ->
                         ClausesEnv ->
                         DataSemEnv ->
                         DefsEnv ->
                         NontermEnv ->
                         DefsEnv ->
                         ([(Int,PP_Doc)]) ->
                         QIdent ->
                         ([(Int,PP_Doc)]) ->
                         Int ->
                         QIdent ->
                         Opts ->
                         DepItem ->
                         Reason ->
                         DepItem ->
                         DepItem ->
                         DepItem ->
                         Reason ->
                         ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),PP_Doc,Bool,Bool,PP_Doc,Int,(Map Ident (Set Ident)),PP_Doc)
sem_MaybeBoundCode_Just :: T_BoundCode  ->
                           T_MaybeBoundCode 
sem_MaybeBoundCode_Just just_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOisJust :: Bool
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOhpp :: PP_Doc
              _lhsOisFun :: Bool
              _lhsOjspp :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOpp :: PP_Doc
              _justOallAvailInvokes :: (Map Ident (Set Ident))
              _justOallVisits :: (Set Ident)
              _justOavailInvokes :: (Map Ident (Set Ident))
              _justObasename :: QIdent
              _justOcoItf :: Ident
              _justOcodeIdCounter :: Int
              _justOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _justOdirectVisitLocalAttrs :: (Map Ident String)
              _justOdistAliasses :: (Map Ident AliasType)
              _justOdistAllChildMinRanges :: (Map Ident [Ident])
              _justOdistAttrSource :: AttrSourceMap
              _justOdistAttrVisMap :: AttrVisMap
              _justOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _justOdistChildEffRanges :: (Map Ident (Set Ident))
              _justOdistChildMinRanges :: (Map Ident [Ident])
              _justOdistChildOcc :: (Map Ident Int)
              _justOdistChildSource :: ChildSourceMap
              _justOdistCycVisMap :: CycVisMap
              _justOdistDataCons :: ConEnv
              _justOdistDataMap :: DataMap
              _justOdistDataSems :: DataSemEnv
              _justOdistDatas :: DataEnv
              _justOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _justOdistDefs :: DefsEnv
              _justOdistInhAttrs :: AttrMap
              _justOdistItfs :: ItfEnv
              _justOdistRanks :: (Map DepItem (Bool,Int))
              _justOdistRenames :: RenameMap
              _justOdistSynAttrs :: AttrMap
              _justOdistVisLocalDefs :: DefsEnv
              _justOdistVisitInhAttrs :: VisitAttrMap
              _justOdistVisitOrder :: (Map Ident [Ident])
              _justOdistVisitSource :: VisitSourceMap
              _justOdistVisitSynAttrs :: VisitAttrMap
              _justOdistVisits :: VisitEnv
              _justOdoneVisits :: ([Ident])
              _justOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _justOgathClauses :: ClausesEnv
              _justOgathDataSems :: DataSemEnv
              _justOgathDefs :: DefsEnv
              _justOgathNonterms :: NontermEnv
              _justOgathVisLocalDefs :: DefsEnv
              _justOhSpilledStmts :: ([(Int,PP_Doc)])
              _justOitf :: QIdent
              _justOjsSpilledStmts :: ([(Int,PP_Doc)])
              _justOlexCounter :: Int
              _justOnonterm :: QIdent
              _justOopts :: Opts
              _justOscopeDep :: DepItem
              _justOscopeReason :: Reason
              _justOstmtSource :: DepItem
              _justOvisitBeginDep :: DepItem
              _justOvisitEndDep :: DepItem
              _justOvisitEndReason :: Reason
              _justIallReqInvokes :: (Map Ident (Set Ident))
              _justIcodeIdCounter :: Int
              _justIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _justIdistDataCons :: ConEnv
              _justIdistDataSems :: DataSemEnv
              _justIdistDatas :: DataEnv
              _justIdistDefs :: DefsEnv
              _justIdistItfs :: ItfEnv
              _justIdistVisLocalDefs :: DefsEnv
              _justIdistVisits :: VisitEnv
              _justIerrs0 :: Errs
              _justIerrs1 :: Errs
              _justIerrs2 :: Errs
              _justIerrs3 :: Errs
              _justIerrs4 :: Errs
              _justIerrs5 :: Errs
              _justIgathAvoidVisits :: (Set DepItem)
              _justIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _justIgathClauses :: ClausesEnv
              _justIgathDataSems :: DataSemEnv
              _justIgathDefs :: DefsEnv
              _justIgathDeps :: Deps
              _justIgathItemVisits :: (Map DepItem DepItem)
              _justIgathLegalCycStmts :: (Set DepItem)
              _justIgathMissingInvokes :: (Set (Ident,Ident))
              _justIgathNonterms :: NontermEnv
              _justIgathSemStarts :: (Seq DepItem)
              _justIgathStmtPosMap :: (Map DepItem Pos)
              _justIgathVisLocalDefs :: DefsEnv
              _justIgathVisitEnds :: (Seq DepItem)
              _justIgathVisitStarts :: (Seq DepItem)
              _justIhpp :: PP_Doc
              _justIisFun :: Bool
              _justIjspp :: PP_Doc
              _justIlexCounter :: Int
              _justIminReqInvokes :: (Map Ident (Set Ident))
              _justIpos :: Pos
              _justIpp :: PP_Doc
              -- "src/Transform.ag"(line 1359, column 14)
              _lhsOisJust =
                  ({-# LINE 1359 "src/Transform.ag" #-}
                   True
                   {-# LINE 38757 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _justIallReqInvokes
                   {-# LINE 38762 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs0
                   {-# LINE 38767 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs1
                   {-# LINE 38772 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs2
                   {-# LINE 38777 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs3
                   {-# LINE 38782 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs4
                   {-# LINE 38787 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _justIerrs5
                   {-# LINE 38792 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _justIgathAvoidVisits
                   {-# LINE 38797 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _justIgathDeps
                   {-# LINE 38802 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _justIgathItemVisits
                   {-# LINE 38807 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _justIgathLegalCycStmts
                   {-# LINE 38812 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _justIgathMissingInvokes
                   {-# LINE 38817 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _justIgathSemStarts
                   {-# LINE 38822 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _justIgathStmtPosMap
                   {-# LINE 38827 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _justIgathVisitEnds
                   {-# LINE 38832 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _justIgathVisitStarts
                   {-# LINE 38837 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _justIminReqInvokes
                   {-# LINE 38842 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _justIcodeIdCounter
                   {-# LINE 38847 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _justIdistChildDefs
                   {-# LINE 38852 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _justIdistDataCons
                   {-# LINE 38857 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _justIdistDataSems
                   {-# LINE 38862 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _justIdistDatas
                   {-# LINE 38867 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _justIdistDefs
                   {-# LINE 38872 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _justIdistItfs
                   {-# LINE 38877 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _justIdistVisLocalDefs
                   {-# LINE 38882 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _justIdistVisits
                   {-# LINE 38887 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _justIgathChildDefs
                   {-# LINE 38892 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _justIgathClauses
                   {-# LINE 38897 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _justIgathDataSems
                   {-# LINE 38902 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _justIgathDefs
                   {-# LINE 38907 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _justIgathNonterms
                   {-# LINE 38912 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _justIgathVisLocalDefs
                   {-# LINE 38917 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOhpp =
                  ({-# LINE 75 "src/TargetHaskell.ag" #-}
                   _justIhpp
                   {-# LINE 38922 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOisFun =
                  ({-# LINE 1977 "src/Transform.ag" #-}
                   _justIisFun
                   {-# LINE 38927 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOjspp =
                  ({-# LINE 35 "src/TargetJs.ag" #-}
                   _justIjspp
                   {-# LINE 38932 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _justIlexCounter
                   {-# LINE 38937 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpp =
                  ({-# LINE 2411 "src/Transform.ag" #-}
                   _justIpp
                   {-# LINE 38942 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 38947 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 38952 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 38957 "src/Transform.hs" #-})
              -- copy rule (down)
              _justObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 38962 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 38967 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 38972 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 38977 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 38982 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 38987 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 38992 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 38997 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 39002 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 39007 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 39012 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 39017 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 39022 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 39027 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 39032 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 39037 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 39042 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 39047 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 39052 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 39057 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 39062 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 39067 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 39072 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 39077 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 39082 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 39087 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 39092 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 39097 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 39102 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 39107 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 39112 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 39117 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 39122 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 39127 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 39132 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 39137 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 39142 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 39147 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 39152 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 39157 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 39162 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 39167 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 39172 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 39177 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 39182 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 39187 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 39192 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 39197 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 39202 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 39207 "src/Transform.hs" #-})
              -- copy rule (down)
              _justOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 39212 "src/Transform.hs" #-})
              ( _justIallReqInvokes,_justIcodeIdCounter,_justIdistChildDefs,_justIdistDataCons,_justIdistDataSems,_justIdistDatas,_justIdistDefs,_justIdistItfs,_justIdistVisLocalDefs,_justIdistVisits,_justIerrs0,_justIerrs1,_justIerrs2,_justIerrs3,_justIerrs4,_justIerrs5,_justIgathAvoidVisits,_justIgathChildDefs,_justIgathClauses,_justIgathDataSems,_justIgathDefs,_justIgathDeps,_justIgathItemVisits,_justIgathLegalCycStmts,_justIgathMissingInvokes,_justIgathNonterms,_justIgathSemStarts,_justIgathStmtPosMap,_justIgathVisLocalDefs,_justIgathVisitEnds,_justIgathVisitStarts,_justIhpp,_justIisFun,_justIjspp,_justIlexCounter,_justIminReqInvokes,_justIpos,_justIpp) =
                  just_ _justOallAvailInvokes _justOallVisits _justOavailInvokes _justObasename _justOcoItf _justOcodeIdCounter _justOdirectVisitAttrs _justOdirectVisitLocalAttrs _justOdistAliasses _justOdistAllChildMinRanges _justOdistAttrSource _justOdistAttrVisMap _justOdistChildDefs _justOdistChildEffRanges _justOdistChildMinRanges _justOdistChildOcc _justOdistChildSource _justOdistCycVisMap _justOdistDataCons _justOdistDataMap _justOdistDataSems _justOdistDatas _justOdistDeflStmts _justOdistDefs _justOdistInhAttrs _justOdistItfs _justOdistRanks _justOdistRenames _justOdistSynAttrs _justOdistVisLocalDefs _justOdistVisitInhAttrs _justOdistVisitOrder _justOdistVisitSource _justOdistVisitSynAttrs _justOdistVisits _justOdoneVisits _justOgathChildDefs _justOgathClauses _justOgathDataSems _justOgathDefs _justOgathNonterms _justOgathVisLocalDefs _justOhSpilledStmts _justOitf _justOjsSpilledStmts _justOlexCounter _justOnonterm _justOopts _justOscopeDep _justOscopeReason _justOstmtSource _justOvisitBeginDep _justOvisitEndDep _justOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisFun,_lhsOisJust,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
sem_MaybeBoundCode_Nothing :: T_MaybeBoundCode 
sem_MaybeBoundCode_Nothing  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOisJust :: Bool
              _lhsOisFun :: Bool
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 1360, column 14)
              _lhsOisJust =
                  ({-# LINE 1360 "src/Transform.ag" #-}
                   False
                   {-# LINE 39314 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1982, column 31)
              _lhsOisFun =
                  ({-# LINE 1982 "src/Transform.ag" #-}
                   False
                   {-# LINE 39319 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2464, column 18)
              _lhsOpp =
                  ({-# LINE 2464 "src/Transform.ag" #-}
                   empty
                   {-# LINE 39324 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 208, column 18)
              _lhsOhpp =
                  ({-# LINE 208 "src/TargetHaskell.ag" #-}
                   empty
                   {-# LINE 39329 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 138, column 18)
              _lhsOjspp =
                  ({-# LINE 138 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 39334 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 39339 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39344 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39349 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39354 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39359 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39364 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39369 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 39374 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39379 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 39384 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 39389 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 39394 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39399 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 39404 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39409 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 39414 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 39419 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 39424 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 39429 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 39434 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 39439 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 39444 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 39449 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 39454 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 39459 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 39464 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 39469 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 39474 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 39479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 39484 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 39489 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 39494 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 39499 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisFun,_lhsOisJust,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp)))
-- Mode --------------------------------------------------------
{-
   visit 0:
      synthesized attributes:
         isMatch              : Bool
         pp                   : PP_Doc
   alternatives:
      alternative Assert:
      alternative Match:
-}
-- cata
sem_Mode :: Mode  ->
            T_Mode 
sem_Mode (Mode_Assert )  =
    (sem_Mode_Assert )
sem_Mode (Mode_Match )  =
    (sem_Mode_Match )
-- semantic domain
type T_Mode  = ( Bool,PP_Doc)
sem_Mode_Assert :: T_Mode 
sem_Mode_Assert  =
    (let _lhsOisMatch :: Bool
         _lhsOpp :: PP_Doc
         -- "src/Transform.ag"(line 1418, column 20)
         _lhsOisMatch =
             ({-# LINE 1418 "src/Transform.ag" #-}
              False
              {-# LINE 39528 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2558, column 18)
         _lhsOpp =
             ({-# LINE 2558 "src/Transform.ag" #-}
              empty
              {-# LINE 39533 "src/Transform.hs" #-})
     in  ( _lhsOisMatch,_lhsOpp))
sem_Mode_Match :: T_Mode 
sem_Mode_Match  =
    (let _lhsOisMatch :: Bool
         _lhsOpp :: PP_Doc
         -- "src/Transform.ag"(line 1417, column 20)
         _lhsOisMatch =
             ({-# LINE 1417 "src/Transform.ag" #-}
              True
              {-# LINE 39543 "src/Transform.hs" #-})
         -- "src/Transform.ag"(line 2557, column 18)
         _lhsOpp =
             ({-# LINE 2557 "src/Transform.ag" #-}
              text "match "
              {-# LINE 39548 "src/Transform.hs" #-})
     in  ( _lhsOisMatch,_lhsOpp))
-- Pat ---------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         isCyclic             : Bool
         isMatch              : Bool
         isRight              : Bool
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         prio                 : Prio
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pos                  : Pos
         pp                   : PP_Doc
   alternatives:
      alternative Attr:
         child child          : {Ident}
         child name           : {Ident}
         visit 0:
            local _tup58      : _
            local _tup59      : _
            local childItf    : _
            local startVisit  : _
            local origName    : _
            inst  tp          : AttrTypePat 
            local hBang       : _
      alternative AttrCon:
         child con            : {Ident}
         child name           : {Ident}
         child dt             : {Ident}
         visit 0:
            local distDatas_augmented_f1 : _
            local gathAttrSource_augmented_f1 : _
            local gathChildDefs_augmented_f1 : _
            local gathDefs_augmented_f1 : _
            local _tup60      : _
            local fieldEnv    : _
            local fields      : _
            local _tup61      : _
            local _tup62      : _
            local childItf    : _
            local startVisit  : _
            local mbAlias     : _
            local isLoc       : _
            local hFldsPPs    : _
            local hBangFldsPPs : _
            local hpp         : _
            local hBang       : _
            local jsFieldPPs  : _
            local jsThrow     : _
            local gathAttrSource_augmented_syn : _
            local distDatas_augmented_syn : _
            local gathChildDefs_augmented_syn : _
            local gathDefs_augmented_syn : _
      alternative Con:
         child name           : {Ident}
         child pats           : Pats 
         visit 0:
            local needPar     : _
            local hBang       : _
            local jsThrow     : _
      alternative Cons:
         child hd             : Pat 
         child tl             : Pat 
         visit 0:
            local needPar     : _
            local hBang       : _
            local jsThrow     : _
      alternative List:
         child pats           : Pats 
         visit 0:
            local hBang       : _
            local jsThrow     : _
      alternative Tup:
         child pats           : Pats 
         visit 0:
            local hBang       : _
            local jsThrow     : _
      alternative Underscore:
         child pos            : {Pos}
         visit 0:
            local hBang       : _
-}
-- cata
sem_Pat :: Pat  ->
           T_Pat 
sem_Pat (Pat_Attr _child _name )  =
    (sem_Pat_Attr _child _name )
sem_Pat (Pat_AttrCon _con _name _dt )  =
    (sem_Pat_AttrCon _con _name _dt )
sem_Pat (Pat_Con _name _pats )  =
    (sem_Pat_Con _name (sem_Pats _pats ) )
sem_Pat (Pat_Cons _hd _tl )  =
    (sem_Pat_Cons (sem_Pat _hd ) (sem_Pat _tl ) )
sem_Pat (Pat_List _pats )  =
    (sem_Pat_List (sem_Pats _pats ) )
sem_Pat (Pat_Tup _pats )  =
    (sem_Pat_Tup (sem_Pats _pats ) )
sem_Pat (Pat_Underscore _pos )  =
    (sem_Pat_Underscore _pos )
-- semantic domain
type T_Pat  = (Map Ident (Set Ident)) ->
              (Set Ident) ->
              (Map Ident (Set Ident)) ->
              QIdent ->
              Ident ->
              Int ->
              (Map Ident (Map Ident String)) ->
              (Map Ident String) ->
              (Map Ident AliasType) ->
              (Map Ident [Ident]) ->
              AttrSourceMap ->
              AttrVisMap ->
              (Env QIdent (QIdent,QIdent)) ->
              (Map Ident (Set Ident)) ->
              (Map Ident [Ident]) ->
              (Map Ident Int) ->
              ChildSourceMap ->
              CycVisMap ->
              ConEnv ->
              DataMap ->
              DataSemEnv ->
              DataEnv ->
              (Map Ident (Bool,Maybe Int)) ->
              DefsEnv ->
              AttrMap ->
              ItfEnv ->
              (Map DepItem (Bool,Int)) ->
              RenameMap ->
              AttrMap ->
              DefsEnv ->
              VisitAttrMap ->
              (Map Ident [Ident]) ->
              VisitSourceMap ->
              VisitAttrMap ->
              VisitEnv ->
              ([Ident]) ->
              (Env QIdent (QIdent, QIdent)) ->
              ClausesEnv ->
              DataSemEnv ->
              DefsEnv ->
              NontermEnv ->
              DefsEnv ->
              ([(Int,PP_Doc)]) ->
              Bool ->
              Bool ->
              Bool ->
              QIdent ->
              ([(Int,PP_Doc)]) ->
              Int ->
              QIdent ->
              Opts ->
              Prio ->
              DepItem ->
              Reason ->
              DepItem ->
              DepItem ->
              DepItem ->
              Reason ->
              ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),Pos,PP_Doc)
sem_Pat_Attr :: Ident ->
                Ident ->
                T_Pat 
sem_Pat_Attr child_ name_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              tp_val_ :: AttrTypePat 
              _tpOchild :: Ident
              _tpOname :: Ident
              _tpOchildItf :: Ident
              _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _tpOallAvailInvokes :: (Map Ident (Set Ident))
              _tpOallVisits :: (Set Ident)
              _tpOavailInvokes :: (Map Ident (Set Ident))
              _tpObasename :: QIdent
              _tpOcoItf :: Ident
              _tpOcodeIdCounter :: Int
              _tpOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tpOdirectVisitLocalAttrs :: (Map Ident String)
              _tpOdistAliasses :: (Map Ident AliasType)
              _tpOdistAllChildMinRanges :: (Map Ident [Ident])
              _tpOdistAttrSource :: AttrSourceMap
              _tpOdistAttrVisMap :: AttrVisMap
              _tpOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tpOdistChildEffRanges :: (Map Ident (Set Ident))
              _tpOdistChildMinRanges :: (Map Ident [Ident])
              _tpOdistChildOcc :: (Map Ident Int)
              _tpOdistChildSource :: ChildSourceMap
              _tpOdistCycVisMap :: CycVisMap
              _tpOdistDataCons :: ConEnv
              _tpOdistDataMap :: DataMap
              _tpOdistDataSems :: DataSemEnv
              _tpOdistDatas :: DataEnv
              _tpOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tpOdistDefs :: DefsEnv
              _tpOdistInhAttrs :: AttrMap
              _tpOdistItfs :: ItfEnv
              _tpOdistRanks :: (Map DepItem (Bool,Int))
              _tpOdistRenames :: RenameMap
              _tpOdistSynAttrs :: AttrMap
              _tpOdistVisLocalDefs :: DefsEnv
              _tpOdistVisitInhAttrs :: VisitAttrMap
              _tpOdistVisitOrder :: (Map Ident [Ident])
              _tpOdistVisitSource :: VisitSourceMap
              _tpOdistVisitSynAttrs :: VisitAttrMap
              _tpOdistVisits :: VisitEnv
              _tpOdoneVisits :: ([Ident])
              _tpOgathClauses :: ClausesEnv
              _tpOgathDataSems :: DataSemEnv
              _tpOgathDefs :: DefsEnv
              _tpOgathNonterms :: NontermEnv
              _tpOgathVisLocalDefs :: DefsEnv
              _tpOhSpilledStmts :: ([(Int,PP_Doc)])
              _tpOitf :: QIdent
              _tpOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tpOlexCounter :: Int
              _tpOnonterm :: QIdent
              _tpOopts :: Opts
              _tpOscopeDep :: DepItem
              _tpOscopeReason :: Reason
              _tpOstmtSource :: DepItem
              _tpOvisitBeginDep :: DepItem
              _tpOvisitEndDep :: DepItem
              _tpOvisitEndReason :: Reason
              _tpIallReqInvokes :: (Map Ident (Set Ident))
              _tpIcodeIdCounter :: Int
              _tpIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tpIdistDataCons :: ConEnv
              _tpIdistDataSems :: DataSemEnv
              _tpIdistDatas :: DataEnv
              _tpIdistDefs :: DefsEnv
              _tpIdistItfs :: ItfEnv
              _tpIdistVisLocalDefs :: DefsEnv
              _tpIdistVisits :: VisitEnv
              _tpIerrs0 :: Errs
              _tpIerrs1 :: Errs
              _tpIerrs2 :: Errs
              _tpIerrs3 :: Errs
              _tpIerrs4 :: Errs
              _tpIerrs5 :: Errs
              _tpIgathAttrSource :: AttrSourceMap
              _tpIgathAvoidVisits :: (Set DepItem)
              _tpIgathChildSource :: ChildSourceMap
              _tpIgathClauses :: ClausesEnv
              _tpIgathDataSems :: DataSemEnv
              _tpIgathDefs :: DefsEnv
              _tpIgathDeps :: Deps
              _tpIgathItemVisits :: (Map DepItem DepItem)
              _tpIgathLegalCycStmts :: (Set DepItem)
              _tpIgathNonterms :: NontermEnv
              _tpIgathSemStarts :: (Seq DepItem)
              _tpIgathStmtPosMap :: (Map DepItem Pos)
              _tpIgathVisLocalDefs :: DefsEnv
              _tpIgathVisitEnds :: (Seq DepItem)
              _tpIgathVisitSource :: VisitSourceMap
              _tpIgathVisitStarts :: (Seq DepItem)
              _tpIhpp :: PP_Doc
              _tpIjspp :: PP_Doc
              _tpIlexCounter :: Int
              _tpIminReqInvokes :: (Map Ident (Set Ident))
              -- "src/Transform.ag"(line 553, column 13)
              __tup58 =
                  ({-# LINE 553 "src/Transform.ag" #-}
                   find [child_] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                   {-# LINE 39981 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 553, column 13)
              (__tup59,_) =
                  ({-# LINE 553 "src/Transform.ag" #-}
                   __tup58
                   {-# LINE 39986 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 553, column 13)
              (_childItf,_) =
                  ({-# LINE 553 "src/Transform.ag" #-}
                   __tup59
                   {-# LINE 39991 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 553, column 13)
              (_,_startVisit) =
                  ({-# LINE 553 "src/Transform.ag" #-}
                   __tup59
                   {-# LINE 39996 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 553, column 13)
              (_,_lhsOdistChildDefs) =
                  ({-# LINE 553 "src/Transform.ag" #-}
                   __tup58
                   {-# LINE 40001 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 613, column 18)
              _origName =
                  ({-# LINE 613 "src/Transform.ag" #-}
                   renameAttrBwd _lhsIdistRenames child_ name_
                   {-# LINE 40006 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 916, column 7)
              tp_val_ =
                  ({-# LINE 916 "src/Transform.ag" #-}
                   case identName child_ of
                     s | s == "loc"                         -> AttrTypePat_ProdLocal
                       | s == "lhs"                         -> AttrTypePat_Lhs
                       | s == "vis"                         -> AttrTypePat_VisLocal
                       | child_ `Set.member` _lhsIallVisits -> AttrTypePat_Visit
                       | _childItf     == locQIdent         -> AttrTypePat_ProdLocal
                       | otherwise                          -> AttrTypePat_Child
                   {-# LINE 40017 "src/Transform.hs" #-})
              tp_inst_ =
                  (sem_AttrTypePat tp_val_ )
              -- "src/Transform.ag"(line 923, column 7)
              _tpOchild =
                  ({-# LINE 923 "src/Transform.ag" #-}
                   child_
                   {-# LINE 40024 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 924, column 7)
              _tpOname =
                  ({-# LINE 924 "src/Transform.ag" #-}
                   _origName
                   {-# LINE 40029 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 925, column 7)
              _tpOchildItf =
                  ({-# LINE 925 "src/Transform.ag" #-}
                   head _childItf
                   {-# LINE 40034 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2037, column 23)
              _lhsOpos =
                  ({-# LINE 2037 "src/Transform.ag" #-}
                   identPos child_
                   {-# LINE 40039 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2576, column 18)
              _lhsOpp =
                  ({-# LINE 2576 "src/Transform.ag" #-}
                   child_ >|< "." >|< name_
                   {-# LINE 40044 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 525, column 18)
              _lhsOhpp =
                  ({-# LINE 525 "src/TargetHaskell.ag" #-}
                   _hBang     >|< hParensWithPos _lhsIopts (identPos child_) _tpIhpp
                   {-# LINE 40049 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 40054 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 312, column 18)
              _lhsOjspp =
                  ({-# LINE 312 "src/TargetJs.ag" #-}
                   "var" >#< _tpIjspp >#< "=" >#< "_res;"
                   {-# LINE 40059 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _tpIallReqInvokes
                   {-# LINE 40064 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs0
                   {-# LINE 40069 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs1
                   {-# LINE 40074 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs2
                   {-# LINE 40079 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs3
                   {-# LINE 40084 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs4
                   {-# LINE 40089 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _tpIerrs5
                   {-# LINE 40094 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _tpIgathAttrSource
                   {-# LINE 40099 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _tpIgathAvoidVisits
                   {-# LINE 40104 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _tpIgathChildSource
                   {-# LINE 40109 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _tpIgathDeps
                   {-# LINE 40114 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _tpIgathItemVisits
                   {-# LINE 40119 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _tpIgathLegalCycStmts
                   {-# LINE 40124 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _tpIgathSemStarts
                   {-# LINE 40129 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _tpIgathStmtPosMap
                   {-# LINE 40134 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _tpIgathVisitEnds
                   {-# LINE 40139 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _tpIgathVisitSource
                   {-# LINE 40144 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _tpIgathVisitStarts
                   {-# LINE 40149 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _tpIminReqInvokes
                   {-# LINE 40154 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tpIcodeIdCounter
                   {-# LINE 40159 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tpIdistDataCons
                   {-# LINE 40164 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tpIdistDataSems
                   {-# LINE 40169 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tpIdistDatas
                   {-# LINE 40174 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIdistDefs
                   {-# LINE 40179 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tpIdistItfs
                   {-# LINE 40184 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIdistVisLocalDefs
                   {-# LINE 40189 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tpIdistVisits
                   {-# LINE 40194 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 40199 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tpIgathClauses
                   {-# LINE 40204 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tpIgathDataSems
                   {-# LINE 40209 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIgathDefs
                   {-# LINE 40214 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tpIgathNonterms
                   {-# LINE 40219 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tpIgathVisLocalDefs
                   {-# LINE 40224 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tpIlexCounter
                   {-# LINE 40229 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 40234 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 40239 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 40244 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 40249 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 40254 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 40259 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 40264 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 40269 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 40274 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 40279 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 40284 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 40289 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 40294 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 40299 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 40304 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 40309 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 40314 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 40319 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 40324 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 40329 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 40334 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 40339 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 40344 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 40349 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 40354 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 40359 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 40364 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 40369 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 40374 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 40379 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 40384 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 40389 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 40394 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 40399 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 40404 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 40409 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 40414 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 40419 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 40424 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 40429 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 40434 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 40439 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 40444 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 40449 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 40454 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 40459 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 40464 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 40469 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 40474 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 40479 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 40484 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 40489 "src/Transform.hs" #-})
              -- copy rule (down)
              _tpOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 40494 "src/Transform.hs" #-})
              ( _tpIallReqInvokes,_tpIcodeIdCounter,_tpIdistChildDefs,_tpIdistDataCons,_tpIdistDataSems,_tpIdistDatas,_tpIdistDefs,_tpIdistItfs,_tpIdistVisLocalDefs,_tpIdistVisits,_tpIerrs0,_tpIerrs1,_tpIerrs2,_tpIerrs3,_tpIerrs4,_tpIerrs5,_tpIgathAttrSource,_tpIgathAvoidVisits,_tpIgathChildSource,_tpIgathClauses,_tpIgathDataSems,_tpIgathDefs,_tpIgathDeps,_tpIgathItemVisits,_tpIgathLegalCycStmts,_tpIgathNonterms,_tpIgathSemStarts,_tpIgathStmtPosMap,_tpIgathVisLocalDefs,_tpIgathVisitEnds,_tpIgathVisitSource,_tpIgathVisitStarts,_tpIhpp,_tpIjspp,_tpIlexCounter,_tpIminReqInvokes) =
                  tp_inst_ _tpOallAvailInvokes _tpOallVisits _tpOavailInvokes _tpObasename _tpOchild _tpOchildItf _tpOcoItf _tpOcodeIdCounter _tpOdirectVisitAttrs _tpOdirectVisitLocalAttrs _tpOdistAliasses _tpOdistAllChildMinRanges _tpOdistAttrSource _tpOdistAttrVisMap _tpOdistChildDefs _tpOdistChildEffRanges _tpOdistChildMinRanges _tpOdistChildOcc _tpOdistChildSource _tpOdistCycVisMap _tpOdistDataCons _tpOdistDataMap _tpOdistDataSems _tpOdistDatas _tpOdistDeflStmts _tpOdistDefs _tpOdistInhAttrs _tpOdistItfs _tpOdistRanks _tpOdistRenames _tpOdistSynAttrs _tpOdistVisLocalDefs _tpOdistVisitInhAttrs _tpOdistVisitOrder _tpOdistVisitSource _tpOdistVisitSynAttrs _tpOdistVisits _tpOdoneVisits _tpOgathClauses _tpOgathDataSems _tpOgathDefs _tpOgathNonterms _tpOgathVisLocalDefs _tpOhSpilledStmts _tpOitf _tpOjsSpilledStmts _tpOlexCounter _tpOname _tpOnonterm _tpOopts _tpOscopeDep _tpOscopeReason _tpOstmtSource _tpOvisitBeginDep _tpOvisitEndDep _tpOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_AttrCon :: Ident ->
                   Ident ->
                   Ident ->
                   T_Pat 
sem_Pat_AttrCon con_ name_ dt_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDatas :: DataEnv
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathDefs :: DefsEnv
              _lhsOdistDataCons :: ConEnv
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDatas =
                  ({-# LINE 486 "src/Transform.ag" #-}
                   foldr ($) _distDatas_augmented_syn [_distDatas_augmented_f1]
                   {-# LINE 40604 "src/Transform.hs" #-})
              -- augment function
              _distDatas_augmented_f1 =
                  ({-# LINE 486 "src/Transform.ag" #-}
                   snd . find dt_ ()
                   {-# LINE 40609 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2104 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 40614 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2104 "src/Transform.ag" #-}
                   Map.union (Map.fromList [ ((not _isLoc    , name_, nm), _lhsIstmtSource) | (nm,_) <- _fields     ])
                   {-# LINE 40619 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathChildDefs =
                  ({-# LINE 554 "src/Transform.ag" #-}
                   foldr ($) _gathChildDefs_augmented_syn [_gathChildDefs_augmented_f1]
                   {-# LINE 40624 "src/Transform.hs" #-})
              -- augment function
              _gathChildDefs_augmented_f1 =
                  ({-# LINE 554 "src/Transform.ag" #-}
                   extendTail [name_] (locQIdent,locQIdent)
                   {-# LINE 40629 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDefs =
                  ({-# LINE 1138 "src/Transform.ag" #-}
                   foldr ($) _gathDefs_augmented_syn [_gathDefs_augmented_f1]
                   {-# LINE 40634 "src/Transform.hs" #-})
              -- augment function
              _gathDefs_augmented_f1 =
                  ({-# LINE 1138 "src/Transform.ag" #-}
                   \env -> foldr (\(nm,tp) -> extend (name_, nm, not _isLoc    ) (Just (either show id tp))) env _fields
                   {-# LINE 40639 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 448, column 3)
              __tup60 =
                  ({-# LINE 448 "src/Transform.ag" #-}
                   find [con_, dt_] emptyEnv _lhsIdistDataCons
                   {-# LINE 40644 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 448, column 3)
              (_fieldEnv,_) =
                  ({-# LINE 448 "src/Transform.ag" #-}
                   __tup60
                   {-# LINE 40649 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 448, column 3)
              (_,_lhsOdistDataCons) =
                  ({-# LINE 448 "src/Transform.ag" #-}
                   __tup60
                   {-# LINE 40654 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 449, column 3)
              _fields =
                  ({-# LINE 449 "src/Transform.ag" #-}
                   sortAssocs $ assocs _fieldEnv
                   {-# LINE 40659 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 555, column 13)
              __tup61 =
                  ({-# LINE 555 "src/Transform.ag" #-}
                   find [name_] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                   {-# LINE 40664 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 555, column 13)
              (__tup62,_) =
                  ({-# LINE 555 "src/Transform.ag" #-}
                   __tup61
                   {-# LINE 40669 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 555, column 13)
              (_childItf,_) =
                  ({-# LINE 555 "src/Transform.ag" #-}
                   __tup62
                   {-# LINE 40674 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 555, column 13)
              (_,_startVisit) =
                  ({-# LINE 555 "src/Transform.ag" #-}
                   __tup62
                   {-# LINE 40679 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 555, column 13)
              (_,_lhsOdistChildDefs) =
                  ({-# LINE 555 "src/Transform.ag" #-}
                   __tup61
                   {-# LINE 40684 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1438, column 26)
              _mbAlias =
                  ({-# LINE 1438 "src/Transform.ag" #-}
                   Map.lookup dt_ _lhsIdistAliasses
                   {-# LINE 40689 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2036, column 23)
              _lhsOpos =
                  ({-# LINE 2036 "src/Transform.ag" #-}
                   identPos dt_
                   {-# LINE 40694 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2103, column 3)
              _isLoc =
                  ({-# LINE 2103 "src/Transform.ag" #-}
                   name_ == locIdent || _childItf     == locQIdent
                   {-# LINE 40699 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2575, column 18)
              _lhsOpp =
                  ({-# LINE 2575 "src/Transform.ag" #-}
                   show dt_ >|< "." >|< show con_ >|< "@" >|< name_
                   {-# LINE 40704 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 512, column 18)
              _lhsOhpp =
                  ({-# LINE 512 "src/TargetHaskell.ag" #-}
                   _hBang     >|< (pp_parens _hpp    )
                   {-# LINE 40709 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 513, column 18)
              _hFldsPPs =
                  ({-# LINE 513 "src/TargetHaskell.ag" #-}
                   [ hParensWithPos _lhsIopts (identPos name_) (hOutpLoc name_ nm) | (nm,_) <- _fields     ]
                   {-# LINE 40714 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 514, column 18)
              _hBangFldsPPs =
                  ({-# LINE 514 "src/TargetHaskell.ag" #-}
                   map (_hBang     >|<) _hFldsPPs
                   {-# LINE 40719 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 515, column 18)
              _hpp =
                  ({-# LINE 515 "src/TargetHaskell.ag" #-}
                   case _mbAlias of
                     Nothing    -> hConNm dt_ con_ >#< hlist_sp _hFldsPPs
                     Just alias -> case alias of
                                     AliasType_Prod _  -> pp_block "(" ")" "," _hBangFldsPPs
                                     AliasType_List _  -> if con_ == ident "Cons"
                                                          then "(:)" >#< hlist_sp _hBangFldsPPs
                                                          else text "[]"
                                     AliasType_Maybe _ -> if con_ == ident "Nothing"
                                                          then text "Nothing"
                                                          else "Just" >#< hlist_sp _hBangFldsPPs
                   {-# LINE 40733 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 40738 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 290, column 18)
              _lhsOjspp =
                  ({-# LINE 290 "src/TargetJs.ag" #-}
                   case _mbAlias of
                     Nothing    -> "if (!(_res instanceof" >#< jsConNm dt_ con_ >|< "))" >#< _jsThrow
                                   >-< "var _val = _res;"
                                   >-< vlist _jsFieldPPs
                     Just alias -> case alias of
                                     AliasType_Prod _  -> "if (!(_res instanceof Tuple))" >#< _jsThrow
                                                          >-< "if (_res.length != " >|< (show $ length _fields    ) >|< ")" >#< _jsThrow
                                                          >-< "var _val = _res;"
                                                          >-< vlist _jsFieldPPs
                                     AliasType_List _  -> if con_ == ident "Cons"
                                                          then "if (!(_res instanceof Array))" >#< _jsThrow
                                                               >-< "if (_res.length < 1)" >#< _jsThrow
                                                               >-< "var" >#< hOutp name_ (ident "hd") >#< "= _res[0];"
                                                               >-< "var" >#< hOutp name_ (ident "tl") >#< "= _res.slice(1);"
                                                          else "if (!(_res instanceof Array))" >#< _jsThrow
                                                               >-< "if (_res.length != 0)" >#< _jsThrow
                                     AliasType_Maybe _ -> if con_ == ident "Nothing"
                                                          then "if (!(_res instanceof Maybe_Nothing))" >#< _jsThrow
                                                          else "if (!(_res instanceof Maybe_Just))" >#< _jsThrow
                                                               >-< "var _val = _res;"
                                                               >-< vlist _jsFieldPPs
                   {-# LINE 40763 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 311, column 18)
              _jsFieldPPs =
                  ({-# LINE 311 "src/TargetJs.ag" #-}
                   [ "var" >#< hOutp name_ nm >#< "= _val." >|< show nm >|< ";" | (nm,_) <- _fields     ]
                   {-# LINE 40768 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 332, column 7)
              _jsThrow =
                  ({-# LINE 332 "src/TargetJs.ag" #-}
                   if _lhsIisMatch
                   then "throw eEval;"
                   else "throw eAbort;"
                   {-# LINE 40775 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40780 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40785 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40790 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40795 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40800 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40805 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40810 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2104 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40815 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 40820 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40825 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40830 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40835 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 40840 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40845 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40850 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40855 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40860 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 40865 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 40870 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 40875 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 40880 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDatas_augmented_syn =
                  ({-# LINE 486 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 40885 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 40890 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 40895 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 40900 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 40905 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathChildDefs_augmented_syn =
                  ({-# LINE 554 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 40910 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 40915 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 40920 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathDefs_augmented_syn =
                  ({-# LINE 1138 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 40925 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 40930 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 40935 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 40940 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_Con :: Ident ->
               T_Pats  ->
               T_Pat 
sem_Pat_Con name_ pats_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _patsOprio :: Prio
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _patsOallAvailInvokes :: (Map Ident (Set Ident))
              _patsOallVisits :: (Set Ident)
              _patsOavailInvokes :: (Map Ident (Set Ident))
              _patsObasename :: QIdent
              _patsOcoItf :: Ident
              _patsOcodeIdCounter :: Int
              _patsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _patsOdirectVisitLocalAttrs :: (Map Ident String)
              _patsOdistAliasses :: (Map Ident AliasType)
              _patsOdistAllChildMinRanges :: (Map Ident [Ident])
              _patsOdistAttrSource :: AttrSourceMap
              _patsOdistAttrVisMap :: AttrVisMap
              _patsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsOdistChildEffRanges :: (Map Ident (Set Ident))
              _patsOdistChildMinRanges :: (Map Ident [Ident])
              _patsOdistChildOcc :: (Map Ident Int)
              _patsOdistChildSource :: ChildSourceMap
              _patsOdistCycVisMap :: CycVisMap
              _patsOdistDataCons :: ConEnv
              _patsOdistDataMap :: DataMap
              _patsOdistDataSems :: DataSemEnv
              _patsOdistDatas :: DataEnv
              _patsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _patsOdistDefs :: DefsEnv
              _patsOdistInhAttrs :: AttrMap
              _patsOdistItfs :: ItfEnv
              _patsOdistRanks :: (Map DepItem (Bool,Int))
              _patsOdistRenames :: RenameMap
              _patsOdistSynAttrs :: AttrMap
              _patsOdistVisLocalDefs :: DefsEnv
              _patsOdistVisitInhAttrs :: VisitAttrMap
              _patsOdistVisitOrder :: (Map Ident [Ident])
              _patsOdistVisitSource :: VisitSourceMap
              _patsOdistVisitSynAttrs :: VisitAttrMap
              _patsOdistVisits :: VisitEnv
              _patsOdoneVisits :: ([Ident])
              _patsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsOgathClauses :: ClausesEnv
              _patsOgathDataSems :: DataSemEnv
              _patsOgathDefs :: DefsEnv
              _patsOgathNonterms :: NontermEnv
              _patsOgathVisLocalDefs :: DefsEnv
              _patsOhSpilledStmts :: ([(Int,PP_Doc)])
              _patsOisCyclic :: Bool
              _patsOisMatch :: Bool
              _patsOitf :: QIdent
              _patsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _patsOlexCounter :: Int
              _patsOnonterm :: QIdent
              _patsOopts :: Opts
              _patsOscopeDep :: DepItem
              _patsOscopeReason :: Reason
              _patsOstmtSource :: DepItem
              _patsOvisitBeginDep :: DepItem
              _patsOvisitEndDep :: DepItem
              _patsOvisitEndReason :: Reason
              _patsIallReqInvokes :: (Map Ident (Set Ident))
              _patsIcodeIdCounter :: Int
              _patsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsIdistDataCons :: ConEnv
              _patsIdistDataSems :: DataSemEnv
              _patsIdistDatas :: DataEnv
              _patsIdistDefs :: DefsEnv
              _patsIdistItfs :: ItfEnv
              _patsIdistVisLocalDefs :: DefsEnv
              _patsIdistVisits :: VisitEnv
              _patsIerrs0 :: Errs
              _patsIerrs1 :: Errs
              _patsIerrs2 :: Errs
              _patsIerrs3 :: Errs
              _patsIerrs4 :: Errs
              _patsIerrs5 :: Errs
              _patsIgathAttrSource :: AttrSourceMap
              _patsIgathAvoidVisits :: (Set DepItem)
              _patsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsIgathChildSource :: ChildSourceMap
              _patsIgathClauses :: ClausesEnv
              _patsIgathDataSems :: DataSemEnv
              _patsIgathDefs :: DefsEnv
              _patsIgathDeps :: Deps
              _patsIgathItemVisits :: (Map DepItem DepItem)
              _patsIgathLegalCycStmts :: (Set DepItem)
              _patsIgathNonterms :: NontermEnv
              _patsIgathSemStarts :: (Seq DepItem)
              _patsIgathStmtPosMap :: (Map DepItem Pos)
              _patsIgathVisLocalDefs :: DefsEnv
              _patsIgathVisitEnds :: (Seq DepItem)
              _patsIgathVisitSource :: VisitSourceMap
              _patsIgathVisitStarts :: (Seq DepItem)
              _patsIhpps :: ([PP_Doc])
              _patsIjspps :: ([PP_Doc])
              _patsIlexCounter :: Int
              _patsIminReqInvokes :: (Map Ident (Set Ident))
              _patsIpos :: Pos
              _patsIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2035, column 23)
              _lhsOpos =
                  ({-# LINE 2035 "src/Transform.ag" #-}
                   identPos name_
                   {-# LINE 41143 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2570, column 18)
              _needPar =
                  ({-# LINE 2570 "src/Transform.ag" #-}
                   needParens PrioCon _lhsIprio _lhsIisRight
                   {-# LINE 41148 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2574, column 18)
              _lhsOpp =
                  ({-# LINE 2574 "src/Transform.ag" #-}
                   addParens _needPar     (name_ >#< hlist_sp _patsIpps)
                   {-# LINE 41153 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2589, column 11)
              _patsOprio =
                  ({-# LINE 2589 "src/Transform.ag" #-}
                   PrioCon
                   {-# LINE 41158 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 511, column 18)
              _lhsOhpp =
                  ({-# LINE 511 "src/TargetHaskell.ag" #-}
                   _hBang     >|< hParensWithPos _lhsIopts (identPos name_) (name_ >#< hlist_sp _patsIhpps)
                   {-# LINE 41163 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 41168 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 285, column 18)
              _lhsOjspp =
                  ({-# LINE 285 "src/TargetJs.ag" #-}
                   "if (!(_res instanceof" >#< show name_ >|< "))" >#< _jsThrow
                   >-< "var _con = _res;"
                   >-< vlist [ "var _res = _con[" >|< show i >|< "];"
                               >-< jspp
                             | (i, jspp) <- zip [0..] _patsIjspps ]
                   {-# LINE 41177 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 332, column 7)
              _jsThrow =
                  ({-# LINE 332 "src/TargetJs.ag" #-}
                   if _lhsIisMatch
                   then "throw eEval;"
                   else "throw eAbort;"
                   {-# LINE 41184 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIallReqInvokes
                   {-# LINE 41189 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs0
                   {-# LINE 41194 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs1
                   {-# LINE 41199 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs2
                   {-# LINE 41204 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs3
                   {-# LINE 41209 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs4
                   {-# LINE 41214 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs5
                   {-# LINE 41219 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _patsIgathAttrSource
                   {-# LINE 41224 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _patsIgathAvoidVisits
                   {-# LINE 41229 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _patsIgathChildSource
                   {-# LINE 41234 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _patsIgathDeps
                   {-# LINE 41239 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _patsIgathItemVisits
                   {-# LINE 41244 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _patsIgathLegalCycStmts
                   {-# LINE 41249 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _patsIgathSemStarts
                   {-# LINE 41254 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _patsIgathStmtPosMap
                   {-# LINE 41259 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitEnds
                   {-# LINE 41264 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _patsIgathVisitSource
                   {-# LINE 41269 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitStarts
                   {-# LINE 41274 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIminReqInvokes
                   {-# LINE 41279 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _patsIcodeIdCounter
                   {-# LINE 41284 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _patsIdistChildDefs
                   {-# LINE 41289 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _patsIdistDataCons
                   {-# LINE 41294 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _patsIdistDataSems
                   {-# LINE 41299 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _patsIdistDatas
                   {-# LINE 41304 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistDefs
                   {-# LINE 41309 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _patsIdistItfs
                   {-# LINE 41314 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistVisLocalDefs
                   {-# LINE 41319 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _patsIdistVisits
                   {-# LINE 41324 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _patsIgathChildDefs
                   {-# LINE 41329 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathClauses
                   {-# LINE 41334 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _patsIgathDataSems
                   {-# LINE 41339 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathDefs
                   {-# LINE 41344 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathNonterms
                   {-# LINE 41349 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathVisLocalDefs
                   {-# LINE 41354 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _patsIlexCounter
                   {-# LINE 41359 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 41364 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 41369 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 41374 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 41379 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 41384 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 41389 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 41394 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 41399 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 41404 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 41409 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 41414 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 41419 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 41424 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 41429 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 41434 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 41439 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 41444 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 41449 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 41454 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 41459 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 41464 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 41469 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 41474 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 41479 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 41484 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 41489 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 41494 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 41499 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 41504 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 41509 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 41514 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 41519 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 41524 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 41529 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 41534 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 41539 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 41544 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 41549 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 41554 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 41559 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 41564 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 41569 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 41574 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 41579 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 41584 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 41589 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 41594 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 41599 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 41604 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 41609 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 41614 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 41619 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 41624 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 41629 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 41634 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 41639 "src/Transform.hs" #-})
              ( _patsIallReqInvokes,_patsIcodeIdCounter,_patsIdistChildDefs,_patsIdistDataCons,_patsIdistDataSems,_patsIdistDatas,_patsIdistDefs,_patsIdistItfs,_patsIdistVisLocalDefs,_patsIdistVisits,_patsIerrs0,_patsIerrs1,_patsIerrs2,_patsIerrs3,_patsIerrs4,_patsIerrs5,_patsIgathAttrSource,_patsIgathAvoidVisits,_patsIgathChildDefs,_patsIgathChildSource,_patsIgathClauses,_patsIgathDataSems,_patsIgathDefs,_patsIgathDeps,_patsIgathItemVisits,_patsIgathLegalCycStmts,_patsIgathNonterms,_patsIgathSemStarts,_patsIgathStmtPosMap,_patsIgathVisLocalDefs,_patsIgathVisitEnds,_patsIgathVisitSource,_patsIgathVisitStarts,_patsIhpps,_patsIjspps,_patsIlexCounter,_patsIminReqInvokes,_patsIpos,_patsIpps) =
                  pats_ _patsOallAvailInvokes _patsOallVisits _patsOavailInvokes _patsObasename _patsOcoItf _patsOcodeIdCounter _patsOdirectVisitAttrs _patsOdirectVisitLocalAttrs _patsOdistAliasses _patsOdistAllChildMinRanges _patsOdistAttrSource _patsOdistAttrVisMap _patsOdistChildDefs _patsOdistChildEffRanges _patsOdistChildMinRanges _patsOdistChildOcc _patsOdistChildSource _patsOdistCycVisMap _patsOdistDataCons _patsOdistDataMap _patsOdistDataSems _patsOdistDatas _patsOdistDeflStmts _patsOdistDefs _patsOdistInhAttrs _patsOdistItfs _patsOdistRanks _patsOdistRenames _patsOdistSynAttrs _patsOdistVisLocalDefs _patsOdistVisitInhAttrs _patsOdistVisitOrder _patsOdistVisitSource _patsOdistVisitSynAttrs _patsOdistVisits _patsOdoneVisits _patsOgathChildDefs _patsOgathClauses _patsOgathDataSems _patsOgathDefs _patsOgathNonterms _patsOgathVisLocalDefs _patsOhSpilledStmts _patsOisCyclic _patsOisMatch _patsOitf _patsOjsSpilledStmts _patsOlexCounter _patsOnonterm _patsOopts _patsOprio _patsOscopeDep _patsOscopeReason _patsOstmtSource _patsOvisitBeginDep _patsOvisitEndDep _patsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_Cons :: T_Pat  ->
                T_Pat  ->
                T_Pat 
sem_Pat_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _hdOprio :: Prio
              _tlOprio :: Prio
              _hdOisRight :: Bool
              _tlOisRight :: Bool
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOisCyclic :: Bool
              _hdOisMatch :: Bool
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOisCyclic :: Bool
              _tlOisMatch :: Bool
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAttrSource :: AttrSourceMap
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathChildSource :: ChildSourceMap
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitSource :: VisitSourceMap
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpos :: Pos
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAttrSource :: AttrSourceMap
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathChildSource :: ChildSourceMap
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitSource :: VisitSourceMap
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhpp :: PP_Doc
              _tlIjspp :: PP_Doc
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpos :: Pos
              _tlIpp :: PP_Doc
              -- "src/Transform.ag"(line 2040, column 23)
              _lhsOpos =
                  ({-# LINE 2040 "src/Transform.ag" #-}
                   _hdIpos
                   {-# LINE 41942 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2571, column 18)
              _needPar =
                  ({-# LINE 2571 "src/Transform.ag" #-}
                   needParens PrioCons _lhsIprio _lhsIisRight
                   {-# LINE 41947 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2579, column 18)
              _lhsOpp =
                  ({-# LINE 2579 "src/Transform.ag" #-}
                   addParens _needPar     (_hdIpp >#< ":" >#< _tlIpp)
                   {-# LINE 41952 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2592, column 11)
              _hdOprio =
                  ({-# LINE 2592 "src/Transform.ag" #-}
                   PrioCons
                   {-# LINE 41957 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2593, column 11)
              _tlOprio =
                  ({-# LINE 2593 "src/Transform.ag" #-}
                   PrioCons
                   {-# LINE 41962 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2598, column 11)
              _hdOisRight =
                  ({-# LINE 2598 "src/Transform.ag" #-}
                   False
                   {-# LINE 41967 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2599, column 11)
              _tlOisRight =
                  ({-# LINE 2599 "src/Transform.ag" #-}
                   True
                   {-# LINE 41972 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 528, column 18)
              _lhsOhpp =
                  ({-# LINE 528 "src/TargetHaskell.ag" #-}
                   _hBang     >|< pp_parens (_hdIhpp >#< ":" >#< pp_parens _tlIhpp)
                   {-# LINE 41977 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 41982 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 323, column 18)
              _lhsOjspp =
                  ({-# LINE 323 "src/TargetJs.ag" #-}
                   "var _arr = _res;"
                   >-< "if (_arr.length < 1)" >#< _jsThrow
                   >-< "var _res = _arr[0];"
                   >-< _hdIjspp
                   >-< "var _res = _arr.slice(1);"
                   >-< _tlIjspp
                   {-# LINE 41992 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 332, column 7)
              _jsThrow =
                  ({-# LINE 332 "src/TargetJs.ag" #-}
                   if _lhsIisMatch
                   then "throw eEval;"
                   else "throw eAbort;"
                   {-# LINE 41999 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 42004 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 42009 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 42014 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 42019 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 42024 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 42029 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 42034 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _hdIgathAttrSource `Map.union` _tlIgathAttrSource
                   {-# LINE 42039 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 42044 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _hdIgathChildSource `unionWithUnion` _tlIgathChildSource
                   {-# LINE 42049 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 42054 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 42059 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 42064 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 42069 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 42074 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 42079 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _hdIgathVisitSource `unionWithUnion` _tlIgathVisitSource
                   {-# LINE 42084 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 42089 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 42094 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 42099 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 42104 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 42109 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 42114 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 42119 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 42124 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 42129 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 42134 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 42139 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 42144 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 42149 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 42154 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 42159 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 42164 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 42169 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 42174 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 42179 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 42184 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 42189 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 42194 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 42199 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 42204 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 42209 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 42214 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 42219 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 42224 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 42229 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 42234 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 42239 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 42244 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 42249 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 42254 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 42259 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 42264 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 42269 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 42274 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 42279 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 42284 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 42289 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 42294 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 42299 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 42304 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 42309 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 42314 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 42319 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 42324 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 42329 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 42334 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 42339 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 42344 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 42349 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 42354 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 42359 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 42364 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 42369 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 42374 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 42379 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 42384 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 42389 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 42394 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 42399 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 42404 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 42409 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 42414 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 42419 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 42424 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 42429 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 42434 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 42439 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 42444 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 42449 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 42454 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 42459 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 42464 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 42469 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 42474 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 42479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 42484 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 42489 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 42494 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 42499 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 42504 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 42509 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 42514 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 42519 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 42524 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 42529 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 42534 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 42539 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 42544 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 42549 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 42554 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 42559 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 42564 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 42569 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 42574 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 42579 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 42584 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 42589 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 42594 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 42599 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 42604 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 42609 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 42614 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 42619 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 42624 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 42629 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 42634 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 42639 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 42644 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 42649 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 42654 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 42659 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 42664 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 42669 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 42674 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 42679 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 42684 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 42689 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 42694 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 42699 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 42704 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 42709 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 42714 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 42719 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 42724 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 42729 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 42734 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAttrSource,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathChildSource,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitSource,_hdIgathVisitStarts,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIminReqInvokes,_hdIpos,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOisCyclic _hdOisMatch _hdOisRight _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOprio _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAttrSource,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathChildSource,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitSource,_tlIgathVisitStarts,_tlIhpp,_tlIjspp,_tlIlexCounter,_tlIminReqInvokes,_tlIpos,_tlIpp) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOisCyclic _tlOisMatch _tlOisRight _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOprio _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_List :: T_Pats  ->
                T_Pat 
sem_Pat_List pats_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _patsOprio :: Prio
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _patsOallAvailInvokes :: (Map Ident (Set Ident))
              _patsOallVisits :: (Set Ident)
              _patsOavailInvokes :: (Map Ident (Set Ident))
              _patsObasename :: QIdent
              _patsOcoItf :: Ident
              _patsOcodeIdCounter :: Int
              _patsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _patsOdirectVisitLocalAttrs :: (Map Ident String)
              _patsOdistAliasses :: (Map Ident AliasType)
              _patsOdistAllChildMinRanges :: (Map Ident [Ident])
              _patsOdistAttrSource :: AttrSourceMap
              _patsOdistAttrVisMap :: AttrVisMap
              _patsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsOdistChildEffRanges :: (Map Ident (Set Ident))
              _patsOdistChildMinRanges :: (Map Ident [Ident])
              _patsOdistChildOcc :: (Map Ident Int)
              _patsOdistChildSource :: ChildSourceMap
              _patsOdistCycVisMap :: CycVisMap
              _patsOdistDataCons :: ConEnv
              _patsOdistDataMap :: DataMap
              _patsOdistDataSems :: DataSemEnv
              _patsOdistDatas :: DataEnv
              _patsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _patsOdistDefs :: DefsEnv
              _patsOdistInhAttrs :: AttrMap
              _patsOdistItfs :: ItfEnv
              _patsOdistRanks :: (Map DepItem (Bool,Int))
              _patsOdistRenames :: RenameMap
              _patsOdistSynAttrs :: AttrMap
              _patsOdistVisLocalDefs :: DefsEnv
              _patsOdistVisitInhAttrs :: VisitAttrMap
              _patsOdistVisitOrder :: (Map Ident [Ident])
              _patsOdistVisitSource :: VisitSourceMap
              _patsOdistVisitSynAttrs :: VisitAttrMap
              _patsOdistVisits :: VisitEnv
              _patsOdoneVisits :: ([Ident])
              _patsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsOgathClauses :: ClausesEnv
              _patsOgathDataSems :: DataSemEnv
              _patsOgathDefs :: DefsEnv
              _patsOgathNonterms :: NontermEnv
              _patsOgathVisLocalDefs :: DefsEnv
              _patsOhSpilledStmts :: ([(Int,PP_Doc)])
              _patsOisCyclic :: Bool
              _patsOisMatch :: Bool
              _patsOitf :: QIdent
              _patsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _patsOlexCounter :: Int
              _patsOnonterm :: QIdent
              _patsOopts :: Opts
              _patsOscopeDep :: DepItem
              _patsOscopeReason :: Reason
              _patsOstmtSource :: DepItem
              _patsOvisitBeginDep :: DepItem
              _patsOvisitEndDep :: DepItem
              _patsOvisitEndReason :: Reason
              _patsIallReqInvokes :: (Map Ident (Set Ident))
              _patsIcodeIdCounter :: Int
              _patsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsIdistDataCons :: ConEnv
              _patsIdistDataSems :: DataSemEnv
              _patsIdistDatas :: DataEnv
              _patsIdistDefs :: DefsEnv
              _patsIdistItfs :: ItfEnv
              _patsIdistVisLocalDefs :: DefsEnv
              _patsIdistVisits :: VisitEnv
              _patsIerrs0 :: Errs
              _patsIerrs1 :: Errs
              _patsIerrs2 :: Errs
              _patsIerrs3 :: Errs
              _patsIerrs4 :: Errs
              _patsIerrs5 :: Errs
              _patsIgathAttrSource :: AttrSourceMap
              _patsIgathAvoidVisits :: (Set DepItem)
              _patsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsIgathChildSource :: ChildSourceMap
              _patsIgathClauses :: ClausesEnv
              _patsIgathDataSems :: DataSemEnv
              _patsIgathDefs :: DefsEnv
              _patsIgathDeps :: Deps
              _patsIgathItemVisits :: (Map DepItem DepItem)
              _patsIgathLegalCycStmts :: (Set DepItem)
              _patsIgathNonterms :: NontermEnv
              _patsIgathSemStarts :: (Seq DepItem)
              _patsIgathStmtPosMap :: (Map DepItem Pos)
              _patsIgathVisLocalDefs :: DefsEnv
              _patsIgathVisitEnds :: (Seq DepItem)
              _patsIgathVisitSource :: VisitSourceMap
              _patsIgathVisitStarts :: (Seq DepItem)
              _patsIhpps :: ([PP_Doc])
              _patsIjspps :: ([PP_Doc])
              _patsIlexCounter :: Int
              _patsIminReqInvokes :: (Map Ident (Set Ident))
              _patsIpos :: Pos
              _patsIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2039, column 23)
              _lhsOpos =
                  ({-# LINE 2039 "src/Transform.ag" #-}
                   _patsIpos
                   {-# LINE 42940 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2578, column 18)
              _lhsOpp =
                  ({-# LINE 2578 "src/Transform.ag" #-}
                   pp_block "[" "]" "," _patsIpps
                   {-# LINE 42945 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2591, column 11)
              _patsOprio =
                  ({-# LINE 2591 "src/Transform.ag" #-}
                   PrioTop
                   {-# LINE 42950 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 527, column 18)
              _lhsOhpp =
                  ({-# LINE 527 "src/TargetHaskell.ag" #-}
                   _hBang     >|< pp_block "[" "]" "," _patsIhpps
                   {-# LINE 42955 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 42960 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 318, column 18)
              _lhsOjspp =
                  ({-# LINE 318 "src/TargetJs.ag" #-}
                   "var _arr = _res;"
                   >-< "if (_tuple.length !=" >#< length (_patsIjspps) >|< ")" >#< _jsThrow
                   >-< vlist [ "var _res = _arr[" >|< show i >|< "];"
                               >-< jspp
                             | (i, jspp) <- zip [0..] _patsIjspps ]
                   {-# LINE 42969 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 332, column 7)
              _jsThrow =
                  ({-# LINE 332 "src/TargetJs.ag" #-}
                   if _lhsIisMatch
                   then "throw eEval;"
                   else "throw eAbort;"
                   {-# LINE 42976 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIallReqInvokes
                   {-# LINE 42981 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs0
                   {-# LINE 42986 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs1
                   {-# LINE 42991 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs2
                   {-# LINE 42996 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs3
                   {-# LINE 43001 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs4
                   {-# LINE 43006 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs5
                   {-# LINE 43011 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _patsIgathAttrSource
                   {-# LINE 43016 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _patsIgathAvoidVisits
                   {-# LINE 43021 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _patsIgathChildSource
                   {-# LINE 43026 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _patsIgathDeps
                   {-# LINE 43031 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _patsIgathItemVisits
                   {-# LINE 43036 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _patsIgathLegalCycStmts
                   {-# LINE 43041 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _patsIgathSemStarts
                   {-# LINE 43046 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _patsIgathStmtPosMap
                   {-# LINE 43051 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitEnds
                   {-# LINE 43056 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _patsIgathVisitSource
                   {-# LINE 43061 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitStarts
                   {-# LINE 43066 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIminReqInvokes
                   {-# LINE 43071 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _patsIcodeIdCounter
                   {-# LINE 43076 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _patsIdistChildDefs
                   {-# LINE 43081 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _patsIdistDataCons
                   {-# LINE 43086 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _patsIdistDataSems
                   {-# LINE 43091 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _patsIdistDatas
                   {-# LINE 43096 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistDefs
                   {-# LINE 43101 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _patsIdistItfs
                   {-# LINE 43106 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistVisLocalDefs
                   {-# LINE 43111 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _patsIdistVisits
                   {-# LINE 43116 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _patsIgathChildDefs
                   {-# LINE 43121 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathClauses
                   {-# LINE 43126 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _patsIgathDataSems
                   {-# LINE 43131 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathDefs
                   {-# LINE 43136 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathNonterms
                   {-# LINE 43141 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathVisLocalDefs
                   {-# LINE 43146 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _patsIlexCounter
                   {-# LINE 43151 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 43156 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 43161 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 43166 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 43171 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 43176 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 43181 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 43186 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 43191 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 43196 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 43201 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 43206 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 43211 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 43216 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 43221 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 43226 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 43231 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 43236 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 43241 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 43246 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 43251 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 43256 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 43261 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 43266 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 43271 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 43276 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 43281 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 43286 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 43291 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 43296 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 43301 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 43306 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 43311 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 43316 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 43321 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 43326 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 43331 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 43336 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 43341 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 43346 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 43351 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 43356 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 43361 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 43366 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 43371 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 43376 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 43381 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 43386 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 43391 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 43396 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 43401 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 43406 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 43411 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 43416 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 43421 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 43426 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 43431 "src/Transform.hs" #-})
              ( _patsIallReqInvokes,_patsIcodeIdCounter,_patsIdistChildDefs,_patsIdistDataCons,_patsIdistDataSems,_patsIdistDatas,_patsIdistDefs,_patsIdistItfs,_patsIdistVisLocalDefs,_patsIdistVisits,_patsIerrs0,_patsIerrs1,_patsIerrs2,_patsIerrs3,_patsIerrs4,_patsIerrs5,_patsIgathAttrSource,_patsIgathAvoidVisits,_patsIgathChildDefs,_patsIgathChildSource,_patsIgathClauses,_patsIgathDataSems,_patsIgathDefs,_patsIgathDeps,_patsIgathItemVisits,_patsIgathLegalCycStmts,_patsIgathNonterms,_patsIgathSemStarts,_patsIgathStmtPosMap,_patsIgathVisLocalDefs,_patsIgathVisitEnds,_patsIgathVisitSource,_patsIgathVisitStarts,_patsIhpps,_patsIjspps,_patsIlexCounter,_patsIminReqInvokes,_patsIpos,_patsIpps) =
                  pats_ _patsOallAvailInvokes _patsOallVisits _patsOavailInvokes _patsObasename _patsOcoItf _patsOcodeIdCounter _patsOdirectVisitAttrs _patsOdirectVisitLocalAttrs _patsOdistAliasses _patsOdistAllChildMinRanges _patsOdistAttrSource _patsOdistAttrVisMap _patsOdistChildDefs _patsOdistChildEffRanges _patsOdistChildMinRanges _patsOdistChildOcc _patsOdistChildSource _patsOdistCycVisMap _patsOdistDataCons _patsOdistDataMap _patsOdistDataSems _patsOdistDatas _patsOdistDeflStmts _patsOdistDefs _patsOdistInhAttrs _patsOdistItfs _patsOdistRanks _patsOdistRenames _patsOdistSynAttrs _patsOdistVisLocalDefs _patsOdistVisitInhAttrs _patsOdistVisitOrder _patsOdistVisitSource _patsOdistVisitSynAttrs _patsOdistVisits _patsOdoneVisits _patsOgathChildDefs _patsOgathClauses _patsOgathDataSems _patsOgathDefs _patsOgathNonterms _patsOgathVisLocalDefs _patsOhSpilledStmts _patsOisCyclic _patsOisMatch _patsOitf _patsOjsSpilledStmts _patsOlexCounter _patsOnonterm _patsOopts _patsOprio _patsOscopeDep _patsOscopeReason _patsOstmtSource _patsOvisitBeginDep _patsOvisitEndDep _patsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_Tup :: T_Pats  ->
               T_Pat 
sem_Pat_Tup pats_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _patsOprio :: Prio
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _patsOallAvailInvokes :: (Map Ident (Set Ident))
              _patsOallVisits :: (Set Ident)
              _patsOavailInvokes :: (Map Ident (Set Ident))
              _patsObasename :: QIdent
              _patsOcoItf :: Ident
              _patsOcodeIdCounter :: Int
              _patsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _patsOdirectVisitLocalAttrs :: (Map Ident String)
              _patsOdistAliasses :: (Map Ident AliasType)
              _patsOdistAllChildMinRanges :: (Map Ident [Ident])
              _patsOdistAttrSource :: AttrSourceMap
              _patsOdistAttrVisMap :: AttrVisMap
              _patsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsOdistChildEffRanges :: (Map Ident (Set Ident))
              _patsOdistChildMinRanges :: (Map Ident [Ident])
              _patsOdistChildOcc :: (Map Ident Int)
              _patsOdistChildSource :: ChildSourceMap
              _patsOdistCycVisMap :: CycVisMap
              _patsOdistDataCons :: ConEnv
              _patsOdistDataMap :: DataMap
              _patsOdistDataSems :: DataSemEnv
              _patsOdistDatas :: DataEnv
              _patsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _patsOdistDefs :: DefsEnv
              _patsOdistInhAttrs :: AttrMap
              _patsOdistItfs :: ItfEnv
              _patsOdistRanks :: (Map DepItem (Bool,Int))
              _patsOdistRenames :: RenameMap
              _patsOdistSynAttrs :: AttrMap
              _patsOdistVisLocalDefs :: DefsEnv
              _patsOdistVisitInhAttrs :: VisitAttrMap
              _patsOdistVisitOrder :: (Map Ident [Ident])
              _patsOdistVisitSource :: VisitSourceMap
              _patsOdistVisitSynAttrs :: VisitAttrMap
              _patsOdistVisits :: VisitEnv
              _patsOdoneVisits :: ([Ident])
              _patsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsOgathClauses :: ClausesEnv
              _patsOgathDataSems :: DataSemEnv
              _patsOgathDefs :: DefsEnv
              _patsOgathNonterms :: NontermEnv
              _patsOgathVisLocalDefs :: DefsEnv
              _patsOhSpilledStmts :: ([(Int,PP_Doc)])
              _patsOisCyclic :: Bool
              _patsOisMatch :: Bool
              _patsOitf :: QIdent
              _patsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _patsOlexCounter :: Int
              _patsOnonterm :: QIdent
              _patsOopts :: Opts
              _patsOscopeDep :: DepItem
              _patsOscopeReason :: Reason
              _patsOstmtSource :: DepItem
              _patsOvisitBeginDep :: DepItem
              _patsOvisitEndDep :: DepItem
              _patsOvisitEndReason :: Reason
              _patsIallReqInvokes :: (Map Ident (Set Ident))
              _patsIcodeIdCounter :: Int
              _patsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patsIdistDataCons :: ConEnv
              _patsIdistDataSems :: DataSemEnv
              _patsIdistDatas :: DataEnv
              _patsIdistDefs :: DefsEnv
              _patsIdistItfs :: ItfEnv
              _patsIdistVisLocalDefs :: DefsEnv
              _patsIdistVisits :: VisitEnv
              _patsIerrs0 :: Errs
              _patsIerrs1 :: Errs
              _patsIerrs2 :: Errs
              _patsIerrs3 :: Errs
              _patsIerrs4 :: Errs
              _patsIerrs5 :: Errs
              _patsIgathAttrSource :: AttrSourceMap
              _patsIgathAvoidVisits :: (Set DepItem)
              _patsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patsIgathChildSource :: ChildSourceMap
              _patsIgathClauses :: ClausesEnv
              _patsIgathDataSems :: DataSemEnv
              _patsIgathDefs :: DefsEnv
              _patsIgathDeps :: Deps
              _patsIgathItemVisits :: (Map DepItem DepItem)
              _patsIgathLegalCycStmts :: (Set DepItem)
              _patsIgathNonterms :: NontermEnv
              _patsIgathSemStarts :: (Seq DepItem)
              _patsIgathStmtPosMap :: (Map DepItem Pos)
              _patsIgathVisLocalDefs :: DefsEnv
              _patsIgathVisitEnds :: (Seq DepItem)
              _patsIgathVisitSource :: VisitSourceMap
              _patsIgathVisitStarts :: (Seq DepItem)
              _patsIhpps :: ([PP_Doc])
              _patsIjspps :: ([PP_Doc])
              _patsIlexCounter :: Int
              _patsIminReqInvokes :: (Map Ident (Set Ident))
              _patsIpos :: Pos
              _patsIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2038, column 23)
              _lhsOpos =
                  ({-# LINE 2038 "src/Transform.ag" #-}
                   _patsIpos
                   {-# LINE 43635 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2577, column 18)
              _lhsOpp =
                  ({-# LINE 2577 "src/Transform.ag" #-}
                   pp_block "(" ")" "," _patsIpps
                   {-# LINE 43640 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2590, column 11)
              _patsOprio =
                  ({-# LINE 2590 "src/Transform.ag" #-}
                   PrioTop
                   {-# LINE 43645 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 526, column 18)
              _lhsOhpp =
                  ({-# LINE 526 "src/TargetHaskell.ag" #-}
                   _hBang     >|< pp_block "(" ")" "," _patsIhpps
                   {-# LINE 43650 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 43655 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 313, column 18)
              _lhsOjspp =
                  ({-# LINE 313 "src/TargetJs.ag" #-}
                   "var _tuple = _res;"
                   >-< "if (_tuple.length !=" >#< length (_patsIjspps) >|< ")" >#< _jsThrow
                   >-< vlist [ "var _res = _tuple[" >|< show i >|< "];"
                               >-< jspp
                             | (i, jspp) <- zip [0..] _patsIjspps ]
                   {-# LINE 43664 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 332, column 7)
              _jsThrow =
                  ({-# LINE 332 "src/TargetJs.ag" #-}
                   if _lhsIisMatch
                   then "throw eEval;"
                   else "throw eAbort;"
                   {-# LINE 43671 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIallReqInvokes
                   {-# LINE 43676 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs0
                   {-# LINE 43681 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs1
                   {-# LINE 43686 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs2
                   {-# LINE 43691 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs3
                   {-# LINE 43696 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs4
                   {-# LINE 43701 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patsIerrs5
                   {-# LINE 43706 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _patsIgathAttrSource
                   {-# LINE 43711 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _patsIgathAvoidVisits
                   {-# LINE 43716 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _patsIgathChildSource
                   {-# LINE 43721 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _patsIgathDeps
                   {-# LINE 43726 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _patsIgathItemVisits
                   {-# LINE 43731 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _patsIgathLegalCycStmts
                   {-# LINE 43736 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _patsIgathSemStarts
                   {-# LINE 43741 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _patsIgathStmtPosMap
                   {-# LINE 43746 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitEnds
                   {-# LINE 43751 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _patsIgathVisitSource
                   {-# LINE 43756 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patsIgathVisitStarts
                   {-# LINE 43761 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patsIminReqInvokes
                   {-# LINE 43766 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _patsIcodeIdCounter
                   {-# LINE 43771 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _patsIdistChildDefs
                   {-# LINE 43776 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _patsIdistDataCons
                   {-# LINE 43781 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _patsIdistDataSems
                   {-# LINE 43786 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _patsIdistDatas
                   {-# LINE 43791 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistDefs
                   {-# LINE 43796 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _patsIdistItfs
                   {-# LINE 43801 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIdistVisLocalDefs
                   {-# LINE 43806 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _patsIdistVisits
                   {-# LINE 43811 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _patsIgathChildDefs
                   {-# LINE 43816 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathClauses
                   {-# LINE 43821 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _patsIgathDataSems
                   {-# LINE 43826 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathDefs
                   {-# LINE 43831 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patsIgathNonterms
                   {-# LINE 43836 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patsIgathVisLocalDefs
                   {-# LINE 43841 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _patsIlexCounter
                   {-# LINE 43846 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 43851 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 43856 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 43861 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 43866 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 43871 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 43876 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 43881 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 43886 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 43891 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 43896 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 43901 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 43906 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 43911 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 43916 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 43921 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 43926 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 43931 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 43936 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 43941 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 43946 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 43951 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 43956 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 43961 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 43966 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 43971 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 43976 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 43981 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 43986 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 43991 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 43996 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 44001 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 44006 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 44011 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 44016 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 44021 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 44026 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 44031 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 44036 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 44041 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 44046 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 44051 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 44056 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 44061 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 44066 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 44071 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 44076 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 44081 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 44086 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 44091 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 44096 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 44101 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 44106 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 44111 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 44116 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 44121 "src/Transform.hs" #-})
              -- copy rule (down)
              _patsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 44126 "src/Transform.hs" #-})
              ( _patsIallReqInvokes,_patsIcodeIdCounter,_patsIdistChildDefs,_patsIdistDataCons,_patsIdistDataSems,_patsIdistDatas,_patsIdistDefs,_patsIdistItfs,_patsIdistVisLocalDefs,_patsIdistVisits,_patsIerrs0,_patsIerrs1,_patsIerrs2,_patsIerrs3,_patsIerrs4,_patsIerrs5,_patsIgathAttrSource,_patsIgathAvoidVisits,_patsIgathChildDefs,_patsIgathChildSource,_patsIgathClauses,_patsIgathDataSems,_patsIgathDefs,_patsIgathDeps,_patsIgathItemVisits,_patsIgathLegalCycStmts,_patsIgathNonterms,_patsIgathSemStarts,_patsIgathStmtPosMap,_patsIgathVisLocalDefs,_patsIgathVisitEnds,_patsIgathVisitSource,_patsIgathVisitStarts,_patsIhpps,_patsIjspps,_patsIlexCounter,_patsIminReqInvokes,_patsIpos,_patsIpps) =
                  pats_ _patsOallAvailInvokes _patsOallVisits _patsOavailInvokes _patsObasename _patsOcoItf _patsOcodeIdCounter _patsOdirectVisitAttrs _patsOdirectVisitLocalAttrs _patsOdistAliasses _patsOdistAllChildMinRanges _patsOdistAttrSource _patsOdistAttrVisMap _patsOdistChildDefs _patsOdistChildEffRanges _patsOdistChildMinRanges _patsOdistChildOcc _patsOdistChildSource _patsOdistCycVisMap _patsOdistDataCons _patsOdistDataMap _patsOdistDataSems _patsOdistDatas _patsOdistDeflStmts _patsOdistDefs _patsOdistInhAttrs _patsOdistItfs _patsOdistRanks _patsOdistRenames _patsOdistSynAttrs _patsOdistVisLocalDefs _patsOdistVisitInhAttrs _patsOdistVisitOrder _patsOdistVisitSource _patsOdistVisitSynAttrs _patsOdistVisits _patsOdoneVisits _patsOgathChildDefs _patsOgathClauses _patsOgathDataSems _patsOgathDefs _patsOgathNonterms _patsOgathVisLocalDefs _patsOhSpilledStmts _patsOisCyclic _patsOisMatch _patsOitf _patsOjsSpilledStmts _patsOlexCounter _patsOnonterm _patsOopts _patsOprio _patsOscopeDep _patsOscopeReason _patsOstmtSource _patsOvisitBeginDep _patsOvisitEndDep _patsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
sem_Pat_Underscore :: Pos ->
                      T_Pat 
sem_Pat_Underscore pos_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIisRight
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2041, column 23)
              _lhsOpos =
                  ({-# LINE 2041 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 44234 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2580, column 18)
              _lhsOpp =
                  ({-# LINE 2580 "src/Transform.ag" #-}
                   text "_"
                   {-# LINE 44239 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 529, column 18)
              _lhsOhpp =
                  ({-# LINE 529 "src/TargetHaskell.ag" #-}
                   _hBang     >|< text "_"
                   {-# LINE 44244 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 530, column 18)
              _hBang =
                  ({-# LINE 530 "src/TargetHaskell.ag" #-}
                   if _lhsIisCyclic then empty else text "!"
                   {-# LINE 44249 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 329, column 18)
              _lhsOjspp =
                  ({-# LINE 329 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 44254 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44259 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44264 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44269 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44274 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44279 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44284 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44289 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44294 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 44299 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44304 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44309 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44314 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 44319 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44324 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44329 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44334 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44339 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 44344 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 44349 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 44354 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 44359 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 44364 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 44369 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 44374 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 44379 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 44384 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 44389 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 44394 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 44399 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 44404 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 44409 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 44414 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 44419 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 44424 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 44429 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpp)))
-- Pats --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         isCyclic             : Bool
         isMatch              : Bool
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         prio                 : Prio
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         minReqInvokes        : Map Ident (Set Ident)
         pos                  : Pos
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Pat 
         child tl             : Pats 
      alternative Nil:
-}
-- cata
sem_Pats :: Pats  ->
            T_Pats 
sem_Pats list  =
    (Prelude.foldr sem_Pats_Cons sem_Pats_Nil (Prelude.map sem_Pat list) )
-- semantic domain
type T_Pats  = (Map Ident (Set Ident)) ->
               (Set Ident) ->
               (Map Ident (Set Ident)) ->
               QIdent ->
               Ident ->
               Int ->
               (Map Ident (Map Ident String)) ->
               (Map Ident String) ->
               (Map Ident AliasType) ->
               (Map Ident [Ident]) ->
               AttrSourceMap ->
               AttrVisMap ->
               (Env QIdent (QIdent,QIdent)) ->
               (Map Ident (Set Ident)) ->
               (Map Ident [Ident]) ->
               (Map Ident Int) ->
               ChildSourceMap ->
               CycVisMap ->
               ConEnv ->
               DataMap ->
               DataSemEnv ->
               DataEnv ->
               (Map Ident (Bool,Maybe Int)) ->
               DefsEnv ->
               AttrMap ->
               ItfEnv ->
               (Map DepItem (Bool,Int)) ->
               RenameMap ->
               AttrMap ->
               DefsEnv ->
               VisitAttrMap ->
               (Map Ident [Ident]) ->
               VisitSourceMap ->
               VisitAttrMap ->
               VisitEnv ->
               ([Ident]) ->
               (Env QIdent (QIdent, QIdent)) ->
               ClausesEnv ->
               DataSemEnv ->
               DefsEnv ->
               NontermEnv ->
               DefsEnv ->
               ([(Int,PP_Doc)]) ->
               Bool ->
               Bool ->
               QIdent ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               Opts ->
               Prio ->
               DepItem ->
               Reason ->
               DepItem ->
               DepItem ->
               DepItem ->
               Reason ->
               ( (Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),([PP_Doc]),([PP_Doc]),Int,(Map Ident (Set Ident)),Pos,([PP_Doc]))
sem_Pats_Cons :: T_Pat  ->
                 T_Pats  ->
                 T_Pats 
sem_Pats_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _hdOisRight :: Bool
              _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOisCyclic :: Bool
              _hdOisMatch :: Bool
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOprio :: Prio
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOisCyclic :: Bool
              _tlOisMatch :: Bool
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOprio :: Prio
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAttrSource :: AttrSourceMap
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathChildSource :: ChildSourceMap
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitSource :: VisitSourceMap
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpos :: Pos
              _hdIpp :: PP_Doc
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAttrSource :: AttrSourceMap
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathChildSource :: ChildSourceMap
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitSource :: VisitSourceMap
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpos :: Pos
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2042, column 23)
              _lhsOpos =
                  ({-# LINE 2042 "src/Transform.ag" #-}
                   _hdIpos
                   {-# LINE 44884 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2595, column 18)
              _hdOisRight =
                  ({-# LINE 2595 "src/Transform.ag" #-}
                   False
                   {-# LINE 44889 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2665, column 11)
              _lhsOpps =
                  ({-# LINE 2665 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 44894 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 578, column 11)
              _lhsOhpps =
                  ({-# LINE 578 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 44899 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 373, column 11)
              _lhsOjspps =
                  ({-# LINE 373 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 44904 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 44909 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 44914 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 44919 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 44924 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 44929 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 44934 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 44939 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _hdIgathAttrSource `Map.union` _tlIgathAttrSource
                   {-# LINE 44944 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 44949 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _hdIgathChildSource `unionWithUnion` _tlIgathChildSource
                   {-# LINE 44954 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 44959 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 44964 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 44969 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 44974 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 44979 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 44984 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _hdIgathVisitSource `unionWithUnion` _tlIgathVisitSource
                   {-# LINE 44989 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 44994 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 44999 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 45004 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 45009 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 45014 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 45019 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 45024 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 45029 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 45034 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 45039 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 45044 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 45049 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 45054 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 45059 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 45064 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 45069 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 45074 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 45079 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 45084 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 45089 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 45094 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 45099 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 45104 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 45109 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 45114 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 45119 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 45124 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 45129 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 45134 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 45139 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 45144 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 45149 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 45154 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 45159 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 45164 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 45169 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 45174 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 45179 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 45184 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 45189 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 45194 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 45199 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 45204 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 45209 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 45214 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 45219 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 45224 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 45229 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 45234 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 45239 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 45244 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 45249 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 45254 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 45259 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 45264 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 45269 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 45274 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 45279 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 45284 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 45289 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 45294 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 45299 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 45304 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 45309 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 45314 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 45319 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 45324 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 45329 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOprio =
                  ({-# LINE 2582 "src/Transform.ag" #-}
                   _lhsIprio
                   {-# LINE 45334 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 45339 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 45344 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 45349 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 45354 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 45359 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 45364 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 45369 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 45374 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 45379 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 45384 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 45389 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 45394 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 45399 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 45404 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 45409 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 45414 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 45419 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 45424 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 45429 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 45434 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 45439 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 45444 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 45449 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 45454 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 45459 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 45464 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 45469 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 45474 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 45479 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 45484 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 45489 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 45494 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 45499 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 45504 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 45509 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 45514 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 45519 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 45524 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 45529 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 45534 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 45539 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 45544 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 45549 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 45554 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 45559 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 45564 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 45569 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 45574 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 45579 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _lhsIisCyclic
                   {-# LINE 45584 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOisMatch =
                  ({-# LINE 282 "src/TargetJs.ag" #-}
                   _lhsIisMatch
                   {-# LINE 45589 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 45594 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 45599 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 45604 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 45609 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 45614 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOprio =
                  ({-# LINE 2582 "src/Transform.ag" #-}
                   _lhsIprio
                   {-# LINE 45619 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 45624 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 45629 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 45634 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 45639 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 45644 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 45649 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAttrSource,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathChildSource,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitSource,_hdIgathVisitStarts,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIminReqInvokes,_hdIpos,_hdIpp) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOisCyclic _hdOisMatch _hdOisRight _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOprio _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAttrSource,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathChildSource,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitSource,_tlIgathVisitStarts,_tlIhpps,_tlIjspps,_tlIlexCounter,_tlIminReqInvokes,_tlIpos,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOisCyclic _tlOisMatch _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOprio _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpps)))
sem_Pats_Nil :: T_Pats 
sem_Pats_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIisCyclic
       _lhsIisMatch
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIprio
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpos :: Pos
              _lhsOpps :: ([PP_Doc])
              _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2043, column 23)
              _lhsOpos =
                  ({-# LINE 2043 "src/Transform.ag" #-}
                   noPos
                   {-# LINE 45757 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2666, column 11)
              _lhsOpps =
                  ({-# LINE 2666 "src/Transform.ag" #-}
                   []
                   {-# LINE 45762 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 579, column 11)
              _lhsOhpps =
                  ({-# LINE 579 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 45767 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 374, column 11)
              _lhsOjspps =
                  ({-# LINE 374 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 45772 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45777 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45782 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45787 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45792 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45797 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45802 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45807 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45812 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 45817 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45822 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45827 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45832 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 45837 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45842 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45847 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45852 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45857 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 45862 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 45867 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 45872 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 45877 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 45882 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 45887 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 45892 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 45897 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 45902 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 45907 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 45912 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 45917 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 45922 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 45927 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 45932 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 45937 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 45942 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 45947 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpps,_lhsOjspps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpos,_lhsOpps)))
-- Program -----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         opts                 : Opts
         pos                  : Pos
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         graph                : PP_Doc
         pp                   : PP_Doc
         pretty               : PP_Doc
   alternatives:
      alternative Program:
         child blocks         : BlocksTop 
         visit 0:
            local errs0_augmented_f1 : _
            local errs0_augmented_f2 : _
            local errs0_augmented_f3 : _
            local errs0_augmented_f4 : _
            local errs0_augmented_f5 : _
            local errs0_augmented_f6 : _
            local errs0_augmented_f7 : _
            local errs0_augmented_f8 : _
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs1_augmented_f3 : _
            local errs1_augmented_f4 : _
            local errs1_augmented_f5 : _
            local errs1_augmented_f6 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local errs4_augmented_f1 : _
            local pp_augmented_f1 : _
            local pp_augmented_f2 : _
            local pp_augmented_syn : _
            local unqDeps     : _
            local unqItems    : _
            local components  : _
            local distRanks   : _
            local cyclicComps : _
            local cyclicItems : _
            local cyclicErrComps : _
            local ppId        : _
            local hpp         : _
            local jspp        : _
            local ppGraph     : _
            local errs0_augmented_syn : _
            local errs1_augmented_syn : _
            local errs3_augmented_syn : _
            local errs4_augmented_syn : _
-}
-- cata
sem_Program :: Program  ->
               T_Program 
sem_Program (Program_Program _blocks )  =
    (sem_Program_Program (sem_BlocksTop _blocks ) )
-- semantic domain
type T_Program  = Opts ->
                  Pos ->
                  ( Errs,Errs,Errs,Errs,Errs,Errs,PP_Doc,PP_Doc,PP_Doc)
data Inh_Program  = Inh_Program {opts_Inh_Program :: !(Opts),pos_Inh_Program :: !(Pos)}
data Syn_Program  = Syn_Program {errs0_Syn_Program :: !(Errs),errs1_Syn_Program :: !(Errs),errs2_Syn_Program :: !(Errs),errs3_Syn_Program :: !(Errs),errs4_Syn_Program :: !(Errs),errs5_Syn_Program :: !(Errs),graph_Syn_Program :: !(PP_Doc),pp_Syn_Program :: !(PP_Doc),pretty_Syn_Program :: !(PP_Doc)}
wrap_Program :: T_Program  ->
                Inh_Program  ->
                Syn_Program 
wrap_Program sem (Inh_Program _lhsIopts _lhsIpos )  =
    (let ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgraph,_lhsOpp,_lhsOpretty) = sem _lhsIopts _lhsIpos 
     in  (Syn_Program _lhsOerrs0 _lhsOerrs1 _lhsOerrs2 _lhsOerrs3 _lhsOerrs4 _lhsOerrs5 _lhsOgraph _lhsOpp _lhsOpretty ))
sem_Program_Program :: T_BlocksTop  ->
                       T_Program 
sem_Program_Program blocks_  =
    (\ _lhsIopts
       _lhsIpos ->
         (let _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOpp :: PP_Doc
              _lhsOpretty :: PP_Doc
              _lhsOgraph :: PP_Doc
              _blocksOgathItfs :: ItfEnv
              _blocksOgathVisits :: VisitEnv
              _blocksOgathInhs :: AttrEnv
              _blocksOgathSyns :: AttrEnv
              _blocksOgathNonterms :: NontermEnv
              _blocksOgathClauses :: ClausesEnv
              _blocksOgathDataSems :: DataSemEnv
              _blocksOdistDataSems :: DataSemEnv
              _blocksOallVisits :: (Set Ident)
              _blocksOgathDataCons :: ConEnv
              _blocksOdistDataCons :: ConEnv
              _blocksOgathDatas :: DataEnv
              _blocksOdistItfs :: ItfEnv
              _blocksOdistVisits :: VisitEnv
              _blocksOdistDatas :: DataEnv
              _blocksOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _blocksOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _blocksOdistRenames :: RenameMap
              _blocksOdistVisitOrder :: (Map Ident [Ident])
              _blocksOdoneVisits :: ([Ident])
              _blocksOdistInhAttrs :: AttrMap
              _blocksOdistSynAttrs :: AttrMap
              _blocksOdistVisitInhAttrs :: VisitAttrMap
              _blocksOdistVisitSynAttrs :: VisitAttrMap
              _blocksOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _blocksOdirectVisitLocalAttrs :: (Map Ident String)
              _blocksOgathDefs :: DefsEnv
              _blocksOgathVisLocalDefs :: DefsEnv
              _blocksOdistDefs :: DefsEnv
              _blocksOdistVisLocalDefs :: DefsEnv
              _blocksOlexCounter :: Int
              _blocksOdistChildOcc :: (Map Ident Int)
              _blocksOdistAttrVisMap :: AttrVisMap
              _blocksOdistDataMap :: DataMap
              _blocksObasename :: QIdent
              _blocksOdistAliasses :: (Map Ident AliasType)
              _blocksOdistChildMinRanges :: (Map Ident [Ident])
              _blocksOdistAllChildMinRanges :: (Map Ident [Ident])
              _blocksOdistChildEffRanges :: (Map Ident (Set Ident))
              _blocksOavailInvokes :: (Map Ident (Set Ident))
              _blocksOallAvailInvokes :: (Map Ident (Set Ident))
              _blocksOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _blocksOcodeIdCounter :: Int
              _blocksOdistCycVisMap :: CycVisMap
              _blocksOstmtSource :: DepItem
              _blocksOdistAttrSource :: AttrSourceMap
              _blocksOdistChildSource :: ChildSourceMap
              _blocksOdistVisitSource :: VisitSourceMap
              _blocksOscopeReason :: Reason
              _blocksOscopeDep :: DepItem
              _blocksOvisitBeginDep :: DepItem
              _blocksOvisitEndDep :: DepItem
              _blocksOvisitEndReason :: Reason
              _blocksOhSpilledStmts :: ([(Int,PP_Doc)])
              _blocksOjsSpilledStmts :: ([(Int,PP_Doc)])
              _lhsOerrs2 :: Errs
              _lhsOerrs5 :: Errs
              _blocksOdistRanks :: (Map DepItem (Bool,Int))
              _blocksOopts :: Opts
              _blocksIallReqInvokes :: (Map Ident (Set Ident))
              _blocksIcodeIdCounter :: Int
              _blocksIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _blocksIdistDataCons :: ConEnv
              _blocksIdistDataSems :: DataSemEnv
              _blocksIdistDatas :: DataEnv
              _blocksIdistDefs :: DefsEnv
              _blocksIdistItfs :: ItfEnv
              _blocksIdistVisLocalDefs :: DefsEnv
              _blocksIdistVisits :: VisitEnv
              _blocksIerrs0 :: Errs
              _blocksIerrs1 :: Errs
              _blocksIerrs2 :: Errs
              _blocksIerrs3 :: Errs
              _blocksIerrs4 :: Errs
              _blocksIerrs5 :: Errs
              _blocksIgathAliasses :: (Map Ident AliasType)
              _blocksIgathAttrVisMap :: AttrVisMap
              _blocksIgathAvoidVisits :: (Set DepItem)
              _blocksIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _blocksIgathClauses :: ClausesEnv
              _blocksIgathCycVisMap :: CycVisMap
              _blocksIgathDataCons :: ConEnv
              _blocksIgathDataMap :: DataMap
              _blocksIgathDataSems :: DataSemEnv
              _blocksIgathDatas :: DataEnv
              _blocksIgathDefs :: DefsEnv
              _blocksIgathDeps :: Deps
              _blocksIgathInhAttrs :: AttrMap
              _blocksIgathInhs :: AttrEnv
              _blocksIgathItemVisits :: (Map DepItem DepItem)
              _blocksIgathItfs :: ItfEnv
              _blocksIgathLegalCycStmts :: (Set DepItem)
              _blocksIgathNonterms :: NontermEnv
              _blocksIgathSemStarts :: (Seq DepItem)
              _blocksIgathStmtPosMap :: (Map DepItem Pos)
              _blocksIgathSynAttrs :: AttrMap
              _blocksIgathSyns :: AttrEnv
              _blocksIgathVisLocalDefs :: DefsEnv
              _blocksIgathVisitEnds :: (Seq DepItem)
              _blocksIgathVisitInhAttrs :: VisitAttrMap
              _blocksIgathVisitOrder :: (Map Ident [Ident])
              _blocksIgathVisitStarts :: (Seq DepItem)
              _blocksIgathVisitSynAttrs :: VisitAttrMap
              _blocksIgathVisits :: VisitEnv
              _blocksIhpps :: ([PP_Doc])
              _blocksIjspps :: ([PP_Doc])
              _blocksIlexCounter :: Int
              _blocksIminReqInvokes :: (Map Ident (Set Ident))
              _blocksIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1, _errs0_augmented_f2, _errs0_augmented_f3, _errs0_augmented_f4, _errs0_augmented_f5, _errs0_augmented_f6, _errs0_augmented_f7, _errs0_augmented_f8]
                   {-# LINE 46147 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addUseErrs' _blocksIdistDatas
                   {-# LINE 46152 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f2 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs' _blocksIgathDatas
                   {-# LINE 46157 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f3 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addUseErrs _blocksIdistDataCons
                   {-# LINE 46162 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f4 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathDataCons
                   {-# LINE 46167 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f5 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathSyns
                   {-# LINE 46172 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f6 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathInhs
                   {-# LINE 46177 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f7 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathVisits
                   {-# LINE 46182 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f8 =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathItfs
                   {-# LINE 46187 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2, _errs1_augmented_f3, _errs1_augmented_f4, _errs1_augmented_f5, _errs1_augmented_f6]
                   {-# LINE 46192 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addUseErrs' _blocksIdistDataSems
                   {-# LINE 46197 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addUseErrs _blocksIdistChildDefs
                   {-# LINE 46202 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f3 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addUseErrs _blocksIdistVisits
                   {-# LINE 46207 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f4 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addUseErrs _blocksIdistItfs
                   {-# LINE 46212 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f5 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathClauses
                   {-# LINE 46217 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f6 =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   addDefErrs _blocksIgathNonterms
                   {-# LINE 46222 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 126 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2]
                   {-# LINE 46227 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 126 "src/Transform.ag" #-}
                   addUseErrs'' _blocksIdistDefs
                   {-# LINE 46232 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 126 "src/Transform.ag" #-}
                   addDefErrs'' _blocksIgathDefs
                   {-# LINE 46237 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs4 =
                  ({-# LINE 2362 "src/Transform.ag" #-}
                   foldr ($) _errs4_augmented_syn [_errs4_augmented_f1]
                   {-# LINE 46242 "src/Transform.hs" #-})
              -- augment function
              _errs4_augmented_f1 =
                  ({-# LINE 2362 "src/Transform.ag" #-}
                   Seq.fromList (map (Err_Cyclic _lhsIpos _blocksIgathStmtPosMap) _cyclicErrComps    ) Seq.><
                   {-# LINE 46247 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOpp =
                  ({-# LINE 6 "src/TargetJs.ag" #-}
                   foldr ($) _pp_augmented_syn [_pp_augmented_f1, _pp_augmented_f2]
                   {-# LINE 46252 "src/Transform.hs" #-})
              -- augment function
              _pp_augmented_f1 =
                  ({-# LINE 6 "src/TargetJs.ag" #-}
                   if genJs _lhsIopts
                   then (_jspp     >-<)
                   else id
                   {-# LINE 46259 "src/Transform.hs" #-})
              -- augment function
              _pp_augmented_f2 =
                  ({-# LINE 6 "src/TargetJs.ag" #-}
                   if genHaskell _lhsIopts
                   then (_hpp     >-<)
                   else id
                   {-# LINE 46266 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 71, column 3)
              _pp_augmented_syn =
                  ({-# LINE 6 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 46271 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 72, column 3)
              _lhsOpretty =
                  ({-# LINE 72 "src/Transform.ag" #-}
                   _ppId
                   {-# LINE 46276 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 73, column 3)
              _lhsOgraph =
                  ({-# LINE 73 "src/Transform.ag" #-}
                   _ppGraph
                   {-# LINE 46281 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 179, column 24)
              _blocksOgathItfs =
                  ({-# LINE 179 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46286 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 193, column 24)
              _blocksOgathVisits =
                  ({-# LINE 193 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46291 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 217, column 14)
              _blocksOgathInhs =
                  ({-# LINE 217 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46296 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 218, column 14)
              _blocksOgathSyns =
                  ({-# LINE 218 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46301 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 254, column 14)
              _blocksOgathNonterms =
                  ({-# LINE 254 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46306 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 255, column 14)
              _blocksOgathClauses =
                  ({-# LINE 255 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46311 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 271, column 3)
              _blocksOgathDataSems =
                  ({-# LINE 271 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46316 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 272, column 3)
              _blocksOdistDataSems =
                  ({-# LINE 272 "src/Transform.ag" #-}
                   _blocksIgathDataSems
                   {-# LINE 46321 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 280, column 3)
              _blocksOallVisits =
                  ({-# LINE 280 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 46326 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 312, column 3)
              _blocksOgathDataCons =
                  ({-# LINE 312 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46331 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 313, column 3)
              _blocksOdistDataCons =
                  ({-# LINE 313 "src/Transform.ag" #-}
                   _blocksIgathDataCons
                   {-# LINE 46336 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 319, column 24)
              _blocksOgathDatas =
                  ({-# LINE 319 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46341 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 398, column 14)
              _blocksOdistItfs =
                  ({-# LINE 398 "src/Transform.ag" #-}
                   _blocksIgathItfs
                   {-# LINE 46346 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 427, column 14)
              _blocksOdistVisits =
                  ({-# LINE 427 "src/Transform.ag" #-}
                   _blocksIgathVisits
                   {-# LINE 46351 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 469, column 3)
              _blocksOdistDatas =
                  ({-# LINE 469 "src/Transform.ag" #-}
                   _blocksIgathDatas
                   {-# LINE 46356 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 501, column 24)
              _blocksOgathChildDefs =
                  ({-# LINE 501 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46361 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 502, column 24)
              _blocksOdistChildDefs =
                  ({-# LINE 502 "src/Transform.ag" #-}
                   _blocksIgathChildDefs
                   {-# LINE 46366 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 597, column 24)
              _blocksOdistRenames =
                  ({-# LINE 597 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46371 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 713, column 24)
              _blocksOdistVisitOrder =
                  ({-# LINE 713 "src/Transform.ag" #-}
                   _blocksIgathVisitOrder
                   {-# LINE 46376 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 727, column 24)
              _blocksOdoneVisits =
                  ({-# LINE 727 "src/Transform.ag" #-}
                   []
                   {-# LINE 46381 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 889, column 3)
              _blocksOdistInhAttrs =
                  ({-# LINE 889 "src/Transform.ag" #-}
                   _blocksIgathInhAttrs
                   {-# LINE 46386 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 890, column 3)
              _blocksOdistSynAttrs =
                  ({-# LINE 890 "src/Transform.ag" #-}
                   _blocksIgathSynAttrs
                   {-# LINE 46391 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 891, column 3)
              _blocksOdistVisitInhAttrs =
                  ({-# LINE 891 "src/Transform.ag" #-}
                   _blocksIgathVisitInhAttrs
                   {-# LINE 46396 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 892, column 3)
              _blocksOdistVisitSynAttrs =
                  ({-# LINE 892 "src/Transform.ag" #-}
                   _blocksIgathVisitSynAttrs
                   {-# LINE 46401 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 900, column 24)
              _blocksOdirectVisitAttrs =
                  ({-# LINE 900 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46406 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 904, column 24)
              _blocksOdirectVisitLocalAttrs =
                  ({-# LINE 904 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46411 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 995, column 24)
              _blocksOgathDefs =
                  ({-# LINE 995 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46416 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 996, column 24)
              _blocksOgathVisLocalDefs =
                  ({-# LINE 996 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 46421 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 997, column 24)
              _blocksOdistDefs =
                  ({-# LINE 997 "src/Transform.ag" #-}
                   _blocksIgathDefs
                   {-# LINE 46426 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 998, column 24)
              _blocksOdistVisLocalDefs =
                  ({-# LINE 998 "src/Transform.ag" #-}
                   _blocksIgathVisLocalDefs
                   {-# LINE 46431 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1279, column 3)
              _blocksOlexCounter =
                  ({-# LINE 1279 "src/Transform.ag" #-}
                   1
                   {-# LINE 46436 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1309, column 24)
              _blocksOdistChildOcc =
                  ({-# LINE 1309 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46441 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1377, column 24)
              _blocksOdistAttrVisMap =
                  ({-# LINE 1377 "src/Transform.ag" #-}
                   _blocksIgathAttrVisMap
                   {-# LINE 46446 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1394, column 24)
              _blocksOdistDataMap =
                  ({-# LINE 1394 "src/Transform.ag" #-}
                   _blocksIgathDataMap
                   {-# LINE 46451 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1400, column 24)
              _blocksObasename =
                  ({-# LINE 1400 "src/Transform.ag" #-}
                   [ident "<root>"]
                   {-# LINE 46456 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1436, column 24)
              _blocksOdistAliasses =
                  ({-# LINE 1436 "src/Transform.ag" #-}
                   _blocksIgathAliasses
                   {-# LINE 46461 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1610, column 24)
              _blocksOdistChildMinRanges =
                  ({-# LINE 1610 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46466 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1611, column 24)
              _blocksOdistAllChildMinRanges =
                  ({-# LINE 1611 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46471 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1612, column 24)
              _blocksOdistChildEffRanges =
                  ({-# LINE 1612 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46476 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1750, column 24)
              _blocksOavailInvokes =
                  ({-# LINE 1750 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46481 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1751, column 24)
              _blocksOallAvailInvokes =
                  ({-# LINE 1751 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46486 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1815, column 24)
              _blocksOdistDeflStmts =
                  ({-# LINE 1815 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46491 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1826, column 24)
              _blocksOcodeIdCounter =
                  ({-# LINE 1826 "src/Transform.ag" #-}
                   1
                   {-# LINE 46496 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1893, column 24)
              _blocksOdistCycVisMap =
                  ({-# LINE 1893 "src/Transform.ag" #-}
                   _blocksIgathCycVisMap
                   {-# LINE 46501 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2016, column 24)
              _blocksOstmtSource =
                  ({-# LINE 2016 "src/Transform.ag" #-}
                   DepMatch (-999)
                   {-# LINE 46506 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2055, column 25)
              _blocksOdistAttrSource =
                  ({-# LINE 2055 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46511 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2114, column 25)
              _blocksOdistChildSource =
                  ({-# LINE 2114 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46516 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2133, column 25)
              _blocksOdistVisitSource =
                  ({-# LINE 2133 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 46521 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2152, column 3)
              _blocksOscopeReason =
                  ({-# LINE 2152 "src/Transform.ag" #-}
                   ReasonScopeVisit (ident "<root>")
                   {-# LINE 46526 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2153, column 3)
              _blocksOscopeDep =
                  ({-# LINE 2153 "src/Transform.ag" #-}
                   DepVisStart [ident "<root>"]
                   {-# LINE 46531 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2154, column 3)
              _blocksOvisitBeginDep =
                  ({-# LINE 2154 "src/Transform.ag" #-}
                   DepVisStart [ident "<root>"]
                   {-# LINE 46536 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2155, column 3)
              _blocksOvisitEndDep =
                  ({-# LINE 2155 "src/Transform.ag" #-}
                   DepVisEnd [ident "<root>"]
                   {-# LINE 46541 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2156, column 3)
              _blocksOvisitEndReason =
                  ({-# LINE 2156 "src/Transform.ag" #-}
                   ReasonScopeEnd (ident "<root>")
                   {-# LINE 46546 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2332, column 3)
              _unqDeps =
                  ({-# LINE 2332 "src/Transform.ag" #-}
                   Map.fromListWith (\(r1,as) (r2,bs) -> (mostDescriptiveReason r1 r2,nub (as ++ bs)))
                     [ (from, (reason,tos)) | (Dep from reason tos) <- toList _blocksIgathDeps ]
                   `Map.union`
                     (Map.fromList [ (i, (ReasonSink,[])) | i <- _unqItems     ])
                   {-# LINE 46554 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2336, column 3)
              _unqItems =
                  ({-# LINE 2336 "src/Transform.ag" #-}
                   Set.toList $ Set.fromList $ concatMap (\(Dep from _ tos) -> from : tos) $ toList _blocksIgathDeps
                   {-# LINE 46559 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2337, column 3)
              _components =
                  ({-# LINE 2337 "src/Transform.ag" #-}
                   analyze (toList _blocksIgathSemStarts) (toList _blocksIgathVisitStarts) (toList _blocksIgathVisitEnds) _blocksIgathAvoidVisits $
                     map (\(from,(reason,tos)) -> (reason,from,tos)) $ Map.assocs _unqDeps
                   {-# LINE 46565 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2339, column 3)
              _distRanks =
                  ({-# LINE 2339 "src/Transform.ag" #-}
                   let merge rank (AcyclicSCC d) = [(d,(False,rank))]
                       merge rank (CyclicSCC ps) = zip ps (repeat (True,rank))
                       mp = Map.fromList $ concat $ zipWith merge [1..] _components
                   in  mp
                   {-# LINE 46573 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2344, column 3)
              _cyclicComps =
                  ({-# LINE 2344 "src/Transform.ag" #-}
                   let isCyclicSCC (CyclicSCC _)    = True
                       isCyclicSCC _                = False
                       fromCyclicSCC (CyclicSCC xs) = xs
                   in [ fromCyclicSCC c | c <- _components    , isCyclicSCC c ]
                   {-# LINE 46581 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2348, column 3)
              _cyclicItems =
                  ({-# LINE 2348 "src/Transform.ag" #-}
                   Set.fromList $ concat _cyclicComps
                   {-# LINE 46586 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2349, column 3)
              _cyclicErrComps =
                  ({-# LINE 2349 "src/Transform.ag" #-}
                   let isLegalComp items
                         = length vis <= 1 && all isLegal items && any isInvoke items
                         where vis   = nub [ Map.findWithDefault item item _blocksIgathItemVisits | item <- items ]
                       isLegal (DepClause _)   = True
                       isLegal (DepVisStart _) = True
                       isLegal (DepVisEnd _)   = True
                       isLegal item            = Set.member item _blocksIgathLegalCycStmts
                       isInvoke (DepInvoke _)  = True
                       isInvoke _              = False
                   in filter (not . isLegalComp) _cyclicComps
                   {-# LINE 46600 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2414, column 18)
              _ppId =
                  ({-# LINE 2414 "src/Transform.ag" #-}
                   vlist _blocksIpps
                   {-# LINE 46605 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 71, column 3)
              _hpp =
                  ({-# LINE 71 "src/TargetHaskell.ag" #-}
                   vlist _blocksIhpps
                   {-# LINE 46610 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 591, column 24)
              _blocksOhSpilledStmts =
                  ({-# LINE 591 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 46615 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 31, column 3)
              _jspp =
                  ({-# LINE 31 "src/TargetJs.ag" #-}
                   vlist _blocksIjspps
                   {-# LINE 46620 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 386, column 24)
              _blocksOjsSpilledStmts =
                  ({-# LINE 386 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 46625 "src/Transform.hs" #-})
              -- "src/TargetGraph.ag"(line 5, column 3)
              _ppGraph =
                  ({-# LINE 5 "src/TargetGraph.ag" #-}
                   "digraph Deps {"
                   >-< indent 2 ( vlist
                        [ ppgNode (Map.findWithDefault noPos d _blocksIgathStmtPosMap) d _distRanks
                        | d <- _unqItems
                        ])
                   >-< indent 2 ( vlist
                         [ label' from >#< "->" >#< ppgDeps (map label' [to])
                             >#< pp_block "[" "]" "," ( ppgColor (isOnCycle from _distRanks     && isOnCycle to _distRanks    )
                                                      : maybe [] (\d -> [ppgProp "label" d]) (ppgReason reason))
                             >|< ";"
                         | (from, (reason, tos)) <- Map.assocs _unqDeps
                         , length tos >= 1
                         , let label' = \item -> ppgKey (Map.findWithDefault noPos item _blocksIgathStmtPosMap) item
                         , to <- tos ]
                       )
                   >-< "}"
                   {-# LINE 46645 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 122 "src/Transform.ag" #-}
                   _blocksIerrs0
                   {-# LINE 46650 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 124 "src/Transform.ag" #-}
                   _blocksIerrs1
                   {-# LINE 46655 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs2
                   {-# LINE 46660 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 126 "src/Transform.ag" #-}
                   _blocksIerrs3
                   {-# LINE 46665 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs4_augmented_syn =
                  ({-# LINE 2362 "src/Transform.ag" #-}
                   _blocksIerrs4
                   {-# LINE 46670 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _blocksIerrs5
                   {-# LINE 46675 "src/Transform.hs" #-})
              -- copy rule (from local)
              _blocksOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _distRanks
                   {-# LINE 46680 "src/Transform.hs" #-})
              -- copy rule (down)
              _blocksOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 46685 "src/Transform.hs" #-})
              ( _blocksIallReqInvokes,_blocksIcodeIdCounter,_blocksIdistChildDefs,_blocksIdistDataCons,_blocksIdistDataSems,_blocksIdistDatas,_blocksIdistDefs,_blocksIdistItfs,_blocksIdistVisLocalDefs,_blocksIdistVisits,_blocksIerrs0,_blocksIerrs1,_blocksIerrs2,_blocksIerrs3,_blocksIerrs4,_blocksIerrs5,_blocksIgathAliasses,_blocksIgathAttrVisMap,_blocksIgathAvoidVisits,_blocksIgathChildDefs,_blocksIgathClauses,_blocksIgathCycVisMap,_blocksIgathDataCons,_blocksIgathDataMap,_blocksIgathDataSems,_blocksIgathDatas,_blocksIgathDefs,_blocksIgathDeps,_blocksIgathInhAttrs,_blocksIgathInhs,_blocksIgathItemVisits,_blocksIgathItfs,_blocksIgathLegalCycStmts,_blocksIgathNonterms,_blocksIgathSemStarts,_blocksIgathStmtPosMap,_blocksIgathSynAttrs,_blocksIgathSyns,_blocksIgathVisLocalDefs,_blocksIgathVisitEnds,_blocksIgathVisitInhAttrs,_blocksIgathVisitOrder,_blocksIgathVisitStarts,_blocksIgathVisitSynAttrs,_blocksIgathVisits,_blocksIhpps,_blocksIjspps,_blocksIlexCounter,_blocksIminReqInvokes,_blocksIpps) =
                  blocks_ _blocksOallAvailInvokes _blocksOallVisits _blocksOavailInvokes _blocksObasename _blocksOcodeIdCounter _blocksOdirectVisitAttrs _blocksOdirectVisitLocalAttrs _blocksOdistAliasses _blocksOdistAllChildMinRanges _blocksOdistAttrSource _blocksOdistAttrVisMap _blocksOdistChildDefs _blocksOdistChildEffRanges _blocksOdistChildMinRanges _blocksOdistChildOcc _blocksOdistChildSource _blocksOdistCycVisMap _blocksOdistDataCons _blocksOdistDataMap _blocksOdistDataSems _blocksOdistDatas _blocksOdistDeflStmts _blocksOdistDefs _blocksOdistInhAttrs _blocksOdistItfs _blocksOdistRanks _blocksOdistRenames _blocksOdistSynAttrs _blocksOdistVisLocalDefs _blocksOdistVisitInhAttrs _blocksOdistVisitOrder _blocksOdistVisitSource _blocksOdistVisitSynAttrs _blocksOdistVisits _blocksOdoneVisits _blocksOgathChildDefs _blocksOgathClauses _blocksOgathDataCons _blocksOgathDataSems _blocksOgathDatas _blocksOgathDefs _blocksOgathInhs _blocksOgathItfs _blocksOgathNonterms _blocksOgathSyns _blocksOgathVisLocalDefs _blocksOgathVisits _blocksOhSpilledStmts _blocksOjsSpilledStmts _blocksOlexCounter _blocksOopts _blocksOscopeDep _blocksOscopeReason _blocksOstmtSource _blocksOvisitBeginDep _blocksOvisitEndDep _blocksOvisitEndReason 
          in  ( _lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgraph,_lhsOpp,_lhsOpretty)))
-- Rename ------------------------------------------------------
{-
   visit 0:
      synthesized attribute:
         gathRenames          : Map Ident Ident
   alternatives:
      alternative Rename:
         child source         : {Ident}
         child dest           : {Ident}
-}
-- cata
sem_Rename :: Rename  ->
              T_Rename 
sem_Rename (Rename_Rename _source _dest )  =
    (sem_Rename_Rename _source _dest )
-- semantic domain
type T_Rename  = ( (Map Ident Ident))
sem_Rename_Rename :: Ident ->
                     Ident ->
                     T_Rename 
sem_Rename_Rename source_ dest_  =
    (let _lhsOgathRenames :: (Map Ident Ident)
         -- "src/Transform.ag"(line 593, column 3)
         _lhsOgathRenames =
             ({-# LINE 593 "src/Transform.ag" #-}
              Map.fromList [ (source_, dest_), (dest_, source_) ]
              {-# LINE 46715 "src/Transform.hs" #-})
     in  ( _lhsOgathRenames))
-- Renames -----------------------------------------------------
{-
   visit 0:
      synthesized attribute:
         gathRenames          : Map Ident Ident
   alternatives:
      alternative Cons:
         child hd             : Rename 
         child tl             : Renames 
      alternative Nil:
-}
-- cata
sem_Renames :: Renames  ->
               T_Renames 
sem_Renames list  =
    (Prelude.foldr sem_Renames_Cons sem_Renames_Nil (Prelude.map sem_Rename list) )
-- semantic domain
type T_Renames  = ( (Map Ident Ident))
sem_Renames_Cons :: T_Rename  ->
                    T_Renames  ->
                    T_Renames 
sem_Renames_Cons hd_ tl_  =
    (let _lhsOgathRenames :: (Map Ident Ident)
         _hdIgathRenames :: (Map Ident Ident)
         _tlIgathRenames :: (Map Ident Ident)
         -- use rule "src/Transform.ag"(line 591, column 39)
         _lhsOgathRenames =
             ({-# LINE 591 "src/Transform.ag" #-}
              _hdIgathRenames `mappend` _tlIgathRenames
              {-# LINE 46746 "src/Transform.hs" #-})
         ( _hdIgathRenames) =
             hd_ 
         ( _tlIgathRenames) =
             tl_ 
     in  ( _lhsOgathRenames))
sem_Renames_Nil :: T_Renames 
sem_Renames_Nil  =
    (let _lhsOgathRenames :: (Map Ident Ident)
         -- use rule "src/Transform.ag"(line 591, column 39)
         _lhsOgathRenames =
             ({-# LINE 591 "src/Transform.ag" #-}
              mempty
              {-# LINE 46759 "src/Transform.hs" #-})
     in  ( _lhsOgathRenames))
-- SemCon ------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         clauseExtras         : Map Ident Stmts
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Con:
         child pos            : {Pos}
         child name           : {Ident}
         child fields         : SemFields 
-}
-- cata
sem_SemCon :: SemCon  ->
              T_SemCon 
sem_SemCon (SemCon_Con _pos _name _fields )  =
    (sem_SemCon_Con _pos _name (sem_SemFields _fields ) )
-- semantic domain
type T_SemCon  = (Map Ident (Set Ident)) ->
                 (Set Ident) ->
                 (Map Ident (Set Ident)) ->
                 QIdent ->
                 Ident ->
                 Int ->
                 (Map Ident (Map Ident String)) ->
                 (Map Ident String) ->
                 (Map Ident AliasType) ->
                 (Map Ident [Ident]) ->
                 AttrSourceMap ->
                 AttrVisMap ->
                 (Env QIdent (QIdent,QIdent)) ->
                 (Map Ident (Set Ident)) ->
                 (Map Ident [Ident]) ->
                 (Map Ident Int) ->
                 ChildSourceMap ->
                 CycVisMap ->
                 ConEnv ->
                 DataMap ->
                 DataSemEnv ->
                 DataEnv ->
                 (Map Ident (Bool,Maybe Int)) ->
                 DefsEnv ->
                 AttrMap ->
                 ItfEnv ->
                 (Map DepItem (Bool,Int)) ->
                 RenameMap ->
                 AttrMap ->
                 DefsEnv ->
                 VisitAttrMap ->
                 (Map Ident [Ident]) ->
                 VisitSourceMap ->
                 VisitAttrMap ->
                 VisitEnv ->
                 ([Ident]) ->
                 (Env QIdent (QIdent, QIdent)) ->
                 ClausesEnv ->
                 DataSemEnv ->
                 DefsEnv ->
                 NontermEnv ->
                 DefsEnv ->
                 ([(Int,PP_Doc)]) ->
                 QIdent ->
                 ([(Int,PP_Doc)]) ->
                 Int ->
                 QIdent ->
                 Opts ->
                 DepItem ->
                 Reason ->
                 DepItem ->
                 DepItem ->
                 DepItem ->
                 Reason ->
                 ( (Map Ident (Set Ident)),(Map Ident Stmts),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),Int,(Map Ident (Set Ident)))
sem_SemCon_Con :: Pos ->
                  Ident ->
                  T_SemFields  ->
                  T_SemCon 
sem_SemCon_Con pos_ name_ fields_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOclauseExtras :: (Map Ident Stmts)
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _fieldsOallAvailInvokes :: (Map Ident (Set Ident))
              _fieldsOallVisits :: (Set Ident)
              _fieldsOavailInvokes :: (Map Ident (Set Ident))
              _fieldsObasename :: QIdent
              _fieldsOcoItf :: Ident
              _fieldsOcodeIdCounter :: Int
              _fieldsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _fieldsOdirectVisitLocalAttrs :: (Map Ident String)
              _fieldsOdistAliasses :: (Map Ident AliasType)
              _fieldsOdistAllChildMinRanges :: (Map Ident [Ident])
              _fieldsOdistAttrSource :: AttrSourceMap
              _fieldsOdistAttrVisMap :: AttrVisMap
              _fieldsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _fieldsOdistChildEffRanges :: (Map Ident (Set Ident))
              _fieldsOdistChildMinRanges :: (Map Ident [Ident])
              _fieldsOdistChildOcc :: (Map Ident Int)
              _fieldsOdistChildSource :: ChildSourceMap
              _fieldsOdistCycVisMap :: CycVisMap
              _fieldsOdistDataCons :: ConEnv
              _fieldsOdistDataMap :: DataMap
              _fieldsOdistDataSems :: DataSemEnv
              _fieldsOdistDatas :: DataEnv
              _fieldsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _fieldsOdistDefs :: DefsEnv
              _fieldsOdistInhAttrs :: AttrMap
              _fieldsOdistItfs :: ItfEnv
              _fieldsOdistRanks :: (Map DepItem (Bool,Int))
              _fieldsOdistRenames :: RenameMap
              _fieldsOdistSynAttrs :: AttrMap
              _fieldsOdistVisLocalDefs :: DefsEnv
              _fieldsOdistVisitInhAttrs :: VisitAttrMap
              _fieldsOdistVisitOrder :: (Map Ident [Ident])
              _fieldsOdistVisitSource :: VisitSourceMap
              _fieldsOdistVisitSynAttrs :: VisitAttrMap
              _fieldsOdistVisits :: VisitEnv
              _fieldsOdoneVisits :: ([Ident])
              _fieldsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _fieldsOgathClauses :: ClausesEnv
              _fieldsOgathDataSems :: DataSemEnv
              _fieldsOgathDefs :: DefsEnv
              _fieldsOgathNonterms :: NontermEnv
              _fieldsOgathVisLocalDefs :: DefsEnv
              _fieldsOhSpilledStmts :: ([(Int,PP_Doc)])
              _fieldsOitf :: QIdent
              _fieldsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _fieldsOlexCounter :: Int
              _fieldsOnonterm :: QIdent
              _fieldsOopts :: Opts
              _fieldsOscopeDep :: DepItem
              _fieldsOscopeReason :: Reason
              _fieldsOstmtSource :: DepItem
              _fieldsOvisitBeginDep :: DepItem
              _fieldsOvisitEndDep :: DepItem
              _fieldsOvisitEndReason :: Reason
              _fieldsIallReqInvokes :: (Map Ident (Set Ident))
              _fieldsIclauseExtras :: Stmts 
              _fieldsIcodeIdCounter :: Int
              _fieldsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _fieldsIdistDataCons :: ConEnv
              _fieldsIdistDataSems :: DataSemEnv
              _fieldsIdistDatas :: DataEnv
              _fieldsIdistDefs :: DefsEnv
              _fieldsIdistItfs :: ItfEnv
              _fieldsIdistVisLocalDefs :: DefsEnv
              _fieldsIdistVisits :: VisitEnv
              _fieldsIerrs0 :: Errs
              _fieldsIerrs1 :: Errs
              _fieldsIerrs2 :: Errs
              _fieldsIerrs3 :: Errs
              _fieldsIerrs4 :: Errs
              _fieldsIerrs5 :: Errs
              _fieldsIgathAvoidVisits :: (Set DepItem)
              _fieldsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _fieldsIgathClauses :: ClausesEnv
              _fieldsIgathDataSems :: DataSemEnv
              _fieldsIgathDefs :: DefsEnv
              _fieldsIgathDeps :: Deps
              _fieldsIgathItemVisits :: (Map DepItem DepItem)
              _fieldsIgathLegalCycStmts :: (Set DepItem)
              _fieldsIgathNonterms :: NontermEnv
              _fieldsIgathSemStarts :: (Seq DepItem)
              _fieldsIgathStmtPosMap :: (Map DepItem Pos)
              _fieldsIgathVisLocalDefs :: DefsEnv
              _fieldsIgathVisitEnds :: (Seq DepItem)
              _fieldsIgathVisitStarts :: (Seq DepItem)
              _fieldsIlexCounter :: Int
              _fieldsIminReqInvokes :: (Map Ident (Set Ident))
              -- "src/Transform.ag"(line 646, column 3)
              _lhsOclauseExtras =
                  ({-# LINE 646 "src/Transform.ag" #-}
                   Map.singleton name_
                     ( Stmt_Eval Mode_Match (Pat_AttrCon name_ (replPos pos_ locIdent) (head _lhsIitf))
                         (BoundCode_Code Bind_Fun pos_ $ Code_Code
                            [Item_Attr pos_ (replPos pos_ lhsIdent) (replPos pos_ astIdent) ])
                     : _fieldsIclauseExtras )
                   {-# LINE 47092 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _fieldsIallReqInvokes
                   {-# LINE 47097 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs0
                   {-# LINE 47102 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs1
                   {-# LINE 47107 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs2
                   {-# LINE 47112 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs3
                   {-# LINE 47117 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs4
                   {-# LINE 47122 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _fieldsIerrs5
                   {-# LINE 47127 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _fieldsIgathAvoidVisits
                   {-# LINE 47132 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _fieldsIgathDeps
                   {-# LINE 47137 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _fieldsIgathItemVisits
                   {-# LINE 47142 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _fieldsIgathLegalCycStmts
                   {-# LINE 47147 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _fieldsIgathSemStarts
                   {-# LINE 47152 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _fieldsIgathStmtPosMap
                   {-# LINE 47157 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _fieldsIgathVisitEnds
                   {-# LINE 47162 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _fieldsIgathVisitStarts
                   {-# LINE 47167 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _fieldsIminReqInvokes
                   {-# LINE 47172 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _fieldsIcodeIdCounter
                   {-# LINE 47177 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _fieldsIdistChildDefs
                   {-# LINE 47182 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _fieldsIdistDataCons
                   {-# LINE 47187 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _fieldsIdistDataSems
                   {-# LINE 47192 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _fieldsIdistDatas
                   {-# LINE 47197 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIdistDefs
                   {-# LINE 47202 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _fieldsIdistItfs
                   {-# LINE 47207 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIdistVisLocalDefs
                   {-# LINE 47212 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _fieldsIdistVisits
                   {-# LINE 47217 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _fieldsIgathChildDefs
                   {-# LINE 47222 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _fieldsIgathClauses
                   {-# LINE 47227 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _fieldsIgathDataSems
                   {-# LINE 47232 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIgathDefs
                   {-# LINE 47237 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _fieldsIgathNonterms
                   {-# LINE 47242 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _fieldsIgathVisLocalDefs
                   {-# LINE 47247 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _fieldsIlexCounter
                   {-# LINE 47252 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 47257 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 47262 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 47267 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 47272 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 47277 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 47282 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 47287 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 47292 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 47297 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 47302 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 47307 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 47312 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 47317 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 47322 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 47327 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 47332 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 47337 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 47342 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 47347 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 47352 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 47357 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 47362 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 47367 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 47372 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 47377 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 47382 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 47387 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 47392 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 47397 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 47402 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 47407 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 47412 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 47417 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 47422 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 47427 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 47432 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 47437 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 47442 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 47447 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 47452 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 47457 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 47462 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 47467 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 47472 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 47477 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 47482 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 47487 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 47492 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 47497 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 47502 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 47507 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 47512 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 47517 "src/Transform.hs" #-})
              -- copy rule (down)
              _fieldsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 47522 "src/Transform.hs" #-})
              ( _fieldsIallReqInvokes,_fieldsIclauseExtras,_fieldsIcodeIdCounter,_fieldsIdistChildDefs,_fieldsIdistDataCons,_fieldsIdistDataSems,_fieldsIdistDatas,_fieldsIdistDefs,_fieldsIdistItfs,_fieldsIdistVisLocalDefs,_fieldsIdistVisits,_fieldsIerrs0,_fieldsIerrs1,_fieldsIerrs2,_fieldsIerrs3,_fieldsIerrs4,_fieldsIerrs5,_fieldsIgathAvoidVisits,_fieldsIgathChildDefs,_fieldsIgathClauses,_fieldsIgathDataSems,_fieldsIgathDefs,_fieldsIgathDeps,_fieldsIgathItemVisits,_fieldsIgathLegalCycStmts,_fieldsIgathNonterms,_fieldsIgathSemStarts,_fieldsIgathStmtPosMap,_fieldsIgathVisLocalDefs,_fieldsIgathVisitEnds,_fieldsIgathVisitStarts,_fieldsIlexCounter,_fieldsIminReqInvokes) =
                  fields_ _fieldsOallAvailInvokes _fieldsOallVisits _fieldsOavailInvokes _fieldsObasename _fieldsOcoItf _fieldsOcodeIdCounter _fieldsOdirectVisitAttrs _fieldsOdirectVisitLocalAttrs _fieldsOdistAliasses _fieldsOdistAllChildMinRanges _fieldsOdistAttrSource _fieldsOdistAttrVisMap _fieldsOdistChildDefs _fieldsOdistChildEffRanges _fieldsOdistChildMinRanges _fieldsOdistChildOcc _fieldsOdistChildSource _fieldsOdistCycVisMap _fieldsOdistDataCons _fieldsOdistDataMap _fieldsOdistDataSems _fieldsOdistDatas _fieldsOdistDeflStmts _fieldsOdistDefs _fieldsOdistInhAttrs _fieldsOdistItfs _fieldsOdistRanks _fieldsOdistRenames _fieldsOdistSynAttrs _fieldsOdistVisLocalDefs _fieldsOdistVisitInhAttrs _fieldsOdistVisitOrder _fieldsOdistVisitSource _fieldsOdistVisitSynAttrs _fieldsOdistVisits _fieldsOdoneVisits _fieldsOgathChildDefs _fieldsOgathClauses _fieldsOgathDataSems _fieldsOgathDefs _fieldsOgathNonterms _fieldsOgathVisLocalDefs _fieldsOhSpilledStmts _fieldsOitf _fieldsOjsSpilledStmts _fieldsOlexCounter _fieldsOnonterm _fieldsOopts _fieldsOscopeDep _fieldsOscopeReason _fieldsOstmtSource _fieldsOvisitBeginDep _fieldsOvisitEndDep _fieldsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
-- SemCons -----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         clauseExtras         : Map Ident Stmts
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Cons:
         child hd             : SemCon 
         child tl             : SemCons 
      alternative Nil:
-}
-- cata
sem_SemCons :: SemCons  ->
               T_SemCons 
sem_SemCons list  =
    (Prelude.foldr sem_SemCons_Cons sem_SemCons_Nil (Prelude.map sem_SemCon list) )
-- semantic domain
type T_SemCons  = (Map Ident (Set Ident)) ->
                  (Set Ident) ->
                  (Map Ident (Set Ident)) ->
                  QIdent ->
                  Ident ->
                  Int ->
                  (Map Ident (Map Ident String)) ->
                  (Map Ident String) ->
                  (Map Ident AliasType) ->
                  (Map Ident [Ident]) ->
                  AttrSourceMap ->
                  AttrVisMap ->
                  (Env QIdent (QIdent,QIdent)) ->
                  (Map Ident (Set Ident)) ->
                  (Map Ident [Ident]) ->
                  (Map Ident Int) ->
                  ChildSourceMap ->
                  CycVisMap ->
                  ConEnv ->
                  DataMap ->
                  DataSemEnv ->
                  DataEnv ->
                  (Map Ident (Bool,Maybe Int)) ->
                  DefsEnv ->
                  AttrMap ->
                  ItfEnv ->
                  (Map DepItem (Bool,Int)) ->
                  RenameMap ->
                  AttrMap ->
                  DefsEnv ->
                  VisitAttrMap ->
                  (Map Ident [Ident]) ->
                  VisitSourceMap ->
                  VisitAttrMap ->
                  VisitEnv ->
                  ([Ident]) ->
                  (Env QIdent (QIdent, QIdent)) ->
                  ClausesEnv ->
                  DataSemEnv ->
                  DefsEnv ->
                  NontermEnv ->
                  DefsEnv ->
                  ([(Int,PP_Doc)]) ->
                  QIdent ->
                  ([(Int,PP_Doc)]) ->
                  Int ->
                  QIdent ->
                  Opts ->
                  DepItem ->
                  Reason ->
                  DepItem ->
                  DepItem ->
                  DepItem ->
                  Reason ->
                  ( (Map Ident (Set Ident)),(Map Ident Stmts),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),Int,(Map Ident (Set Ident)))
sem_SemCons_Cons :: T_SemCon  ->
                    T_SemCons  ->
                    T_SemCons 
sem_SemCons_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOclauseExtras :: (Map Ident Stmts)
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIclauseExtras :: (Map Ident Stmts)
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIclauseExtras :: (Map Ident Stmts)
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 47939 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 642, column 40)
              _lhsOclauseExtras =
                  ({-# LINE 642 "src/Transform.ag" #-}
                   _hdIclauseExtras `Map.union` _tlIclauseExtras
                   {-# LINE 47944 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 47949 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 47954 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 47959 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 47964 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 47969 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 47974 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 47979 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 47984 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 47989 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 47994 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 47999 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 48004 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 48009 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 48014 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 48019 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 48024 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 48029 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 48034 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 48039 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 48044 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 48049 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 48054 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 48059 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 48064 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 48069 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 48074 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 48079 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 48084 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 48089 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 48094 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 48099 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 48104 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 48109 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 48114 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 48119 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 48124 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 48129 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 48134 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 48139 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 48144 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 48149 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 48154 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 48159 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 48164 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 48169 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 48174 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 48179 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 48184 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 48189 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 48194 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 48199 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 48204 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 48209 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 48214 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 48219 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 48224 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 48229 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 48234 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 48239 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 48244 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 48249 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 48254 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 48259 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 48264 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 48269 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 48274 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 48279 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 48284 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 48289 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 48294 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 48299 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 48304 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 48309 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 48314 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 48319 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 48324 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 48329 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 48334 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 48339 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 48344 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 48349 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 48354 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 48359 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 48364 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 48369 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 48374 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 48379 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 48384 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 48389 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 48394 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 48399 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 48404 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 48409 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 48414 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 48419 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 48424 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 48429 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 48434 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 48439 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 48444 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 48449 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 48454 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 48459 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 48464 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 48469 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 48474 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 48479 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 48484 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 48489 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 48494 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 48499 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 48504 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 48509 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 48514 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 48519 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 48524 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 48529 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 48534 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 48539 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 48544 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 48549 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 48554 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 48559 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 48564 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 48569 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 48574 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 48579 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 48584 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 48589 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 48594 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 48599 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 48604 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 48609 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 48614 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 48619 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 48624 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 48629 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 48634 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 48639 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIclauseExtras,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitStarts,_hdIlexCounter,_hdIminReqInvokes) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIclauseExtras,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitStarts,_tlIlexCounter,_tlIminReqInvokes) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_SemCons_Nil :: T_SemCons 
sem_SemCons_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOclauseExtras :: (Map Ident Stmts)
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 48738 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 642, column 40)
              _lhsOclauseExtras =
                  ({-# LINE 642 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 48743 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48748 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48753 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48758 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48763 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48768 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48773 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 48778 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48783 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 48788 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 48793 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48798 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 48803 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48808 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 48813 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 48818 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 48823 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 48828 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 48833 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 48838 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 48843 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 48848 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 48853 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 48858 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 48863 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 48868 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 48873 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 48878 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 48883 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 48888 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 48893 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 48898 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
-- SemField ----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         clauseExtras         : Stmts 
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Field:
         child pos            : {Pos}
         child name           : {Ident}
         child type           : {Either Ident String}
         visit 0:
            local distDataSems_augmented_f1 : _
            local isNonterm   : _
            local distDataSems_augmented_syn : _
-}
-- cata
sem_SemField :: SemField  ->
                T_SemField 
sem_SemField (SemField_Field _pos _name _type )  =
    (sem_SemField_Field _pos _name _type )
-- semantic domain
type T_SemField  = (Map Ident (Set Ident)) ->
                   (Set Ident) ->
                   (Map Ident (Set Ident)) ->
                   QIdent ->
                   Ident ->
                   Int ->
                   (Map Ident (Map Ident String)) ->
                   (Map Ident String) ->
                   (Map Ident AliasType) ->
                   (Map Ident [Ident]) ->
                   AttrSourceMap ->
                   AttrVisMap ->
                   (Env QIdent (QIdent,QIdent)) ->
                   (Map Ident (Set Ident)) ->
                   (Map Ident [Ident]) ->
                   (Map Ident Int) ->
                   ChildSourceMap ->
                   CycVisMap ->
                   ConEnv ->
                   DataMap ->
                   DataSemEnv ->
                   DataEnv ->
                   (Map Ident (Bool,Maybe Int)) ->
                   DefsEnv ->
                   AttrMap ->
                   ItfEnv ->
                   (Map DepItem (Bool,Int)) ->
                   RenameMap ->
                   AttrMap ->
                   DefsEnv ->
                   VisitAttrMap ->
                   (Map Ident [Ident]) ->
                   VisitSourceMap ->
                   VisitAttrMap ->
                   VisitEnv ->
                   ([Ident]) ->
                   (Env QIdent (QIdent, QIdent)) ->
                   ClausesEnv ->
                   DataSemEnv ->
                   DefsEnv ->
                   NontermEnv ->
                   DefsEnv ->
                   ([(Int,PP_Doc)]) ->
                   QIdent ->
                   ([(Int,PP_Doc)]) ->
                   Int ->
                   QIdent ->
                   Opts ->
                   DepItem ->
                   Reason ->
                   DepItem ->
                   DepItem ->
                   DepItem ->
                   Reason ->
                   ( (Map Ident (Set Ident)),Stmts ,Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),Int,(Map Ident (Set Ident)))
sem_SemField_Field :: Pos ->
                      Ident ->
                      (Either Ident String) ->
                      T_SemField 
sem_SemField_Field pos_ name_ type_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDataSems :: DataSemEnv
              _lhsOclauseExtras :: Stmts 
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOdistDataSems =
                  ({-# LINE 656 "src/Transform.ag" #-}
                   foldr ($) _distDataSems_augmented_syn [_distDataSems_augmented_f1]
                   {-# LINE 49144 "src/Transform.hs" #-})
              -- augment function
              _distDataSems_augmented_f1 =
                  ({-# LINE 656 "src/Transform.ag" #-}
                   case type_ of
                     Left nt | _isNonterm     -> snd . find nt ()
                     _ -> id
                   {-# LINE 49151 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 653, column 3)
              _isNonterm =
                  ({-# LINE 653 "src/Transform.ag" #-}
                   case type_ of
                     Left nt -> Map.member nt _lhsIdistDataMap
                     Right _ -> False
                   {-# LINE 49158 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 659, column 3)
              _lhsOclauseExtras =
                  ({-# LINE 659 "src/Transform.ag" #-}
                   case type_ of
                     Left nt | _isNonterm     ->
                           [ Stmt_Attach pos_ Nothing name_ nt Nothing
                           , Stmt_Eval Mode_Assert (Pat_Attr name_ (replPos pos_ astIdent))
                                                   (BoundCode_Code Bind_Fun pos_ (Code_Code [
                                                     Item_Attr pos_ (replPos pos_ locIdent) name_ ]))
                           ]
                     _ -> []
                   {-# LINE 49170 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 49175 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49180 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49185 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49190 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49195 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49200 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49205 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 49210 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49215 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 49220 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 49225 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49230 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 49235 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49240 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 49245 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 49250 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 49255 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 49260 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 49265 "src/Transform.hs" #-})
              -- copy rule (chain)
              _distDataSems_augmented_syn =
                  ({-# LINE 656 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 49270 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 49275 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 49280 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 49285 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 49290 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 49295 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 49300 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 49305 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 49310 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 49315 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 49320 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 49325 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 49330 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
-- SemFields ---------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         hSpilledStmts        : [(Int,PP_Doc)]
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         clauseExtras         : Stmts 
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAvoidVisits      : Set DepItem
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitStarts      : Seq DepItem
         minReqInvokes        : Map Ident (Set Ident)
   alternatives:
      alternative Cons:
         child hd             : SemField 
         child tl             : SemFields 
      alternative Nil:
-}
-- cata
sem_SemFields :: SemFields  ->
                 T_SemFields 
sem_SemFields list  =
    (Prelude.foldr sem_SemFields_Cons sem_SemFields_Nil (Prelude.map sem_SemField list) )
-- semantic domain
type T_SemFields  = (Map Ident (Set Ident)) ->
                    (Set Ident) ->
                    (Map Ident (Set Ident)) ->
                    QIdent ->
                    Ident ->
                    Int ->
                    (Map Ident (Map Ident String)) ->
                    (Map Ident String) ->
                    (Map Ident AliasType) ->
                    (Map Ident [Ident]) ->
                    AttrSourceMap ->
                    AttrVisMap ->
                    (Env QIdent (QIdent,QIdent)) ->
                    (Map Ident (Set Ident)) ->
                    (Map Ident [Ident]) ->
                    (Map Ident Int) ->
                    ChildSourceMap ->
                    CycVisMap ->
                    ConEnv ->
                    DataMap ->
                    DataSemEnv ->
                    DataEnv ->
                    (Map Ident (Bool,Maybe Int)) ->
                    DefsEnv ->
                    AttrMap ->
                    ItfEnv ->
                    (Map DepItem (Bool,Int)) ->
                    RenameMap ->
                    AttrMap ->
                    DefsEnv ->
                    VisitAttrMap ->
                    (Map Ident [Ident]) ->
                    VisitSourceMap ->
                    VisitAttrMap ->
                    VisitEnv ->
                    ([Ident]) ->
                    (Env QIdent (QIdent, QIdent)) ->
                    ClausesEnv ->
                    DataSemEnv ->
                    DefsEnv ->
                    NontermEnv ->
                    DefsEnv ->
                    ([(Int,PP_Doc)]) ->
                    QIdent ->
                    ([(Int,PP_Doc)]) ->
                    Int ->
                    QIdent ->
                    Opts ->
                    DepItem ->
                    Reason ->
                    DepItem ->
                    DepItem ->
                    DepItem ->
                    Reason ->
                    ( (Map Ident (Set Ident)),Stmts ,Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set DepItem),(Env QIdent (QIdent, QIdent)),ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),NontermEnv,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),(Seq DepItem),Int,(Map Ident (Set Ident)))
sem_SemFields_Cons :: T_SemField  ->
                      T_SemFields  ->
                      T_SemFields 
sem_SemFields_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOclauseExtras :: Stmts 
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIclauseExtras :: Stmts 
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathNonterms :: NontermEnv
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIclauseExtras :: Stmts 
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathNonterms :: NontermEnv
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 49745 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 643, column 44)
              _lhsOclauseExtras =
                  ({-# LINE 643 "src/Transform.ag" #-}
                   _hdIclauseExtras ++ _tlIclauseExtras
                   {-# LINE 49750 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 49755 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 49760 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 49765 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 49770 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 49775 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 49780 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 49785 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 49790 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 49795 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 49800 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 49805 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 49810 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 49815 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 49820 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 49825 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 49830 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 49835 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 49840 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 49845 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 49850 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 49855 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 49860 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 49865 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 49870 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 49875 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 49880 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 49885 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 49890 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 49895 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 49900 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 49905 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 49910 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 49915 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 49920 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 49925 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 49930 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 49935 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 49940 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 49945 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 49950 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 49955 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 49960 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 49965 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 49970 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 49975 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 49980 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 49985 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 49990 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 49995 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 50000 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 50005 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 50010 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 50015 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 50020 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 50025 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 50030 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 50035 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 50040 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 50045 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 50050 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 50055 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 50060 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 50065 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 50070 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 50075 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 50080 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 50085 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 50090 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 50095 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 50100 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 50105 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 50110 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 50115 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 50120 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 50125 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 50130 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 50135 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 50140 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 50145 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 50150 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 50155 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 50160 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 50165 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 50170 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 50175 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 50180 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 50185 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 50190 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 50195 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 50200 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 50205 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 50210 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 50215 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 50220 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 50225 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 50230 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 50235 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 50240 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 50245 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 50250 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 50255 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 50260 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 50265 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 50270 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 50275 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 50280 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 50285 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 50290 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 50295 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 50300 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 50305 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 50310 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 50315 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 50320 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 50325 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 50330 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 50335 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 50340 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 50345 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 50350 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 50355 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 50360 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 50365 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 50370 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 50375 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 50380 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 50385 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 50390 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 50395 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 50400 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 50405 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 50410 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 50415 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 50420 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 50425 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 50430 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 50435 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 50440 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 50445 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIclauseExtras,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathClauses,_hdIgathDataSems,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathNonterms,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitStarts,_hdIlexCounter,_hdIminReqInvokes) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIclauseExtras,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathClauses,_tlIgathDataSems,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathNonterms,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitStarts,_tlIlexCounter,_tlIminReqInvokes) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
sem_SemFields_Nil :: T_SemFields 
sem_SemFields_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOclauseExtras :: Stmts 
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 50544 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 643, column 44)
              _lhsOclauseExtras =
                  ({-# LINE 643 "src/Transform.ag" #-}
                   []
                   {-# LINE 50549 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50554 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50564 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50569 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50574 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50579 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 50584 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50589 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 50594 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 50599 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50604 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 50609 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50614 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 50619 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 50624 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 50629 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 50634 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 50639 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 50644 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 50649 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 50654 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 50659 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 50664 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 50669 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 50674 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 50679 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 50684 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 50689 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 50694 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 50699 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 50704 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsOclauseExtras,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathNonterms,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitStarts,_lhsOlexCounter,_lhsOminReqInvokes)))
-- SemVisit ----------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         clauseExtras         : Map Ident Stmts
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distNextVisits       : Map Ident (Maybe Ident)
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclic           : Bool
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         localAttrs           : Map Ident String
         masterPos            : Pos
         myNextVisits         : Map Ident (Maybe Ident)
         nextVisits           : [Ident]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         semBasename          : QIdent
         stmtSource           : DepItem
         visit                : Ident
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
         visitNr              : Int
         withinCoSem          : Bool
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         gathVisitNames       : Env Ident ()
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAllowCycVisits   : Set Ident
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildSource      : ChildSourceMap
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathSemAttrSource    : AttrSourceMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisRankMap       : IntMap Ident
         gathVisitAttrs       : Map Ident (Map Ident String)
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         isInternal           : Bool
         jspp                 : PP_Doc
         mbNextVisit          : Maybe Ident
         minRank              : Int
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
   alternatives:
      alternative End:
         visit 0:
            local errs0_augmented_f1 : _
            local hGroupedStmts : _
            local jsGroupedStmts : _
            local errs0_augmented_syn : _
      alternative Impl:
         visit 0:
            inst  actual      : SemVisit 
      alternative Internal:
         child pos            : {Pos}
         child name           : {Ident}
         child cyclic         : {Bool}
         child stmts          : Stmts 
         child clauses        : ClausesTop 
         visit 0:
            local bannedInvokes_augmented_f1 : _
            local errs1_augmented_f1 : _
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local gathAllowCycVisits_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathItemVisits_augmented_f1 : _
            local gathVisRankMap_augmented_f1 : _
            local gathVisitEnds_augmented_f1 : _
            local gathVisitNames_augmented_f1 : _
            local gathVisitStarts_augmented_f1 : _
            local distRenames : _
            local name        : _
            local unqualItf   : _
            local masterPos   : _
            inst  impls       : ImplStmts 
            local distChildOcc : _
            local itfNm       : _
            local distChildMinRanges : _
            local distAllChildMinRanges : _
            local distChildEffRanges : _
            local introChildren : _
            local minReqInvokes1 : _
            local allReqInvokes1 : _
            local minReqInvokes : _
            local allReqInvokes : _
            local implicitInvokes : _
            local additionalInvokes : _
            local availInvokes : _
            local allAvailInvokes : _
            local missingInvokes : _
            local distDeflStmts : _
            local fullCyclic  : _
            local allowCycles : _
            local nClauses    : _
            local distAttrSource : _
            local distChildSource : _
            local distVisitSource : _
            local scopeReason : _
            local scopeDep    : _
            local visitBeginDep : _
            local visitEndDep : _
            local visitEndReason : _
            local _tup63      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local _tup64      : _
            local hoStmts     : _
            local hGroupedStmts : _
            local _tup65      : _
            local jsoStmts    : _
            local jsGroupedStmts : _
            local _tup66      : {(Int,Int)}
            local lexOrder    : {Int}
            local bannedInvokes_augmented_syn : _
            local errs1_augmented_syn : _
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local gathAllowCycVisits_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathVisRankMap_augmented_syn : _
            local gathVisitEnds_augmented_syn : _
            local gathVisitStarts_augmented_syn : _
            local gathVisitNames_augmented_syn : _
      alternative Prependable:
         child pos            : {Pos}
         child name           : {Ident}
         child actual         : {SemVisit}
         visit 0:
            local errs0_augmented_f1 : _
            local missingVisits : _
            local remainingVisits : _
            inst  visits      : SemVisit 
            local errs0_augmented_syn : _
      alternative Visit:
         child pos            : {Pos}
         child name           : {Ident}
         child cyclic         : {Bool}
         child attrs          : VisitAttrs 
         child stmts          : Stmts 
         child clauses        : ClausesTop 
         visit 0:
            local bannedInvokes_augmented_f1 : _
            local distVisits_augmented_f1 : _
            local errs0_augmented_f1 : _
            local errs0_augmented_f2 : _
            local errs1_augmented_f1 : _
            local errs2_augmented_f1 : _
            local errs3_augmented_f1 : _
            local errs3_augmented_f2 : _
            local gathAllowCycVisits_augmented_f1 : _
            local gathAvoidVisits_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathItemVisits_augmented_f1 : _
            local gathSemStarts_augmented_f1 : _
            local gathVisRankMap_augmented_f1 : _
            local gathVisitAttrs_augmented_f1 : _
            local gathVisitEnds_augmented_f1 : _
            local gathVisitNames_augmented_f1 : _
            local gathVisitStarts_augmented_f1 : _
            local distRenames : _
            local visitNr     : _
            local doneVisits  : _
            local unqualItf   : _
            local itfVisits   : _
            local _tup67      : _
            local sequenceErrs : _
            local masterPos   : _
            local ldefs1      : _
            local _tup68      : _
            local localVisLocalDefs : _
            local _tup69      : _
            local localVisLocalDefs' : _
            local ldefs2      : _
            local inhAttrMap  : _
            inst  impls       : ImplStmts 
            local distChildOcc : _
            local itfNm       : _
            local myNextVisits : _
            local distChildMinRanges : _
            local distAllChildMinRanges : _
            local distChildEffRanges : _
            local introChildren : _
            local minReqInvokes1 : _
            local allReqInvokes1 : _
            local minReqInvokes : _
            local allReqInvokes : _
            local implicitInvokes : _
            local additionalInvokes : _
            local availInvokes : _
            local allAvailInvokes : _
            local missingInvokes : _
            local distDeflStmts : _
            local fullCyclic  : _
            local allowCycles : _
            local nClauses    : _
            local distAttrSource : _
            local gathChnAttrSource : _
            local gathVisAttrSource : _
            local distChildSource : _
            local distVisitSource : _
            local scopeReason : _
            local scopeDep    : _
            local visitBeginDep : _
            local visitEndDep : _
            local visitEndReason : _
            local _tup70      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local hChildren   : _
            local hChns       : _
            local hChnsOut    : _
            local hInhPPs     : _
            local hMatch      : _
            local hVisType    : _
            local _tup71      : _
            local hoStmts     : _
            local hGroupedStmts : _
            local _tup72      : _
            local jsoStmts    : _
            local jsGroupedStmts : _
            local _tup73      : {(Int,Int)}
            local lexOrder    : {Int}
            local bannedInvokes_augmented_syn : _
            local errs0_augmented_syn : _
            local errs1_augmented_syn : _
            local errs2_augmented_syn : _
            local errs3_augmented_syn : _
            local gathAllowCycVisits_augmented_syn : _
            local gathAvoidVisits_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathSemStarts_augmented_syn : _
            local gathVisRankMap_augmented_syn : _
            local gathVisitAttrs_augmented_syn : _
            local gathVisitEnds_augmented_syn : _
            local gathVisitStarts_augmented_syn : _
            local distVisits_augmented_syn : _
            local gathVisitNames_augmented_syn : _
-}
-- cata
sem_SemVisit :: SemVisit  ->
                T_SemVisit 
sem_SemVisit (SemVisit_End )  =
    (sem_SemVisit_End )
sem_SemVisit (SemVisit_Impl )  =
    (sem_SemVisit_Impl )
sem_SemVisit (SemVisit_Internal _pos _name _cyclic _stmts _clauses )  =
    (sem_SemVisit_Internal _pos _name _cyclic (sem_Stmts _stmts ) (sem_ClausesTop _clauses ) )
sem_SemVisit (SemVisit_Prependable _pos _name _actual )  =
    (sem_SemVisit_Prependable _pos _name _actual )
sem_SemVisit (SemVisit_Visit _pos _name _cyclic _attrs _stmts _clauses )  =
    (sem_SemVisit_Visit _pos _name _cyclic (sem_VisitAttrs _attrs ) (sem_Stmts _stmts ) (sem_ClausesTop _clauses ) )
-- semantic domain
type T_SemVisit  = (Map Ident (Set Ident)) ->
                   (Set Ident) ->
                   (Set Ident) ->
                   (Map Ident (Set Ident)) ->
                   QIdent ->
                   (Map Ident Stmts) ->
                   Ident ->
                   Int ->
                   (Map Ident (Map Ident String)) ->
                   (Map Ident String) ->
                   (Map Ident AliasType) ->
                   (Map Ident [Ident]) ->
                   AttrSourceMap ->
                   AttrVisMap ->
                   (Env QIdent (QIdent,QIdent)) ->
                   (Map Ident (Set Ident)) ->
                   (Map Ident [Ident]) ->
                   (Map Ident Int) ->
                   ChildSourceMap ->
                   CycVisMap ->
                   ConEnv ->
                   DataMap ->
                   DataSemEnv ->
                   DataEnv ->
                   (Map Ident (Bool,Maybe Int)) ->
                   DefsEnv ->
                   AttrMap ->
                   ItfEnv ->
                   (Map Ident (Maybe Ident)) ->
                   (Map DepItem (Bool,Int)) ->
                   RenameMap ->
                   AttrMap ->
                   DefsEnv ->
                   (IntMap Ident) ->
                   VisitAttrMap ->
                   (Map Ident [Ident]) ->
                   VisitSourceMap ->
                   VisitAttrMap ->
                   VisitEnv ->
                   ([Ident]) ->
                   Bool ->
                   (Set Ident) ->
                   (Env QIdent (QIdent, QIdent)) ->
                   ClausesEnv ->
                   DataSemEnv ->
                   DefsEnv ->
                   NontermEnv ->
                   DefsEnv ->
                   (Env Ident ()) ->
                   ([(Int,PP_Doc)]) ->
                   Int ->
                   QIdent ->
                   ([(Int,PP_Doc)]) ->
                   Int ->
                   (Map Ident String) ->
                   Pos ->
                   (Map Ident (Maybe Ident)) ->
                   ([Ident]) ->
                   QIdent ->
                   Opts ->
                   DepItem ->
                   Reason ->
                   QIdent ->
                   DepItem ->
                   Ident ->
                   DepItem ->
                   DepItem ->
                   Reason ->
                   Int ->
                   Bool ->
                   ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Set Ident),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),ChildSourceMap,ClausesEnv,DataSemEnv,DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),NontermEnv,AttrSourceMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,(IntMap Ident),(Map Ident (Map Ident String)),(Seq DepItem),(Env Ident ()),VisitSourceMap,(Seq DepItem),PP_Doc,Bool,PP_Doc,Int,(Maybe Ident),Int,(Map Ident (Set Ident)),PP_Doc)
sem_SemVisit_End :: T_SemVisit 
sem_SemVisit_End  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsOerrs0 :: Errs
              _lhsOisInternal :: Bool
              _lhsOmbNextVisit :: (Maybe Ident)
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOlexCounter :: Int
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 761 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 51224 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 761 "src/Transform.ag" #-}
                   (if null _lhsInextVisits then Seq.empty else Seq.singleton (Err_VisitsNotImpl _lhsInonterm _lhsInextVisits)) Seq.><
                   {-# LINE 51229 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 848, column 15)
              _lhsOisInternal =
                  ({-# LINE 848 "src/Transform.ag" #-}
                   False
                   {-# LINE 51234 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1355, column 21)
              _lhsOmbNextVisit =
                  ({-# LINE 1355 "src/Transform.ag" #-}
                   Nothing
                   {-# LINE 51239 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2524, column 18)
              _lhsOpp =
                  ({-# LINE 2524 "src/Transform.ag" #-}
                   empty
                   {-# LINE 51244 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 300, column 18)
              _lhsOhpp =
                  ({-# LINE 300 "src/TargetHaskell.ag" #-}
                   if _lhsIfullCyclic
                   then vlist _hGroupedStmts
                   else hppStmtBlock _hGroupedStmts
                   {-# LINE 51251 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 599, column 3)
              _hGroupedStmts =
                  ({-# LINE 599 "src/TargetHaskell.ag" #-}
                   groupPairs _lhsIhSpilledStmts
                   {-# LINE 51256 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 179, column 18)
              _lhsOjspp =
                  ({-# LINE 179 "src/TargetJs.ag" #-}
                   if _lhsIfullCyclic
                   then vlist _jsGroupedStmts
                   else jsppStmtBlock _jsGroupedStmts
                   {-# LINE 51263 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 394, column 3)
              _jsGroupedStmts =
                  ({-# LINE 394 "src/TargetJs.ag" #-}
                   groupPairs _lhsIjsSpilledStmts
                   {-# LINE 51268 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51273 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51278 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 761 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51283 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51288 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51293 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51298 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51303 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51308 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 51313 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51318 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 51323 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51328 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51333 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51338 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 51343 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 51348 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51353 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51358 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51363 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 51368 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 51373 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51378 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51383 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 51388 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   maxBound
                   {-# LINE 51393 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 51398 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 51403 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 51408 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 51413 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 51418 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 51423 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 51428 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 51433 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 51438 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 51443 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 51448 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 51453 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 51458 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 51463 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 51468 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 51473 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 51478 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 51483 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisInternal,_lhsOjspp,_lhsOlexCounter,_lhsOmbNextVisit,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
sem_SemVisit_Impl :: T_SemVisit 
sem_SemVisit_Impl  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let actual_val_ :: SemVisit 
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOhpp :: PP_Doc
              _lhsOisInternal :: Bool
              _lhsOjspp :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOmbNextVisit :: (Maybe Ident)
              _lhsOpp :: PP_Doc
              _actualOallAvailInvokes :: (Map Ident (Set Ident))
              _actualOallVisits :: (Set Ident)
              _actualOallowCycVisits :: (Set Ident)
              _actualOavailInvokes :: (Map Ident (Set Ident))
              _actualObasename :: QIdent
              _actualOclauseExtras :: (Map Ident Stmts)
              _actualOcoItf :: Ident
              _actualOcodeIdCounter :: Int
              _actualOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _actualOdirectVisitLocalAttrs :: (Map Ident String)
              _actualOdistAliasses :: (Map Ident AliasType)
              _actualOdistAllChildMinRanges :: (Map Ident [Ident])
              _actualOdistAttrSource :: AttrSourceMap
              _actualOdistAttrVisMap :: AttrVisMap
              _actualOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _actualOdistChildEffRanges :: (Map Ident (Set Ident))
              _actualOdistChildMinRanges :: (Map Ident [Ident])
              _actualOdistChildOcc :: (Map Ident Int)
              _actualOdistChildSource :: ChildSourceMap
              _actualOdistCycVisMap :: CycVisMap
              _actualOdistDataCons :: ConEnv
              _actualOdistDataMap :: DataMap
              _actualOdistDataSems :: DataSemEnv
              _actualOdistDatas :: DataEnv
              _actualOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _actualOdistDefs :: DefsEnv
              _actualOdistInhAttrs :: AttrMap
              _actualOdistItfs :: ItfEnv
              _actualOdistNextVisits :: (Map Ident (Maybe Ident))
              _actualOdistRanks :: (Map DepItem (Bool,Int))
              _actualOdistRenames :: RenameMap
              _actualOdistSynAttrs :: AttrMap
              _actualOdistVisLocalDefs :: DefsEnv
              _actualOdistVisRankMap :: (IntMap Ident)
              _actualOdistVisitInhAttrs :: VisitAttrMap
              _actualOdistVisitOrder :: (Map Ident [Ident])
              _actualOdistVisitSource :: VisitSourceMap
              _actualOdistVisitSynAttrs :: VisitAttrMap
              _actualOdistVisits :: VisitEnv
              _actualOdoneVisits :: ([Ident])
              _actualOfullCyclic :: Bool
              _actualOfullCyclicVisits :: (Set Ident)
              _actualOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _actualOgathClauses :: ClausesEnv
              _actualOgathDataSems :: DataSemEnv
              _actualOgathDefs :: DefsEnv
              _actualOgathNonterms :: NontermEnv
              _actualOgathVisLocalDefs :: DefsEnv
              _actualOgathVisitNames :: (Env Ident ())
              _actualOhSpilledStmts :: ([(Int,PP_Doc)])
              _actualOindent :: Int
              _actualOitf :: QIdent
              _actualOjsSpilledStmts :: ([(Int,PP_Doc)])
              _actualOlexCounter :: Int
              _actualOlocalAttrs :: (Map Ident String)
              _actualOmasterPos :: Pos
              _actualOmyNextVisits :: (Map Ident (Maybe Ident))
              _actualOnextVisits :: ([Ident])
              _actualOnonterm :: QIdent
              _actualOopts :: Opts
              _actualOscopeDep :: DepItem
              _actualOscopeReason :: Reason
              _actualOsemBasename :: QIdent
              _actualOstmtSource :: DepItem
              _actualOvisit :: Ident
              _actualOvisitBeginDep :: DepItem
              _actualOvisitEndDep :: DepItem
              _actualOvisitEndReason :: Reason
              _actualOvisitNr :: Int
              _actualOwithinCoSem :: Bool
              _actualIallReqInvokes :: (Map Ident (Set Ident))
              _actualIbannedInvokes :: (Map Ident (Set Ident))
              _actualIcodeIdCounter :: Int
              _actualIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _actualIdistDataCons :: ConEnv
              _actualIdistDataSems :: DataSemEnv
              _actualIdistDatas :: DataEnv
              _actualIdistDefs :: DefsEnv
              _actualIdistItfs :: ItfEnv
              _actualIdistVisLocalDefs :: DefsEnv
              _actualIdistVisits :: VisitEnv
              _actualIerrs0 :: Errs
              _actualIerrs1 :: Errs
              _actualIerrs2 :: Errs
              _actualIerrs3 :: Errs
              _actualIerrs4 :: Errs
              _actualIerrs5 :: Errs
              _actualIgathAllowCycVisits :: (Set Ident)
              _actualIgathAttrSource :: AttrSourceMap
              _actualIgathAvoidVisits :: (Set DepItem)
              _actualIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _actualIgathChildSource :: ChildSourceMap
              _actualIgathClauses :: ClausesEnv
              _actualIgathDataSems :: DataSemEnv
              _actualIgathDefs :: DefsEnv
              _actualIgathDeps :: Deps
              _actualIgathItemVisits :: (Map DepItem DepItem)
              _actualIgathLegalCycStmts :: (Set DepItem)
              _actualIgathMissingInvokes :: (Set (Ident,Ident))
              _actualIgathNonterms :: NontermEnv
              _actualIgathSemAttrSource :: AttrSourceMap
              _actualIgathSemStarts :: (Seq DepItem)
              _actualIgathStmtPosMap :: (Map DepItem Pos)
              _actualIgathVisLocalDefs :: DefsEnv
              _actualIgathVisRankMap :: (IntMap Ident)
              _actualIgathVisitAttrs :: (Map Ident (Map Ident String))
              _actualIgathVisitEnds :: (Seq DepItem)
              _actualIgathVisitNames :: (Env Ident ())
              _actualIgathVisitSource :: VisitSourceMap
              _actualIgathVisitStarts :: (Seq DepItem)
              _actualIhpp :: PP_Doc
              _actualIisInternal :: Bool
              _actualIjspp :: PP_Doc
              _actualIlexCounter :: Int
              _actualImbNextVisit :: (Maybe Ident)
              _actualIminRank :: Int
              _actualIminReqInvokes :: (Map Ident (Set Ident))
              _actualIpp :: PP_Doc
              -- "src/Transform.ag"(line 746, column 12)
              actual_val_ =
                  ({-# LINE 746 "src/Transform.ag" #-}
                   prependEmptyVisits _lhsIbasename _lhsImasterPos SemVisit_End _lhsInextVisits
                   {-# LINE 51728 "src/Transform.hs" #-})
              actual_inst_ =
                  (sem_SemVisit actual_val_ )
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _actualIallReqInvokes
                   {-# LINE 51735 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _actualIbannedInvokes
                   {-# LINE 51740 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs0
                   {-# LINE 51745 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs1
                   {-# LINE 51750 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs2
                   {-# LINE 51755 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs3
                   {-# LINE 51760 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs4
                   {-# LINE 51765 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _actualIerrs5
                   {-# LINE 51770 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _actualIgathAllowCycVisits
                   {-# LINE 51775 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _actualIgathAttrSource
                   {-# LINE 51780 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _actualIgathAvoidVisits
                   {-# LINE 51785 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _actualIgathChildSource
                   {-# LINE 51790 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _actualIgathDeps
                   {-# LINE 51795 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _actualIgathItemVisits
                   {-# LINE 51800 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _actualIgathLegalCycStmts
                   {-# LINE 51805 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _actualIgathMissingInvokes
                   {-# LINE 51810 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _actualIgathSemAttrSource
                   {-# LINE 51815 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _actualIgathSemStarts
                   {-# LINE 51820 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _actualIgathStmtPosMap
                   {-# LINE 51825 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _actualIgathVisRankMap
                   {-# LINE 51830 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _actualIgathVisitAttrs
                   {-# LINE 51835 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _actualIgathVisitEnds
                   {-# LINE 51840 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _actualIgathVisitSource
                   {-# LINE 51845 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _actualIgathVisitStarts
                   {-# LINE 51850 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   _actualIminRank
                   {-# LINE 51855 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _actualIminReqInvokes
                   {-# LINE 51860 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _actualIcodeIdCounter
                   {-# LINE 51865 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _actualIdistChildDefs
                   {-# LINE 51870 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _actualIdistDataCons
                   {-# LINE 51875 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _actualIdistDataSems
                   {-# LINE 51880 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _actualIdistDatas
                   {-# LINE 51885 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIdistDefs
                   {-# LINE 51890 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _actualIdistItfs
                   {-# LINE 51895 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIdistVisLocalDefs
                   {-# LINE 51900 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _actualIdistVisits
                   {-# LINE 51905 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _actualIgathChildDefs
                   {-# LINE 51910 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _actualIgathClauses
                   {-# LINE 51915 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _actualIgathDataSems
                   {-# LINE 51920 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIgathDefs
                   {-# LINE 51925 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _actualIgathNonterms
                   {-# LINE 51930 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _actualIgathVisLocalDefs
                   {-# LINE 51935 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _actualIgathVisitNames
                   {-# LINE 51940 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOhpp =
                  ({-# LINE 75 "src/TargetHaskell.ag" #-}
                   _actualIhpp
                   {-# LINE 51945 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOisInternal =
                  ({-# LINE 844 "src/Transform.ag" #-}
                   _actualIisInternal
                   {-# LINE 51950 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOjspp =
                  ({-# LINE 35 "src/TargetJs.ag" #-}
                   _actualIjspp
                   {-# LINE 51955 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _actualIlexCounter
                   {-# LINE 51960 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOmbNextVisit =
                  ({-# LINE 1352 "src/Transform.ag" #-}
                   _actualImbNextVisit
                   {-# LINE 51965 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpp =
                  ({-# LINE 2411 "src/Transform.ag" #-}
                   _actualIpp
                   {-# LINE 51970 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 51975 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 51980 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 51985 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 51990 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 51995 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 52000 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 52005 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 52010 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 52015 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 52020 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 52025 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 52030 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 52035 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 52040 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 52045 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 52050 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 52055 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 52060 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 52065 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 52070 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 52075 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 52080 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 52085 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 52090 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 52095 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 52100 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 52105 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 52110 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 52115 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 52120 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 52125 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 52130 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 52135 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 52140 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 52145 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 52150 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 52155 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 52160 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 52165 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 52170 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 52175 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 52180 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 52185 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 52190 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 52195 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 52200 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 52205 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 52210 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 52215 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 52220 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 52225 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 52230 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 52235 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 52240 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 52245 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 52250 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 52255 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 52260 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 52265 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 52270 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 52275 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 52280 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 52285 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 52290 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 52295 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 52300 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 52305 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 52310 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 52315 "src/Transform.hs" #-})
              -- copy rule (down)
              _actualOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 52320 "src/Transform.hs" #-})
              ( _actualIallReqInvokes,_actualIbannedInvokes,_actualIcodeIdCounter,_actualIdistChildDefs,_actualIdistDataCons,_actualIdistDataSems,_actualIdistDatas,_actualIdistDefs,_actualIdistItfs,_actualIdistVisLocalDefs,_actualIdistVisits,_actualIerrs0,_actualIerrs1,_actualIerrs2,_actualIerrs3,_actualIerrs4,_actualIerrs5,_actualIgathAllowCycVisits,_actualIgathAttrSource,_actualIgathAvoidVisits,_actualIgathChildDefs,_actualIgathChildSource,_actualIgathClauses,_actualIgathDataSems,_actualIgathDefs,_actualIgathDeps,_actualIgathItemVisits,_actualIgathLegalCycStmts,_actualIgathMissingInvokes,_actualIgathNonterms,_actualIgathSemAttrSource,_actualIgathSemStarts,_actualIgathStmtPosMap,_actualIgathVisLocalDefs,_actualIgathVisRankMap,_actualIgathVisitAttrs,_actualIgathVisitEnds,_actualIgathVisitNames,_actualIgathVisitSource,_actualIgathVisitStarts,_actualIhpp,_actualIisInternal,_actualIjspp,_actualIlexCounter,_actualImbNextVisit,_actualIminRank,_actualIminReqInvokes,_actualIpp) =
                  actual_inst_ _actualOallAvailInvokes _actualOallVisits _actualOallowCycVisits _actualOavailInvokes _actualObasename _actualOclauseExtras _actualOcoItf _actualOcodeIdCounter _actualOdirectVisitAttrs _actualOdirectVisitLocalAttrs _actualOdistAliasses _actualOdistAllChildMinRanges _actualOdistAttrSource _actualOdistAttrVisMap _actualOdistChildDefs _actualOdistChildEffRanges _actualOdistChildMinRanges _actualOdistChildOcc _actualOdistChildSource _actualOdistCycVisMap _actualOdistDataCons _actualOdistDataMap _actualOdistDataSems _actualOdistDatas _actualOdistDeflStmts _actualOdistDefs _actualOdistInhAttrs _actualOdistItfs _actualOdistNextVisits _actualOdistRanks _actualOdistRenames _actualOdistSynAttrs _actualOdistVisLocalDefs _actualOdistVisRankMap _actualOdistVisitInhAttrs _actualOdistVisitOrder _actualOdistVisitSource _actualOdistVisitSynAttrs _actualOdistVisits _actualOdoneVisits _actualOfullCyclic _actualOfullCyclicVisits _actualOgathChildDefs _actualOgathClauses _actualOgathDataSems _actualOgathDefs _actualOgathNonterms _actualOgathVisLocalDefs _actualOgathVisitNames _actualOhSpilledStmts _actualOindent _actualOitf _actualOjsSpilledStmts _actualOlexCounter _actualOlocalAttrs _actualOmasterPos _actualOmyNextVisits _actualOnextVisits _actualOnonterm _actualOopts _actualOscopeDep _actualOscopeReason _actualOsemBasename _actualOstmtSource _actualOvisit _actualOvisitBeginDep _actualOvisitEndDep _actualOvisitEndReason _actualOvisitNr _actualOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisInternal,_lhsOjspp,_lhsOlexCounter,_lhsOmbNextVisit,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
sem_SemVisit_Internal :: Pos ->
                         Ident ->
                         Bool ->
                         T_Stmts  ->
                         T_ClausesTop  ->
                         T_SemVisit 
sem_SemVisit_Internal pos_ name_ cyclic_ stmts_ clauses_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOisInternal :: Bool
              impls_val_ :: ImplStmts 
              _lhsOmbNextVisit :: (Maybe Ident)
              _stmtsOgathNextVisits :: (Map Ident (Maybe Ident))
              _clausesOdistNextVisits :: (Map Ident (Maybe Ident))
              _lhsOminRank :: Int
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _clausesOhSpilledStmts :: ([(Int,PP_Doc)])
              _lhsOjspp :: PP_Doc
              _clausesOjsSpilledStmts :: ([(Int,PP_Doc)])
              __tup66 :: ((Int,Int))
              _stmtsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _stmtsOallAvailInvokes :: (Map Ident (Set Ident))
              _stmtsOallVisits :: (Set Ident)
              _stmtsOallowCycVisits :: (Set Ident)
              _stmtsOavailInvokes :: (Map Ident (Set Ident))
              _stmtsObasename :: QIdent
              _stmtsOcoItf :: Ident
              _stmtsOcodeIdCounter :: Int
              _stmtsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _stmtsOdirectVisitLocalAttrs :: (Map Ident String)
              _stmtsOdistAliasses :: (Map Ident AliasType)
              _stmtsOdistAllChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistAttrSource :: AttrSourceMap
              _stmtsOdistAttrVisMap :: AttrVisMap
              _stmtsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsOdistChildEffRanges :: (Map Ident (Set Ident))
              _stmtsOdistChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistChildOcc :: (Map Ident Int)
              _stmtsOdistChildSource :: ChildSourceMap
              _stmtsOdistCycVisMap :: CycVisMap
              _stmtsOdistDataCons :: ConEnv
              _stmtsOdistDataMap :: DataMap
              _stmtsOdistDataSems :: DataSemEnv
              _stmtsOdistDatas :: DataEnv
              _stmtsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsOdistDefs :: DefsEnv
              _stmtsOdistInhAttrs :: AttrMap
              _stmtsOdistItfs :: ItfEnv
              _stmtsOdistRanks :: (Map DepItem (Bool,Int))
              _stmtsOdistRenames :: RenameMap
              _stmtsOdistSynAttrs :: AttrMap
              _stmtsOdistVisLocalDefs :: DefsEnv
              _stmtsOdistVisRankMap :: (IntMap Ident)
              _stmtsOdistVisitInhAttrs :: VisitAttrMap
              _stmtsOdistVisitOrder :: (Map Ident [Ident])
              _stmtsOdistVisitSource :: VisitSourceMap
              _stmtsOdistVisitSynAttrs :: VisitAttrMap
              _stmtsOdistVisits :: VisitEnv
              _stmtsOdoneVisits :: ([Ident])
              _stmtsOfullCyclicVisits :: (Set Ident)
              _stmtsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsOgathClauses :: ClausesEnv
              _stmtsOgathDataSems :: DataSemEnv
              _stmtsOgathDefs :: DefsEnv
              _stmtsOgathNonterms :: NontermEnv
              _stmtsOgathVisLocalDefs :: DefsEnv
              _stmtsOhSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOindent :: Int
              _stmtsOitf :: QIdent
              _stmtsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOnonterm :: QIdent
              _stmtsOopts :: Opts
              _stmtsOscopeDep :: DepItem
              _stmtsOscopeReason :: Reason
              _stmtsOstmtSource :: DepItem
              _stmtsOvisitBeginDep :: DepItem
              _stmtsOvisitEndDep :: DepItem
              _stmtsOvisitEndReason :: Reason
              _clausesOallAvailInvokes :: (Map Ident (Set Ident))
              _clausesOallVisits :: (Set Ident)
              _clausesOallowCycVisits :: (Set Ident)
              _clausesOavailInvokes :: (Map Ident (Set Ident))
              _clausesObasename :: QIdent
              _clausesOclauseExtras :: (Map Ident Stmts)
              _clausesOcoItf :: Ident
              _clausesOcodeIdCounter :: Int
              _clausesOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _clausesOdirectVisitLocalAttrs :: (Map Ident String)
              _clausesOdistAliasses :: (Map Ident AliasType)
              _clausesOdistAllChildMinRanges :: (Map Ident [Ident])
              _clausesOdistAttrSource :: AttrSourceMap
              _clausesOdistAttrVisMap :: AttrVisMap
              _clausesOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesOdistChildEffRanges :: (Map Ident (Set Ident))
              _clausesOdistChildMinRanges :: (Map Ident [Ident])
              _clausesOdistChildOcc :: (Map Ident Int)
              _clausesOdistChildSource :: ChildSourceMap
              _clausesOdistCycVisMap :: CycVisMap
              _clausesOdistDataCons :: ConEnv
              _clausesOdistDataMap :: DataMap
              _clausesOdistDataSems :: DataSemEnv
              _clausesOdistDatas :: DataEnv
              _clausesOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _clausesOdistDefs :: DefsEnv
              _clausesOdistInhAttrs :: AttrMap
              _clausesOdistItfs :: ItfEnv
              _clausesOdistRanks :: (Map DepItem (Bool,Int))
              _clausesOdistRenames :: RenameMap
              _clausesOdistSynAttrs :: AttrMap
              _clausesOdistVisLocalDefs :: DefsEnv
              _clausesOdistVisRankMap :: (IntMap Ident)
              _clausesOdistVisitInhAttrs :: VisitAttrMap
              _clausesOdistVisitOrder :: (Map Ident [Ident])
              _clausesOdistVisitSource :: VisitSourceMap
              _clausesOdistVisitSynAttrs :: VisitAttrMap
              _clausesOdistVisits :: VisitEnv
              _clausesOdoneVisits :: ([Ident])
              _clausesOfullCyclic :: Bool
              _clausesOfullCyclicVisits :: (Set Ident)
              _clausesOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesOgathClauses :: ClausesEnv
              _clausesOgathDataSems :: DataSemEnv
              _clausesOgathDefs :: DefsEnv
              _clausesOgathNonterms :: NontermEnv
              _clausesOgathVisLocalDefs :: DefsEnv
              _clausesOgathVisitNames :: (Env Ident ())
              _clausesOindent :: Int
              _clausesOitf :: QIdent
              _clausesOlexCounter :: Int
              _clausesOlocalAttrs :: (Map Ident String)
              _clausesOmasterPos :: Pos
              _clausesOmyNextVisits :: (Map Ident (Maybe Ident))
              _clausesOnextVisits :: ([Ident])
              _clausesOnonterm :: QIdent
              _clausesOopts :: Opts
              _clausesOscopeDep :: DepItem
              _clausesOscopeReason :: Reason
              _clausesOsemBasename :: QIdent
              _clausesOstmtSource :: DepItem
              _clausesOvisit :: Ident
              _clausesOvisitBeginDep :: DepItem
              _clausesOvisitEndDep :: DepItem
              _clausesOvisitEndReason :: Reason
              _clausesOvisitNr :: Int
              _clausesOwithinCoSem :: Bool
              _implsOallAvailInvokes :: (Map Ident (Set Ident))
              _implsOallVisits :: (Set Ident)
              _implsOallowCycVisits :: (Set Ident)
              _implsOavailInvokes :: (Map Ident (Set Ident))
              _implsObasename :: QIdent
              _implsOcoItf :: Ident
              _implsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _implsOdirectVisitLocalAttrs :: (Map Ident String)
              _implsOdistAliasses :: (Map Ident AliasType)
              _implsOdistAllChildMinRanges :: (Map Ident [Ident])
              _implsOdistAttrSource :: AttrSourceMap
              _implsOdistAttrVisMap :: AttrVisMap
              _implsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOdistChildEffRanges :: (Map Ident (Set Ident))
              _implsOdistChildMinRanges :: (Map Ident [Ident])
              _implsOdistChildOcc :: (Map Ident Int)
              _implsOdistChildSource :: ChildSourceMap
              _implsOdistCycVisMap :: CycVisMap
              _implsOdistDataCons :: ConEnv
              _implsOdistDataMap :: DataMap
              _implsOdistDataSems :: DataEnv
              _implsOdistDatas :: DataEnv
              _implsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _implsOdistDefs :: DefsEnv
              _implsOdistInhAttrs :: AttrMap
              _implsOdistItfs :: ItfEnv
              _implsOdistRanks :: (Map DepItem (Bool,Int))
              _implsOdistRenames :: RenameMap
              _implsOdistSynAttrs :: AttrMap
              _implsOdistVisLocalDefs :: DefsEnv
              _implsOdistVisRankMap :: (IntMap Ident)
              _implsOdistVisitInhAttrs :: VisitAttrMap
              _implsOdistVisitOrder :: (Map Ident [Ident])
              _implsOdistVisitSource :: VisitSourceMap
              _implsOdistVisitSynAttrs :: VisitAttrMap
              _implsOdistVisits :: VisitEnv
              _implsOdoneVisits :: ([Ident])
              _implsOfullCyclicVisits :: (Set Ident)
              _implsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOgathClauses :: ClausesEnv
              _implsOgathDefs :: DefsEnv
              _implsOgathNextVisits :: (Map Ident (Maybe Ident))
              _implsOgathNonterms :: NontermEnv
              _implsOgathVisLocalDefs :: DefsEnv
              _implsOhSpilledStmts :: ([(Int,PP_Doc)])
              _implsOitf :: QIdent
              _implsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _implsOlexCounter :: Int
              _implsOnonterm :: QIdent
              _implsOopts :: Opts
              _implsOscopeDep :: DepItem
              _implsOscopeReason :: Reason
              _implsOstmtSource :: DepItem
              _implsOvisitBeginDep :: DepItem
              _implsOvisitEndDep :: DepItem
              _implsOvisitEndReason :: Reason
              _stmtsIallReqInvokes :: (Map Ident (Set Ident))
              _stmtsIbannedInvokes :: (Map Ident (Set Ident))
              _stmtsIcodeIdCounter :: Int
              _stmtsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsIdistDataCons :: ConEnv
              _stmtsIdistDataSems :: DataSemEnv
              _stmtsIdistDatas :: DataEnv
              _stmtsIdistDefs :: DefsEnv
              _stmtsIdistItfs :: ItfEnv
              _stmtsIdistVisLocalDefs :: DefsEnv
              _stmtsIdistVisits :: VisitEnv
              _stmtsIerrs0 :: Errs
              _stmtsIerrs1 :: Errs
              _stmtsIerrs2 :: Errs
              _stmtsIerrs3 :: Errs
              _stmtsIerrs4 :: Errs
              _stmtsIerrs5 :: Errs
              _stmtsIexplInvokes :: (Map Ident (Set Ident))
              _stmtsIgathAttrSource :: AttrSourceMap
              _stmtsIgathAvoidVisits :: (Set DepItem)
              _stmtsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsIgathChildEffRanges :: (Map Ident (Set Ident))
              _stmtsIgathChildMinRanges :: (Map Ident [Ident])
              _stmtsIgathChildOcc :: (Map Ident Int)
              _stmtsIgathChildSource :: ChildSourceMap
              _stmtsIgathClauses :: ClausesEnv
              _stmtsIgathDataSems :: DataSemEnv
              _stmtsIgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsIgathDefs :: DefsEnv
              _stmtsIgathDeps :: Deps
              _stmtsIgathItemVisits :: (Map DepItem DepItem)
              _stmtsIgathLegalCycStmts :: (Set DepItem)
              _stmtsIgathMissingInvokes :: (Set (Ident,Ident))
              _stmtsIgathNextVisits :: (Map Ident (Maybe Ident))
              _stmtsIgathNonterms :: NontermEnv
              _stmtsIgathRenames :: RenameMap
              _stmtsIgathSemStarts :: (Seq DepItem)
              _stmtsIgathStmtPosMap :: (Map DepItem Pos)
              _stmtsIgathVisLocalDefs :: DefsEnv
              _stmtsIgathVisitEnds :: (Seq DepItem)
              _stmtsIgathVisitSource :: VisitSourceMap
              _stmtsIgathVisitStarts :: (Seq DepItem)
              _stmtsIhopps :: ([(Int, PP_Doc)])
              _stmtsIjsopps :: ([(Int, PP_Doc)])
              _stmtsIlexCounter :: Int
              _stmtsIminReqInvokes :: (Map Ident (Set Ident))
              _stmtsIpps :: ([PP_Doc])
              _clausesIallReqInvokes :: (Map Ident (Set Ident))
              _clausesIbannedInvokes :: (Map Ident (Set Ident))
              _clausesIcodeIdCounter :: Int
              _clausesIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesIdistDataCons :: ConEnv
              _clausesIdistDataSems :: DataSemEnv
              _clausesIdistDatas :: DataEnv
              _clausesIdistDefs :: DefsEnv
              _clausesIdistItfs :: ItfEnv
              _clausesIdistVisLocalDefs :: DefsEnv
              _clausesIdistVisits :: VisitEnv
              _clausesIerrs0 :: Errs
              _clausesIerrs1 :: Errs
              _clausesIerrs2 :: Errs
              _clausesIerrs3 :: Errs
              _clausesIerrs4 :: Errs
              _clausesIerrs5 :: Errs
              _clausesIgathAllowCycVisits :: (Set Ident)
              _clausesIgathAttrSource :: AttrSourceMap
              _clausesIgathAvoidVisits :: (Set DepItem)
              _clausesIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesIgathChildSource :: ChildSourceMap
              _clausesIgathClauseNames :: (Set Ident)
              _clausesIgathClauses :: ClausesEnv
              _clausesIgathDataSems :: DataSemEnv
              _clausesIgathDefs :: DefsEnv
              _clausesIgathDeps :: Deps
              _clausesIgathItemVisits :: (Map DepItem DepItem)
              _clausesIgathLegalCycStmts :: (Set DepItem)
              _clausesIgathMissingInvokes :: (Set (Ident,Ident))
              _clausesIgathNonterms :: NontermEnv
              _clausesIgathSemAttrSource :: AttrSourceMap
              _clausesIgathSemStarts :: (Seq DepItem)
              _clausesIgathStmtPosMap :: (Map DepItem Pos)
              _clausesIgathVisLocalDefs :: DefsEnv
              _clausesIgathVisRankMap :: (IntMap Ident)
              _clausesIgathVisitAttrs :: (Map Ident (Map Ident String))
              _clausesIgathVisitEnds :: (Seq DepItem)
              _clausesIgathVisitNames :: (Env Ident ())
              _clausesIgathVisitSource :: VisitSourceMap
              _clausesIgathVisitStarts :: (Seq DepItem)
              _clausesIhpp :: PP_Doc
              _clausesIjspp :: PP_Doc
              _clausesIlexCounter :: Int
              _clausesIminRank :: Int
              _clausesIminReqInvokes :: (Map Ident (Set Ident))
              _clausesInClauses :: Int
              _clausesIpps :: ([PP_Doc])
              _implsIdistDefs :: DefsEnv
              _implsIdistVisLocalDefs :: DefsEnv
              _implsIerrs2 :: Errs
              _implsIerrs3 :: Errs
              _implsIerrs4 :: Errs
              _implsIerrs5 :: Errs
              _implsIgathAttrSource :: AttrSourceMap
              _implsIgathChildSource :: ChildSourceMap
              _implsIgathDefs :: DefsEnv
              _implsIgathDeps :: Deps
              _implsIgathItemVisits :: (Map DepItem DepItem)
              _implsIgathLegalCycStmts :: (Set DepItem)
              _implsIgathNextVisits :: (Map Ident (Maybe Ident))
              _implsIgathStmtPosMap :: (Map DepItem Pos)
              _implsIgathVisLocalDefs :: DefsEnv
              _implsIgathVisitSource :: VisitSourceMap
              _implsIhopps :: ([(Int, PP_Doc)])
              _implsIjsopps :: ([(Int, PP_Doc)])
              _implsIlexCounter :: Int
              _implsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsObannedInvokes =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   foldr ($) _bannedInvokes_augmented_syn [_bannedInvokes_augmented_f1]
                   {-# LINE 52756 "src/Transform.hs" #-})
              -- augment function
              _bannedInvokes_augmented_f1 =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   _stmtsIexplInvokes `unionWithUnion`
                   {-# LINE 52761 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 52766 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   if _fullCyclic     && _nClauses     /= 1 && not _lhsIwithinCoSem
                   then (Err_ClausesCyclic pos_ name_ _nClauses     Seq.<|)
                   else id
                   {-# LINE 52773 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 52778 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   Seq.fromList (map (\(nm,vs) -> Err_MissingVisit pos_ nm vs) _missingInvokes    ) Seq.><
                   {-# LINE 52783 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1910 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1]
                   {-# LINE 52788 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1910 "src/Transform.ag" #-}
                   if _lhsIfullCyclic
                   then (Err_InternalInCyclic pos_ name_ Seq.<|)
                   else id
                   {-# LINE 52795 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1920 "src/Transform.ag" #-}
                   foldr ($) _gathAllowCycVisits_augmented_syn [_gathAllowCycVisits_augmented_f1]
                   {-# LINE 52800 "src/Transform.hs" #-})
              -- augment function
              _gathAllowCycVisits_augmented_f1 =
                  ({-# LINE 1920 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _name     else id
                   {-# LINE 52805 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2304 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 52810 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2304 "src/Transform.ag" #-}
                   addDep _visitEndDep     (ReasonScopeVisit name_) [_scopeDep    ]
                   {-# LINE 52815 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2304 "src/Transform.ag" #-}
                   addDep _scopeDep     _lhsIvisitEndReason [_lhsIvisitEndDep]
                   {-# LINE 52820 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 52825 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   Map.insert _scopeDep     _scopeDep
                   {-# LINE 52830 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisRankMap =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   foldr ($) _gathVisRankMap_augmented_syn [_gathVisRankMap_augmented_f1]
                   {-# LINE 52835 "src/Transform.hs" #-})
              -- augment function
              _gathVisRankMap_augmented_f1 =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   IntMap.insert _rank     name_
                   {-# LINE 52840 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitEnds =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   foldr ($) _gathVisitEnds_augmented_syn [_gathVisitEnds_augmented_f1]
                   {-# LINE 52845 "src/Transform.hs" #-})
              -- augment function
              _gathVisitEnds_augmented_f1 =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   _visitEndDep     Seq.<|
                   {-# LINE 52850 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitNames =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   foldr ($) _gathVisitNames_augmented_syn [_gathVisitNames_augmented_f1]
                   {-# LINE 52855 "src/Transform.hs" #-})
              -- augment function
              _gathVisitNames_augmented_f1 =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   extend name_ ()
                   {-# LINE 52860 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitStarts =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   foldr ($) _gathVisitStarts_augmented_syn [_gathVisitStarts_augmented_f1]
                   {-# LINE 52865 "src/Transform.hs" #-})
              -- augment function
              _gathVisitStarts_augmented_f1 =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   _scopeDep       Seq.<|
                   {-# LINE 52870 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 603, column 26)
              _distRenames =
                  ({-# LINE 603 "src/Transform.ag" #-}
                   _stmtsIgathRenames `unionWithUnion` _lhsIdistRenames
                   {-# LINE 52875 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 743, column 12)
              _name =
                  ({-# LINE 743 "src/Transform.ag" #-}
                   Ident (show name_ ++ "_int" ++ show _lexOrder    ) (identPos name_)
                   {-# LINE 52880 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 744, column 12)
              _unqualItf =
                  ({-# LINE 744 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 52885 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 766, column 32)
              _masterPos =
                  ({-# LINE 766 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 52890 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 847, column 15)
              _lhsOisInternal =
                  ({-# LINE 847 "src/Transform.ag" #-}
                   True
                   {-# LINE 52895 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1193, column 3)
              impls_val_ =
                  ({-# LINE 1193 "src/Transform.ag" #-}
                   [ ImplStmt_Invoke pos_ nm s (findChild nm _lhsIdistChildDefs)
                   | (nm,vs) <- Map.assocs _implicitInvokes    , s <- Set.toList vs ]
                   {-# LINE 52901 "src/Transform.hs" #-})
              impls_inst_ =
                  (sem_ImplStmts impls_val_ )
              -- "src/Transform.ag"(line 1313, column 32)
              _distChildOcc =
                  ({-# LINE 1313 "src/Transform.ag" #-}
                   _stmtsIgathChildOcc `unionWithMin` _lhsIdistChildOcc
                   {-# LINE 52908 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1349, column 32)
              _itfNm =
                  ({-# LINE 1349 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 52913 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1354, column 21)
              _lhsOmbNextVisit =
                  ({-# LINE 1354 "src/Transform.ag" #-}
                   Just name_
                   {-# LINE 52918 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1560, column 3)
              _stmtsOgathNextVisits =
                  ({-# LINE 1560 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 52923 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1561, column 3)
              _clausesOdistNextVisits =
                  ({-# LINE 1561 "src/Transform.ag" #-}
                   _implsIgathNextVisits `Map.union` _lhsIdistNextVisits
                   {-# LINE 52928 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1626, column 3)
              _distChildMinRanges =
                  ({-# LINE 1626 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `unionWithPlusplus` _lhsIdistChildMinRanges
                   {-# LINE 52933 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1627, column 3)
              _distAllChildMinRanges =
                  ({-# LINE 1627 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `Map.union` _lhsIdistChildMinRanges
                   {-# LINE 52938 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1628, column 3)
              _distChildEffRanges =
                  ({-# LINE 1628 "src/Transform.ag" #-}
                   _stmtsIgathChildEffRanges `unionWithUnion` _lhsIdistChildEffRanges
                   {-# LINE 52943 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1629, column 3)
              _introChildren =
                  ({-# LINE 1629 "src/Transform.ag" #-}
                   Map.keysSet (Map.difference _stmtsIgathChildMinRanges _lhsIdistAllChildMinRanges)
                   {-# LINE 52948 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1678, column 3)
              _minReqInvokes1 =
                  ({-# LINE 1678 "src/Transform.ag" #-}
                   _stmtsIminReqInvokes `unionWithUnion` _clausesIminReqInvokes
                   {-# LINE 52953 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1679, column 3)
              _allReqInvokes1 =
                  ({-# LINE 1679 "src/Transform.ag" #-}
                   _stmtsIallReqInvokes `unionWithUnion` _clausesIallReqInvokes
                   {-# LINE 52958 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1680, column 3)
              _minReqInvokes =
                  ({-# LINE 1680 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _minReqInvokes1
                   {-# LINE 52963 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1681, column 3)
              _allReqInvokes =
                  ({-# LINE 1681 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _allReqInvokes1
                   {-# LINE 52968 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1757, column 3)
              _implicitInvokes =
                  ({-# LINE 1757 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _lhsIavailInvokes
                                       `diffInside` _stmtsIexplInvokes
                                       `diffInside` _clausesIbannedInvokes
                   {-# LINE 52975 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1760, column 3)
              _additionalInvokes =
                  ({-# LINE 1760 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _clausesIbannedInvokes `unionWithUnion` _stmtsIexplInvokes
                   {-# LINE 52980 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1761, column 3)
              _availInvokes =
                  ({-# LINE 1761 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` _lhsIavailInvokes
                   {-# LINE 52985 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1762, column 3)
              _allAvailInvokes =
                  ({-# LINE 1762 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` (
                     Map.filterWithKey (notIn _introChildren    ) _lhsIallAvailInvokes )
                   {-# LINE 52991 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1801, column 3)
              _missingInvokes =
                  ({-# LINE 1801 "src/Transform.ag" #-}
                   Set.toList (_stmtsIgathMissingInvokes `Set.difference` _clausesIgathMissingInvokes)
                   {-# LINE 52996 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1822, column 32)
              _distDeflStmts =
                  ({-# LINE 1822 "src/Transform.ag" #-}
                   _stmtsIgathDeflStmts `Map.union` _lhsIdistDeflStmts
                   {-# LINE 53001 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1908, column 3)
              _fullCyclic =
                  ({-# LINE 1908 "src/Transform.ag" #-}
                   False
                   {-# LINE 53006 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1909, column 3)
              _allowCycles =
                  ({-# LINE 1909 "src/Transform.ag" #-}
                   cyclic_
                   {-# LINE 53011 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1967, column 3)
              _nClauses =
                  ({-# LINE 1967 "src/Transform.ag" #-}
                   Set.size _clausesIgathClauseNames
                   {-# LINE 53016 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2061, column 25)
              _distAttrSource =
                  ({-# LINE 2061 "src/Transform.ag" #-}
                   Map.unions [ _stmtsIgathAttrSource
                              , _implsIgathAttrSource
                              , _lhsIdistAttrSource ]
                   {-# LINE 53023 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2116, column 3)
              _distChildSource =
                  ({-# LINE 2116 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathChildSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistChildSource ]
                   {-# LINE 53029 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2135, column 3)
              _distVisitSource =
                  ({-# LINE 2135 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathVisitSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistVisitSource ]
                   {-# LINE 53035 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2166, column 3)
              _scopeReason =
                  ({-# LINE 2166 "src/Transform.ag" #-}
                   ReasonScopeVisit name_
                   {-# LINE 53040 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2167, column 3)
              _scopeDep =
                  ({-# LINE 2167 "src/Transform.ag" #-}
                   DepVisStart (_name     : _lhsIsemBasename)
                   {-# LINE 53045 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2168, column 3)
              _visitBeginDep =
                  ({-# LINE 2168 "src/Transform.ag" #-}
                   DepVisStart (_name     : _lhsIsemBasename)
                   {-# LINE 53050 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2169, column 3)
              _visitEndDep =
                  ({-# LINE 2169 "src/Transform.ag" #-}
                   DepVisEnd   (_name     : _lhsIsemBasename)
                   {-# LINE 53055 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2170, column 3)
              _visitEndReason =
                  ({-# LINE 2170 "src/Transform.ag" #-}
                   ReasonScopeEnd name_
                   {-# LINE 53060 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              __tup63 =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _scopeDep     _lhsIdistRanks
                   {-# LINE 53065 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   __tup63
                   {-# LINE 53070 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              (_,_rank) =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   __tup63
                   {-# LINE 53075 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2388, column 3)
              _isCyclic =
                  ({-# LINE 2388 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 53080 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2398, column 32)
              _lhsOminRank =
                  ({-# LINE 2398 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 53085 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2520, column 18)
              _lhsOpp =
                  ({-# LINE 2520 "src/Transform.ag" #-}
                   "internal" >#< name_
                   >-< indent 2 (   vlist _stmtsIpps
                                >-< vlist _clausesIpps
                                )
                   {-# LINE 53093 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 298, column 18)
              _lhsOhpp =
                  ({-# LINE 298 "src/TargetHaskell.ag" #-}
                   hppStmtBlock _hGroupedStmts
                   >-< _clausesIhpp
                   {-# LINE 53099 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              __tup64 =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   partition (rankIsLower _clausesIminRank)
                     (_lhsIhSpilledStmts ++ _implsIhopps ++ _stmtsIhopps)
                   {-# LINE 53105 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              (_hoStmts,_) =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   __tup64
                   {-# LINE 53110 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              (_,_clausesOhSpilledStmts) =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   __tup64
                   {-# LINE 53115 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 596, column 3)
              _hGroupedStmts =
                  ({-# LINE 596 "src/TargetHaskell.ag" #-}
                   groupPairs _hoStmts
                   {-# LINE 53120 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 177, column 18)
              _lhsOjspp =
                  ({-# LINE 177 "src/TargetJs.ag" #-}
                   jsppStmtBlock _jsGroupedStmts
                   >-< _clausesIjspp
                   {-# LINE 53126 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              __tup65 =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   partition (rankIsLower _clausesIminRank)
                     (_lhsIjsSpilledStmts ++ _implsIjsopps ++ _stmtsIjsopps)
                   {-# LINE 53132 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              (_jsoStmts,_) =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   __tup65
                   {-# LINE 53137 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              (_,_clausesOjsSpilledStmts) =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   __tup65
                   {-# LINE 53142 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 391, column 3)
              _jsGroupedStmts =
                  ({-# LINE 391 "src/TargetJs.ag" #-}
                   groupPairs _jsoStmts
                   {-# LINE 53147 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup66 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_stmtsOlexCounter,_) =
                  ({-# LINE 1288 "src/Transform.ag" #-}
                   __tup66
                   {-# LINE 53155 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1288 "src/Transform.ag" #-}
                   __tup66
                   {-# LINE 53160 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _allReqInvokes
                   {-# LINE 53165 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _bannedInvokes_augmented_syn =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   _stmtsIbannedInvokes `unionWithUnion` _clausesIbannedInvokes
                   {-# LINE 53170 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs0 Seq.>< _clausesIerrs0
                   {-# LINE 53175 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   _stmtsIerrs1 Seq.>< _clausesIerrs1
                   {-# LINE 53180 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   _stmtsIerrs2 Seq.>< _clausesIerrs2 Seq.>< _implsIerrs2
                   {-# LINE 53185 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1910 "src/Transform.ag" #-}
                   _stmtsIerrs3 Seq.>< _clausesIerrs3 Seq.>< _implsIerrs3
                   {-# LINE 53190 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs4 Seq.>< _clausesIerrs4 Seq.>< _implsIerrs4
                   {-# LINE 53195 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs5 Seq.>< _clausesIerrs5 Seq.>< _implsIerrs5
                   {-# LINE 53200 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _gathAllowCycVisits_augmented_syn =
                  ({-# LINE 1920 "src/Transform.ag" #-}
                   _clausesIgathAllowCycVisits
                   {-# LINE 53205 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _stmtsIgathAttrSource `Map.union` _clausesIgathAttrSource `Map.union` _implsIgathAttrSource
                   {-# LINE 53210 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _stmtsIgathAvoidVisits `Set.union` _clausesIgathAvoidVisits
                   {-# LINE 53215 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _stmtsIgathChildSource `unionWithUnion` _clausesIgathChildSource `unionWithUnion` _implsIgathChildSource
                   {-# LINE 53220 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2304 "src/Transform.ag" #-}
                   _stmtsIgathDeps Seq.>< _clausesIgathDeps Seq.>< _implsIgathDeps
                   {-# LINE 53225 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   _stmtsIgathItemVisits `Map.union` _clausesIgathItemVisits `Map.union` _implsIgathItemVisits
                   {-# LINE 53230 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _stmtsIgathLegalCycStmts `Set.union` _clausesIgathLegalCycStmts `Set.union` _implsIgathLegalCycStmts
                   {-# LINE 53235 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _stmtsIgathMissingInvokes `Set.union` _clausesIgathMissingInvokes
                   {-# LINE 53240 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _clausesIgathSemAttrSource
                   {-# LINE 53245 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _stmtsIgathSemStarts Seq.>< _clausesIgathSemStarts
                   {-# LINE 53250 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _stmtsIgathStmtPosMap `Map.union` _clausesIgathStmtPosMap `Map.union` _implsIgathStmtPosMap
                   {-# LINE 53255 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _gathVisRankMap_augmented_syn =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   _clausesIgathVisRankMap
                   {-# LINE 53260 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _clausesIgathVisitAttrs
                   {-# LINE 53265 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _gathVisitEnds_augmented_syn =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   _stmtsIgathVisitEnds Seq.>< _clausesIgathVisitEnds
                   {-# LINE 53270 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _stmtsIgathVisitSource `unionWithUnion` _clausesIgathVisitSource `unionWithUnion` _implsIgathVisitSource
                   {-# LINE 53275 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _gathVisitStarts_augmented_syn =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   _stmtsIgathVisitStarts Seq.>< _clausesIgathVisitStarts
                   {-# LINE 53280 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _minReqInvokes
                   {-# LINE 53285 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _clausesIcodeIdCounter
                   {-# LINE 53290 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 53295 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 53300 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 53305 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 53310 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIdistDefs
                   {-# LINE 53315 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 53320 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIdistVisLocalDefs
                   {-# LINE 53325 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 53330 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 53335 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 53340 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _clausesIgathDataSems
                   {-# LINE 53345 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIgathDefs
                   {-# LINE 53350 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 53355 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIgathVisLocalDefs
                   {-# LINE 53360 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathVisitNames_augmented_syn =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   _clausesIgathVisitNames
                   {-# LINE 53365 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _implsIlexCounter
                   {-# LINE 53370 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 53375 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 53380 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 53385 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 53390 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 53395 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 53400 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 53405 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 53410 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 53415 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 53420 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 53425 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 53430 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 53435 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 53440 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 53445 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 53450 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 53455 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 53460 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 53465 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 53470 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 53475 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 53480 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 53485 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 53490 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 53495 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 53500 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 53505 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 53510 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 53515 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 53520 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 53525 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 53530 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 53535 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 53540 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 53545 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 53550 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 53555 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 53560 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 53565 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 53570 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 53575 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 53580 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 53585 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 53590 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 53595 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 53600 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 53605 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 53610 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 53615 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 53620 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 53625 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 53630 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 53635 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 53640 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 53645 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 53650 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 53655 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 53660 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 53665 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 53670 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 53675 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 53680 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 53685 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 53690 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _stmtsIcodeIdCounter
                   {-# LINE 53695 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 53700 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 53705 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 53710 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 53715 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 53720 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 53725 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _stmtsIdistChildDefs
                   {-# LINE 53730 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 53735 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 53740 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 53745 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 53750 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 53755 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _stmtsIdistDataCons
                   {-# LINE 53760 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 53765 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _stmtsIdistDataSems
                   {-# LINE 53770 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _stmtsIdistDatas
                   {-# LINE 53775 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 53780 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIdistDefs
                   {-# LINE 53785 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 53790 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _stmtsIdistItfs
                   {-# LINE 53795 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 53800 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 53805 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 53810 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIdistVisLocalDefs
                   {-# LINE 53815 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 53820 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 53825 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 53830 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 53835 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 53840 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _stmtsIdistVisits
                   {-# LINE 53845 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 53850 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _fullCyclic
                   {-# LINE 53855 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 53860 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _stmtsIgathChildDefs
                   {-# LINE 53865 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathClauses
                   {-# LINE 53870 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _stmtsIgathDataSems
                   {-# LINE 53875 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIgathDefs
                   {-# LINE 53880 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathNonterms
                   {-# LINE 53885 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIgathVisLocalDefs
                   {-# LINE 53890 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 53895 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 53900 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 53905 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _stmtsIlexCounter
                   {-# LINE 53910 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 53915 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _masterPos
                   {-# LINE 53920 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 53925 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 53930 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 53935 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 53940 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 53945 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 53950 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 53955 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 53960 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 53965 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 53970 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 53975 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 53980 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 53985 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 53990 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 53995 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 54000 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 54005 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 54010 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 54015 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 54020 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 54025 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 54030 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 54035 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 54040 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 54045 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 54050 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 54055 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 54060 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 54065 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 54070 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 54075 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 54080 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 54085 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 54090 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 54095 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 54100 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 54105 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistDefs
                   {-# LINE 54110 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 54115 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 54120 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 54125 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 54130 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 54135 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistVisLocalDefs
                   {-# LINE 54140 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 54145 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 54150 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 54155 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 54160 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 54165 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 54170 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 54175 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 54180 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 54185 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 54190 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathDefs
                   {-# LINE 54195 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _stmtsIgathNextVisits
                   {-# LINE 54200 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 54205 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathVisLocalDefs
                   {-# LINE 54210 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 54215 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 54220 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 54225 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _clausesIlexCounter
                   {-# LINE 54230 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 54235 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 54240 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 54245 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 54250 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 54255 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 54260 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 54265 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 54270 "src/Transform.hs" #-})
              ( _stmtsIallReqInvokes,_stmtsIbannedInvokes,_stmtsIcodeIdCounter,_stmtsIdistChildDefs,_stmtsIdistDataCons,_stmtsIdistDataSems,_stmtsIdistDatas,_stmtsIdistDefs,_stmtsIdistItfs,_stmtsIdistVisLocalDefs,_stmtsIdistVisits,_stmtsIerrs0,_stmtsIerrs1,_stmtsIerrs2,_stmtsIerrs3,_stmtsIerrs4,_stmtsIerrs5,_stmtsIexplInvokes,_stmtsIgathAttrSource,_stmtsIgathAvoidVisits,_stmtsIgathChildDefs,_stmtsIgathChildEffRanges,_stmtsIgathChildMinRanges,_stmtsIgathChildOcc,_stmtsIgathChildSource,_stmtsIgathClauses,_stmtsIgathDataSems,_stmtsIgathDeflStmts,_stmtsIgathDefs,_stmtsIgathDeps,_stmtsIgathItemVisits,_stmtsIgathLegalCycStmts,_stmtsIgathMissingInvokes,_stmtsIgathNextVisits,_stmtsIgathNonterms,_stmtsIgathRenames,_stmtsIgathSemStarts,_stmtsIgathStmtPosMap,_stmtsIgathVisLocalDefs,_stmtsIgathVisitEnds,_stmtsIgathVisitSource,_stmtsIgathVisitStarts,_stmtsIhopps,_stmtsIjsopps,_stmtsIlexCounter,_stmtsIminReqInvokes,_stmtsIpps) =
                  stmts_ _stmtsOallAvailInvokes _stmtsOallVisits _stmtsOallowCycVisits _stmtsOavailInvokes _stmtsObasename _stmtsOcoItf _stmtsOcodeIdCounter _stmtsOdirectVisitAttrs _stmtsOdirectVisitLocalAttrs _stmtsOdistAliasses _stmtsOdistAllChildMinRanges _stmtsOdistAttrSource _stmtsOdistAttrVisMap _stmtsOdistChildDefs _stmtsOdistChildEffRanges _stmtsOdistChildMinRanges _stmtsOdistChildOcc _stmtsOdistChildSource _stmtsOdistCycVisMap _stmtsOdistDataCons _stmtsOdistDataMap _stmtsOdistDataSems _stmtsOdistDatas _stmtsOdistDeflStmts _stmtsOdistDefs _stmtsOdistInhAttrs _stmtsOdistItfs _stmtsOdistRanks _stmtsOdistRenames _stmtsOdistSynAttrs _stmtsOdistVisLocalDefs _stmtsOdistVisRankMap _stmtsOdistVisitInhAttrs _stmtsOdistVisitOrder _stmtsOdistVisitSource _stmtsOdistVisitSynAttrs _stmtsOdistVisits _stmtsOdoneVisits _stmtsOfullCyclicVisits _stmtsOgathChildDefs _stmtsOgathClauses _stmtsOgathDataSems _stmtsOgathDefs _stmtsOgathNextVisits _stmtsOgathNonterms _stmtsOgathVisLocalDefs _stmtsOhSpilledStmts _stmtsOindent _stmtsOitf _stmtsOjsSpilledStmts _stmtsOlexCounter _stmtsOnonterm _stmtsOopts _stmtsOscopeDep _stmtsOscopeReason _stmtsOstmtSource _stmtsOvisitBeginDep _stmtsOvisitEndDep _stmtsOvisitEndReason 
              ( _clausesIallReqInvokes,_clausesIbannedInvokes,_clausesIcodeIdCounter,_clausesIdistChildDefs,_clausesIdistDataCons,_clausesIdistDataSems,_clausesIdistDatas,_clausesIdistDefs,_clausesIdistItfs,_clausesIdistVisLocalDefs,_clausesIdistVisits,_clausesIerrs0,_clausesIerrs1,_clausesIerrs2,_clausesIerrs3,_clausesIerrs4,_clausesIerrs5,_clausesIgathAllowCycVisits,_clausesIgathAttrSource,_clausesIgathAvoidVisits,_clausesIgathChildDefs,_clausesIgathChildSource,_clausesIgathClauseNames,_clausesIgathClauses,_clausesIgathDataSems,_clausesIgathDefs,_clausesIgathDeps,_clausesIgathItemVisits,_clausesIgathLegalCycStmts,_clausesIgathMissingInvokes,_clausesIgathNonterms,_clausesIgathSemAttrSource,_clausesIgathSemStarts,_clausesIgathStmtPosMap,_clausesIgathVisLocalDefs,_clausesIgathVisRankMap,_clausesIgathVisitAttrs,_clausesIgathVisitEnds,_clausesIgathVisitNames,_clausesIgathVisitSource,_clausesIgathVisitStarts,_clausesIhpp,_clausesIjspp,_clausesIlexCounter,_clausesIminRank,_clausesIminReqInvokes,_clausesInClauses,_clausesIpps) =
                  clauses_ _clausesOallAvailInvokes _clausesOallVisits _clausesOallowCycVisits _clausesOavailInvokes _clausesObasename _clausesOclauseExtras _clausesOcoItf _clausesOcodeIdCounter _clausesOdirectVisitAttrs _clausesOdirectVisitLocalAttrs _clausesOdistAliasses _clausesOdistAllChildMinRanges _clausesOdistAttrSource _clausesOdistAttrVisMap _clausesOdistChildDefs _clausesOdistChildEffRanges _clausesOdistChildMinRanges _clausesOdistChildOcc _clausesOdistChildSource _clausesOdistCycVisMap _clausesOdistDataCons _clausesOdistDataMap _clausesOdistDataSems _clausesOdistDatas _clausesOdistDeflStmts _clausesOdistDefs _clausesOdistInhAttrs _clausesOdistItfs _clausesOdistNextVisits _clausesOdistRanks _clausesOdistRenames _clausesOdistSynAttrs _clausesOdistVisLocalDefs _clausesOdistVisRankMap _clausesOdistVisitInhAttrs _clausesOdistVisitOrder _clausesOdistVisitSource _clausesOdistVisitSynAttrs _clausesOdistVisits _clausesOdoneVisits _clausesOfullCyclic _clausesOfullCyclicVisits _clausesOgathChildDefs _clausesOgathClauses _clausesOgathDataSems _clausesOgathDefs _clausesOgathNonterms _clausesOgathVisLocalDefs _clausesOgathVisitNames _clausesOhSpilledStmts _clausesOindent _clausesOitf _clausesOjsSpilledStmts _clausesOlexCounter _clausesOlocalAttrs _clausesOmasterPos _clausesOmyNextVisits _clausesOnextVisits _clausesOnonterm _clausesOopts _clausesOscopeDep _clausesOscopeReason _clausesOsemBasename _clausesOstmtSource _clausesOvisit _clausesOvisitBeginDep _clausesOvisitEndDep _clausesOvisitEndReason _clausesOvisitNr _clausesOwithinCoSem 
              ( _implsIdistDefs,_implsIdistVisLocalDefs,_implsIerrs2,_implsIerrs3,_implsIerrs4,_implsIerrs5,_implsIgathAttrSource,_implsIgathChildSource,_implsIgathDefs,_implsIgathDeps,_implsIgathItemVisits,_implsIgathLegalCycStmts,_implsIgathNextVisits,_implsIgathStmtPosMap,_implsIgathVisLocalDefs,_implsIgathVisitSource,_implsIhopps,_implsIjsopps,_implsIlexCounter,_implsIpps) =
                  impls_inst_ _implsOallAvailInvokes _implsOallVisits _implsOallowCycVisits _implsOavailInvokes _implsObasename _implsOcoItf _implsOdirectVisitAttrs _implsOdirectVisitLocalAttrs _implsOdistAliasses _implsOdistAllChildMinRanges _implsOdistAttrSource _implsOdistAttrVisMap _implsOdistChildDefs _implsOdistChildEffRanges _implsOdistChildMinRanges _implsOdistChildOcc _implsOdistChildSource _implsOdistCycVisMap _implsOdistDataCons _implsOdistDataMap _implsOdistDataSems _implsOdistDatas _implsOdistDeflStmts _implsOdistDefs _implsOdistInhAttrs _implsOdistItfs _implsOdistRanks _implsOdistRenames _implsOdistSynAttrs _implsOdistVisLocalDefs _implsOdistVisRankMap _implsOdistVisitInhAttrs _implsOdistVisitOrder _implsOdistVisitSource _implsOdistVisitSynAttrs _implsOdistVisits _implsOdoneVisits _implsOfullCyclicVisits _implsOgathChildDefs _implsOgathClauses _implsOgathDefs _implsOgathNextVisits _implsOgathNonterms _implsOgathVisLocalDefs _implsOhSpilledStmts _implsOitf _implsOjsSpilledStmts _implsOlexCounter _implsOnonterm _implsOopts _implsOscopeDep _implsOscopeReason _implsOstmtSource _implsOvisitBeginDep _implsOvisitEndDep _implsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisInternal,_lhsOjspp,_lhsOlexCounter,_lhsOmbNextVisit,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
sem_SemVisit_Prependable :: Pos ->
                            Ident ->
                            SemVisit ->
                            T_SemVisit 
sem_SemVisit_Prependable pos_ name_ actual_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsOerrs0 :: Errs
              visits_val_ :: SemVisit 
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminRank :: Int
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOhpp :: PP_Doc
              _lhsOisInternal :: Bool
              _lhsOjspp :: PP_Doc
              _lhsOlexCounter :: Int
              _lhsOmbNextVisit :: (Maybe Ident)
              _lhsOpp :: PP_Doc
              _visitsOallAvailInvokes :: (Map Ident (Set Ident))
              _visitsOallVisits :: (Set Ident)
              _visitsOallowCycVisits :: (Set Ident)
              _visitsOavailInvokes :: (Map Ident (Set Ident))
              _visitsObasename :: QIdent
              _visitsOclauseExtras :: (Map Ident Stmts)
              _visitsOcoItf :: Ident
              _visitsOcodeIdCounter :: Int
              _visitsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _visitsOdirectVisitLocalAttrs :: (Map Ident String)
              _visitsOdistAliasses :: (Map Ident AliasType)
              _visitsOdistAllChildMinRanges :: (Map Ident [Ident])
              _visitsOdistAttrSource :: AttrSourceMap
              _visitsOdistAttrVisMap :: AttrVisMap
              _visitsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _visitsOdistChildEffRanges :: (Map Ident (Set Ident))
              _visitsOdistChildMinRanges :: (Map Ident [Ident])
              _visitsOdistChildOcc :: (Map Ident Int)
              _visitsOdistChildSource :: ChildSourceMap
              _visitsOdistCycVisMap :: CycVisMap
              _visitsOdistDataCons :: ConEnv
              _visitsOdistDataMap :: DataMap
              _visitsOdistDataSems :: DataSemEnv
              _visitsOdistDatas :: DataEnv
              _visitsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _visitsOdistDefs :: DefsEnv
              _visitsOdistInhAttrs :: AttrMap
              _visitsOdistItfs :: ItfEnv
              _visitsOdistNextVisits :: (Map Ident (Maybe Ident))
              _visitsOdistRanks :: (Map DepItem (Bool,Int))
              _visitsOdistRenames :: RenameMap
              _visitsOdistSynAttrs :: AttrMap
              _visitsOdistVisLocalDefs :: DefsEnv
              _visitsOdistVisRankMap :: (IntMap Ident)
              _visitsOdistVisitInhAttrs :: VisitAttrMap
              _visitsOdistVisitOrder :: (Map Ident [Ident])
              _visitsOdistVisitSource :: VisitSourceMap
              _visitsOdistVisitSynAttrs :: VisitAttrMap
              _visitsOdistVisits :: VisitEnv
              _visitsOdoneVisits :: ([Ident])
              _visitsOfullCyclic :: Bool
              _visitsOfullCyclicVisits :: (Set Ident)
              _visitsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _visitsOgathClauses :: ClausesEnv
              _visitsOgathDataSems :: DataSemEnv
              _visitsOgathDefs :: DefsEnv
              _visitsOgathNonterms :: NontermEnv
              _visitsOgathVisLocalDefs :: DefsEnv
              _visitsOgathVisitNames :: (Env Ident ())
              _visitsOhSpilledStmts :: ([(Int,PP_Doc)])
              _visitsOindent :: Int
              _visitsOitf :: QIdent
              _visitsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _visitsOlexCounter :: Int
              _visitsOlocalAttrs :: (Map Ident String)
              _visitsOmasterPos :: Pos
              _visitsOmyNextVisits :: (Map Ident (Maybe Ident))
              _visitsOnextVisits :: ([Ident])
              _visitsOnonterm :: QIdent
              _visitsOopts :: Opts
              _visitsOscopeDep :: DepItem
              _visitsOscopeReason :: Reason
              _visitsOsemBasename :: QIdent
              _visitsOstmtSource :: DepItem
              _visitsOvisit :: Ident
              _visitsOvisitBeginDep :: DepItem
              _visitsOvisitEndDep :: DepItem
              _visitsOvisitEndReason :: Reason
              _visitsOvisitNr :: Int
              _visitsOwithinCoSem :: Bool
              _visitsIallReqInvokes :: (Map Ident (Set Ident))
              _visitsIbannedInvokes :: (Map Ident (Set Ident))
              _visitsIcodeIdCounter :: Int
              _visitsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _visitsIdistDataCons :: ConEnv
              _visitsIdistDataSems :: DataSemEnv
              _visitsIdistDatas :: DataEnv
              _visitsIdistDefs :: DefsEnv
              _visitsIdistItfs :: ItfEnv
              _visitsIdistVisLocalDefs :: DefsEnv
              _visitsIdistVisits :: VisitEnv
              _visitsIerrs0 :: Errs
              _visitsIerrs1 :: Errs
              _visitsIerrs2 :: Errs
              _visitsIerrs3 :: Errs
              _visitsIerrs4 :: Errs
              _visitsIerrs5 :: Errs
              _visitsIgathAllowCycVisits :: (Set Ident)
              _visitsIgathAttrSource :: AttrSourceMap
              _visitsIgathAvoidVisits :: (Set DepItem)
              _visitsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _visitsIgathChildSource :: ChildSourceMap
              _visitsIgathClauses :: ClausesEnv
              _visitsIgathDataSems :: DataSemEnv
              _visitsIgathDefs :: DefsEnv
              _visitsIgathDeps :: Deps
              _visitsIgathItemVisits :: (Map DepItem DepItem)
              _visitsIgathLegalCycStmts :: (Set DepItem)
              _visitsIgathMissingInvokes :: (Set (Ident,Ident))
              _visitsIgathNonterms :: NontermEnv
              _visitsIgathSemAttrSource :: AttrSourceMap
              _visitsIgathSemStarts :: (Seq DepItem)
              _visitsIgathStmtPosMap :: (Map DepItem Pos)
              _visitsIgathVisLocalDefs :: DefsEnv
              _visitsIgathVisRankMap :: (IntMap Ident)
              _visitsIgathVisitAttrs :: (Map Ident (Map Ident String))
              _visitsIgathVisitEnds :: (Seq DepItem)
              _visitsIgathVisitNames :: (Env Ident ())
              _visitsIgathVisitSource :: VisitSourceMap
              _visitsIgathVisitStarts :: (Seq DepItem)
              _visitsIhpp :: PP_Doc
              _visitsIisInternal :: Bool
              _visitsIjspp :: PP_Doc
              _visitsIlexCounter :: Int
              _visitsImbNextVisit :: (Maybe Ident)
              _visitsIminRank :: Int
              _visitsIminReqInvokes :: (Map Ident (Set Ident))
              _visitsIpp :: PP_Doc
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 756 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1]
                   {-# LINE 54524 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 756 "src/Transform.ag" #-}
                   if null _remainingVisits     && not (null _lhsInextVisits)
                   then (Err_ExpVisit pos_ name_ (head _lhsInextVisits) Seq.<|)
                   else if name_ `elem` _lhsIdoneVisits
                        then (Err_Dup [name_] Seq.<|)
                        else id
                   {-# LINE 54533 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 748, column 12)
              _missingVisits =
                  ({-# LINE 748 "src/Transform.ag" #-}
                   if elem name_ _lhsInextVisits
                   then takeWhile (/= name_) _lhsInextVisits
                   else []
                   {-# LINE 54540 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 751, column 12)
              _remainingVisits =
                  ({-# LINE 751 "src/Transform.ag" #-}
                   drop (length _missingVisits    ) _lhsInextVisits
                   {-# LINE 54545 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 753, column 12)
              visits_val_ =
                  ({-# LINE 753 "src/Transform.ag" #-}
                   if null _remainingVisits     || name_ `elem` _lhsIdoneVisits
                   then SemVisit_End
                   else prependEmptyVisits _lhsIbasename pos_ actual_ _missingVisits
                   {-# LINE 54552 "src/Transform.hs" #-})
              visits_inst_ =
                  (sem_SemVisit visits_val_ )
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _visitsIallReqInvokes
                   {-# LINE 54559 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _visitsIbannedInvokes
                   {-# LINE 54564 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 756 "src/Transform.ag" #-}
                   _visitsIerrs0
                   {-# LINE 54569 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs1
                   {-# LINE 54574 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs2
                   {-# LINE 54579 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs3
                   {-# LINE 54584 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs4
                   {-# LINE 54589 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _visitsIerrs5
                   {-# LINE 54594 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1914 "src/Transform.ag" #-}
                   _visitsIgathAllowCycVisits
                   {-# LINE 54599 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _visitsIgathAttrSource
                   {-# LINE 54604 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _visitsIgathAvoidVisits
                   {-# LINE 54609 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _visitsIgathChildSource
                   {-# LINE 54614 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _visitsIgathDeps
                   {-# LINE 54619 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _visitsIgathItemVisits
                   {-# LINE 54624 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _visitsIgathLegalCycStmts
                   {-# LINE 54629 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _visitsIgathMissingInvokes
                   {-# LINE 54634 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _visitsIgathSemAttrSource
                   {-# LINE 54639 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _visitsIgathSemStarts
                   {-# LINE 54644 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _visitsIgathStmtPosMap
                   {-# LINE 54649 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _lhsOgathVisRankMap =
                  ({-# LINE 1857 "src/Transform.ag" #-}
                   _visitsIgathVisRankMap
                   {-# LINE 54654 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _lhsOgathVisitAttrs =
                  ({-# LINE 895 "src/Transform.ag" #-}
                   _visitsIgathVisitAttrs
                   {-# LINE 54659 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _visitsIgathVisitEnds
                   {-# LINE 54664 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _visitsIgathVisitSource
                   {-# LINE 54669 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _visitsIgathVisitStarts
                   {-# LINE 54674 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2395, column 36)
              _lhsOminRank =
                  ({-# LINE 2395 "src/Transform.ag" #-}
                   _visitsIminRank
                   {-# LINE 54679 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _visitsIminReqInvokes
                   {-# LINE 54684 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _visitsIcodeIdCounter
                   {-# LINE 54689 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _visitsIdistChildDefs
                   {-# LINE 54694 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _visitsIdistDataCons
                   {-# LINE 54699 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _visitsIdistDataSems
                   {-# LINE 54704 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _visitsIdistDatas
                   {-# LINE 54709 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _visitsIdistDefs
                   {-# LINE 54714 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _visitsIdistItfs
                   {-# LINE 54719 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _visitsIdistVisLocalDefs
                   {-# LINE 54724 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _visitsIdistVisits
                   {-# LINE 54729 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _visitsIgathChildDefs
                   {-# LINE 54734 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _visitsIgathClauses
                   {-# LINE 54739 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _visitsIgathDataSems
                   {-# LINE 54744 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _visitsIgathDefs
                   {-# LINE 54749 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _visitsIgathNonterms
                   {-# LINE 54754 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _visitsIgathVisLocalDefs
                   {-# LINE 54759 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _visitsIgathVisitNames
                   {-# LINE 54764 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOhpp =
                  ({-# LINE 75 "src/TargetHaskell.ag" #-}
                   _visitsIhpp
                   {-# LINE 54769 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOisInternal =
                  ({-# LINE 844 "src/Transform.ag" #-}
                   _visitsIisInternal
                   {-# LINE 54774 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOjspp =
                  ({-# LINE 35 "src/TargetJs.ag" #-}
                   _visitsIjspp
                   {-# LINE 54779 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _visitsIlexCounter
                   {-# LINE 54784 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOmbNextVisit =
                  ({-# LINE 1352 "src/Transform.ag" #-}
                   _visitsImbNextVisit
                   {-# LINE 54789 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOpp =
                  ({-# LINE 2411 "src/Transform.ag" #-}
                   _visitsIpp
                   {-# LINE 54794 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 54799 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 54804 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 54809 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 54814 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 54819 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 54824 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 54829 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 54834 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 54839 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 54844 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 54849 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 54854 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 54859 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 54864 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 54869 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 54874 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 54879 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 54884 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 54889 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 54894 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 54899 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 54904 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 54909 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 54914 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 54919 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 54924 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 54929 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 54934 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistNextVisits =
                  ({-# LINE 1551 "src/Transform.ag" #-}
                   _lhsIdistNextVisits
                   {-# LINE 54939 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 54944 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 54949 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 54954 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 54959 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 54964 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 54969 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 54974 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 54979 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 54984 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 54989 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 54994 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _lhsIfullCyclic
                   {-# LINE 54999 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 55004 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 55009 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 55014 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 55019 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 55024 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 55029 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 55034 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 55039 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 55044 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 55049 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 55054 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 55059 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 55064 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOlocalAttrs =
                  ({-# LINE 1098 "src/Transform.ag" #-}
                   _lhsIlocalAttrs
                   {-# LINE 55069 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _lhsImasterPos
                   {-# LINE 55074 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _lhsImyNextVisits
                   {-# LINE 55079 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOnextVisits =
                  ({-# LINE 711 "src/Transform.ag" #-}
                   _lhsInextVisits
                   {-# LINE 55084 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 55089 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 55094 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 55099 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 55104 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 55109 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 55114 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOvisit =
                  ({-# LINE 1115 "src/Transform.ag" #-}
                   _lhsIvisit
                   {-# LINE 55119 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 55124 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 55129 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 55134 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _lhsIvisitNr
                   {-# LINE 55139 "src/Transform.hs" #-})
              -- copy rule (down)
              _visitsOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 55144 "src/Transform.hs" #-})
              ( _visitsIallReqInvokes,_visitsIbannedInvokes,_visitsIcodeIdCounter,_visitsIdistChildDefs,_visitsIdistDataCons,_visitsIdistDataSems,_visitsIdistDatas,_visitsIdistDefs,_visitsIdistItfs,_visitsIdistVisLocalDefs,_visitsIdistVisits,_visitsIerrs0,_visitsIerrs1,_visitsIerrs2,_visitsIerrs3,_visitsIerrs4,_visitsIerrs5,_visitsIgathAllowCycVisits,_visitsIgathAttrSource,_visitsIgathAvoidVisits,_visitsIgathChildDefs,_visitsIgathChildSource,_visitsIgathClauses,_visitsIgathDataSems,_visitsIgathDefs,_visitsIgathDeps,_visitsIgathItemVisits,_visitsIgathLegalCycStmts,_visitsIgathMissingInvokes,_visitsIgathNonterms,_visitsIgathSemAttrSource,_visitsIgathSemStarts,_visitsIgathStmtPosMap,_visitsIgathVisLocalDefs,_visitsIgathVisRankMap,_visitsIgathVisitAttrs,_visitsIgathVisitEnds,_visitsIgathVisitNames,_visitsIgathVisitSource,_visitsIgathVisitStarts,_visitsIhpp,_visitsIisInternal,_visitsIjspp,_visitsIlexCounter,_visitsImbNextVisit,_visitsIminRank,_visitsIminReqInvokes,_visitsIpp) =
                  visits_inst_ _visitsOallAvailInvokes _visitsOallVisits _visitsOallowCycVisits _visitsOavailInvokes _visitsObasename _visitsOclauseExtras _visitsOcoItf _visitsOcodeIdCounter _visitsOdirectVisitAttrs _visitsOdirectVisitLocalAttrs _visitsOdistAliasses _visitsOdistAllChildMinRanges _visitsOdistAttrSource _visitsOdistAttrVisMap _visitsOdistChildDefs _visitsOdistChildEffRanges _visitsOdistChildMinRanges _visitsOdistChildOcc _visitsOdistChildSource _visitsOdistCycVisMap _visitsOdistDataCons _visitsOdistDataMap _visitsOdistDataSems _visitsOdistDatas _visitsOdistDeflStmts _visitsOdistDefs _visitsOdistInhAttrs _visitsOdistItfs _visitsOdistNextVisits _visitsOdistRanks _visitsOdistRenames _visitsOdistSynAttrs _visitsOdistVisLocalDefs _visitsOdistVisRankMap _visitsOdistVisitInhAttrs _visitsOdistVisitOrder _visitsOdistVisitSource _visitsOdistVisitSynAttrs _visitsOdistVisits _visitsOdoneVisits _visitsOfullCyclic _visitsOfullCyclicVisits _visitsOgathChildDefs _visitsOgathClauses _visitsOgathDataSems _visitsOgathDefs _visitsOgathNonterms _visitsOgathVisLocalDefs _visitsOgathVisitNames _visitsOhSpilledStmts _visitsOindent _visitsOitf _visitsOjsSpilledStmts _visitsOlexCounter _visitsOlocalAttrs _visitsOmasterPos _visitsOmyNextVisits _visitsOnextVisits _visitsOnonterm _visitsOopts _visitsOscopeDep _visitsOscopeReason _visitsOsemBasename _visitsOstmtSource _visitsOvisit _visitsOvisitBeginDep _visitsOvisitEndDep _visitsOvisitEndReason _visitsOvisitNr _visitsOwithinCoSem 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisInternal,_lhsOjspp,_lhsOlexCounter,_lhsOmbNextVisit,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
sem_SemVisit_Visit :: Pos ->
                      Ident ->
                      Bool ->
                      T_VisitAttrs  ->
                      T_Stmts  ->
                      T_ClausesTop  ->
                      T_SemVisit 
sem_SemVisit_Visit pos_ name_ cyclic_ attrs_ stmts_ clauses_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIclauseExtras
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistNextVisits
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclic
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIgathVisitNames
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsIlocalAttrs
       _lhsImasterPos
       _lhsImyNextVisits
       _lhsInextVisits
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIsemBasename
       _lhsIstmtSource
       _lhsIvisit
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason
       _lhsIvisitNr
       _lhsIwithinCoSem ->
         (let _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOdistVisits :: VisitEnv
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOgathAllowCycVisits :: (Set Ident)
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisRankMap :: (IntMap Ident)
              _lhsOgathVisitAttrs :: (Map Ident (Map Ident String))
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitNames :: (Env Ident ())
              _lhsOgathVisitStarts :: (Seq DepItem)
              _attrsOgathChns :: AttrEnv
              _clausesOnextVisits :: ([Ident])
              _lhsOisInternal :: Bool
              _stmtsOdirectVisitLocalAttrs :: (Map Ident String)
              _clausesOdirectVisitLocalAttrs :: (Map Ident String)
              _stmtsOgathVisLocalDefs :: DefsEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _stmtsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _clausesOlocalAttrs :: (Map Ident String)
              _clausesOvisit :: Ident
              impls_val_ :: ImplStmts 
              _lhsOmbNextVisit :: (Maybe Ident)
              _stmtsOgathNextVisits :: (Map Ident (Maybe Ident))
              _clausesOdistNextVisits :: (Map Ident (Maybe Ident))
              _lhsOminRank :: Int
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _clausesOhSpilledStmts :: ([(Int,PP_Doc)])
              _lhsOjspp :: PP_Doc
              _clausesOjsSpilledStmts :: ([(Int,PP_Doc)])
              __tup73 :: ((Int,Int))
              _stmtsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemAttrSource :: AttrSourceMap
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOlexCounter :: Int
              _stmtsOallAvailInvokes :: (Map Ident (Set Ident))
              _stmtsOallVisits :: (Set Ident)
              _stmtsOallowCycVisits :: (Set Ident)
              _stmtsOavailInvokes :: (Map Ident (Set Ident))
              _stmtsObasename :: QIdent
              _stmtsOcoItf :: Ident
              _stmtsOcodeIdCounter :: Int
              _stmtsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _stmtsOdistAliasses :: (Map Ident AliasType)
              _stmtsOdistAllChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistAttrSource :: AttrSourceMap
              _stmtsOdistAttrVisMap :: AttrVisMap
              _stmtsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsOdistChildEffRanges :: (Map Ident (Set Ident))
              _stmtsOdistChildMinRanges :: (Map Ident [Ident])
              _stmtsOdistChildOcc :: (Map Ident Int)
              _stmtsOdistChildSource :: ChildSourceMap
              _stmtsOdistCycVisMap :: CycVisMap
              _stmtsOdistDataCons :: ConEnv
              _stmtsOdistDataMap :: DataMap
              _stmtsOdistDataSems :: DataSemEnv
              _stmtsOdistDatas :: DataEnv
              _stmtsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsOdistDefs :: DefsEnv
              _stmtsOdistInhAttrs :: AttrMap
              _stmtsOdistItfs :: ItfEnv
              _stmtsOdistRanks :: (Map DepItem (Bool,Int))
              _stmtsOdistRenames :: RenameMap
              _stmtsOdistSynAttrs :: AttrMap
              _stmtsOdistVisRankMap :: (IntMap Ident)
              _stmtsOdistVisitInhAttrs :: VisitAttrMap
              _stmtsOdistVisitOrder :: (Map Ident [Ident])
              _stmtsOdistVisitSource :: VisitSourceMap
              _stmtsOdistVisitSynAttrs :: VisitAttrMap
              _stmtsOdistVisits :: VisitEnv
              _stmtsOdoneVisits :: ([Ident])
              _stmtsOfullCyclicVisits :: (Set Ident)
              _stmtsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsOgathClauses :: ClausesEnv
              _stmtsOgathDataSems :: DataSemEnv
              _stmtsOgathDefs :: DefsEnv
              _stmtsOgathNonterms :: NontermEnv
              _stmtsOhSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOindent :: Int
              _stmtsOitf :: QIdent
              _stmtsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _stmtsOnonterm :: QIdent
              _stmtsOopts :: Opts
              _stmtsOscopeDep :: DepItem
              _stmtsOscopeReason :: Reason
              _stmtsOstmtSource :: DepItem
              _stmtsOvisitBeginDep :: DepItem
              _stmtsOvisitEndDep :: DepItem
              _stmtsOvisitEndReason :: Reason
              _clausesOallAvailInvokes :: (Map Ident (Set Ident))
              _clausesOallVisits :: (Set Ident)
              _clausesOallowCycVisits :: (Set Ident)
              _clausesOavailInvokes :: (Map Ident (Set Ident))
              _clausesObasename :: QIdent
              _clausesOclauseExtras :: (Map Ident Stmts)
              _clausesOcoItf :: Ident
              _clausesOcodeIdCounter :: Int
              _clausesOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _clausesOdistAliasses :: (Map Ident AliasType)
              _clausesOdistAllChildMinRanges :: (Map Ident [Ident])
              _clausesOdistAttrSource :: AttrSourceMap
              _clausesOdistAttrVisMap :: AttrVisMap
              _clausesOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesOdistChildEffRanges :: (Map Ident (Set Ident))
              _clausesOdistChildMinRanges :: (Map Ident [Ident])
              _clausesOdistChildOcc :: (Map Ident Int)
              _clausesOdistChildSource :: ChildSourceMap
              _clausesOdistCycVisMap :: CycVisMap
              _clausesOdistDataCons :: ConEnv
              _clausesOdistDataMap :: DataMap
              _clausesOdistDataSems :: DataSemEnv
              _clausesOdistDatas :: DataEnv
              _clausesOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _clausesOdistDefs :: DefsEnv
              _clausesOdistInhAttrs :: AttrMap
              _clausesOdistItfs :: ItfEnv
              _clausesOdistRanks :: (Map DepItem (Bool,Int))
              _clausesOdistRenames :: RenameMap
              _clausesOdistSynAttrs :: AttrMap
              _clausesOdistVisLocalDefs :: DefsEnv
              _clausesOdistVisRankMap :: (IntMap Ident)
              _clausesOdistVisitInhAttrs :: VisitAttrMap
              _clausesOdistVisitOrder :: (Map Ident [Ident])
              _clausesOdistVisitSource :: VisitSourceMap
              _clausesOdistVisitSynAttrs :: VisitAttrMap
              _clausesOdistVisits :: VisitEnv
              _clausesOdoneVisits :: ([Ident])
              _clausesOfullCyclic :: Bool
              _clausesOfullCyclicVisits :: (Set Ident)
              _clausesOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesOgathClauses :: ClausesEnv
              _clausesOgathDataSems :: DataSemEnv
              _clausesOgathDefs :: DefsEnv
              _clausesOgathNonterms :: NontermEnv
              _clausesOgathVisLocalDefs :: DefsEnv
              _clausesOgathVisitNames :: (Env Ident ())
              _clausesOindent :: Int
              _clausesOitf :: QIdent
              _clausesOlexCounter :: Int
              _clausesOmasterPos :: Pos
              _clausesOmyNextVisits :: (Map Ident (Maybe Ident))
              _clausesOnonterm :: QIdent
              _clausesOopts :: Opts
              _clausesOscopeDep :: DepItem
              _clausesOscopeReason :: Reason
              _clausesOsemBasename :: QIdent
              _clausesOstmtSource :: DepItem
              _clausesOvisitBeginDep :: DepItem
              _clausesOvisitEndDep :: DepItem
              _clausesOvisitEndReason :: Reason
              _clausesOvisitNr :: Int
              _clausesOwithinCoSem :: Bool
              _implsOallAvailInvokes :: (Map Ident (Set Ident))
              _implsOallVisits :: (Set Ident)
              _implsOallowCycVisits :: (Set Ident)
              _implsOavailInvokes :: (Map Ident (Set Ident))
              _implsObasename :: QIdent
              _implsOcoItf :: Ident
              _implsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _implsOdirectVisitLocalAttrs :: (Map Ident String)
              _implsOdistAliasses :: (Map Ident AliasType)
              _implsOdistAllChildMinRanges :: (Map Ident [Ident])
              _implsOdistAttrSource :: AttrSourceMap
              _implsOdistAttrVisMap :: AttrVisMap
              _implsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOdistChildEffRanges :: (Map Ident (Set Ident))
              _implsOdistChildMinRanges :: (Map Ident [Ident])
              _implsOdistChildOcc :: (Map Ident Int)
              _implsOdistChildSource :: ChildSourceMap
              _implsOdistCycVisMap :: CycVisMap
              _implsOdistDataCons :: ConEnv
              _implsOdistDataMap :: DataMap
              _implsOdistDataSems :: DataEnv
              _implsOdistDatas :: DataEnv
              _implsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _implsOdistDefs :: DefsEnv
              _implsOdistInhAttrs :: AttrMap
              _implsOdistItfs :: ItfEnv
              _implsOdistRanks :: (Map DepItem (Bool,Int))
              _implsOdistRenames :: RenameMap
              _implsOdistSynAttrs :: AttrMap
              _implsOdistVisLocalDefs :: DefsEnv
              _implsOdistVisRankMap :: (IntMap Ident)
              _implsOdistVisitInhAttrs :: VisitAttrMap
              _implsOdistVisitOrder :: (Map Ident [Ident])
              _implsOdistVisitSource :: VisitSourceMap
              _implsOdistVisitSynAttrs :: VisitAttrMap
              _implsOdistVisits :: VisitEnv
              _implsOdoneVisits :: ([Ident])
              _implsOfullCyclicVisits :: (Set Ident)
              _implsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _implsOgathClauses :: ClausesEnv
              _implsOgathDefs :: DefsEnv
              _implsOgathNextVisits :: (Map Ident (Maybe Ident))
              _implsOgathNonterms :: NontermEnv
              _implsOgathVisLocalDefs :: DefsEnv
              _implsOhSpilledStmts :: ([(Int,PP_Doc)])
              _implsOitf :: QIdent
              _implsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _implsOlexCounter :: Int
              _implsOnonterm :: QIdent
              _implsOopts :: Opts
              _implsOscopeDep :: DepItem
              _implsOscopeReason :: Reason
              _implsOstmtSource :: DepItem
              _implsOvisitBeginDep :: DepItem
              _implsOvisitEndDep :: DepItem
              _implsOvisitEndReason :: Reason
              _attrsIgathChns :: AttrEnv
              _attrsIgathVisitLocalAttrs :: (Map Ident String)
              _attrsIpps :: ([PP_Doc])
              _stmtsIallReqInvokes :: (Map Ident (Set Ident))
              _stmtsIbannedInvokes :: (Map Ident (Set Ident))
              _stmtsIcodeIdCounter :: Int
              _stmtsIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _stmtsIdistDataCons :: ConEnv
              _stmtsIdistDataSems :: DataSemEnv
              _stmtsIdistDatas :: DataEnv
              _stmtsIdistDefs :: DefsEnv
              _stmtsIdistItfs :: ItfEnv
              _stmtsIdistVisLocalDefs :: DefsEnv
              _stmtsIdistVisits :: VisitEnv
              _stmtsIerrs0 :: Errs
              _stmtsIerrs1 :: Errs
              _stmtsIerrs2 :: Errs
              _stmtsIerrs3 :: Errs
              _stmtsIerrs4 :: Errs
              _stmtsIerrs5 :: Errs
              _stmtsIexplInvokes :: (Map Ident (Set Ident))
              _stmtsIgathAttrSource :: AttrSourceMap
              _stmtsIgathAvoidVisits :: (Set DepItem)
              _stmtsIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _stmtsIgathChildEffRanges :: (Map Ident (Set Ident))
              _stmtsIgathChildMinRanges :: (Map Ident [Ident])
              _stmtsIgathChildOcc :: (Map Ident Int)
              _stmtsIgathChildSource :: ChildSourceMap
              _stmtsIgathClauses :: ClausesEnv
              _stmtsIgathDataSems :: DataSemEnv
              _stmtsIgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _stmtsIgathDefs :: DefsEnv
              _stmtsIgathDeps :: Deps
              _stmtsIgathItemVisits :: (Map DepItem DepItem)
              _stmtsIgathLegalCycStmts :: (Set DepItem)
              _stmtsIgathMissingInvokes :: (Set (Ident,Ident))
              _stmtsIgathNextVisits :: (Map Ident (Maybe Ident))
              _stmtsIgathNonterms :: NontermEnv
              _stmtsIgathRenames :: RenameMap
              _stmtsIgathSemStarts :: (Seq DepItem)
              _stmtsIgathStmtPosMap :: (Map DepItem Pos)
              _stmtsIgathVisLocalDefs :: DefsEnv
              _stmtsIgathVisitEnds :: (Seq DepItem)
              _stmtsIgathVisitSource :: VisitSourceMap
              _stmtsIgathVisitStarts :: (Seq DepItem)
              _stmtsIhopps :: ([(Int, PP_Doc)])
              _stmtsIjsopps :: ([(Int, PP_Doc)])
              _stmtsIlexCounter :: Int
              _stmtsIminReqInvokes :: (Map Ident (Set Ident))
              _stmtsIpps :: ([PP_Doc])
              _clausesIallReqInvokes :: (Map Ident (Set Ident))
              _clausesIbannedInvokes :: (Map Ident (Set Ident))
              _clausesIcodeIdCounter :: Int
              _clausesIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _clausesIdistDataCons :: ConEnv
              _clausesIdistDataSems :: DataSemEnv
              _clausesIdistDatas :: DataEnv
              _clausesIdistDefs :: DefsEnv
              _clausesIdistItfs :: ItfEnv
              _clausesIdistVisLocalDefs :: DefsEnv
              _clausesIdistVisits :: VisitEnv
              _clausesIerrs0 :: Errs
              _clausesIerrs1 :: Errs
              _clausesIerrs2 :: Errs
              _clausesIerrs3 :: Errs
              _clausesIerrs4 :: Errs
              _clausesIerrs5 :: Errs
              _clausesIgathAllowCycVisits :: (Set Ident)
              _clausesIgathAttrSource :: AttrSourceMap
              _clausesIgathAvoidVisits :: (Set DepItem)
              _clausesIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _clausesIgathChildSource :: ChildSourceMap
              _clausesIgathClauseNames :: (Set Ident)
              _clausesIgathClauses :: ClausesEnv
              _clausesIgathDataSems :: DataSemEnv
              _clausesIgathDefs :: DefsEnv
              _clausesIgathDeps :: Deps
              _clausesIgathItemVisits :: (Map DepItem DepItem)
              _clausesIgathLegalCycStmts :: (Set DepItem)
              _clausesIgathMissingInvokes :: (Set (Ident,Ident))
              _clausesIgathNonterms :: NontermEnv
              _clausesIgathSemAttrSource :: AttrSourceMap
              _clausesIgathSemStarts :: (Seq DepItem)
              _clausesIgathStmtPosMap :: (Map DepItem Pos)
              _clausesIgathVisLocalDefs :: DefsEnv
              _clausesIgathVisRankMap :: (IntMap Ident)
              _clausesIgathVisitAttrs :: (Map Ident (Map Ident String))
              _clausesIgathVisitEnds :: (Seq DepItem)
              _clausesIgathVisitNames :: (Env Ident ())
              _clausesIgathVisitSource :: VisitSourceMap
              _clausesIgathVisitStarts :: (Seq DepItem)
              _clausesIhpp :: PP_Doc
              _clausesIjspp :: PP_Doc
              _clausesIlexCounter :: Int
              _clausesIminRank :: Int
              _clausesIminReqInvokes :: (Map Ident (Set Ident))
              _clausesInClauses :: Int
              _clausesIpps :: ([PP_Doc])
              _implsIdistDefs :: DefsEnv
              _implsIdistVisLocalDefs :: DefsEnv
              _implsIerrs2 :: Errs
              _implsIerrs3 :: Errs
              _implsIerrs4 :: Errs
              _implsIerrs5 :: Errs
              _implsIgathAttrSource :: AttrSourceMap
              _implsIgathChildSource :: ChildSourceMap
              _implsIgathDefs :: DefsEnv
              _implsIgathDeps :: Deps
              _implsIgathItemVisits :: (Map DepItem DepItem)
              _implsIgathLegalCycStmts :: (Set DepItem)
              _implsIgathNextVisits :: (Map Ident (Maybe Ident))
              _implsIgathStmtPosMap :: (Map DepItem Pos)
              _implsIgathVisLocalDefs :: DefsEnv
              _implsIgathVisitSource :: VisitSourceMap
              _implsIhopps :: ([(Int, PP_Doc)])
              _implsIjsopps :: ([(Int, PP_Doc)])
              _implsIlexCounter :: Int
              _implsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsObannedInvokes =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   foldr ($) _bannedInvokes_augmented_syn [_bannedInvokes_augmented_f1]
                   {-# LINE 55585 "src/Transform.hs" #-})
              -- augment function
              _bannedInvokes_augmented_f1 =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   _stmtsIexplInvokes `unionWithUnion`
                   {-# LINE 55590 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOdistVisits =
                  ({-# LINE 430 "src/Transform.ag" #-}
                   foldr ($) _distVisits_augmented_syn [_distVisits_augmented_f1]
                   {-# LINE 55595 "src/Transform.hs" #-})
              -- augment function
              _distVisits_augmented_f1 =
                  ({-# LINE 430 "src/Transform.ag" #-}
                   snd . find (name_ : _lhsIitf) ()
                   {-# LINE 55600 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs0 =
                  ({-# LINE 739 "src/Transform.ag" #-}
                   foldr ($) _errs0_augmented_syn [_errs0_augmented_f1, _errs0_augmented_f2]
                   {-# LINE 55605 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f1 =
                  ({-# LINE 739 "src/Transform.ag" #-}
                   if not (name_ `elem` _itfVisits    )
                   then (Err_UndeclVisit pos_ name_ _unqualItf     Seq.<|)
                   else (_sequenceErrs     Seq.><)
                   {-# LINE 55612 "src/Transform.hs" #-})
              -- augment function
              _errs0_augmented_f2 =
                  ({-# LINE 739 "src/Transform.ag" #-}
                   addDefErrs _attrsIgathChns
                   {-# LINE 55617 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 55622 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   if _fullCyclic     && _nClauses     /= 1 && not _lhsIwithinCoSem
                   then (Err_ClausesCyclic pos_ name_ _nClauses     Seq.<|)
                   else id
                   {-# LINE 55629 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 55634 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   Seq.fromList (map (\(nm,vs) -> Err_MissingVisit pos_ nm vs) _missingInvokes    ) Seq.><
                   {-# LINE 55639 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs3 =
                  ({-# LINE 1062 "src/Transform.ag" #-}
                   foldr ($) _errs3_augmented_syn [_errs3_augmented_f1, _errs3_augmented_f2]
                   {-# LINE 55644 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f1 =
                  ({-# LINE 1062 "src/Transform.ag" #-}
                   addUseErrs'' _localVisLocalDefs'
                   {-# LINE 55649 "src/Transform.hs" #-})
              -- augment function
              _errs3_augmented_f2 =
                  ({-# LINE 1062 "src/Transform.ag" #-}
                   addDefErrs'' _localVisLocalDefs
                   {-# LINE 55654 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAllowCycVisits =
                  ({-# LINE 1919 "src/Transform.ag" #-}
                   foldr ($) _gathAllowCycVisits_augmented_syn [_gathAllowCycVisits_augmented_f1]
                   {-# LINE 55659 "src/Transform.hs" #-})
              -- augment function
              _gathAllowCycVisits_augmented_f1 =
                  ({-# LINE 1919 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert name_ else id
                   {-# LINE 55664 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAvoidVisits =
                  ({-# LINE 1987 "src/Transform.ag" #-}
                   foldr ($) _gathAvoidVisits_augmented_syn [_gathAvoidVisits_augmented_f1]
                   {-# LINE 55669 "src/Transform.hs" #-})
              -- augment function
              _gathAvoidVisits_augmented_f1 =
                  ({-# LINE 1987 "src/Transform.ag" #-}
                   if _fullCyclic
                   then Set.insert _visitEndDep
                   else id
                   {-# LINE 55676 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2300 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 55681 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2300 "src/Transform.ag" #-}
                   addDep _visitEndDep     (ReasonScopeVisit name_) [_scopeDep    ]
                   {-# LINE 55686 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2300 "src/Transform.ag" #-}
                   if null _lhsIdoneVisits
                   then id
                   else addDep _scopeDep     _lhsIvisitEndReason [_lhsIvisitEndDep]
                   {-# LINE 55693 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 55698 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   Map.insert _scopeDep     _scopeDep
                   {-# LINE 55703 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathSemStarts =
                  ({-# LINE 1848 "src/Transform.ag" #-}
                   foldr ($) _gathSemStarts_augmented_syn [_gathSemStarts_augmented_f1]
                   {-# LINE 55708 "src/Transform.hs" #-})
              -- augment function
              _gathSemStarts_augmented_f1 =
                  ({-# LINE 1848 "src/Transform.ag" #-}
                   if _lhsIvisitNr == 1
                   then (_scopeDep     Seq.<|)
                   else id
                   {-# LINE 55715 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisRankMap =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   foldr ($) _gathVisRankMap_augmented_syn [_gathVisRankMap_augmented_f1]
                   {-# LINE 55720 "src/Transform.hs" #-})
              -- augment function
              _gathVisRankMap_augmented_f1 =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   IntMap.insert _rank     name_
                   {-# LINE 55725 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitAttrs =
                  ({-# LINE 898 "src/Transform.ag" #-}
                   foldr ($) _gathVisitAttrs_augmented_syn [_gathVisitAttrs_augmented_f1]
                   {-# LINE 55730 "src/Transform.hs" #-})
              -- augment function
              _gathVisitAttrs_augmented_f1 =
                  ({-# LINE 898 "src/Transform.ag" #-}
                   Map.insert name_ _attrsIgathVisitLocalAttrs
                   {-# LINE 55735 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitEnds =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   foldr ($) _gathVisitEnds_augmented_syn [_gathVisitEnds_augmented_f1]
                   {-# LINE 55740 "src/Transform.hs" #-})
              -- augment function
              _gathVisitEnds_augmented_f1 =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   _visitEndDep     Seq.<|
                   {-# LINE 55745 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitNames =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   foldr ($) _gathVisitNames_augmented_syn [_gathVisitNames_augmented_f1]
                   {-# LINE 55750 "src/Transform.hs" #-})
              -- augment function
              _gathVisitNames_augmented_f1 =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   extend name_ ()
                   {-# LINE 55755 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitStarts =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   foldr ($) _gathVisitStarts_augmented_syn [_gathVisitStarts_augmented_f1]
                   {-# LINE 55760 "src/Transform.hs" #-})
              -- augment function
              _gathVisitStarts_augmented_f1 =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   _scopeDep       Seq.<|
                   {-# LINE 55765 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 229, column 12)
              _attrsOgathChns =
                  ({-# LINE 229 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 55770 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 602, column 26)
              _distRenames =
                  ({-# LINE 602 "src/Transform.ag" #-}
                   _stmtsIgathRenames `unionWithUnion` _lhsIdistRenames
                   {-# LINE 55775 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 697, column 32)
              _visitNr =
                  ({-# LINE 697 "src/Transform.ag" #-}
                   _lhsIvisitNr + 1
                   {-# LINE 55780 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 732, column 23)
              _doneVisits =
                  ({-# LINE 732 "src/Transform.ag" #-}
                   name_ : _lhsIdoneVisits
                   {-# LINE 55785 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 736, column 12)
              _unqualItf =
                  ({-# LINE 736 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 55790 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 737, column 12)
              _itfVisits =
                  ({-# LINE 737 "src/Transform.ag" #-}
                   Map.findWithDefault [] _unqualItf     _lhsIdistVisitOrder
                   {-# LINE 55795 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 738, column 12)
              __tup67 =
                  ({-# LINE 738 "src/Transform.ag" #-}
                   checkVisitSequence pos_ name_ _lhsInextVisits
                   {-# LINE 55800 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 738, column 12)
              (_sequenceErrs,_) =
                  ({-# LINE 738 "src/Transform.ag" #-}
                   __tup67
                   {-# LINE 55805 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 738, column 12)
              (_,_clausesOnextVisits) =
                  ({-# LINE 738 "src/Transform.ag" #-}
                   __tup67
                   {-# LINE 55810 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 766, column 32)
              _masterPos =
                  ({-# LINE 766 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 55815 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 846, column 15)
              _lhsOisInternal =
                  ({-# LINE 846 "src/Transform.ag" #-}
                   False
                   {-# LINE 55820 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 905, column 24)
              _stmtsOdirectVisitLocalAttrs =
                  ({-# LINE 905 "src/Transform.ag" #-}
                   _attrsIgathVisitLocalAttrs
                   {-# LINE 55825 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 906, column 24)
              _clausesOdirectVisitLocalAttrs =
                  ({-# LINE 906 "src/Transform.ag" #-}
                   _attrsIgathVisitLocalAttrs
                   {-# LINE 55830 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1055, column 7)
              _ldefs1 =
                  ({-# LINE 1055 "src/Transform.ag" #-}
                   enter _lhsIgathVisLocalDefs
                   {-# LINE 55835 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1056, column 7)
              _stmtsOgathVisLocalDefs =
                  ({-# LINE 1056 "src/Transform.ag" #-}
                   _ldefs2
                   {-# LINE 55840 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1057, column 7)
              __tup68 =
                  ({-# LINE 1057 "src/Transform.ag" #-}
                   leave _implsIgathVisLocalDefs
                   {-# LINE 55845 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1057, column 7)
              (_lhsOgathVisLocalDefs,_) =
                  ({-# LINE 1057 "src/Transform.ag" #-}
                   __tup68
                   {-# LINE 55850 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1057, column 7)
              (_,_localVisLocalDefs) =
                  ({-# LINE 1057 "src/Transform.ag" #-}
                   __tup68
                   {-# LINE 55855 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1058, column 7)
              _stmtsOdistVisLocalDefs =
                  ({-# LINE 1058 "src/Transform.ag" #-}
                   enterWith _localVisLocalDefs     _lhsIdistVisLocalDefs
                   {-# LINE 55860 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1059, column 7)
              __tup69 =
                  ({-# LINE 1059 "src/Transform.ag" #-}
                   leave _implsIdistVisLocalDefs
                   {-# LINE 55865 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1059, column 7)
              (_lhsOdistVisLocalDefs,_) =
                  ({-# LINE 1059 "src/Transform.ag" #-}
                   __tup69
                   {-# LINE 55870 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1059, column 7)
              (_,_localVisLocalDefs') =
                  ({-# LINE 1059 "src/Transform.ag" #-}
                   __tup69
                   {-# LINE 55875 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1096, column 7)
              _ldefs2 =
                  ({-# LINE 1096 "src/Transform.ag" #-}
                   Map.foldWithKey (\n t -> extend (replPos pos_ visIdent,replPos pos_ n,True) (Just t)) _ldefs1     _attrsIgathVisitLocalAttrs
                   {-# LINE 55880 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1102, column 23)
              _clausesOlocalAttrs =
                  ({-# LINE 1102 "src/Transform.ag" #-}
                   _attrsIgathVisitLocalAttrs
                   {-# LINE 55885 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1113, column 3)
              _inhAttrMap =
                  ({-# LINE 1113 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty name_ (Map.findWithDefault Map.empty (head _lhsIitf) _lhsIdistVisitInhAttrs)
                   {-# LINE 55890 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1118, column 23)
              _clausesOvisit =
                  ({-# LINE 1118 "src/Transform.ag" #-}
                   name_
                   {-# LINE 55895 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1193, column 3)
              impls_val_ =
                  ({-# LINE 1193 "src/Transform.ag" #-}
                   [ ImplStmt_Invoke pos_ nm s (findChild nm _lhsIdistChildDefs)
                   | (nm,vs) <- Map.assocs _implicitInvokes    , s <- Set.toList vs ]
                   {-# LINE 55901 "src/Transform.hs" #-})
              impls_inst_ =
                  (sem_ImplStmts impls_val_ )
              -- "src/Transform.ag"(line 1313, column 32)
              _distChildOcc =
                  ({-# LINE 1313 "src/Transform.ag" #-}
                   _stmtsIgathChildOcc `unionWithMin` _lhsIdistChildOcc
                   {-# LINE 55908 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1349, column 32)
              _itfNm =
                  ({-# LINE 1349 "src/Transform.ag" #-}
                   head _lhsIitf
                   {-# LINE 55913 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1354, column 21)
              _lhsOmbNextVisit =
                  ({-# LINE 1354 "src/Transform.ag" #-}
                   Just name_
                   {-# LINE 55918 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1560, column 3)
              _stmtsOgathNextVisits =
                  ({-# LINE 1560 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 55923 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1561, column 3)
              _clausesOdistNextVisits =
                  ({-# LINE 1561 "src/Transform.ag" #-}
                   _implsIgathNextVisits `Map.union` _lhsIdistNextVisits
                   {-# LINE 55928 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1596, column 3)
              _myNextVisits =
                  ({-# LINE 1596 "src/Transform.ag" #-}
                   Map.filter isJust _lhsIdistNextVisits
                   {-# LINE 55933 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1626, column 3)
              _distChildMinRanges =
                  ({-# LINE 1626 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `unionWithPlusplus` _lhsIdistChildMinRanges
                   {-# LINE 55938 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1627, column 3)
              _distAllChildMinRanges =
                  ({-# LINE 1627 "src/Transform.ag" #-}
                   _stmtsIgathChildMinRanges `Map.union` _lhsIdistChildMinRanges
                   {-# LINE 55943 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1628, column 3)
              _distChildEffRanges =
                  ({-# LINE 1628 "src/Transform.ag" #-}
                   _stmtsIgathChildEffRanges `unionWithUnion` _lhsIdistChildEffRanges
                   {-# LINE 55948 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1629, column 3)
              _introChildren =
                  ({-# LINE 1629 "src/Transform.ag" #-}
                   Map.keysSet (Map.difference _stmtsIgathChildMinRanges _lhsIdistAllChildMinRanges)
                   {-# LINE 55953 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1678, column 3)
              _minReqInvokes1 =
                  ({-# LINE 1678 "src/Transform.ag" #-}
                   _stmtsIminReqInvokes `unionWithUnion` _clausesIminReqInvokes
                   {-# LINE 55958 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1679, column 3)
              _allReqInvokes1 =
                  ({-# LINE 1679 "src/Transform.ag" #-}
                   _stmtsIallReqInvokes `unionWithUnion` _clausesIallReqInvokes
                   {-# LINE 55963 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1680, column 3)
              _minReqInvokes =
                  ({-# LINE 1680 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _minReqInvokes1
                   {-# LINE 55968 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1681, column 3)
              _allReqInvokes =
                  ({-# LINE 1681 "src/Transform.ag" #-}
                   Map.filterWithKey (\k _ -> not (Set.member k _introChildren    )) _allReqInvokes1
                   {-# LINE 55973 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1757, column 3)
              _implicitInvokes =
                  ({-# LINE 1757 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _lhsIavailInvokes
                                       `diffInside` _stmtsIexplInvokes
                                       `diffInside` _clausesIbannedInvokes
                   {-# LINE 55980 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1760, column 3)
              _additionalInvokes =
                  ({-# LINE 1760 "src/Transform.ag" #-}
                   _minReqInvokes1     `diffInside` _clausesIbannedInvokes `unionWithUnion` _stmtsIexplInvokes
                   {-# LINE 55985 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1761, column 3)
              _availInvokes =
                  ({-# LINE 1761 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` _lhsIavailInvokes
                   {-# LINE 55990 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1762, column 3)
              _allAvailInvokes =
                  ({-# LINE 1762 "src/Transform.ag" #-}
                   _additionalInvokes     `unionWithUnion` (
                     Map.filterWithKey (notIn _introChildren    ) _lhsIallAvailInvokes )
                   {-# LINE 55996 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1801, column 3)
              _missingInvokes =
                  ({-# LINE 1801 "src/Transform.ag" #-}
                   Set.toList (_stmtsIgathMissingInvokes `Set.difference` _clausesIgathMissingInvokes)
                   {-# LINE 56001 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1822, column 32)
              _distDeflStmts =
                  ({-# LINE 1822 "src/Transform.ag" #-}
                   _stmtsIgathDeflStmts `Map.union` _lhsIdistDeflStmts
                   {-# LINE 56006 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1904, column 3)
              _fullCyclic =
                  ({-# LINE 1904 "src/Transform.ag" #-}
                   Set.member name_ _lhsIfullCyclicVisits
                   {-# LINE 56011 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1905, column 3)
              _allowCycles =
                  ({-# LINE 1905 "src/Transform.ag" #-}
                   cyclic_ || _lhsIfullCyclic
                   {-# LINE 56016 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1967, column 3)
              _nClauses =
                  ({-# LINE 1967 "src/Transform.ag" #-}
                   Set.size _clausesIgathClauseNames
                   {-# LINE 56021 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2056, column 25)
              _distAttrSource =
                  ({-# LINE 2056 "src/Transform.ag" #-}
                   Map.unions [ _gathChnAttrSource
                              , _stmtsIgathAttrSource
                              , _gathVisAttrSource
                              , _implsIgathAttrSource
                              , _lhsIdistAttrSource ]
                   {-# LINE 56030 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2070, column 3)
              _gathChnAttrSource =
                  ({-# LINE 2070 "src/Transform.ag" #-}
                   Map.fromList [ ((True,visIdent,attr),  _scopeDep    )    | attr <- Map.keys _attrsIgathVisitLocalAttrs ]
                   {-# LINE 56035 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2071, column 3)
              _gathVisAttrSource =
                  ({-# LINE 2071 "src/Transform.ag" #-}
                   Map.fromList [ ((False,name_,attr),    _visitEndDep    ) | attr <- Map.keys _attrsIgathVisitLocalAttrs ]
                   {-# LINE 56040 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2116, column 3)
              _distChildSource =
                  ({-# LINE 2116 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathChildSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistChildSource ]
                   {-# LINE 56046 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2135, column 3)
              _distVisitSource =
                  ({-# LINE 2135 "src/Transform.ag" #-}
                   Map.unionsWith mappend [ _stmtsIgathVisitSource
                                          , Map.filterWithKey (notIn _introChildren    ) _lhsIdistVisitSource ]
                   {-# LINE 56052 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2159, column 3)
              _scopeReason =
                  ({-# LINE 2159 "src/Transform.ag" #-}
                   ReasonScopeVisit name_
                   {-# LINE 56057 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2160, column 3)
              _scopeDep =
                  ({-# LINE 2160 "src/Transform.ag" #-}
                   DepVisStart (name_ : _lhsIsemBasename)
                   {-# LINE 56062 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2161, column 3)
              _visitBeginDep =
                  ({-# LINE 2161 "src/Transform.ag" #-}
                   DepVisStart (name_ : _lhsIsemBasename)
                   {-# LINE 56067 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2162, column 3)
              _visitEndDep =
                  ({-# LINE 2162 "src/Transform.ag" #-}
                   DepVisEnd   (name_ : _lhsIsemBasename)
                   {-# LINE 56072 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2163, column 3)
              _visitEndReason =
                  ({-# LINE 2163 "src/Transform.ag" #-}
                   ReasonScopeEnd name_
                   {-# LINE 56077 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              __tup70 =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _scopeDep     _lhsIdistRanks
                   {-# LINE 56082 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   __tup70
                   {-# LINE 56087 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2387, column 3)
              (_,_rank) =
                  ({-# LINE 2387 "src/Transform.ag" #-}
                   __tup70
                   {-# LINE 56092 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2388, column 3)
              _isCyclic =
                  ({-# LINE 2388 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 56097 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2398, column 32)
              _lhsOminRank =
                  ({-# LINE 2398 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 56102 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2514, column 18)
              _lhsOpp =
                  ({-# LINE 2514 "src/Transform.ag" #-}
                   "visit" >#< name_
                   >-< indent 2 (   vlist _attrsIpps
                                >-< vlist _stmtsIpps
                                >-< vlist _implsIpps
                                >-< vlist _clausesIpps
                                )
                   {-# LINE 56112 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 270, column 18)
              _hChildren =
                  ({-# LINE 270 "src/TargetHaskell.ag" #-}
                   hlist_sp [ hSemNm k v | (k, Just v) <- Map.assocs _myNextVisits     ]
                   {-# LINE 56117 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 271, column 18)
              _hChns =
                  ({-# LINE 271 "src/TargetHaskell.ag" #-}
                   [ hParensWithPos _lhsIopts pos_ $ hInp visIdent nm | (nm,_) <- Map.assocs _attrsIgathVisitLocalAttrs ]
                   {-# LINE 56122 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 272, column 18)
              _hChnsOut =
                  ({-# LINE 272 "src/TargetHaskell.ag" #-}
                   [ hParensWithPos _lhsIopts pos_ $ hOutp name_ nm | (nm,_) <- Map.assocs _attrsIgathVisitLocalAttrs ]
                   {-# LINE 56127 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 273, column 18)
              _hInhPPs =
                  ({-# LINE 273 "src/TargetHaskell.ag" #-}
                   [ hInhFldNm nm _itfNm     name_ >#< "=" >#< hParensWithPos _lhsIopts pos_ (hInp lhsIdent nm)
                   | (nm,_) <- Map.assocs _inhAttrMap     ]
                   {-# LINE 56133 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 275, column 18)
              _hMatch =
                  ({-# LINE 275 "src/TargetHaskell.ag" #-}
                   pp_parens (hInhDt _itfNm     name_ >#< pp_block "{" "}" "," _hInhPPs    )
                   {-# LINE 56138 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 276, column 18)
              _hVisType =
                  ({-# LINE 276 "src/TargetHaskell.ag" #-}
                   if _lhsIwithinCoSem
                   then text (hCoItfVsNm _lhsIcoItf name_)
                   else text (hItfVsNm _itfNm     name_)
                   {-# LINE 56145 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 279, column 18)
              _lhsOhpp =
                  ({-# LINE 279 "src/TargetHaskell.ag" #-}
                   pp_parens (
                     "let -- __vis ::" >#< _hVisType
                     >-< "    __vis =" >#< (
                       "let" >#< ( hVis name_ >#< _hChildren     >#< _hChns     >#< _hMatch
                                 >-< indent 2 (
                                   "=" >#< ( if _fullCyclic
                                             then "let" >#< vlist (concat _hGroupedStmts    )
                                                  >-< "in" >#< _clausesIhpp
                                             else "do" >#< (
                                                    hppStmtBlock _hGroupedStmts
                                                    >-< _clausesIhpp
                                                  )
                                           )
                                   )
                                 )
                       >-< "in" >#< hItfVsNm _itfNm     name_ >#<
                             pp_parens (hVis name_ >#< _hChildren     >#< _hChnsOut    )
                     ) >-< "in __vis"
                   )
                   {-# LINE 56168 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              __tup71 =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   partition (rankIsLower _clausesIminRank)
                     (_lhsIhSpilledStmts ++ _implsIhopps ++ _stmtsIhopps)
                   {-# LINE 56174 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              (_hoStmts,_) =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   __tup71
                   {-# LINE 56179 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 594, column 3)
              (_,_clausesOhSpilledStmts) =
                  ({-# LINE 594 "src/TargetHaskell.ag" #-}
                   __tup71
                   {-# LINE 56184 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 596, column 3)
              _hGroupedStmts =
                  ({-# LINE 596 "src/TargetHaskell.ag" #-}
                   groupPairs _hoStmts
                   {-# LINE 56189 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 169, column 18)
              _lhsOjspp =
                  ({-# LINE 169 "src/TargetJs.ag" #-}
                   "function (_inps)"
                   >-< pp_braces (
                         "_inps.check();"
                         >-< vlist [ "var" >#< jsInp lhsIdent nm >#< "=" >#< "_inps." >|< show nm >|< ";"
                                   | (nm,_) <- Map.assocs _inhAttrMap     ]
                         >-< jsppStmtBlock _jsGroupedStmts
                         >-< _clausesIjspp
                       )
                   {-# LINE 56201 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              __tup72 =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   partition (rankIsLower _clausesIminRank)
                     (_lhsIjsSpilledStmts ++ _implsIjsopps ++ _stmtsIjsopps)
                   {-# LINE 56207 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              (_jsoStmts,_) =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   __tup72
                   {-# LINE 56212 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 389, column 3)
              (_,_clausesOjsSpilledStmts) =
                  ({-# LINE 389 "src/TargetJs.ag" #-}
                   __tup72
                   {-# LINE 56217 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 391, column 3)
              _jsGroupedStmts =
                  ({-# LINE 391 "src/TargetJs.ag" #-}
                   groupPairs _jsoStmts
                   {-# LINE 56222 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup73 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_stmtsOlexCounter,_) =
                  ({-# LINE 1288 "src/Transform.ag" #-}
                   __tup73
                   {-# LINE 56230 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1288 "src/Transform.ag" #-}
                   __tup73
                   {-# LINE 56235 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _allReqInvokes
                   {-# LINE 56240 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _bannedInvokes_augmented_syn =
                  ({-# LINE 1652 "src/Transform.ag" #-}
                   _stmtsIbannedInvokes `unionWithUnion` _clausesIbannedInvokes
                   {-# LINE 56245 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs0_augmented_syn =
                  ({-# LINE 739 "src/Transform.ag" #-}
                   _stmtsIerrs0 Seq.>< _clausesIerrs0
                   {-# LINE 56250 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 1968 "src/Transform.ag" #-}
                   _stmtsIerrs1 Seq.>< _clausesIerrs1
                   {-# LINE 56255 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 1802 "src/Transform.ag" #-}
                   _stmtsIerrs2 Seq.>< _clausesIerrs2 Seq.>< _implsIerrs2
                   {-# LINE 56260 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs3_augmented_syn =
                  ({-# LINE 1062 "src/Transform.ag" #-}
                   _stmtsIerrs3 Seq.>< _clausesIerrs3 Seq.>< _implsIerrs3
                   {-# LINE 56265 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs4 Seq.>< _clausesIerrs4 Seq.>< _implsIerrs4
                   {-# LINE 56270 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _stmtsIerrs5 Seq.>< _clausesIerrs5 Seq.>< _implsIerrs5
                   {-# LINE 56275 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1914, column 66)
              _gathAllowCycVisits_augmented_syn =
                  ({-# LINE 1919 "src/Transform.ag" #-}
                   _clausesIgathAllowCycVisits
                   {-# LINE 56280 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _stmtsIgathAttrSource `Map.union` _clausesIgathAttrSource `Map.union` _implsIgathAttrSource
                   {-# LINE 56285 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _gathAvoidVisits_augmented_syn =
                  ({-# LINE 1987 "src/Transform.ag" #-}
                   _stmtsIgathAvoidVisits `Set.union` _clausesIgathAvoidVisits
                   {-# LINE 56290 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _stmtsIgathChildSource `unionWithUnion` _clausesIgathChildSource `unionWithUnion` _implsIgathChildSource
                   {-# LINE 56295 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2300 "src/Transform.ag" #-}
                   _stmtsIgathDeps Seq.>< _clausesIgathDeps Seq.>< _implsIgathDeps
                   {-# LINE 56300 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1993 "src/Transform.ag" #-}
                   _stmtsIgathItemVisits `Map.union` _clausesIgathItemVisits `Map.union` _implsIgathItemVisits
                   {-# LINE 56305 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _stmtsIgathLegalCycStmts `Set.union` _clausesIgathLegalCycStmts `Set.union` _implsIgathLegalCycStmts
                   {-# LINE 56310 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _stmtsIgathMissingInvokes `Set.union` _clausesIgathMissingInvokes
                   {-# LINE 56315 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2053, column 46)
              _lhsOgathSemAttrSource =
                  ({-# LINE 2053 "src/Transform.ag" #-}
                   _clausesIgathSemAttrSource
                   {-# LINE 56320 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _gathSemStarts_augmented_syn =
                  ({-# LINE 1848 "src/Transform.ag" #-}
                   _stmtsIgathSemStarts Seq.>< _clausesIgathSemStarts
                   {-# LINE 56325 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _stmtsIgathStmtPosMap `Map.union` _clausesIgathStmtPosMap `Map.union` _implsIgathStmtPosMap
                   {-# LINE 56330 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1857, column 43)
              _gathVisRankMap_augmented_syn =
                  ({-# LINE 1861 "src/Transform.ag" #-}
                   _clausesIgathVisRankMap
                   {-# LINE 56335 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 895, column 62)
              _gathVisitAttrs_augmented_syn =
                  ({-# LINE 898 "src/Transform.ag" #-}
                   _clausesIgathVisitAttrs
                   {-# LINE 56340 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _gathVisitEnds_augmented_syn =
                  ({-# LINE 1840 "src/Transform.ag" #-}
                   _stmtsIgathVisitEnds Seq.>< _clausesIgathVisitEnds
                   {-# LINE 56345 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _stmtsIgathVisitSource `unionWithUnion` _clausesIgathVisitSource `unionWithUnion` _implsIgathVisitSource
                   {-# LINE 56350 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _gathVisitStarts_augmented_syn =
                  ({-# LINE 1839 "src/Transform.ag" #-}
                   _stmtsIgathVisitStarts Seq.>< _clausesIgathVisitStarts
                   {-# LINE 56355 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _minReqInvokes
                   {-# LINE 56360 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _clausesIcodeIdCounter
                   {-# LINE 56365 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 56370 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 56375 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 56380 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 56385 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIdistDefs
                   {-# LINE 56390 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 56395 "src/Transform.hs" #-})
              -- copy rule (up)
              _distVisits_augmented_syn =
                  ({-# LINE 430 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 56400 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 56405 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 56410 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _clausesIgathDataSems
                   {-# LINE 56415 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _implsIgathDefs
                   {-# LINE 56420 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 56425 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathVisitNames_augmented_syn =
                  ({-# LINE 832 "src/Transform.ag" #-}
                   _clausesIgathVisitNames
                   {-# LINE 56430 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _implsIlexCounter
                   {-# LINE 56435 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 56440 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 56445 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 56450 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 56455 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 56460 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 56465 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 56470 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 56475 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 56480 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 56485 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 56490 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 56495 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 56500 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 56505 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 56510 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 56515 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 56520 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 56525 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 56530 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 56535 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 56540 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 56545 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 56550 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 56555 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 56560 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 56565 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 56570 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 56575 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 56580 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 56585 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 56590 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 56595 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 56600 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 56605 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 56610 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 56615 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 56620 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 56625 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 56630 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 56635 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 56640 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 56645 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 56650 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 56655 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 56660 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 56665 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 56670 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 56675 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 56680 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 56685 "src/Transform.hs" #-})
              -- copy rule (down)
              _stmtsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 56690 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 56695 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 56700 "src/Transform.hs" #-})
              -- copy rule (from local)
              _stmtsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 56705 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 56710 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 56715 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 56720 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 56725 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 56730 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOclauseExtras =
                  ({-# LINE 620 "src/Transform.ag" #-}
                   _lhsIclauseExtras
                   {-# LINE 56735 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 56740 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _stmtsIcodeIdCounter
                   {-# LINE 56745 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 56750 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 56755 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 56760 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 56765 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 56770 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _stmtsIdistChildDefs
                   {-# LINE 56775 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 56780 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 56785 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 56790 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 56795 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 56800 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _stmtsIdistDataCons
                   {-# LINE 56805 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 56810 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _stmtsIdistDataSems
                   {-# LINE 56815 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _stmtsIdistDatas
                   {-# LINE 56820 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 56825 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIdistDefs
                   {-# LINE 56830 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 56835 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _stmtsIdistItfs
                   {-# LINE 56840 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 56845 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 56850 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 56855 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIdistVisLocalDefs
                   {-# LINE 56860 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 56865 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 56870 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 56875 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 56880 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 56885 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _stmtsIdistVisits
                   {-# LINE 56890 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 56895 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOfullCyclic =
                  ({-# LINE 1896 "src/Transform.ag" #-}
                   _fullCyclic
                   {-# LINE 56900 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 56905 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _stmtsIgathChildDefs
                   {-# LINE 56910 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathClauses
                   {-# LINE 56915 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _stmtsIgathDataSems
                   {-# LINE 56920 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIgathDefs
                   {-# LINE 56925 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _stmtsIgathNonterms
                   {-# LINE 56930 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _stmtsIgathVisLocalDefs
                   {-# LINE 56935 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOgathVisitNames =
                  ({-# LINE 830 "src/Transform.ag" #-}
                   _lhsIgathVisitNames
                   {-# LINE 56940 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 56945 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 56950 "src/Transform.hs" #-})
              -- copy rule (chain)
              _clausesOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _stmtsIlexCounter
                   {-# LINE 56955 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOmasterPos =
                  ({-# LINE 763 "src/Transform.ag" #-}
                   _masterPos
                   {-# LINE 56960 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOmyNextVisits =
                  ({-# LINE 1591 "src/Transform.ag" #-}
                   _myNextVisits
                   {-# LINE 56965 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 56970 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 56975 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 56980 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 56985 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOsemBasename =
                  ({-# LINE 1398 "src/Transform.ag" #-}
                   _lhsIsemBasename
                   {-# LINE 56990 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 56995 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 57000 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 57005 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 57010 "src/Transform.hs" #-})
              -- copy rule (from local)
              _clausesOvisitNr =
                  ({-# LINE 693 "src/Transform.ag" #-}
                   _visitNr
                   {-# LINE 57015 "src/Transform.hs" #-})
              -- copy rule (down)
              _clausesOwithinCoSem =
                  ({-# LINE 1409 "src/Transform.ag" #-}
                   _lhsIwithinCoSem
                   {-# LINE 57020 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _allAvailInvokes
                   {-# LINE 57025 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 57030 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 57035 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _availInvokes
                   {-# LINE 57040 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 57045 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 57050 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 57055 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 57060 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 57065 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distAllChildMinRanges
                   {-# LINE 57070 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _distAttrSource
                   {-# LINE 57075 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 57080 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _clausesIdistChildDefs
                   {-# LINE 57085 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _distChildEffRanges
                   {-# LINE 57090 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _distChildMinRanges
                   {-# LINE 57095 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _distChildOcc
                   {-# LINE 57100 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _distChildSource
                   {-# LINE 57105 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 57110 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _clausesIdistDataCons
                   {-# LINE 57115 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 57120 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _clausesIdistDataSems
                   {-# LINE 57125 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _clausesIdistDatas
                   {-# LINE 57130 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _distDeflStmts
                   {-# LINE 57135 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistDefs
                   {-# LINE 57140 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 57145 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _clausesIdistItfs
                   {-# LINE 57150 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 57155 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _distRenames
                   {-# LINE 57160 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 57165 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIdistVisLocalDefs
                   {-# LINE 57170 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 57175 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 57180 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 57185 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _distVisitSource
                   {-# LINE 57190 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 57195 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _clausesIdistVisits
                   {-# LINE 57200 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _doneVisits
                   {-# LINE 57205 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 57210 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _clausesIgathChildDefs
                   {-# LINE 57215 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _clausesIgathClauses
                   {-# LINE 57220 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathDefs
                   {-# LINE 57225 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _stmtsIgathNextVisits
                   {-# LINE 57230 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _clausesIgathNonterms
                   {-# LINE 57235 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _clausesIgathVisLocalDefs
                   {-# LINE 57240 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 57245 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 57250 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 57255 "src/Transform.hs" #-})
              -- copy rule (chain)
              _implsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _clausesIlexCounter
                   {-# LINE 57260 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 57265 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 57270 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeDep
                   {-# LINE 57275 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _scopeReason
                   {-# LINE 57280 "src/Transform.hs" #-})
              -- copy rule (down)
              _implsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 57285 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitBeginDep
                   {-# LINE 57290 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndDep
                   {-# LINE 57295 "src/Transform.hs" #-})
              -- copy rule (from local)
              _implsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _visitEndReason
                   {-# LINE 57300 "src/Transform.hs" #-})
              ( _attrsIgathChns,_attrsIgathVisitLocalAttrs,_attrsIpps) =
                  attrs_ _attrsOgathChns 
              ( _stmtsIallReqInvokes,_stmtsIbannedInvokes,_stmtsIcodeIdCounter,_stmtsIdistChildDefs,_stmtsIdistDataCons,_stmtsIdistDataSems,_stmtsIdistDatas,_stmtsIdistDefs,_stmtsIdistItfs,_stmtsIdistVisLocalDefs,_stmtsIdistVisits,_stmtsIerrs0,_stmtsIerrs1,_stmtsIerrs2,_stmtsIerrs3,_stmtsIerrs4,_stmtsIerrs5,_stmtsIexplInvokes,_stmtsIgathAttrSource,_stmtsIgathAvoidVisits,_stmtsIgathChildDefs,_stmtsIgathChildEffRanges,_stmtsIgathChildMinRanges,_stmtsIgathChildOcc,_stmtsIgathChildSource,_stmtsIgathClauses,_stmtsIgathDataSems,_stmtsIgathDeflStmts,_stmtsIgathDefs,_stmtsIgathDeps,_stmtsIgathItemVisits,_stmtsIgathLegalCycStmts,_stmtsIgathMissingInvokes,_stmtsIgathNextVisits,_stmtsIgathNonterms,_stmtsIgathRenames,_stmtsIgathSemStarts,_stmtsIgathStmtPosMap,_stmtsIgathVisLocalDefs,_stmtsIgathVisitEnds,_stmtsIgathVisitSource,_stmtsIgathVisitStarts,_stmtsIhopps,_stmtsIjsopps,_stmtsIlexCounter,_stmtsIminReqInvokes,_stmtsIpps) =
                  stmts_ _stmtsOallAvailInvokes _stmtsOallVisits _stmtsOallowCycVisits _stmtsOavailInvokes _stmtsObasename _stmtsOcoItf _stmtsOcodeIdCounter _stmtsOdirectVisitAttrs _stmtsOdirectVisitLocalAttrs _stmtsOdistAliasses _stmtsOdistAllChildMinRanges _stmtsOdistAttrSource _stmtsOdistAttrVisMap _stmtsOdistChildDefs _stmtsOdistChildEffRanges _stmtsOdistChildMinRanges _stmtsOdistChildOcc _stmtsOdistChildSource _stmtsOdistCycVisMap _stmtsOdistDataCons _stmtsOdistDataMap _stmtsOdistDataSems _stmtsOdistDatas _stmtsOdistDeflStmts _stmtsOdistDefs _stmtsOdistInhAttrs _stmtsOdistItfs _stmtsOdistRanks _stmtsOdistRenames _stmtsOdistSynAttrs _stmtsOdistVisLocalDefs _stmtsOdistVisRankMap _stmtsOdistVisitInhAttrs _stmtsOdistVisitOrder _stmtsOdistVisitSource _stmtsOdistVisitSynAttrs _stmtsOdistVisits _stmtsOdoneVisits _stmtsOfullCyclicVisits _stmtsOgathChildDefs _stmtsOgathClauses _stmtsOgathDataSems _stmtsOgathDefs _stmtsOgathNextVisits _stmtsOgathNonterms _stmtsOgathVisLocalDefs _stmtsOhSpilledStmts _stmtsOindent _stmtsOitf _stmtsOjsSpilledStmts _stmtsOlexCounter _stmtsOnonterm _stmtsOopts _stmtsOscopeDep _stmtsOscopeReason _stmtsOstmtSource _stmtsOvisitBeginDep _stmtsOvisitEndDep _stmtsOvisitEndReason 
              ( _clausesIallReqInvokes,_clausesIbannedInvokes,_clausesIcodeIdCounter,_clausesIdistChildDefs,_clausesIdistDataCons,_clausesIdistDataSems,_clausesIdistDatas,_clausesIdistDefs,_clausesIdistItfs,_clausesIdistVisLocalDefs,_clausesIdistVisits,_clausesIerrs0,_clausesIerrs1,_clausesIerrs2,_clausesIerrs3,_clausesIerrs4,_clausesIerrs5,_clausesIgathAllowCycVisits,_clausesIgathAttrSource,_clausesIgathAvoidVisits,_clausesIgathChildDefs,_clausesIgathChildSource,_clausesIgathClauseNames,_clausesIgathClauses,_clausesIgathDataSems,_clausesIgathDefs,_clausesIgathDeps,_clausesIgathItemVisits,_clausesIgathLegalCycStmts,_clausesIgathMissingInvokes,_clausesIgathNonterms,_clausesIgathSemAttrSource,_clausesIgathSemStarts,_clausesIgathStmtPosMap,_clausesIgathVisLocalDefs,_clausesIgathVisRankMap,_clausesIgathVisitAttrs,_clausesIgathVisitEnds,_clausesIgathVisitNames,_clausesIgathVisitSource,_clausesIgathVisitStarts,_clausesIhpp,_clausesIjspp,_clausesIlexCounter,_clausesIminRank,_clausesIminReqInvokes,_clausesInClauses,_clausesIpps) =
                  clauses_ _clausesOallAvailInvokes _clausesOallVisits _clausesOallowCycVisits _clausesOavailInvokes _clausesObasename _clausesOclauseExtras _clausesOcoItf _clausesOcodeIdCounter _clausesOdirectVisitAttrs _clausesOdirectVisitLocalAttrs _clausesOdistAliasses _clausesOdistAllChildMinRanges _clausesOdistAttrSource _clausesOdistAttrVisMap _clausesOdistChildDefs _clausesOdistChildEffRanges _clausesOdistChildMinRanges _clausesOdistChildOcc _clausesOdistChildSource _clausesOdistCycVisMap _clausesOdistDataCons _clausesOdistDataMap _clausesOdistDataSems _clausesOdistDatas _clausesOdistDeflStmts _clausesOdistDefs _clausesOdistInhAttrs _clausesOdistItfs _clausesOdistNextVisits _clausesOdistRanks _clausesOdistRenames _clausesOdistSynAttrs _clausesOdistVisLocalDefs _clausesOdistVisRankMap _clausesOdistVisitInhAttrs _clausesOdistVisitOrder _clausesOdistVisitSource _clausesOdistVisitSynAttrs _clausesOdistVisits _clausesOdoneVisits _clausesOfullCyclic _clausesOfullCyclicVisits _clausesOgathChildDefs _clausesOgathClauses _clausesOgathDataSems _clausesOgathDefs _clausesOgathNonterms _clausesOgathVisLocalDefs _clausesOgathVisitNames _clausesOhSpilledStmts _clausesOindent _clausesOitf _clausesOjsSpilledStmts _clausesOlexCounter _clausesOlocalAttrs _clausesOmasterPos _clausesOmyNextVisits _clausesOnextVisits _clausesOnonterm _clausesOopts _clausesOscopeDep _clausesOscopeReason _clausesOsemBasename _clausesOstmtSource _clausesOvisit _clausesOvisitBeginDep _clausesOvisitEndDep _clausesOvisitEndReason _clausesOvisitNr _clausesOwithinCoSem 
              ( _implsIdistDefs,_implsIdistVisLocalDefs,_implsIerrs2,_implsIerrs3,_implsIerrs4,_implsIerrs5,_implsIgathAttrSource,_implsIgathChildSource,_implsIgathDefs,_implsIgathDeps,_implsIgathItemVisits,_implsIgathLegalCycStmts,_implsIgathNextVisits,_implsIgathStmtPosMap,_implsIgathVisLocalDefs,_implsIgathVisitSource,_implsIhopps,_implsIjsopps,_implsIlexCounter,_implsIpps) =
                  impls_inst_ _implsOallAvailInvokes _implsOallVisits _implsOallowCycVisits _implsOavailInvokes _implsObasename _implsOcoItf _implsOdirectVisitAttrs _implsOdirectVisitLocalAttrs _implsOdistAliasses _implsOdistAllChildMinRanges _implsOdistAttrSource _implsOdistAttrVisMap _implsOdistChildDefs _implsOdistChildEffRanges _implsOdistChildMinRanges _implsOdistChildOcc _implsOdistChildSource _implsOdistCycVisMap _implsOdistDataCons _implsOdistDataMap _implsOdistDataSems _implsOdistDatas _implsOdistDeflStmts _implsOdistDefs _implsOdistInhAttrs _implsOdistItfs _implsOdistRanks _implsOdistRenames _implsOdistSynAttrs _implsOdistVisLocalDefs _implsOdistVisRankMap _implsOdistVisitInhAttrs _implsOdistVisitOrder _implsOdistVisitSource _implsOdistVisitSynAttrs _implsOdistVisits _implsOdoneVisits _implsOfullCyclicVisits _implsOgathChildDefs _implsOgathClauses _implsOgathDefs _implsOgathNextVisits _implsOgathNonterms _implsOgathVisLocalDefs _implsOhSpilledStmts _implsOitf _implsOjsSpilledStmts _implsOlexCounter _implsOnonterm _implsOopts _implsOscopeDep _implsOscopeReason _implsOstmtSource _implsOvisitBeginDep _implsOvisitEndDep _implsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAllowCycVisits,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNonterms,_lhsOgathSemAttrSource,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisRankMap,_lhsOgathVisitAttrs,_lhsOgathVisitEnds,_lhsOgathVisitNames,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOisInternal,_lhsOjspp,_lhsOlexCounter,_lhsOmbNextVisit,_lhsOminRank,_lhsOminReqInvokes,_lhsOpp)))
-- Stmt --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNextVisits       : Map Ident (Maybe Ident)
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         explInvokes          : Map Ident (Set Ident)
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildEffRanges   : Map Ident (Set Ident)
         gathChildMinRanges   : Map Ident [Ident]
         gathChildOcc         : Map Ident Int
         gathChildSource      : ChildSourceMap
         gathDeflStmts        : Map Ident (Bool,Maybe Int)
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathRenames          : RenameMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         minReqInvokes        : Map Ident (Set Ident)
         pp                   : PP_Doc
         rank                 : Int
   alternatives:
      alternative Attach:
         child pos            : {Pos}
         child mbVisit        : {Maybe Ident}
         child name           : {Ident}
         child type           : {Ident}
         child code           : MaybeBoundCode 
         visit 0:
            local distDataSems_augmented_f1 : _
            local distItfs_augmented_f1 : _
            local errs1_augmented_f1 : _
            local errs1_augmented_f2 : _
            local errs1_augmented_f3 : _
            local errs2_augmented_f1 : _
            local errs5_augmented_f1 : _
            local gathChildDefs_augmented_f1 : _
            local gathChildSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local childVisits : _
            local visit       : _
            local allAttaches : _
            local initType    : _
            local attrVisits  : _
            local visitReqs   : _
            local invokeReqs  : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local childSources : _
            local mbPrevEntry : _
            local _tup74      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local infoComment : _
            local hRhsCode    : _
            local jsRhsCode   : _
            local _tup75      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs1_augmented_syn : _
            local errs2_augmented_syn : _
            local errs5_augmented_syn : _
            local gathChildSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
            local distDataSems_augmented_syn : _
            local distItfs_augmented_syn : _
            local gathChildDefs_augmented_syn : _
      alternative Default:
         child allowEmpty     : {Bool}
         child pos            : {Pos}
         child name           : {Ident}
         child mbCode         : MaybeBoundCode 
         visit 0:
            local errs1_augmented_f1 : _
            local errs5_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local visitReqs   : _
            local invokeReqs  : _
            local mbCodeId    : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local _tup76      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local infoComment : _
            local _tup77      : {(Int,Int)}
            local codeId      : {Int}
            local _tup78      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs1_augmented_syn : _
            local errs5_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
      alternative Eval:
         child mode           : Mode 
         child pat            : Pat 
         child code           : BoundCode 
         visit 0:
            local errs5_augmented_f1 : _
            local errs5_augmented_f2 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local pos         : _
            local _tup79      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local infoComment : _
            local _tup80      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs5_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
      alternative Invoke:
         child pos            : {Pos}
         child visit          : {Ident}
         child name           : {Ident}
         child code           : MaybeBoundCode 
         visit 0:
            local errs1_augmented_f1 : _
            local errs5_augmented_f1 : _
            local errs5_augmented_f2 : _
            local errs5_augmented_f3 : _
            local gathAttrSource_augmented_f1 : _
            local gathDeps_augmented_f1 : _
            local gathDeps_augmented_f2 : _
            local gathDeps_augmented_f3 : _
            local gathDeps_augmented_f4 : _
            local gathDeps_augmented_f5 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathNextVisits_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local gathVisitSource_augmented_f1 : _
            local unqualChildItf : _
            local childVisits : _
            local _tup81      : _
            local _tup82      : _
            local childItf    : _
            local startVisit  : _
            local inhAttrMap  : _
            local synAttrMap  : _
            local missingAttrMap : _
            local _tup83      : _
            local deflAttrMap : _
            local undefAttrMap : _
            local deflAttrs   : _
            inst  deflts      : ImplStmts 
            local mbNextVisit : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local visitCyclic : _
            local behaveCyclic : _
            local stmtSource  : _
            local mbVisitSource : _
            local mbChildSource : _
            local _tup84      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local infoComment : _
            local hBang       : _
            local hRhsCode    : _
            local hIter       : _
            local hfInps      : _
            local hfOuts      : _
            local hgInps      : _
            local hgOuts      : _
            local hRhs        : _
            local hPat        : _
            local hGroupedStmts : _
            local jsGroupedStmts : _
            local _tup85      : {(Int,Int)}
            local lexOrder    : {Int}
            local errs1_augmented_syn : _
            local errs5_augmented_syn : _
            local gathAttrSource_augmented_syn : _
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
            local gathVisitSource_augmented_syn : _
            local gathNextVisits_augmented_syn : _
      alternative Rename:
         child pos            : {Pos}
         child child          : {Ident}
         child subst          : Renames 
         visit 0:
            local gathDeps_augmented_f1 : _
            local gathItemVisits_augmented_f1 : _
            local gathLegalCycStmts_augmented_f1 : _
            local gathStmtPosMap_augmented_f1 : _
            local destVisit   : _
            local fullCyclic  : _
            local allowCycles : _
            local stmtSource  : _
            local _tup86      : _
            local isOnCycle   : _
            local rank        : _
            local isCyclic    : _
            local _tup87      : {(Int,Int)}
            local lexOrder    : {Int}
            local gathDeps_augmented_syn : _
            local gathItemVisits_augmented_syn : _
            local gathLegalCycStmts_augmented_syn : _
            local gathStmtPosMap_augmented_syn : _
-}
-- cata
sem_Stmt :: Stmt  ->
            T_Stmt 
sem_Stmt (Stmt_Attach _pos _mbVisit _name _type _code )  =
    (sem_Stmt_Attach _pos _mbVisit _name _type (sem_MaybeBoundCode _code ) )
sem_Stmt (Stmt_Default _allowEmpty _pos _name _mbCode )  =
    (sem_Stmt_Default _allowEmpty _pos _name (sem_MaybeBoundCode _mbCode ) )
sem_Stmt (Stmt_Eval _mode _pat _code )  =
    (sem_Stmt_Eval (sem_Mode _mode ) (sem_Pat _pat ) (sem_BoundCode _code ) )
sem_Stmt (Stmt_Invoke _pos _visit _name _code )  =
    (sem_Stmt_Invoke _pos _visit _name (sem_MaybeBoundCode _code ) )
sem_Stmt (Stmt_Rename _pos _child _subst )  =
    (sem_Stmt_Rename _pos _child (sem_Renames _subst ) )
-- semantic domain
type T_Stmt  = (Map Ident (Set Ident)) ->
               (Set Ident) ->
               (Set Ident) ->
               (Map Ident (Set Ident)) ->
               QIdent ->
               Ident ->
               Int ->
               (Map Ident (Map Ident String)) ->
               (Map Ident String) ->
               (Map Ident AliasType) ->
               (Map Ident [Ident]) ->
               AttrSourceMap ->
               AttrVisMap ->
               (Env QIdent (QIdent,QIdent)) ->
               (Map Ident (Set Ident)) ->
               (Map Ident [Ident]) ->
               (Map Ident Int) ->
               ChildSourceMap ->
               CycVisMap ->
               ConEnv ->
               DataMap ->
               DataSemEnv ->
               DataEnv ->
               (Map Ident (Bool,Maybe Int)) ->
               DefsEnv ->
               AttrMap ->
               ItfEnv ->
               (Map DepItem (Bool,Int)) ->
               RenameMap ->
               AttrMap ->
               DefsEnv ->
               (IntMap Ident) ->
               VisitAttrMap ->
               (Map Ident [Ident]) ->
               VisitSourceMap ->
               VisitAttrMap ->
               VisitEnv ->
               ([Ident]) ->
               (Set Ident) ->
               (Env QIdent (QIdent, QIdent)) ->
               ClausesEnv ->
               DataSemEnv ->
               DefsEnv ->
               (Map Ident (Maybe Ident)) ->
               NontermEnv ->
               DefsEnv ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               ([(Int,PP_Doc)]) ->
               Int ->
               QIdent ->
               Opts ->
               DepItem ->
               Reason ->
               DepItem ->
               DepItem ->
               DepItem ->
               Reason ->
               ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident (Set Ident)),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),(Map Ident (Set Ident)),(Map Ident [Ident]),(Map Ident Int),ChildSourceMap,ClausesEnv,DataSemEnv,(Map Ident (Bool,Maybe Int)),DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),(Map Ident (Maybe Ident)),NontermEnv,RenameMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),PP_Doc,PP_Doc,Int,(Map Ident (Set Ident)),PP_Doc,Int)
sem_Stmt_Attach :: Pos ->
                   (Maybe Ident) ->
                   Ident ->
                   Ident ->
                   T_MaybeBoundCode  ->
                   T_Stmt 
sem_Stmt_Attach pos_ mbVisit_ name_ type_ code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOdistDataSems :: DataSemEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup75 :: ((Int,Int))
              _codeOlexCounter :: Int
              _lexOrder :: Int
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _lhsOrank :: Int
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOnonterm :: QIdent
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIisFun :: Bool
              _codeIisJust :: Bool
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpp :: PP_Doc
              -- augmented rule
              _lhsOdistDataSems =
                  ({-# LINE 461 "src/Transform.ag" #-}
                   foldr ($) _distDataSems_augmented_syn [_distDataSems_augmented_f1]
                   {-# LINE 57905 "src/Transform.hs" #-})
              -- augment function
              _distDataSems_augmented_f1 =
                  ({-# LINE 461 "src/Transform.ag" #-}
                   if _codeIisJust
                   then id
                   else snd . find type_ ()
                   {-# LINE 57912 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOdistItfs =
                  ({-# LINE 404 "src/Transform.ag" #-}
                   foldr ($) _distItfs_augmented_syn [_distItfs_augmented_f1]
                   {-# LINE 57917 "src/Transform.hs" #-})
              -- augment function
              _distItfs_augmented_f1 =
                  ({-# LINE 404 "src/Transform.ag" #-}
                   snd . find [type_] ()
                   {-# LINE 57922 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 547 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1, _errs1_augmented_f2, _errs1_augmented_f3]
                   {-# LINE 57927 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 547 "src/Transform.ag" #-}
                   if type_ /= _initType
                   then (Err_TypeConflict type_ _initType     Seq.<|)
                   else id
                   {-# LINE 57934 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f2 =
                  ({-# LINE 547 "src/Transform.ag" #-}
                   ( if null _childVisits     || _visit     `elem` _childVisits
                     then Seq.empty else Seq.singleton (Err_UndefVisit name_ _visit     _childVisits    )) Seq.><
                   {-# LINE 57940 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f3 =
                  ({-# LINE 547 "src/Transform.ag" #-}
                   ( if name_ `Set.member` _lhsIallVisits
                     then Seq.singleton $ Err_NameClash name_
                     else Seq.empty
                   ) Seq.><
                   {-# LINE 57948 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs2 =
                  ({-# LINE 1638 "src/Transform.ag" #-}
                   foldr ($) _errs2_augmented_syn [_errs2_augmented_f1]
                   {-# LINE 57953 "src/Transform.hs" #-})
              -- augment function
              _errs2_augmented_f1 =
                  ({-# LINE 1638 "src/Transform.ag" #-}
                   if (length $ filter (== _visit) $ Map.findWithDefault [] name_ _lhsIdistChildMinRanges) > 1
                   then (Err_AmbAttach name_ _visit Seq.<|)
                   else id
                   {-# LINE 57960 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs5 =
                  ({-# LINE 1943 "src/Transform.ag" #-}
                   foldr ($) _errs5_augmented_syn [_errs5_augmented_f1]
                   {-# LINE 57965 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f1 =
                  ({-# LINE 1943 "src/Transform.ag" #-}
                   if _isCyclic     && _codeIisJust && not _codeIisFun
                   then (Err_EffCyclic pos_ Seq.<|)
                   else id
                   {-# LINE 57972 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathChildDefs =
                  ({-# LINE 544 "src/Transform.ag" #-}
                   foldr ($) _gathChildDefs_augmented_syn [_gathChildDefs_augmented_f1]
                   {-# LINE 57977 "src/Transform.hs" #-})
              -- augment function
              _gathChildDefs_augmented_f1 =
                  ({-# LINE 544 "src/Transform.ag" #-}
                   extend [name_] ([type_],[_visit    ,type_])
                   {-# LINE 57982 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathChildSource =
                  ({-# LINE 2123 "src/Transform.ag" #-}
                   foldr ($) _gathChildSource_augmented_syn [_gathChildSource_augmented_f1]
                   {-# LINE 57987 "src/Transform.hs" #-})
              -- augment function
              _gathChildSource_augmented_f1 =
                  ({-# LINE 2123 "src/Transform.ag" #-}
                   Map.insertWith mappend name_ (Map.singleton _visit     _stmtSource    )
                   {-# LINE 57992 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2280 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 57997 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2280 "src/Transform.ag" #-}
                   case _mbPrevEntry     of
                     Nothing    -> id
                     Just (_,d) -> addDep _stmtSource     (ReasonAttach name_ _visit    ) [d]
                   {-# LINE 58004 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2280 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 58009 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 58014 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 58019 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 58024 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 58029 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 58034 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 58039 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 437, column 13)
              _childVisits =
                  ({-# LINE 437 "src/Transform.ag" #-}
                   Map.findWithDefault [] type_ _lhsIdistVisitOrder
                   {-# LINE 58044 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 438, column 13)
              _visit =
                  ({-# LINE 438 "src/Transform.ag" #-}
                   case mbVisit_ of
                     Nothing -> if null _childVisits     then Ident "<unknown>" pos_ else head _childVisits
                     Just v  -> v
                   {-# LINE 58051 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 545, column 13)
              _allAttaches =
                  ({-# LINE 545 "src/Transform.ag" #-}
                   findAll [name_] _lhsIdistChildDefs
                   {-# LINE 58056 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 546, column 13)
              _initType =
                  ({-# LINE 546 "src/Transform.ag" #-}
                   head $ last ([type_] : map fst _allAttaches    )
                   {-# LINE 58061 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1307, column 20)
              _lhsOgathChildOcc =
                  ({-# LINE 1307 "src/Transform.ag" #-}
                   Map.singleton name_ _lexOrder
                   {-# LINE 58066 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1632, column 3)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1632 "src/Transform.ag" #-}
                   Map.singleton name_ [_visit]
                   {-# LINE 58071 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1633, column 3)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1633 "src/Transform.ag" #-}
                   Map.singleton name_ (Set.fromList $ dropWhile (/= _visit    ) _childVisits    )
                   {-# LINE 58076 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1719, column 3)
              _attrVisits =
                  ({-# LINE 1719 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty type_ _lhsIdistAttrVisMap
                   {-# LINE 58081 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1720, column 3)
              _visitReqs =
                  ({-# LINE 1720 "src/Transform.ag" #-}
                   [ rangeUpTo (fromJust mbVis) $ dropWhile (/= _visit    ) _childVisits
                   | attr <- Map.keys _lhsIdistDeflStmts
                   , let mbVis = Map.lookup (False,attr) _attrVisits
                   , isJust mbVis ]
                   {-# LINE 58089 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1724, column 3)
              _invokeReqs =
                  ({-# LINE 1724 "src/Transform.ag" #-}
                   Map.singleton name_ $ Set.fromList (concat _visitReqs    )
                   {-# LINE 58094 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1725, column 3)
              _lhsOminReqInvokes =
                  ({-# LINE 1725 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 58099 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1726, column 3)
              _lhsOallReqInvokes =
                  ({-# LINE 1726 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 58104 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1866, column 19)
              _destVisit =
                  ({-# LINE 1866 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 58109 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1922, column 19)
              _fullCyclic =
                  ({-# LINE 1922 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 58114 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1923, column 19)
              _allowCycles =
                  ({-# LINE 1923 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 58119 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2020, column 14)
              _stmtSource =
                  ({-# LINE 2020 "src/Transform.ag" #-}
                   DepAttach _lexOrder
                   {-# LINE 58124 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2278, column 3)
              _childSources =
                  ({-# LINE 2278 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty name_ _lhsIdistChildSource
                   {-# LINE 58129 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2279, column 3)
              _mbPrevEntry =
                  ({-# LINE 2279 "src/Transform.ag" #-}
                   nearestVisitEntry False _visit     _childVisits     _childSources
                   {-# LINE 58134 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              __tup74 =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 58139 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup74
                   {-# LINE 58144 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_,_rank) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup74
                   {-# LINE 58149 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2380, column 3)
              _isCyclic =
                  ({-# LINE 2380 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 58154 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2539, column 18)
              _lhsOpp =
                  ({-# LINE 2539 "src/Transform.ag" #-}
                   "attach" >#< _visit     >#< "of" >#< name_ >#< ":" >#< type_ >#< _codeIpp
                   {-# LINE 58159 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 382, column 18)
              _infoComment =
                  ({-# LINE 382 "src/TargetHaskell.ag" #-}
                   "-- attach stmt:" >#< show (line pos_) >#< ", rank:" >#< _rank
                   {-# LINE 58164 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 383, column 18)
              _lhsOhpp =
                  ({-# LINE 383 "src/TargetHaskell.ag" #-}
                   ppBind _isCyclic     (hSemNm name_ _visit    ) _hRhsCode     >#< _infoComment
                   {-# LINE 58169 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 384, column 18)
              _hRhsCode =
                  ({-# LINE 384 "src/TargetHaskell.ag" #-}
                   if _codeIisJust
                   then hppWrapRet _codeIisFun _codeIhpp
                   else "return" >#< pp_parens (text $ hDtSemNm type_)
                   {-# LINE 58176 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 225, column 18)
              _lhsOjspp =
                  ({-# LINE 225 "src/TargetJs.ag" #-}
                   "var _semantics =" >#< _jsRhsCode     >|< ";"
                   >-< "if (!_semantics) { throw \"Undefined semantics: " >|< show name_ >|< "\"; }"
                   >-< "var" >#< jsVis name_ _visit >#< "= _semantics();"
                   >-< "if (!" >|< jsVis name_ _visit >|< ") { throw \"Undefined attached semantics: " >|< show name_ >|< "\"; }"
                   {-# LINE 58184 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 229, column 18)
              _jsRhsCode =
                  ({-# LINE 229 "src/TargetJs.ag" #-}
                   if _codeIisJust
                   then _codeIhpp
                   else text $ jsDtSemNm type_
                   {-# LINE 58191 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup75 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_codeOlexCounter,_) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup75
                   {-# LINE 58199 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup75
                   {-# LINE 58204 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58209 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs0
                   {-# LINE 58214 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 547 "src/Transform.ag" #-}
                   _codeIerrs1
                   {-# LINE 58219 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs2_augmented_syn =
                  ({-# LINE 1638 "src/Transform.ag" #-}
                   _codeIerrs2
                   {-# LINE 58224 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs3
                   {-# LINE 58229 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs4
                   {-# LINE 58234 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs5_augmented_syn =
                  ({-# LINE 1943 "src/Transform.ag" #-}
                   _codeIerrs5
                   {-# LINE 58239 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58244 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58249 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _codeIgathAvoidVisits
                   {-# LINE 58254 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _gathChildSource_augmented_syn =
                  ({-# LINE 2123 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58259 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58264 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2280 "src/Transform.ag" #-}
                   _codeIgathDeps
                   {-# LINE 58269 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   _codeIgathItemVisits
                   {-# LINE 58274 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   _codeIgathLegalCycStmts
                   {-# LINE 58279 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _codeIgathMissingInvokes
                   {-# LINE 58284 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 58289 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _codeIgathSemStarts
                   {-# LINE 58294 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   _codeIgathStmtPosMap
                   {-# LINE 58299 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitEnds
                   {-# LINE 58304 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 58309 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitStarts
                   {-# LINE 58314 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 58319 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 58324 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 58329 "src/Transform.hs" #-})
              -- copy rule (up)
              _distDataSems_augmented_syn =
                  ({-# LINE 461 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 58334 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 58339 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 58344 "src/Transform.hs" #-})
              -- copy rule (up)
              _distItfs_augmented_syn =
                  ({-# LINE 404 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 58349 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 58354 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 58359 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathChildDefs_augmented_syn =
                  ({-# LINE 544 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 58364 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 58369 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 58374 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 58379 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 58384 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 58389 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 58394 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 58399 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 58404 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 58409 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 58414 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 58419 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 58424 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 58429 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 58434 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 58439 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 58444 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 58449 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 58454 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 58459 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 58464 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 58469 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 58474 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 58479 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 58484 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 58489 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 58494 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 58499 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 58504 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 58509 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 58514 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 58519 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 58524 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 58529 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 58534 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 58539 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 58544 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 58549 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 58554 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 58559 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 58564 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 58569 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 58574 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 58579 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 58584 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 58589 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 58594 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 58599 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 58604 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 58609 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 58614 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 58619 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 58624 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 58629 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 58634 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 58639 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 58644 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 58649 "src/Transform.hs" #-})
              -- copy rule (from local)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 58654 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 58659 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 58664 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 58669 "src/Transform.hs" #-})
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIisFun,_codeIisJust,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp,_lhsOrank)))
sem_Stmt_Default :: Bool ->
                    Pos ->
                    Ident ->
                    T_MaybeBoundCode  ->
                    T_Stmt 
sem_Stmt_Default allowEmpty_ pos_ name_ mbCode_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs1 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup77 :: ((Int,Int))
              _mbCodeOcodeIdCounter :: Int
              _codeId :: Int
              __tup78 :: ((Int,Int))
              _mbCodeOlexCounter :: Int
              _lexOrder :: Int
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _lhsOrank :: Int
              _mbCodeOallAvailInvokes :: (Map Ident (Set Ident))
              _mbCodeOallVisits :: (Set Ident)
              _mbCodeOavailInvokes :: (Map Ident (Set Ident))
              _mbCodeObasename :: QIdent
              _mbCodeOcoItf :: Ident
              _mbCodeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _mbCodeOdirectVisitLocalAttrs :: (Map Ident String)
              _mbCodeOdistAliasses :: (Map Ident AliasType)
              _mbCodeOdistAllChildMinRanges :: (Map Ident [Ident])
              _mbCodeOdistAttrSource :: AttrSourceMap
              _mbCodeOdistAttrVisMap :: AttrVisMap
              _mbCodeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _mbCodeOdistChildEffRanges :: (Map Ident (Set Ident))
              _mbCodeOdistChildMinRanges :: (Map Ident [Ident])
              _mbCodeOdistChildOcc :: (Map Ident Int)
              _mbCodeOdistChildSource :: ChildSourceMap
              _mbCodeOdistCycVisMap :: CycVisMap
              _mbCodeOdistDataCons :: ConEnv
              _mbCodeOdistDataMap :: DataMap
              _mbCodeOdistDataSems :: DataSemEnv
              _mbCodeOdistDatas :: DataEnv
              _mbCodeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _mbCodeOdistDefs :: DefsEnv
              _mbCodeOdistInhAttrs :: AttrMap
              _mbCodeOdistItfs :: ItfEnv
              _mbCodeOdistRanks :: (Map DepItem (Bool,Int))
              _mbCodeOdistRenames :: RenameMap
              _mbCodeOdistSynAttrs :: AttrMap
              _mbCodeOdistVisLocalDefs :: DefsEnv
              _mbCodeOdistVisitInhAttrs :: VisitAttrMap
              _mbCodeOdistVisitOrder :: (Map Ident [Ident])
              _mbCodeOdistVisitSource :: VisitSourceMap
              _mbCodeOdistVisitSynAttrs :: VisitAttrMap
              _mbCodeOdistVisits :: VisitEnv
              _mbCodeOdoneVisits :: ([Ident])
              _mbCodeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _mbCodeOgathClauses :: ClausesEnv
              _mbCodeOgathDataSems :: DataSemEnv
              _mbCodeOgathDefs :: DefsEnv
              _mbCodeOgathNonterms :: NontermEnv
              _mbCodeOgathVisLocalDefs :: DefsEnv
              _mbCodeOhSpilledStmts :: ([(Int,PP_Doc)])
              _mbCodeOitf :: QIdent
              _mbCodeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _mbCodeOnonterm :: QIdent
              _mbCodeOopts :: Opts
              _mbCodeOscopeDep :: DepItem
              _mbCodeOscopeReason :: Reason
              _mbCodeOstmtSource :: DepItem
              _mbCodeOvisitBeginDep :: DepItem
              _mbCodeOvisitEndDep :: DepItem
              _mbCodeOvisitEndReason :: Reason
              _mbCodeIallReqInvokes :: (Map Ident (Set Ident))
              _mbCodeIcodeIdCounter :: Int
              _mbCodeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _mbCodeIdistDataCons :: ConEnv
              _mbCodeIdistDataSems :: DataSemEnv
              _mbCodeIdistDatas :: DataEnv
              _mbCodeIdistDefs :: DefsEnv
              _mbCodeIdistItfs :: ItfEnv
              _mbCodeIdistVisLocalDefs :: DefsEnv
              _mbCodeIdistVisits :: VisitEnv
              _mbCodeIerrs0 :: Errs
              _mbCodeIerrs1 :: Errs
              _mbCodeIerrs2 :: Errs
              _mbCodeIerrs3 :: Errs
              _mbCodeIerrs4 :: Errs
              _mbCodeIerrs5 :: Errs
              _mbCodeIgathAvoidVisits :: (Set DepItem)
              _mbCodeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _mbCodeIgathClauses :: ClausesEnv
              _mbCodeIgathDataSems :: DataSemEnv
              _mbCodeIgathDefs :: DefsEnv
              _mbCodeIgathDeps :: Deps
              _mbCodeIgathItemVisits :: (Map DepItem DepItem)
              _mbCodeIgathLegalCycStmts :: (Set DepItem)
              _mbCodeIgathMissingInvokes :: (Set (Ident,Ident))
              _mbCodeIgathNonterms :: NontermEnv
              _mbCodeIgathSemStarts :: (Seq DepItem)
              _mbCodeIgathStmtPosMap :: (Map DepItem Pos)
              _mbCodeIgathVisLocalDefs :: DefsEnv
              _mbCodeIgathVisitEnds :: (Seq DepItem)
              _mbCodeIgathVisitStarts :: (Seq DepItem)
              _mbCodeIhpp :: PP_Doc
              _mbCodeIisFun :: Bool
              _mbCodeIisJust :: Bool
              _mbCodeIjspp :: PP_Doc
              _mbCodeIlexCounter :: Int
              _mbCodeIminReqInvokes :: (Map Ident (Set Ident))
              _mbCodeIpp :: PP_Doc
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 1829 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 58886 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 1829 "src/Transform.ag" #-}
                   if Map.findWithDefault (allowEmpty_,_mbCodeId) name_ _lhsIdistDeflStmts /= (allowEmpty_,_mbCodeId)
                   then (Err_AmbDefault pos_ name_ Seq.<|)
                   else id
                   {-# LINE 58893 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs5 =
                  ({-# LINE 1949 "src/Transform.ag" #-}
                   foldr ($) _errs5_augmented_syn [_errs5_augmented_f1]
                   {-# LINE 58898 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f1 =
                  ({-# LINE 1949 "src/Transform.ag" #-}
                   if _isCyclic     && _mbCodeIisJust && not _mbCodeIisFun
                   then (Err_EffCyclic pos_ Seq.<|)
                   else id
                   {-# LINE 58905 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 58910 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 58915 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 58920 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 58925 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 58930 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 58935 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 58940 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 58945 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1700, column 3)
              _visitReqs =
                  ({-# LINE 1700 "src/Transform.ag" #-}
                   [ Map.singleton child $ Set.fromList $ rangeUpTo (fromJust mbVis) range
                     | child <- Map.keys _lhsIdistChildMinRanges
                     , let itf         = findChild child _lhsIdistChildDefs
                           attrVisits  = Map.findWithDefault Map.empty itf _lhsIdistAttrVisMap
                           childVisits = Map.findWithDefault [] itf _lhsIdistVisitOrder
                           minRanges   = Set.fromList $ Map.findWithDefault [] child _lhsIdistChildMinRanges
                           range       = dropWhile (\v -> not (v `Set.member` minRanges)) childVisits
                           mbVis       = Map.lookup (False,nm) attrVisits
                           nm          = renameAttrFwd _lhsIdistRenames child name_
                     , isJust mbVis
                     ]
                   {-# LINE 58960 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1711, column 3)
              _invokeReqs =
                  ({-# LINE 1711 "src/Transform.ag" #-}
                   Map.unionsWith Set.union _visitReqs
                   {-# LINE 58965 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1712, column 3)
              _lhsOminReqInvokes =
                  ({-# LINE 1712 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 58970 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1713, column 3)
              _lhsOallReqInvokes =
                  ({-# LINE 1713 "src/Transform.ag" #-}
                   _invokeReqs
                   {-# LINE 58975 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1820, column 32)
              _mbCodeId =
                  ({-# LINE 1820 "src/Transform.ag" #-}
                   if _mbCodeIisJust then Just _codeId     else Nothing
                   {-# LINE 58980 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1821, column 32)
              _lhsOgathDeflStmts =
                  ({-# LINE 1821 "src/Transform.ag" #-}
                   Map.singleton name_ (allowEmpty_,_mbCodeId)
                   {-# LINE 58985 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1866, column 19)
              _destVisit =
                  ({-# LINE 1866 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 58990 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1922, column 19)
              _fullCyclic =
                  ({-# LINE 1922 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 58995 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1923, column 19)
              _allowCycles =
                  ({-# LINE 1923 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 59000 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2019, column 14)
              _stmtSource =
                  ({-# LINE 2019 "src/Transform.ag" #-}
                   DepDefault _codeId
                   {-# LINE 59005 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              __tup76 =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 59010 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup76
                   {-# LINE 59015 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_,_rank) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup76
                   {-# LINE 59020 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2380, column 3)
              _isCyclic =
                  ({-# LINE 2380 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 59025 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2542, column 18)
              _lhsOpp =
                  ({-# LINE 2542 "src/Transform.ag" #-}
                   "default" >#< name_ >#< "..."
                   {-# LINE 59030 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 440, column 18)
              _infoComment =
                  ({-# LINE 440 "src/TargetHaskell.ag" #-}
                   "-- default stmt:" >#< show (line pos_) >#< ", rank:" >#< _rank
                   {-# LINE 59035 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 441, column 18)
              _lhsOhpp =
                  ({-# LINE 441 "src/TargetHaskell.ag" #-}
                   if _isCyclic
                   then ppBind True (text $ hDfltNm name_ _codeId    ) _mbCodeIhpp >#< _infoComment
                   else if _mbCodeIisJust
                        then ppBindPos _lhsIopts pos_ False ("!" >|< "__fresh") (hppWrapRet _mbCodeIisFun _mbCodeIhpp)
                               >-< "let" >#< pp_parens (text $ hDfltNm name_ _codeId    ) >#< "= __fresh" >#< _infoComment
                        else empty
                   {-# LINE 59045 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 245, column 18)
              _lhsOjspp =
                  ({-# LINE 245 "src/TargetJs.ag" #-}
                   if _mbCodeIisJust
                   then "var _def" >|< show _codeId     >#< "=" >#< _mbCodeIjspp >|< ";"
                   else empty
                   {-# LINE 59052 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup77 =
                  case _lhsIcodeIdCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, codeId) -> (__cont, codeId)}}
              -- -- generated by the unique rule mechanism.
              (_mbCodeOcodeIdCounter,_) =
                  ({-# LINE 1819 "src/Transform.ag" #-}
                   __tup77
                   {-# LINE 59060 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_codeId) =
                  ({-# LINE 1819 "src/Transform.ag" #-}
                   __tup77
                   {-# LINE 59065 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup78 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_mbCodeOlexCounter,_) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup78
                   {-# LINE 59073 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup78
                   {-# LINE 59078 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59083 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _mbCodeIerrs0
                   {-# LINE 59088 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 1829 "src/Transform.ag" #-}
                   _mbCodeIerrs1
                   {-# LINE 59093 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _mbCodeIerrs2
                   {-# LINE 59098 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _mbCodeIerrs3
                   {-# LINE 59103 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _mbCodeIerrs4
                   {-# LINE 59108 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs5_augmented_syn =
                  ({-# LINE 1949 "src/Transform.ag" #-}
                   _mbCodeIerrs5
                   {-# LINE 59113 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59118 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59123 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _mbCodeIgathAvoidVisits
                   {-# LINE 59128 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59133 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59138 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59143 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59148 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   _mbCodeIgathDeps
                   {-# LINE 59153 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   _mbCodeIgathItemVisits
                   {-# LINE 59158 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   _mbCodeIgathLegalCycStmts
                   {-# LINE 59163 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _mbCodeIgathMissingInvokes
                   {-# LINE 59168 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 59173 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _mbCodeIgathSemStarts
                   {-# LINE 59178 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   _mbCodeIgathStmtPosMap
                   {-# LINE 59183 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _mbCodeIgathVisitEnds
                   {-# LINE 59188 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 59193 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _mbCodeIgathVisitStarts
                   {-# LINE 59198 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _mbCodeIcodeIdCounter
                   {-# LINE 59203 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _mbCodeIdistChildDefs
                   {-# LINE 59208 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _mbCodeIdistDataCons
                   {-# LINE 59213 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _mbCodeIdistDataSems
                   {-# LINE 59218 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _mbCodeIdistDatas
                   {-# LINE 59223 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _mbCodeIdistDefs
                   {-# LINE 59228 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _mbCodeIdistItfs
                   {-# LINE 59233 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _mbCodeIdistVisLocalDefs
                   {-# LINE 59238 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _mbCodeIdistVisits
                   {-# LINE 59243 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _mbCodeIgathChildDefs
                   {-# LINE 59248 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _mbCodeIgathClauses
                   {-# LINE 59253 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _mbCodeIgathDataSems
                   {-# LINE 59258 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _mbCodeIgathDefs
                   {-# LINE 59263 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 59268 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _mbCodeIgathNonterms
                   {-# LINE 59273 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _mbCodeIgathVisLocalDefs
                   {-# LINE 59278 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _mbCodeIlexCounter
                   {-# LINE 59283 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 59288 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 59293 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 59298 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 59303 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 59308 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 59313 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 59318 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 59323 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 59328 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 59333 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 59338 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 59343 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 59348 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 59353 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 59358 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 59363 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 59368 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 59373 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 59378 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 59383 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 59388 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 59393 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 59398 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 59403 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 59408 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 59413 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 59418 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 59423 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 59428 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 59433 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 59438 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 59443 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 59448 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 59453 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 59458 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 59463 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 59468 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 59473 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 59478 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 59483 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 59488 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 59493 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 59498 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 59503 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 59508 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 59513 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 59518 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 59523 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 59528 "src/Transform.hs" #-})
              -- copy rule (from local)
              _mbCodeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 59533 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 59538 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 59543 "src/Transform.hs" #-})
              -- copy rule (down)
              _mbCodeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 59548 "src/Transform.hs" #-})
              ( _mbCodeIallReqInvokes,_mbCodeIcodeIdCounter,_mbCodeIdistChildDefs,_mbCodeIdistDataCons,_mbCodeIdistDataSems,_mbCodeIdistDatas,_mbCodeIdistDefs,_mbCodeIdistItfs,_mbCodeIdistVisLocalDefs,_mbCodeIdistVisits,_mbCodeIerrs0,_mbCodeIerrs1,_mbCodeIerrs2,_mbCodeIerrs3,_mbCodeIerrs4,_mbCodeIerrs5,_mbCodeIgathAvoidVisits,_mbCodeIgathChildDefs,_mbCodeIgathClauses,_mbCodeIgathDataSems,_mbCodeIgathDefs,_mbCodeIgathDeps,_mbCodeIgathItemVisits,_mbCodeIgathLegalCycStmts,_mbCodeIgathMissingInvokes,_mbCodeIgathNonterms,_mbCodeIgathSemStarts,_mbCodeIgathStmtPosMap,_mbCodeIgathVisLocalDefs,_mbCodeIgathVisitEnds,_mbCodeIgathVisitStarts,_mbCodeIhpp,_mbCodeIisFun,_mbCodeIisJust,_mbCodeIjspp,_mbCodeIlexCounter,_mbCodeIminReqInvokes,_mbCodeIpp) =
                  mbCode_ _mbCodeOallAvailInvokes _mbCodeOallVisits _mbCodeOavailInvokes _mbCodeObasename _mbCodeOcoItf _mbCodeOcodeIdCounter _mbCodeOdirectVisitAttrs _mbCodeOdirectVisitLocalAttrs _mbCodeOdistAliasses _mbCodeOdistAllChildMinRanges _mbCodeOdistAttrSource _mbCodeOdistAttrVisMap _mbCodeOdistChildDefs _mbCodeOdistChildEffRanges _mbCodeOdistChildMinRanges _mbCodeOdistChildOcc _mbCodeOdistChildSource _mbCodeOdistCycVisMap _mbCodeOdistDataCons _mbCodeOdistDataMap _mbCodeOdistDataSems _mbCodeOdistDatas _mbCodeOdistDeflStmts _mbCodeOdistDefs _mbCodeOdistInhAttrs _mbCodeOdistItfs _mbCodeOdistRanks _mbCodeOdistRenames _mbCodeOdistSynAttrs _mbCodeOdistVisLocalDefs _mbCodeOdistVisitInhAttrs _mbCodeOdistVisitOrder _mbCodeOdistVisitSource _mbCodeOdistVisitSynAttrs _mbCodeOdistVisits _mbCodeOdoneVisits _mbCodeOgathChildDefs _mbCodeOgathClauses _mbCodeOgathDataSems _mbCodeOgathDefs _mbCodeOgathNonterms _mbCodeOgathVisLocalDefs _mbCodeOhSpilledStmts _mbCodeOitf _mbCodeOjsSpilledStmts _mbCodeOlexCounter _mbCodeOnonterm _mbCodeOopts _mbCodeOscopeDep _mbCodeOscopeReason _mbCodeOstmtSource _mbCodeOvisitBeginDep _mbCodeOvisitEndDep _mbCodeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp,_lhsOrank)))
sem_Stmt_Eval :: T_Mode  ->
                 T_Pat  ->
                 T_BoundCode  ->
                 T_Stmt 
sem_Stmt_Eval mode_ pat_ code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs5 :: Errs
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOpp :: PP_Doc
              _patOprio :: Prio
              _patOisRight :: Bool
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _patOisMatch :: Bool
              __tup80 :: ((Int,Int))
              _patOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _lhsOrank :: Int
              _patOallAvailInvokes :: (Map Ident (Set Ident))
              _patOallVisits :: (Set Ident)
              _patOavailInvokes :: (Map Ident (Set Ident))
              _patObasename :: QIdent
              _patOcoItf :: Ident
              _patOcodeIdCounter :: Int
              _patOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _patOdirectVisitLocalAttrs :: (Map Ident String)
              _patOdistAliasses :: (Map Ident AliasType)
              _patOdistAllChildMinRanges :: (Map Ident [Ident])
              _patOdistAttrSource :: AttrSourceMap
              _patOdistAttrVisMap :: AttrVisMap
              _patOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patOdistChildEffRanges :: (Map Ident (Set Ident))
              _patOdistChildMinRanges :: (Map Ident [Ident])
              _patOdistChildOcc :: (Map Ident Int)
              _patOdistChildSource :: ChildSourceMap
              _patOdistCycVisMap :: CycVisMap
              _patOdistDataCons :: ConEnv
              _patOdistDataMap :: DataMap
              _patOdistDataSems :: DataSemEnv
              _patOdistDatas :: DataEnv
              _patOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _patOdistDefs :: DefsEnv
              _patOdistInhAttrs :: AttrMap
              _patOdistItfs :: ItfEnv
              _patOdistRanks :: (Map DepItem (Bool,Int))
              _patOdistRenames :: RenameMap
              _patOdistSynAttrs :: AttrMap
              _patOdistVisLocalDefs :: DefsEnv
              _patOdistVisitInhAttrs :: VisitAttrMap
              _patOdistVisitOrder :: (Map Ident [Ident])
              _patOdistVisitSource :: VisitSourceMap
              _patOdistVisitSynAttrs :: VisitAttrMap
              _patOdistVisits :: VisitEnv
              _patOdoneVisits :: ([Ident])
              _patOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patOgathClauses :: ClausesEnv
              _patOgathDataSems :: DataSemEnv
              _patOgathDefs :: DefsEnv
              _patOgathNonterms :: NontermEnv
              _patOgathVisLocalDefs :: DefsEnv
              _patOhSpilledStmts :: ([(Int,PP_Doc)])
              _patOisCyclic :: Bool
              _patOitf :: QIdent
              _patOjsSpilledStmts :: ([(Int,PP_Doc)])
              _patOnonterm :: QIdent
              _patOopts :: Opts
              _patOscopeDep :: DepItem
              _patOscopeReason :: Reason
              _patOstmtSource :: DepItem
              _patOvisitBeginDep :: DepItem
              _patOvisitEndDep :: DepItem
              _patOvisitEndReason :: Reason
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOlexCounter :: Int
              _codeOnonterm :: QIdent
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _modeIisMatch :: Bool
              _modeIpp :: PP_Doc
              _patIallReqInvokes :: (Map Ident (Set Ident))
              _patIcodeIdCounter :: Int
              _patIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _patIdistDataCons :: ConEnv
              _patIdistDataSems :: DataSemEnv
              _patIdistDatas :: DataEnv
              _patIdistDefs :: DefsEnv
              _patIdistItfs :: ItfEnv
              _patIdistVisLocalDefs :: DefsEnv
              _patIdistVisits :: VisitEnv
              _patIerrs0 :: Errs
              _patIerrs1 :: Errs
              _patIerrs2 :: Errs
              _patIerrs3 :: Errs
              _patIerrs4 :: Errs
              _patIerrs5 :: Errs
              _patIgathAttrSource :: AttrSourceMap
              _patIgathAvoidVisits :: (Set DepItem)
              _patIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _patIgathChildSource :: ChildSourceMap
              _patIgathClauses :: ClausesEnv
              _patIgathDataSems :: DataSemEnv
              _patIgathDefs :: DefsEnv
              _patIgathDeps :: Deps
              _patIgathItemVisits :: (Map DepItem DepItem)
              _patIgathLegalCycStmts :: (Set DepItem)
              _patIgathNonterms :: NontermEnv
              _patIgathSemStarts :: (Seq DepItem)
              _patIgathStmtPosMap :: (Map DepItem Pos)
              _patIgathVisLocalDefs :: DefsEnv
              _patIgathVisitEnds :: (Seq DepItem)
              _patIgathVisitSource :: VisitSourceMap
              _patIgathVisitStarts :: (Seq DepItem)
              _patIhpp :: PP_Doc
              _patIjspp :: PP_Doc
              _patIlexCounter :: Int
              _patIminReqInvokes :: (Map Ident (Set Ident))
              _patIpos :: Pos
              _patIpp :: PP_Doc
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIisFun :: Bool
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpos :: Pos
              _codeIpp :: PP_Doc
              -- augmented rule
              _lhsOerrs5 =
                  ({-# LINE 1940 "src/Transform.ag" #-}
                   foldr ($) _errs5_augmented_syn [_errs5_augmented_f1, _errs5_augmented_f2]
                   {-# LINE 59861 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f1 =
                  ({-# LINE 1940 "src/Transform.ag" #-}
                   if _isCyclic     && not _codeIisFun
                   then (Err_EffCyclic _pos     Seq.<|)
                   else id
                   {-# LINE 59868 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f2 =
                  ({-# LINE 1940 "src/Transform.ag" #-}
                   if _isCyclic     && _modeIisMatch
                   then (Err_MatchCyclic _pos     Seq.<|)
                   else id
                   {-# LINE 59875 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2233 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2]
                   {-# LINE 59880 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2233 "src/Transform.ag" #-}
                   if _modeIisMatch
                   then addDep _lhsIvisitEndDep _lhsIvisitEndReason [_stmtSource    ]
                   else id
                   {-# LINE 59887 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2233 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 59892 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 59897 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 59902 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 59907 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 59912 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 59917 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _pos
                   {-# LINE 59922 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1866, column 19)
              _destVisit =
                  ({-# LINE 1866 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 59927 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1922, column 19)
              _fullCyclic =
                  ({-# LINE 1922 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 59932 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1923, column 19)
              _allowCycles =
                  ({-# LINE 1923 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 59937 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2018, column 14)
              _stmtSource =
                  ({-# LINE 2018 "src/Transform.ag" #-}
                   if _modeIisMatch then DepMatch _lexOrder     else DepAssert _lexOrder
                   {-# LINE 59942 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2030, column 19)
              _pos =
                  ({-# LINE 2030 "src/Transform.ag" #-}
                   _codeIpos
                   {-# LINE 59947 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              __tup79 =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 59952 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup79
                   {-# LINE 59957 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_,_rank) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup79
                   {-# LINE 59962 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2380, column 3)
              _isCyclic =
                  ({-# LINE 2380 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 59967 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2538, column 18)
              _lhsOpp =
                  ({-# LINE 2538 "src/Transform.ag" #-}
                   _modeIpp >|< _patIpp >#< _codeIpp
                   {-# LINE 59972 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2585, column 20)
              _patOprio =
                  ({-# LINE 2585 "src/Transform.ag" #-}
                   PrioTop
                   {-# LINE 59977 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2586, column 20)
              _patOisRight =
                  ({-# LINE 2586 "src/Transform.ag" #-}
                   False
                   {-# LINE 59982 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 372, column 18)
              _infoComment =
                  ({-# LINE 372 "src/TargetHaskell.ag" #-}
                   "-- eval stmt:" >#< show (line _pos    ) >#< ", rank:" >#< _rank
                     >#< ", dest: " >#< show _destVisit
                   {-# LINE 59988 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 374, column 18)
              _lhsOhpp =
                  ({-# LINE 374 "src/TargetHaskell.ag" #-}
                   hWrapLinePragma _lhsIopts _pos     $
                   if _isCyclic
                   then ppBindPos _lhsIopts _pos     _isCyclic     _patIhpp _codeIhpp >#< "-- rank:" >#< show _rank
                   else if _modeIisMatch
                        then ppBindPos _lhsIopts _pos     False _patIhpp (hppWrapRet _codeIisFun _codeIhpp)
                                    >#< _infoComment
                        else ppBindPos _lhsIopts _pos     False ("!" >|< "__fresh") (hppWrapRet _codeIisFun _codeIhpp)
                             >-< "let" >#< pp_parens _patIhpp >#< "= __fresh" >#< _infoComment
                   {-# LINE 60000 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 219, column 18)
              _lhsOjspp =
                  ({-# LINE 219 "src/TargetJs.ag" #-}
                   ( if not _modeIisMatch
                     then "var _res; try" >#< pp_braces ("_res =" >#< _codeIjspp >|< ";")
                           >-< "catch(err) { if (err == eEval) { throw eAbort; } else { throw err; } }"
                     else "var _res = " >#< _codeIjspp
                   ) >|< ";" >-< _patIjspp
                   {-# LINE 60009 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 224, column 18)
              _patOisMatch =
                  ({-# LINE 224 "src/TargetJs.ag" #-}
                   _modeIisMatch
                   {-# LINE 60014 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup80 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_patOlexCounter,_) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup80
                   {-# LINE 60022 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup80
                   {-# LINE 60027 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patIallReqInvokes `unionWithUnion` _codeIallReqInvokes
                   {-# LINE 60032 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60037 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patIerrs0 Seq.>< _codeIerrs0
                   {-# LINE 60042 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patIerrs1 Seq.>< _codeIerrs1
                   {-# LINE 60047 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patIerrs2 Seq.>< _codeIerrs2
                   {-# LINE 60052 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patIerrs3 Seq.>< _codeIerrs3
                   {-# LINE 60057 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _patIerrs4 Seq.>< _codeIerrs4
                   {-# LINE 60062 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs5_augmented_syn =
                  ({-# LINE 1940 "src/Transform.ag" #-}
                   _patIerrs5 Seq.>< _codeIerrs5
                   {-# LINE 60067 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60072 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _patIgathAttrSource
                   {-# LINE 60077 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _patIgathAvoidVisits `Set.union` _codeIgathAvoidVisits
                   {-# LINE 60082 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60087 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60092 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60097 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _patIgathChildSource
                   {-# LINE 60102 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 60107 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2233 "src/Transform.ag" #-}
                   _patIgathDeps Seq.>< _codeIgathDeps
                   {-# LINE 60112 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   _patIgathItemVisits `Map.union` _codeIgathItemVisits
                   {-# LINE 60117 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   _patIgathLegalCycStmts `Set.union` _codeIgathLegalCycStmts
                   {-# LINE 60122 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _codeIgathMissingInvokes
                   {-# LINE 60127 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 60132 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _patIgathSemStarts Seq.>< _codeIgathSemStarts
                   {-# LINE 60137 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   _patIgathStmtPosMap `Map.union` _codeIgathStmtPosMap
                   {-# LINE 60142 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patIgathVisitEnds Seq.>< _codeIgathVisitEnds
                   {-# LINE 60147 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _patIgathVisitSource
                   {-# LINE 60152 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _patIgathVisitStarts Seq.>< _codeIgathVisitStarts
                   {-# LINE 60157 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _patIminReqInvokes `unionWithUnion` _codeIminReqInvokes
                   {-# LINE 60162 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 60167 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 60172 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 60177 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 60182 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 60187 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 60192 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 60197 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 60202 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 60207 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 60212 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 60217 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 60222 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 60227 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 60232 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 60237 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 60242 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 60247 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 60252 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 60257 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 60262 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 60267 "src/Transform.hs" #-})
              -- copy rule (down)
              _patObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 60272 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 60277 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 60282 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 60287 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 60292 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 60297 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 60302 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 60307 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 60312 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 60317 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 60322 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 60327 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 60332 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 60337 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 60342 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 60347 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 60352 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 60357 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 60362 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 60367 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 60372 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 60377 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 60382 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 60387 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 60392 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 60397 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 60402 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 60407 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 60412 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 60417 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 60422 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 60427 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 60432 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 60437 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 60442 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 60447 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 60452 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 60457 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 60462 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 60467 "src/Transform.hs" #-})
              -- copy rule (from local)
              _patOisCyclic =
                  ({-# LINE 2376 "src/Transform.ag" #-}
                   _isCyclic
                   {-# LINE 60472 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 60477 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 60482 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 60487 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 60492 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 60497 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 60502 "src/Transform.hs" #-})
              -- copy rule (from local)
              _patOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 60507 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 60512 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 60517 "src/Transform.hs" #-})
              -- copy rule (down)
              _patOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 60522 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 60527 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 60532 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 60537 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 60542 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 60547 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _patIcodeIdCounter
                   {-# LINE 60552 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 60557 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 60562 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 60567 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 60572 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 60577 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 60582 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _patIdistChildDefs
                   {-# LINE 60587 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 60592 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 60597 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 60602 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 60607 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 60612 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _patIdistDataCons
                   {-# LINE 60617 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 60622 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _patIdistDataSems
                   {-# LINE 60627 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _patIdistDatas
                   {-# LINE 60632 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 60637 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patIdistDefs
                   {-# LINE 60642 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 60647 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _patIdistItfs
                   {-# LINE 60652 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 60657 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 60662 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 60667 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patIdistVisLocalDefs
                   {-# LINE 60672 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 60677 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 60682 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 60687 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 60692 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _patIdistVisits
                   {-# LINE 60697 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 60702 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _patIgathChildDefs
                   {-# LINE 60707 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patIgathClauses
                   {-# LINE 60712 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _patIgathDataSems
                   {-# LINE 60717 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patIgathDefs
                   {-# LINE 60722 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _patIgathNonterms
                   {-# LINE 60727 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _patIgathVisLocalDefs
                   {-# LINE 60732 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 60737 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 60742 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 60747 "src/Transform.hs" #-})
              -- copy rule (chain)
              _codeOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _patIlexCounter
                   {-# LINE 60752 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 60757 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 60762 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 60767 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 60772 "src/Transform.hs" #-})
              -- copy rule (from local)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 60777 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 60782 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 60787 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 60792 "src/Transform.hs" #-})
              ( _modeIisMatch,_modeIpp) =
                  mode_ 
              ( _patIallReqInvokes,_patIcodeIdCounter,_patIdistChildDefs,_patIdistDataCons,_patIdistDataSems,_patIdistDatas,_patIdistDefs,_patIdistItfs,_patIdistVisLocalDefs,_patIdistVisits,_patIerrs0,_patIerrs1,_patIerrs2,_patIerrs3,_patIerrs4,_patIerrs5,_patIgathAttrSource,_patIgathAvoidVisits,_patIgathChildDefs,_patIgathChildSource,_patIgathClauses,_patIgathDataSems,_patIgathDefs,_patIgathDeps,_patIgathItemVisits,_patIgathLegalCycStmts,_patIgathNonterms,_patIgathSemStarts,_patIgathStmtPosMap,_patIgathVisLocalDefs,_patIgathVisitEnds,_patIgathVisitSource,_patIgathVisitStarts,_patIhpp,_patIjspp,_patIlexCounter,_patIminReqInvokes,_patIpos,_patIpp) =
                  pat_ _patOallAvailInvokes _patOallVisits _patOavailInvokes _patObasename _patOcoItf _patOcodeIdCounter _patOdirectVisitAttrs _patOdirectVisitLocalAttrs _patOdistAliasses _patOdistAllChildMinRanges _patOdistAttrSource _patOdistAttrVisMap _patOdistChildDefs _patOdistChildEffRanges _patOdistChildMinRanges _patOdistChildOcc _patOdistChildSource _patOdistCycVisMap _patOdistDataCons _patOdistDataMap _patOdistDataSems _patOdistDatas _patOdistDeflStmts _patOdistDefs _patOdistInhAttrs _patOdistItfs _patOdistRanks _patOdistRenames _patOdistSynAttrs _patOdistVisLocalDefs _patOdistVisitInhAttrs _patOdistVisitOrder _patOdistVisitSource _patOdistVisitSynAttrs _patOdistVisits _patOdoneVisits _patOgathChildDefs _patOgathClauses _patOgathDataSems _patOgathDefs _patOgathNonterms _patOgathVisLocalDefs _patOhSpilledStmts _patOisCyclic _patOisMatch _patOisRight _patOitf _patOjsSpilledStmts _patOlexCounter _patOnonterm _patOopts _patOprio _patOscopeDep _patOscopeReason _patOstmtSource _patOvisitBeginDep _patOvisitEndDep _patOvisitEndReason 
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIisFun,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpos,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp,_lhsOrank)))
sem_Stmt_Invoke :: Pos ->
                   Ident ->
                   Ident ->
                   T_MaybeBoundCode  ->
                   T_Stmt 
sem_Stmt_Invoke pos_ visit_ name_ code_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOerrs1 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitSource :: VisitSourceMap
              _codeOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDefs :: DefsEnv
              _lhsOgathDefs :: DefsEnv
              deflts_val_ :: ImplStmts 
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup85 :: ((Int,Int))
              _codeOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _lhsOrank :: Int
              _codeOallAvailInvokes :: (Map Ident (Set Ident))
              _codeOallVisits :: (Set Ident)
              _codeOavailInvokes :: (Map Ident (Set Ident))
              _codeObasename :: QIdent
              _codeOcoItf :: Ident
              _codeOcodeIdCounter :: Int
              _codeOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _codeOdirectVisitLocalAttrs :: (Map Ident String)
              _codeOdistAliasses :: (Map Ident AliasType)
              _codeOdistAllChildMinRanges :: (Map Ident [Ident])
              _codeOdistAttrSource :: AttrSourceMap
              _codeOdistAttrVisMap :: AttrVisMap
              _codeOdistChildEffRanges :: (Map Ident (Set Ident))
              _codeOdistChildMinRanges :: (Map Ident [Ident])
              _codeOdistChildOcc :: (Map Ident Int)
              _codeOdistChildSource :: ChildSourceMap
              _codeOdistCycVisMap :: CycVisMap
              _codeOdistDataCons :: ConEnv
              _codeOdistDataMap :: DataMap
              _codeOdistDataSems :: DataSemEnv
              _codeOdistDatas :: DataEnv
              _codeOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _codeOdistDefs :: DefsEnv
              _codeOdistInhAttrs :: AttrMap
              _codeOdistItfs :: ItfEnv
              _codeOdistRanks :: (Map DepItem (Bool,Int))
              _codeOdistRenames :: RenameMap
              _codeOdistSynAttrs :: AttrMap
              _codeOdistVisLocalDefs :: DefsEnv
              _codeOdistVisitInhAttrs :: VisitAttrMap
              _codeOdistVisitOrder :: (Map Ident [Ident])
              _codeOdistVisitSource :: VisitSourceMap
              _codeOdistVisitSynAttrs :: VisitAttrMap
              _codeOdistVisits :: VisitEnv
              _codeOdoneVisits :: ([Ident])
              _codeOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeOgathClauses :: ClausesEnv
              _codeOgathDataSems :: DataSemEnv
              _codeOgathDefs :: DefsEnv
              _codeOgathNonterms :: NontermEnv
              _codeOgathVisLocalDefs :: DefsEnv
              _codeOhSpilledStmts :: ([(Int,PP_Doc)])
              _codeOitf :: QIdent
              _codeOjsSpilledStmts :: ([(Int,PP_Doc)])
              _codeOnonterm :: QIdent
              _codeOopts :: Opts
              _codeOscopeDep :: DepItem
              _codeOscopeReason :: Reason
              _codeOstmtSource :: DepItem
              _codeOvisitBeginDep :: DepItem
              _codeOvisitEndDep :: DepItem
              _codeOvisitEndReason :: Reason
              _defltsOallAvailInvokes :: (Map Ident (Set Ident))
              _defltsOallVisits :: (Set Ident)
              _defltsOallowCycVisits :: (Set Ident)
              _defltsOavailInvokes :: (Map Ident (Set Ident))
              _defltsObasename :: QIdent
              _defltsOcoItf :: Ident
              _defltsOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _defltsOdirectVisitLocalAttrs :: (Map Ident String)
              _defltsOdistAliasses :: (Map Ident AliasType)
              _defltsOdistAllChildMinRanges :: (Map Ident [Ident])
              _defltsOdistAttrSource :: AttrSourceMap
              _defltsOdistAttrVisMap :: AttrVisMap
              _defltsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOdistChildEffRanges :: (Map Ident (Set Ident))
              _defltsOdistChildMinRanges :: (Map Ident [Ident])
              _defltsOdistChildOcc :: (Map Ident Int)
              _defltsOdistChildSource :: ChildSourceMap
              _defltsOdistCycVisMap :: CycVisMap
              _defltsOdistDataCons :: ConEnv
              _defltsOdistDataMap :: DataMap
              _defltsOdistDataSems :: DataEnv
              _defltsOdistDatas :: DataEnv
              _defltsOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _defltsOdistDefs :: DefsEnv
              _defltsOdistInhAttrs :: AttrMap
              _defltsOdistItfs :: ItfEnv
              _defltsOdistRanks :: (Map DepItem (Bool,Int))
              _defltsOdistRenames :: RenameMap
              _defltsOdistSynAttrs :: AttrMap
              _defltsOdistVisLocalDefs :: DefsEnv
              _defltsOdistVisRankMap :: (IntMap Ident)
              _defltsOdistVisitInhAttrs :: VisitAttrMap
              _defltsOdistVisitOrder :: (Map Ident [Ident])
              _defltsOdistVisitSource :: VisitSourceMap
              _defltsOdistVisitSynAttrs :: VisitAttrMap
              _defltsOdistVisits :: VisitEnv
              _defltsOdoneVisits :: ([Ident])
              _defltsOfullCyclicVisits :: (Set Ident)
              _defltsOgathChildDefs :: (Env QIdent (QIdent,QIdent))
              _defltsOgathClauses :: ClausesEnv
              _defltsOgathDefs :: DefsEnv
              _defltsOgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsOgathNonterms :: NontermEnv
              _defltsOgathVisLocalDefs :: DefsEnv
              _defltsOhSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOitf :: QIdent
              _defltsOjsSpilledStmts :: ([(Int,PP_Doc)])
              _defltsOlexCounter :: Int
              _defltsOnonterm :: QIdent
              _defltsOopts :: Opts
              _defltsOscopeDep :: DepItem
              _defltsOscopeReason :: Reason
              _defltsOstmtSource :: DepItem
              _defltsOvisitBeginDep :: DepItem
              _defltsOvisitEndDep :: DepItem
              _defltsOvisitEndReason :: Reason
              _codeIallReqInvokes :: (Map Ident (Set Ident))
              _codeIcodeIdCounter :: Int
              _codeIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _codeIdistDataCons :: ConEnv
              _codeIdistDataSems :: DataSemEnv
              _codeIdistDatas :: DataEnv
              _codeIdistDefs :: DefsEnv
              _codeIdistItfs :: ItfEnv
              _codeIdistVisLocalDefs :: DefsEnv
              _codeIdistVisits :: VisitEnv
              _codeIerrs0 :: Errs
              _codeIerrs1 :: Errs
              _codeIerrs2 :: Errs
              _codeIerrs3 :: Errs
              _codeIerrs4 :: Errs
              _codeIerrs5 :: Errs
              _codeIgathAvoidVisits :: (Set DepItem)
              _codeIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _codeIgathClauses :: ClausesEnv
              _codeIgathDataSems :: DataSemEnv
              _codeIgathDefs :: DefsEnv
              _codeIgathDeps :: Deps
              _codeIgathItemVisits :: (Map DepItem DepItem)
              _codeIgathLegalCycStmts :: (Set DepItem)
              _codeIgathMissingInvokes :: (Set (Ident,Ident))
              _codeIgathNonterms :: NontermEnv
              _codeIgathSemStarts :: (Seq DepItem)
              _codeIgathStmtPosMap :: (Map DepItem Pos)
              _codeIgathVisLocalDefs :: DefsEnv
              _codeIgathVisitEnds :: (Seq DepItem)
              _codeIgathVisitStarts :: (Seq DepItem)
              _codeIhpp :: PP_Doc
              _codeIisFun :: Bool
              _codeIisJust :: Bool
              _codeIjspp :: PP_Doc
              _codeIlexCounter :: Int
              _codeIminReqInvokes :: (Map Ident (Set Ident))
              _codeIpp :: PP_Doc
              _defltsIdistDefs :: DefsEnv
              _defltsIdistVisLocalDefs :: DefsEnv
              _defltsIerrs2 :: Errs
              _defltsIerrs3 :: Errs
              _defltsIerrs4 :: Errs
              _defltsIerrs5 :: Errs
              _defltsIgathAttrSource :: AttrSourceMap
              _defltsIgathChildSource :: ChildSourceMap
              _defltsIgathDefs :: DefsEnv
              _defltsIgathDeps :: Deps
              _defltsIgathItemVisits :: (Map DepItem DepItem)
              _defltsIgathLegalCycStmts :: (Set DepItem)
              _defltsIgathNextVisits :: (Map Ident (Maybe Ident))
              _defltsIgathStmtPosMap :: (Map DepItem Pos)
              _defltsIgathVisLocalDefs :: DefsEnv
              _defltsIgathVisitSource :: VisitSourceMap
              _defltsIhopps :: ([(Int, PP_Doc)])
              _defltsIjsopps :: ([(Int, PP_Doc)])
              _defltsIlexCounter :: Int
              _defltsIpps :: ([PP_Doc])
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 435 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 61088 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 435 "src/Transform.ag" #-}
                   ( if null _childVisits     || visit_ `elem` _childVisits
                     then Seq.empty else Seq.singleton (Err_UndefVisit name_ visit_ _childVisits    )) Seq.><
                   {-# LINE 61094 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOerrs5 =
                  ({-# LINE 1957 "src/Transform.ag" #-}
                   foldr ($) _errs5_augmented_syn [_errs5_augmented_f1, _errs5_augmented_f2, _errs5_augmented_f3]
                   {-# LINE 61099 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f1 =
                  ({-# LINE 1957 "src/Transform.ag" #-}
                   if _codeIisJust && _isCyclic
                   then (Err_IterCyclic pos_ Seq.<|)
                   else id
                   {-# LINE 61106 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f2 =
                  ({-# LINE 1957 "src/Transform.ag" #-}
                   if _isCyclic     && not _visitCyclic
                   then (Err_VisExpCyclic visit_ name_ Seq.<|)
                   else id
                   {-# LINE 61113 "src/Transform.hs" #-})
              -- augment function
              _errs5_augmented_f3 =
                  ({-# LINE 1957 "src/Transform.ag" #-}
                   if _isCyclic     && _codeIisJust && not _codeIisFun
                   then (Err_EffCyclic pos_ Seq.<|)
                   else id
                   {-# LINE 61120 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathAttrSource =
                  ({-# LINE 2087 "src/Transform.ag" #-}
                   foldr ($) _gathAttrSource_augmented_syn [_gathAttrSource_augmented_f1]
                   {-# LINE 61125 "src/Transform.hs" #-})
              -- augment function
              _gathAttrSource_augmented_f1 =
                  ({-# LINE 2087 "src/Transform.ag" #-}
                   Map.union $ Map.fromList [ ((False,name_,attr), _stmtSource    ) | attr <- Map.keys _synAttrMap     ]
                   {-# LINE 61130 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1, _gathDeps_augmented_f2, _gathDeps_augmented_f3, _gathDeps_augmented_f4, _gathDeps_augmented_f5]
                   {-# LINE 61135 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   addDep _lhsIvisitEndDep _lhsIvisitEndReason [_stmtSource    ]
                   {-# LINE 61140 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f2 =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   Seq.fromList [ Dep _stmtSource     (ReasonAttrReq name_ attr)
                                    [Map.findWithDefault (trace "Stmt.Invoke.unknown.inh" unknDepItem) (True,name_,attr) _lhsIdistAttrSource]
                                | attr <- Map.keys _inhAttrMap     ] Seq.><
                   {-# LINE 61147 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f3 =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   case _mbChildSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _stmtSource     (ReasonChildReq name_) [d]
                   {-# LINE 61154 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f4 =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   case _mbVisitSource     of
                     Nothing    -> id
                     Just (_,d) -> addDep _stmtSource     (ReasonInvokeReq visit_) [d]
                   {-# LINE 61161 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f5 =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 61166 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 61171 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 61176 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 61181 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 61186 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathNextVisits =
                  ({-# LINE 1568 "src/Transform.ag" #-}
                   foldr ($) _gathNextVisits_augmented_syn [_gathNextVisits_augmented_f1]
                   {-# LINE 61191 "src/Transform.hs" #-})
              -- augment function
              _gathNextVisits_augmented_f1 =
                  ({-# LINE 1568 "src/Transform.ag" #-}
                   Map.insertWith (laterVisit _childVisits    ) name_ _mbNextVisit
                   {-# LINE 61196 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 61201 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 61206 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathVisitSource =
                  ({-# LINE 2144 "src/Transform.ag" #-}
                   foldr ($) _gathVisitSource_augmented_syn [_gathVisitSource_augmented_f1]
                   {-# LINE 61211 "src/Transform.hs" #-})
              -- augment function
              _gathVisitSource_augmented_f1 =
                  ({-# LINE 2144 "src/Transform.ag" #-}
                   Map.insertWith mappend name_ (Map.singleton visit_ _stmtSource    )
                   {-# LINE 61216 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 433, column 13)
              _unqualChildItf =
                  ({-# LINE 433 "src/Transform.ag" #-}
                   head _childItf
                   {-# LINE 61221 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 434, column 13)
              _childVisits =
                  ({-# LINE 434 "src/Transform.ag" #-}
                   Map.findWithDefault [] _unqualChildItf     _lhsIdistVisitOrder
                   {-# LINE 61226 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 550, column 13)
              __tup81 =
                  ({-# LINE 550 "src/Transform.ag" #-}
                   find [name_] (unknQIdent,unknQIdent) _lhsIdistChildDefs
                   {-# LINE 61231 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 550, column 13)
              (__tup82,_) =
                  ({-# LINE 550 "src/Transform.ag" #-}
                   __tup81
                   {-# LINE 61236 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 550, column 13)
              (_childItf,_) =
                  ({-# LINE 550 "src/Transform.ag" #-}
                   __tup82
                   {-# LINE 61241 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 550, column 13)
              (_,_startVisit) =
                  ({-# LINE 550 "src/Transform.ag" #-}
                   __tup82
                   {-# LINE 61246 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 550, column 13)
              (_,_codeOdistChildDefs) =
                  ({-# LINE 550 "src/Transform.ag" #-}
                   __tup81
                   {-# LINE 61251 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1155, column 3)
              _inhAttrMap =
                  ({-# LINE 1155 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty visit_ (Map.findWithDefault Map.empty _unqualChildItf     _lhsIdistVisitInhAttrs)
                   {-# LINE 61256 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1156, column 3)
              _synAttrMap =
                  ({-# LINE 1156 "src/Transform.ag" #-}
                   Map.findWithDefault Map.empty visit_ (Map.findWithDefault Map.empty _unqualChildItf     _lhsIdistVisitSynAttrs)
                   {-# LINE 61261 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1158, column 3)
              _missingAttrMap =
                  ({-# LINE 1158 "src/Transform.ag" #-}
                   Map.filterWithKey (\n _ -> not $ defined (name_,n,True) _lhsIdistDefs) _inhAttrMap
                   {-# LINE 61266 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1159, column 3)
              __tup83 =
                  ({-# LINE 1159 "src/Transform.ag" #-}
                   Map.partitionWithKey (\n _ -> Map.member n _lhsIdistDeflStmts) _missingAttrMap
                   {-# LINE 61271 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1159, column 3)
              (_deflAttrMap,_) =
                  ({-# LINE 1159 "src/Transform.ag" #-}
                   __tup83
                   {-# LINE 61276 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1159, column 3)
              (_,_undefAttrMap) =
                  ({-# LINE 1159 "src/Transform.ag" #-}
                   __tup83
                   {-# LINE 61281 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1160, column 3)
              _deflAttrs =
                  ({-# LINE 1160 "src/Transform.ag" #-}
                   [ (a, Map.findWithDefault (False,Nothing) a _lhsIdistDeflStmts) | a <- Map.keys _deflAttrMap     ]
                   {-# LINE 61286 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1163, column 3)
              _lhsOdistDefs =
                  ({-# LINE 1163 "src/Transform.ag" #-}
                   Map.foldWithKey (\n _ -> snd . find (name_,replPos pos_ n,True) Nothing) _codeIdistDefs _undefAttrMap
                   {-# LINE 61291 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1164, column 3)
              _lhsOgathDefs =
                  ({-# LINE 1164 "src/Transform.ag" #-}
                   Map.foldWithKey (\n t -> extend (name_,replPos pos_ n,False) (Just t)) _codeIgathDefs _synAttrMap
                   {-# LINE 61296 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1212, column 3)
              deflts_val_ =
                  ({-# LINE 1212 "src/Transform.ag" #-}
                   map (\(nm,(empty,mbCode)) -> ImplStmt_DefaultChild pos_ empty name_ nm mbCode) _deflAttrs
                   {-# LINE 61301 "src/Transform.hs" #-})
              deflts_inst_ =
                  (sem_ImplStmts deflts_val_ )
              -- "src/Transform.ag"(line 1556, column 24)
              _mbNextVisit =
                  ({-# LINE 1556 "src/Transform.ag" #-}
                   visitAfter visit_ _childVisits
                   {-# LINE 61308 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1650, column 32)
              _lhsOexplInvokes =
                  ({-# LINE 1650 "src/Transform.ag" #-}
                   Map.singleton name_ (Set.singleton visit_)
                   {-# LINE 61313 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1866, column 19)
              _destVisit =
                  ({-# LINE 1866 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 61318 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1922, column 19)
              _fullCyclic =
                  ({-# LINE 1922 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 61323 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1923, column 19)
              _allowCycles =
                  ({-# LINE 1923 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 61328 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1928, column 3)
              _visitCyclic =
                  ({-# LINE 1928 "src/Transform.ag" #-}
                   Set.member visit_ (Map.findWithDefault Set.empty _unqualChildItf     _lhsIdistCycVisMap)
                   {-# LINE 61333 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1929, column 3)
              _behaveCyclic =
                  ({-# LINE 1929 "src/Transform.ag" #-}
                   _fullCyclic     || _visitCyclic
                   {-# LINE 61338 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2021, column 14)
              _stmtSource =
                  ({-# LINE 2021 "src/Transform.ag" #-}
                   DepInvoke (visit_ : name_ : _lhsIbasename)
                   {-# LINE 61343 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2238, column 3)
              _mbVisitSource =
                  ({-# LINE 2238 "src/Transform.ag" #-}
                   nearestVisitEntry False visit_ _childVisits     $ Map.findWithDefault Map.empty name_ _lhsIdistVisitSource
                   {-# LINE 61348 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2239, column 3)
              _mbChildSource =
                  ({-# LINE 2239 "src/Transform.ag" #-}
                   nearestVisitEntry True  visit_ _childVisits     $ Map.findWithDefault Map.empty name_ _lhsIdistChildSource
                   {-# LINE 61353 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              __tup84 =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 61358 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup84
                   {-# LINE 61363 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_,_rank) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup84
                   {-# LINE 61368 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2380, column 3)
              _isCyclic =
                  ({-# LINE 2380 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 61373 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2540, column 18)
              _lhsOpp =
                  ({-# LINE 2540 "src/Transform.ag" #-}
                   vlist _defltsIpps
                   >-< "invoke" >#< visit_ >#< "of" >#< name_ >#< _codeIpp
                   {-# LINE 61379 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 387, column 18)
              _infoComment =
                  ({-# LINE 387 "src/TargetHaskell.ag" #-}
                   "-- invoke stmt:" >#< show (line pos_) >#< ", rank:" >#< _rank
                   {-# LINE 61384 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 388, column 18)
              _hBang =
                  ({-# LINE 388 "src/TargetHaskell.ag" #-}
                   if _behaveCyclic     then empty else text "!"
                   {-# LINE 61389 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 389, column 18)
              _lhsOhpp =
                  ({-# LINE 389 "src/TargetHaskell.ag" #-}
                   (if _isCyclic
                    then vlist (concat _hGroupedStmts    )
                    else hppStmtBlock _hGroupedStmts    )
                   >-< if _codeIisJust
                       then ppBind _isCyclic     _hPat     ("let" >#< _hIter     >-< "in" >#< _hRhs    ) >#< _infoComment
                       else ppBind _isCyclic     (_hBang     >|< _hPat    )
                                 ((\p -> if not _isCyclic     && _behaveCyclic     then "return" >#< pp_parens p else p) (
                                   ("let" >#< _hBang     >|< pp_parens (hItfVsNm _unqualChildItf     visit_
                                                                          >#< "!" >|< "__f")
                                          >#< "=" >#< hSemNm name_ visit_
                                    >-< "in" >#< "__f" >#< _hfInps    )))
                              >#< _infoComment
                   {-# LINE 61405 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 401, column 18)
              _hRhsCode =
                  ({-# LINE 401 "src/TargetHaskell.ag" #-}
                   if _codeIisJust
                   then _codeIhpp
                   else "return" >#< pp_parens ("mk" >|< noIterNm _unqualChildItf     visit_)
                   {-# LINE 61412 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 404, column 18)
              _hIter =
                  ({-# LINE 404 "src/TargetHaskell.ag" #-}
                   "__iter" >#< "!" >|< pp_parens (hItfVsNm _unqualChildItf     visit_ >#< "!" >|< "__f")
                            >#< _hfInps
                   >-< indent 2 ( "=" >#< "do" >#< (
                         "!" >|< ppBind False (hCoItfVsNm _unqualChildItf     visit_ >#< "!" >|< "__g") _hRhsCode
                         >-< ppBind _behaveCyclic     (_hBang     >|< "__res@" >|< _hfOuts    ) ("__f" >#< _hfInps    )
                         >-< hCatch ("do" >#< (
                                               _hBang     >|< ppBind False _hgOuts     ("__g" >#< _hgInps    )
                                               >-< "__iter" >#< "__f" >#< _hfInps
                                             ))
                                    (text "const (return __res)")
                       ))
                   {-# LINE 61427 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 415, column 18)
              _hfInps =
                  ({-# LINE 415 "src/TargetHaskell.ag" #-}
                   pp_parens (hInhDt _unqualChildItf     visit_ >#< pp_block "{" "}" ","
                     [ hInhFldNm nm _unqualChildItf     visit_ >#< "=" >#<
                         hParensWithPos _lhsIopts pos_ (hOutp name_ nm)
                     | (nm,_) <- Map.assocs _inhAttrMap     ] )
                   {-# LINE 61435 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 419, column 18)
              _hfOuts =
                  ({-# LINE 419 "src/TargetHaskell.ag" #-}
                   pp_parens (hSynDt _unqualChildItf     visit_ >#< pp_block "{" "}" ","
                     ( (hSynFldNmFull repIdent _unqualChildItf     visit_ >#< "=" >#< "__f") :
                     [ hSynFldNm nm _unqualChildItf     visit_ >#< "=" >#<
                         hParensWithPos _lhsIopts pos_ (hInp name_ nm)
                     | (nm,_) <- Map.assocs _synAttrMap     ] ))
                   {-# LINE 61444 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 424, column 18)
              _hgInps =
                  ({-# LINE 424 "src/TargetHaskell.ag" #-}
                   pp_parens (hCoInhDt _unqualChildItf     visit_ >#< pp_block "{" "}" ","
                     [ hCoInhFldNm nm _unqualChildItf     visit_ >#< "=" >#<
                         hParensWithPos _lhsIopts pos_ (hInp name_ nm)
                     | (nm,_) <- Map.assocs _synAttrMap     ] )
                   {-# LINE 61452 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 428, column 18)
              _hgOuts =
                  ({-# LINE 428 "src/TargetHaskell.ag" #-}
                   pp_parens (hCoSynDt _unqualChildItf     visit_ >#< pp_block "{" "}" ","
                     [ hCoSynFldNm nm _unqualChildItf     visit_ >#< "=" >#<
                         hParensWithPos _lhsIopts pos_ (hOutp name_ nm)
                     | (nm,_) <- Map.assocs _inhAttrMap     ] )
                   {-# LINE 61460 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 432, column 18)
              _hRhs =
                  ({-# LINE 432 "src/TargetHaskell.ag" #-}
                   "__iter" >#< hSemNm name_ visit_ >#< _hfInps
                   {-# LINE 61465 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 433, column 18)
              _hPat =
                  ({-# LINE 433 "src/TargetHaskell.ag" #-}
                   pp_parens (
                     hSynDt _unqualChildItf     visit_ >#< pp_block "{" "}" "," (
                       ( maybe [] (\nm -> [ hSynFldNmFull nextIdent _unqualChildItf     visit_ >#< "=" >#< hSemNm name_ nm ])
                         _mbNextVisit    ) ++
                       [ hSynFldNm nm _unqualChildItf     visit_ >#< "=" >#< hInp name_ nm
                       | (nm,_) <- Map.assocs _synAttrMap     ]
                   ))
                   {-# LINE 61476 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 607, column 24)
              _hGroupedStmts =
                  ({-# LINE 607 "src/TargetHaskell.ag" #-}
                   groupPairs _defltsIhopps
                   {-# LINE 61481 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 232, column 18)
              _lhsOjspp =
                  ({-# LINE 232 "src/TargetJs.ag" #-}
                   jsppStmtBlock _jsGroupedStmts
                   >-< "var _args = new Inh_" >|< jsConNm _unqualChildItf     visit_ >|< "();"
                   >-< vlist [ "_args." >|< show nm >#< "=" >#< jsOutp name_ nm >|< ";"
                             | (nm,_) <- Map.assocs _inhAttrMap     ]
                   >-< "if (!" >|< jsVis name_ visit_ >|< ") { throw \"uninitialized semantics: ">|< jsVis name_ visit_ >#< "(expl)\"; }"
                   >-< "var _res =" >#< jsVis name_ visit_ >#< pp_parens (text "_args") >|< ";"
                   >-< "_res.check();"
                   >-< vlist [ "var" >#< (jsInp name_ nm) >#< "=" >#< "_res." >|< show nm >|< ";"
                             | (nm,_) <- Map.assocs _synAttrMap     ]
                   >-< case _mbNextVisit     of
                         Nothing   -> empty
                         Just next -> "var" >#< jsVis name_ next >#< "= _res._next;"
                   {-# LINE 61497 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 402, column 24)
              _jsGroupedStmts =
                  ({-# LINE 402 "src/TargetJs.ag" #-}
                   groupPairs _defltsIjsopps
                   {-# LINE 61502 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup85 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_codeOlexCounter,_) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup85
                   {-# LINE 61510 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup85
                   {-# LINE 61515 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIallReqInvokes
                   {-# LINE 61520 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 61525 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs0
                   {-# LINE 61530 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 435 "src/Transform.ag" #-}
                   _codeIerrs1
                   {-# LINE 61535 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs2 Seq.>< _defltsIerrs2
                   {-# LINE 61540 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs3 Seq.>< _defltsIerrs3
                   {-# LINE 61545 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _codeIerrs4 Seq.>< _defltsIerrs4
                   {-# LINE 61550 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs5_augmented_syn =
                  ({-# LINE 1957 "src/Transform.ag" #-}
                   _codeIerrs5 Seq.>< _defltsIerrs5
                   {-# LINE 61555 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _gathAttrSource_augmented_syn =
                  ({-# LINE 2087 "src/Transform.ag" #-}
                   _defltsIgathAttrSource
                   {-# LINE 61560 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _codeIgathAvoidVisits
                   {-# LINE 61565 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 61570 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 61575 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 61580 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _defltsIgathChildSource
                   {-# LINE 61585 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 61590 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2249 "src/Transform.ag" #-}
                   _codeIgathDeps Seq.>< _defltsIgathDeps
                   {-# LINE 61595 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   _codeIgathItemVisits `Map.union` _defltsIgathItemVisits
                   {-# LINE 61600 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   _codeIgathLegalCycStmts `Set.union` _defltsIgathLegalCycStmts
                   {-# LINE 61605 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _codeIgathMissingInvokes
                   {-# LINE 61610 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 61615 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _codeIgathSemStarts
                   {-# LINE 61620 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   _codeIgathStmtPosMap `Map.union` _defltsIgathStmtPosMap
                   {-# LINE 61625 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitEnds
                   {-# LINE 61630 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _gathVisitSource_augmented_syn =
                  ({-# LINE 2144 "src/Transform.ag" #-}
                   _defltsIgathVisitSource
                   {-# LINE 61635 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _codeIgathVisitStarts
                   {-# LINE 61640 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _codeIminReqInvokes
                   {-# LINE 61645 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _codeIcodeIdCounter
                   {-# LINE 61650 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 61655 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 61660 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 61665 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 61670 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 61675 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _defltsIdistVisLocalDefs
                   {-# LINE 61680 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 61685 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 61690 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 61695 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _codeIgathDataSems
                   {-# LINE 61700 "src/Transform.hs" #-})
              -- copy rule (up)
              _gathNextVisits_augmented_syn =
                  ({-# LINE 1568 "src/Transform.ag" #-}
                   _defltsIgathNextVisits
                   {-# LINE 61705 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 61710 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _defltsIgathVisLocalDefs
                   {-# LINE 61715 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _defltsIlexCounter
                   {-# LINE 61720 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 61725 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 61730 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 61735 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 61740 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 61745 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 61750 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 61755 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 61760 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 61765 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 61770 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 61775 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 61780 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 61785 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 61790 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 61795 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 61800 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 61805 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 61810 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 61815 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 61820 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 61825 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 61830 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 61835 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 61840 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 61845 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 61850 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 61855 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 61860 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 61865 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 61870 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 61875 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 61880 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 61885 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 61890 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 61895 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 61900 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 61905 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 61910 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 61915 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 61920 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 61925 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 61930 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 61935 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 61940 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 61945 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 61950 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 61955 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 61960 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 61965 "src/Transform.hs" #-})
              -- copy rule (from local)
              _codeOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 61970 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 61975 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 61980 "src/Transform.hs" #-})
              -- copy rule (down)
              _codeOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 61985 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 61990 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 61995 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 62000 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 62005 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 62010 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 62015 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 62020 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 62025 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 62030 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 62035 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 62040 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 62045 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _codeIdistChildDefs
                   {-# LINE 62050 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 62055 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 62060 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 62065 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 62070 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 62075 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDataCons =
                  ({-# LINE 309 "src/Transform.ag" #-}
                   _codeIdistDataCons
                   {-# LINE 62080 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 62085 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDataSems =
                  ({-# LINE 268 "src/Transform.ag" #-}
                   _codeIdistDataSems
                   {-# LINE 62090 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDatas =
                  ({-# LINE 466 "src/Transform.ag" #-}
                   _codeIdistDatas
                   {-# LINE 62095 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 62100 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistDefs
                   {-# LINE 62105 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 62110 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistItfs =
                  ({-# LINE 395 "src/Transform.ag" #-}
                   _codeIdistItfs
                   {-# LINE 62115 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 62120 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 62125 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 62130 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIdistVisLocalDefs
                   {-# LINE 62135 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 62140 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 62145 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 62150 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 62155 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 62160 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOdistVisits =
                  ({-# LINE 424 "src/Transform.ag" #-}
                   _codeIdistVisits
                   {-# LINE 62165 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 62170 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 62175 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathChildDefs =
                  ({-# LINE 499 "src/Transform.ag" #-}
                   _codeIgathChildDefs
                   {-# LINE 62180 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathClauses =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _codeIgathClauses
                   {-# LINE 62185 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathDefs
                   {-# LINE 62190 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 62195 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathNonterms =
                  ({-# LINE 242 "src/Transform.ag" #-}
                   _codeIgathNonterms
                   {-# LINE 62200 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _codeIgathVisLocalDefs
                   {-# LINE 62205 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 62210 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 62215 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 62220 "src/Transform.hs" #-})
              -- copy rule (chain)
              _defltsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _codeIlexCounter
                   {-# LINE 62225 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 62230 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 62235 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 62240 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 62245 "src/Transform.hs" #-})
              -- copy rule (from local)
              _defltsOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _stmtSource
                   {-# LINE 62250 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 62255 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 62260 "src/Transform.hs" #-})
              -- copy rule (down)
              _defltsOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 62265 "src/Transform.hs" #-})
              ( _codeIallReqInvokes,_codeIcodeIdCounter,_codeIdistChildDefs,_codeIdistDataCons,_codeIdistDataSems,_codeIdistDatas,_codeIdistDefs,_codeIdistItfs,_codeIdistVisLocalDefs,_codeIdistVisits,_codeIerrs0,_codeIerrs1,_codeIerrs2,_codeIerrs3,_codeIerrs4,_codeIerrs5,_codeIgathAvoidVisits,_codeIgathChildDefs,_codeIgathClauses,_codeIgathDataSems,_codeIgathDefs,_codeIgathDeps,_codeIgathItemVisits,_codeIgathLegalCycStmts,_codeIgathMissingInvokes,_codeIgathNonterms,_codeIgathSemStarts,_codeIgathStmtPosMap,_codeIgathVisLocalDefs,_codeIgathVisitEnds,_codeIgathVisitStarts,_codeIhpp,_codeIisFun,_codeIisJust,_codeIjspp,_codeIlexCounter,_codeIminReqInvokes,_codeIpp) =
                  code_ _codeOallAvailInvokes _codeOallVisits _codeOavailInvokes _codeObasename _codeOcoItf _codeOcodeIdCounter _codeOdirectVisitAttrs _codeOdirectVisitLocalAttrs _codeOdistAliasses _codeOdistAllChildMinRanges _codeOdistAttrSource _codeOdistAttrVisMap _codeOdistChildDefs _codeOdistChildEffRanges _codeOdistChildMinRanges _codeOdistChildOcc _codeOdistChildSource _codeOdistCycVisMap _codeOdistDataCons _codeOdistDataMap _codeOdistDataSems _codeOdistDatas _codeOdistDeflStmts _codeOdistDefs _codeOdistInhAttrs _codeOdistItfs _codeOdistRanks _codeOdistRenames _codeOdistSynAttrs _codeOdistVisLocalDefs _codeOdistVisitInhAttrs _codeOdistVisitOrder _codeOdistVisitSource _codeOdistVisitSynAttrs _codeOdistVisits _codeOdoneVisits _codeOgathChildDefs _codeOgathClauses _codeOgathDataSems _codeOgathDefs _codeOgathNonterms _codeOgathVisLocalDefs _codeOhSpilledStmts _codeOitf _codeOjsSpilledStmts _codeOlexCounter _codeOnonterm _codeOopts _codeOscopeDep _codeOscopeReason _codeOstmtSource _codeOvisitBeginDep _codeOvisitEndDep _codeOvisitEndReason 
              ( _defltsIdistDefs,_defltsIdistVisLocalDefs,_defltsIerrs2,_defltsIerrs3,_defltsIerrs4,_defltsIerrs5,_defltsIgathAttrSource,_defltsIgathChildSource,_defltsIgathDefs,_defltsIgathDeps,_defltsIgathItemVisits,_defltsIgathLegalCycStmts,_defltsIgathNextVisits,_defltsIgathStmtPosMap,_defltsIgathVisLocalDefs,_defltsIgathVisitSource,_defltsIhopps,_defltsIjsopps,_defltsIlexCounter,_defltsIpps) =
                  deflts_inst_ _defltsOallAvailInvokes _defltsOallVisits _defltsOallowCycVisits _defltsOavailInvokes _defltsObasename _defltsOcoItf _defltsOdirectVisitAttrs _defltsOdirectVisitLocalAttrs _defltsOdistAliasses _defltsOdistAllChildMinRanges _defltsOdistAttrSource _defltsOdistAttrVisMap _defltsOdistChildDefs _defltsOdistChildEffRanges _defltsOdistChildMinRanges _defltsOdistChildOcc _defltsOdistChildSource _defltsOdistCycVisMap _defltsOdistDataCons _defltsOdistDataMap _defltsOdistDataSems _defltsOdistDatas _defltsOdistDeflStmts _defltsOdistDefs _defltsOdistInhAttrs _defltsOdistItfs _defltsOdistRanks _defltsOdistRenames _defltsOdistSynAttrs _defltsOdistVisLocalDefs _defltsOdistVisRankMap _defltsOdistVisitInhAttrs _defltsOdistVisitOrder _defltsOdistVisitSource _defltsOdistVisitSynAttrs _defltsOdistVisits _defltsOdoneVisits _defltsOfullCyclicVisits _defltsOgathChildDefs _defltsOgathClauses _defltsOgathDefs _defltsOgathNextVisits _defltsOgathNonterms _defltsOgathVisLocalDefs _defltsOhSpilledStmts _defltsOitf _defltsOjsSpilledStmts _defltsOlexCounter _defltsOnonterm _defltsOopts _defltsOscopeDep _defltsOscopeReason _defltsOstmtSource _defltsOvisitBeginDep _defltsOvisitEndDep _defltsOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp,_lhsOrank)))
sem_Stmt_Rename :: Pos ->
                   Ident ->
                   T_Renames  ->
                   T_Stmt 
sem_Stmt_Rename pos_ child_ subst_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathRenames :: RenameMap
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              __tup87 :: ((Int,Int))
              _lhsOlexCounter :: Int
              _lexOrder :: Int
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOrank :: Int
              _substIgathRenames :: (Map Ident Ident)
              -- augmented rule
              _lhsOgathDeps =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   foldr ($) _gathDeps_augmented_syn [_gathDeps_augmented_f1]
                   {-# LINE 62390 "src/Transform.hs" #-})
              -- augment function
              _gathDeps_augmented_f1 =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   addDep _stmtSource     _lhsIscopeReason [_lhsIscopeDep]
                   {-# LINE 62395 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathItemVisits =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   foldr ($) _gathItemVisits_augmented_syn [_gathItemVisits_augmented_f1]
                   {-# LINE 62400 "src/Transform.hs" #-})
              -- augment function
              _gathItemVisits_augmented_f1 =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.insert _stmtSource     _lhsIvisitBeginDep
                   {-# LINE 62405 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   foldr ($) _gathLegalCycStmts_augmented_syn [_gathLegalCycStmts_augmented_f1]
                   {-# LINE 62410 "src/Transform.hs" #-})
              -- augment function
              _gathLegalCycStmts_augmented_f1 =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   if _allowCycles     then Set.insert _stmtSource     else id
                   {-# LINE 62415 "src/Transform.hs" #-})
              -- augmented rule
              _lhsOgathStmtPosMap =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   foldr ($) _gathStmtPosMap_augmented_syn [_gathStmtPosMap_augmented_f1]
                   {-# LINE 62420 "src/Transform.hs" #-})
              -- augment function
              _gathStmtPosMap_augmented_f1 =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.insert _stmtSource     pos_
                   {-# LINE 62425 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 589, column 3)
              _lhsOgathRenames =
                  ({-# LINE 589 "src/Transform.ag" #-}
                   Map.singleton child_ _substIgathRenames
                   {-# LINE 62430 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1866, column 19)
              _destVisit =
                  ({-# LINE 1866 "src/Transform.ag" #-}
                   getDestVisit _rank     _lhsIdistVisRankMap
                   {-# LINE 62435 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1922, column 19)
              _fullCyclic =
                  ({-# LINE 1922 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIfullCyclicVisits
                   {-# LINE 62440 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1923, column 19)
              _allowCycles =
                  ({-# LINE 1923 "src/Transform.ag" #-}
                   Set.member _destVisit     _lhsIallowCycVisits
                   {-# LINE 62445 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2022, column 14)
              _stmtSource =
                  ({-# LINE 2022 "src/Transform.ag" #-}
                   DepAssert _lexOrder
                   {-# LINE 62450 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              __tup86 =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   Map.findWithDefault (False,_lexOrder    ) _stmtSource     _lhsIdistRanks
                   {-# LINE 62455 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_isOnCycle,_) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup86
                   {-# LINE 62460 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2379, column 3)
              (_,_rank) =
                  ({-# LINE 2379 "src/Transform.ag" #-}
                   __tup86
                   {-# LINE 62465 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2380, column 3)
              _isCyclic =
                  ({-# LINE 2380 "src/Transform.ag" #-}
                   _fullCyclic     || _isOnCycle
                   {-# LINE 62470 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2543, column 18)
              _lhsOpp =
                  ({-# LINE 2543 "src/Transform.ag" #-}
                   empty
                   {-# LINE 62475 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 447, column 18)
              _lhsOhpp =
                  ({-# LINE 447 "src/TargetHaskell.ag" #-}
                   empty
                   {-# LINE 62480 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 248, column 18)
              _lhsOjspp =
                  ({-# LINE 248 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 62485 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              __tup87 =
                  case _lhsIlexCounter of { __cont | __cont `seq` True -> case nextUnique __cont of { (__cont, lexOrder) -> (__cont, lexOrder)}}
              -- -- generated by the unique rule mechanism.
              (_lhsOlexCounter,_) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup87
                   {-# LINE 62493 "src/Transform.hs" #-})
              -- -- generated by the unique rule mechanism.
              (_,_lexOrder) =
                  ({-# LINE 1282 "src/Transform.ag" #-}
                   __tup87
                   {-# LINE 62498 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62503 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62508 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62513 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62518 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62523 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62528 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62533 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62538 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62543 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62548 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 62553 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62558 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62563 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62568 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62573 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62578 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _gathDeps_augmented_syn =
                  ({-# LINE 2222 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62583 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _gathItemVisits_augmented_syn =
                  ({-# LINE 1995 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62588 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _gathLegalCycStmts_augmented_syn =
                  ({-# LINE 1999 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 62593 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 62598 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62603 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _gathStmtPosMap_augmented_syn =
                  ({-# LINE 2031 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62608 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62613 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62618 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 62623 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 62628 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 62633 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 62638 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 62643 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 62648 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 62653 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 62658 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 62663 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 62668 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 62673 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 62678 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 62683 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 62688 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 62693 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 62698 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 62703 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 62708 "src/Transform.hs" #-})
              -- copy rule (from local)
              _lhsOrank =
                  ({-# LINE 2375 "src/Transform.ag" #-}
                   _rank
                   {-# LINE 62713 "src/Transform.hs" #-})
              ( _substIgathRenames) =
                  subst_ 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhpp,_lhsOjspp,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpp,_lhsOrank)))
-- Stmts -------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         allAvailInvokes      : Map Ident (Set Ident)
         allVisits            : Set Ident
         allowCycVisits       : Set Ident
         availInvokes         : Map Ident (Set Ident)
         basename             : QIdent
         coItf                : Ident
         directVisitAttrs     : Map Ident (Map Ident String)
         directVisitLocalAttrs : Map Ident String
         distAliasses         : Map Ident AliasType
         distAllChildMinRanges : Map Ident [Ident]
         distAttrSource       : AttrSourceMap
         distAttrVisMap       : AttrVisMap
         distChildEffRanges   : Map Ident (Set Ident)
         distChildMinRanges   : Map Ident [Ident]
         distChildOcc         : Map Ident Int
         distChildSource      : ChildSourceMap
         distCycVisMap        : CycVisMap
         distDataMap          : DataMap
         distDeflStmts        : Map Ident (Bool,Maybe Int)
         distInhAttrs         : AttrMap
         distRanks            : Map DepItem (Bool,Int)
         distRenames          : RenameMap
         distSynAttrs         : AttrMap
         distVisRankMap       : IntMap Ident
         distVisitInhAttrs    : VisitAttrMap
         distVisitOrder       : Map Ident [Ident]
         distVisitSource      : VisitSourceMap
         distVisitSynAttrs    : VisitAttrMap
         doneVisits           : [Ident]
         fullCyclicVisits     : Set Ident
         hSpilledStmts        : [(Int,PP_Doc)]
         indent               : Int
         itf                  : QIdent
         jsSpilledStmts       : [(Int,PP_Doc)]
         nonterm              : QIdent
         opts                 : Opts
         scopeDep             : DepItem
         scopeReason          : Reason
         stmtSource           : DepItem
         visitBeginDep        : DepItem
         visitEndDep          : DepItem
         visitEndReason       : Reason
      chained attributes:
         codeIdCounter        : Int
         distChildDefs        : Env QIdent (QIdent,QIdent)
         distDataCons         : ConEnv
         distDataSems         : DataSemEnv
         distDatas            : DataEnv
         distDefs             : DefsEnv
         distItfs             : ItfEnv
         distVisLocalDefs     : DefsEnv
         distVisits           : VisitEnv
         gathChildDefs        : Env QIdent (QIdent, QIdent)
         gathClauses          : ClausesEnv
         gathDataSems         : DataSemEnv
         gathDefs             : DefsEnv
         gathNextVisits       : Map Ident (Maybe Ident)
         gathNonterms         : NontermEnv
         gathVisLocalDefs     : DefsEnv
         lexCounter           : Int
      synthesized attributes:
         allReqInvokes        : Map Ident (Set Ident)
         bannedInvokes        : Map Ident (Set Ident)
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         explInvokes          : Map Ident (Set Ident)
         gathAttrSource       : AttrSourceMap
         gathAvoidVisits      : Set DepItem
         gathChildEffRanges   : Map Ident (Set Ident)
         gathChildMinRanges   : Map Ident [Ident]
         gathChildOcc         : Map Ident Int
         gathChildSource      : ChildSourceMap
         gathDeflStmts        : Map Ident (Bool,Maybe Int)
         gathDeps             : Deps
         gathItemVisits       : Map DepItem DepItem
         gathLegalCycStmts    : Set DepItem
         gathMissingInvokes   : Set (Ident,Ident)
         gathRenames          : RenameMap
         gathSemStarts        : Seq DepItem
         gathStmtPosMap       : Map DepItem Pos
         gathVisitEnds        : Seq DepItem
         gathVisitSource      : VisitSourceMap
         gathVisitStarts      : Seq DepItem
         hopps                : [(Int, PP_Doc)]
         jsopps               : [(Int, PP_Doc)]
         minReqInvokes        : Map Ident (Set Ident)
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : Stmt 
         child tl             : Stmts 
      alternative Nil:
-}
-- cata
sem_Stmts :: Stmts  ->
             T_Stmts 
sem_Stmts list  =
    (Prelude.foldr sem_Stmts_Cons sem_Stmts_Nil (Prelude.map sem_Stmt list) )
-- semantic domain
type T_Stmts  = (Map Ident (Set Ident)) ->
                (Set Ident) ->
                (Set Ident) ->
                (Map Ident (Set Ident)) ->
                QIdent ->
                Ident ->
                Int ->
                (Map Ident (Map Ident String)) ->
                (Map Ident String) ->
                (Map Ident AliasType) ->
                (Map Ident [Ident]) ->
                AttrSourceMap ->
                AttrVisMap ->
                (Env QIdent (QIdent,QIdent)) ->
                (Map Ident (Set Ident)) ->
                (Map Ident [Ident]) ->
                (Map Ident Int) ->
                ChildSourceMap ->
                CycVisMap ->
                ConEnv ->
                DataMap ->
                DataSemEnv ->
                DataEnv ->
                (Map Ident (Bool,Maybe Int)) ->
                DefsEnv ->
                AttrMap ->
                ItfEnv ->
                (Map DepItem (Bool,Int)) ->
                RenameMap ->
                AttrMap ->
                DefsEnv ->
                (IntMap Ident) ->
                VisitAttrMap ->
                (Map Ident [Ident]) ->
                VisitSourceMap ->
                VisitAttrMap ->
                VisitEnv ->
                ([Ident]) ->
                (Set Ident) ->
                (Env QIdent (QIdent, QIdent)) ->
                ClausesEnv ->
                DataSemEnv ->
                DefsEnv ->
                (Map Ident (Maybe Ident)) ->
                NontermEnv ->
                DefsEnv ->
                ([(Int,PP_Doc)]) ->
                Int ->
                QIdent ->
                ([(Int,PP_Doc)]) ->
                Int ->
                QIdent ->
                Opts ->
                DepItem ->
                Reason ->
                DepItem ->
                DepItem ->
                DepItem ->
                Reason ->
                ( (Map Ident (Set Ident)),(Map Ident (Set Ident)),Int,(Env QIdent (QIdent,QIdent)),ConEnv,DataSemEnv,DataEnv,DefsEnv,ItfEnv,DefsEnv,VisitEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident (Set Ident)),AttrSourceMap,(Set DepItem),(Env QIdent (QIdent, QIdent)),(Map Ident (Set Ident)),(Map Ident [Ident]),(Map Ident Int),ChildSourceMap,ClausesEnv,DataSemEnv,(Map Ident (Bool,Maybe Int)),DefsEnv,Deps,(Map DepItem DepItem),(Set DepItem),(Set (Ident,Ident)),(Map Ident (Maybe Ident)),NontermEnv,RenameMap,(Seq DepItem),(Map DepItem Pos),DefsEnv,(Seq DepItem),VisitSourceMap,(Seq DepItem),([(Int, PP_Doc)]),([(Int, PP_Doc)]),Int,(Map Ident (Set Ident)),([PP_Doc]))
sem_Stmts_Cons :: T_Stmt  ->
                  T_Stmts  ->
                  T_Stmts 
sem_Stmts_Cons hd_ tl_  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int, PP_Doc)])
              _lhsOjsopps :: ([(Int, PP_Doc)])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              _hdOallAvailInvokes :: (Map Ident (Set Ident))
              _hdOallVisits :: (Set Ident)
              _hdOallowCycVisits :: (Set Ident)
              _hdOavailInvokes :: (Map Ident (Set Ident))
              _hdObasename :: QIdent
              _hdOcoItf :: Ident
              _hdOcodeIdCounter :: Int
              _hdOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _hdOdirectVisitLocalAttrs :: (Map Ident String)
              _hdOdistAliasses :: (Map Ident AliasType)
              _hdOdistAllChildMinRanges :: (Map Ident [Ident])
              _hdOdistAttrSource :: AttrSourceMap
              _hdOdistAttrVisMap :: AttrVisMap
              _hdOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdOdistChildEffRanges :: (Map Ident (Set Ident))
              _hdOdistChildMinRanges :: (Map Ident [Ident])
              _hdOdistChildOcc :: (Map Ident Int)
              _hdOdistChildSource :: ChildSourceMap
              _hdOdistCycVisMap :: CycVisMap
              _hdOdistDataCons :: ConEnv
              _hdOdistDataMap :: DataMap
              _hdOdistDataSems :: DataSemEnv
              _hdOdistDatas :: DataEnv
              _hdOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdOdistDefs :: DefsEnv
              _hdOdistInhAttrs :: AttrMap
              _hdOdistItfs :: ItfEnv
              _hdOdistRanks :: (Map DepItem (Bool,Int))
              _hdOdistRenames :: RenameMap
              _hdOdistSynAttrs :: AttrMap
              _hdOdistVisLocalDefs :: DefsEnv
              _hdOdistVisRankMap :: (IntMap Ident)
              _hdOdistVisitInhAttrs :: VisitAttrMap
              _hdOdistVisitOrder :: (Map Ident [Ident])
              _hdOdistVisitSource :: VisitSourceMap
              _hdOdistVisitSynAttrs :: VisitAttrMap
              _hdOdistVisits :: VisitEnv
              _hdOdoneVisits :: ([Ident])
              _hdOfullCyclicVisits :: (Set Ident)
              _hdOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdOgathClauses :: ClausesEnv
              _hdOgathDataSems :: DataSemEnv
              _hdOgathDefs :: DefsEnv
              _hdOgathNextVisits :: (Map Ident (Maybe Ident))
              _hdOgathNonterms :: NontermEnv
              _hdOgathVisLocalDefs :: DefsEnv
              _hdOhSpilledStmts :: ([(Int,PP_Doc)])
              _hdOindent :: Int
              _hdOitf :: QIdent
              _hdOjsSpilledStmts :: ([(Int,PP_Doc)])
              _hdOlexCounter :: Int
              _hdOnonterm :: QIdent
              _hdOopts :: Opts
              _hdOscopeDep :: DepItem
              _hdOscopeReason :: Reason
              _hdOstmtSource :: DepItem
              _hdOvisitBeginDep :: DepItem
              _hdOvisitEndDep :: DepItem
              _hdOvisitEndReason :: Reason
              _tlOallAvailInvokes :: (Map Ident (Set Ident))
              _tlOallVisits :: (Set Ident)
              _tlOallowCycVisits :: (Set Ident)
              _tlOavailInvokes :: (Map Ident (Set Ident))
              _tlObasename :: QIdent
              _tlOcoItf :: Ident
              _tlOcodeIdCounter :: Int
              _tlOdirectVisitAttrs :: (Map Ident (Map Ident String))
              _tlOdirectVisitLocalAttrs :: (Map Ident String)
              _tlOdistAliasses :: (Map Ident AliasType)
              _tlOdistAllChildMinRanges :: (Map Ident [Ident])
              _tlOdistAttrSource :: AttrSourceMap
              _tlOdistAttrVisMap :: AttrVisMap
              _tlOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlOdistChildEffRanges :: (Map Ident (Set Ident))
              _tlOdistChildMinRanges :: (Map Ident [Ident])
              _tlOdistChildOcc :: (Map Ident Int)
              _tlOdistChildSource :: ChildSourceMap
              _tlOdistCycVisMap :: CycVisMap
              _tlOdistDataCons :: ConEnv
              _tlOdistDataMap :: DataMap
              _tlOdistDataSems :: DataSemEnv
              _tlOdistDatas :: DataEnv
              _tlOdistDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlOdistDefs :: DefsEnv
              _tlOdistInhAttrs :: AttrMap
              _tlOdistItfs :: ItfEnv
              _tlOdistRanks :: (Map DepItem (Bool,Int))
              _tlOdistRenames :: RenameMap
              _tlOdistSynAttrs :: AttrMap
              _tlOdistVisLocalDefs :: DefsEnv
              _tlOdistVisRankMap :: (IntMap Ident)
              _tlOdistVisitInhAttrs :: VisitAttrMap
              _tlOdistVisitOrder :: (Map Ident [Ident])
              _tlOdistVisitSource :: VisitSourceMap
              _tlOdistVisitSynAttrs :: VisitAttrMap
              _tlOdistVisits :: VisitEnv
              _tlOdoneVisits :: ([Ident])
              _tlOfullCyclicVisits :: (Set Ident)
              _tlOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlOgathClauses :: ClausesEnv
              _tlOgathDataSems :: DataSemEnv
              _tlOgathDefs :: DefsEnv
              _tlOgathNextVisits :: (Map Ident (Maybe Ident))
              _tlOgathNonterms :: NontermEnv
              _tlOgathVisLocalDefs :: DefsEnv
              _tlOhSpilledStmts :: ([(Int,PP_Doc)])
              _tlOindent :: Int
              _tlOitf :: QIdent
              _tlOjsSpilledStmts :: ([(Int,PP_Doc)])
              _tlOlexCounter :: Int
              _tlOnonterm :: QIdent
              _tlOopts :: Opts
              _tlOscopeDep :: DepItem
              _tlOscopeReason :: Reason
              _tlOstmtSource :: DepItem
              _tlOvisitBeginDep :: DepItem
              _tlOvisitEndDep :: DepItem
              _tlOvisitEndReason :: Reason
              _hdIallReqInvokes :: (Map Ident (Set Ident))
              _hdIbannedInvokes :: (Map Ident (Set Ident))
              _hdIcodeIdCounter :: Int
              _hdIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _hdIdistDataCons :: ConEnv
              _hdIdistDataSems :: DataSemEnv
              _hdIdistDatas :: DataEnv
              _hdIdistDefs :: DefsEnv
              _hdIdistItfs :: ItfEnv
              _hdIdistVisLocalDefs :: DefsEnv
              _hdIdistVisits :: VisitEnv
              _hdIerrs0 :: Errs
              _hdIerrs1 :: Errs
              _hdIerrs2 :: Errs
              _hdIerrs3 :: Errs
              _hdIerrs4 :: Errs
              _hdIerrs5 :: Errs
              _hdIexplInvokes :: (Map Ident (Set Ident))
              _hdIgathAttrSource :: AttrSourceMap
              _hdIgathAvoidVisits :: (Set DepItem)
              _hdIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _hdIgathChildEffRanges :: (Map Ident (Set Ident))
              _hdIgathChildMinRanges :: (Map Ident [Ident])
              _hdIgathChildOcc :: (Map Ident Int)
              _hdIgathChildSource :: ChildSourceMap
              _hdIgathClauses :: ClausesEnv
              _hdIgathDataSems :: DataSemEnv
              _hdIgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _hdIgathDefs :: DefsEnv
              _hdIgathDeps :: Deps
              _hdIgathItemVisits :: (Map DepItem DepItem)
              _hdIgathLegalCycStmts :: (Set DepItem)
              _hdIgathMissingInvokes :: (Set (Ident,Ident))
              _hdIgathNextVisits :: (Map Ident (Maybe Ident))
              _hdIgathNonterms :: NontermEnv
              _hdIgathRenames :: RenameMap
              _hdIgathSemStarts :: (Seq DepItem)
              _hdIgathStmtPosMap :: (Map DepItem Pos)
              _hdIgathVisLocalDefs :: DefsEnv
              _hdIgathVisitEnds :: (Seq DepItem)
              _hdIgathVisitSource :: VisitSourceMap
              _hdIgathVisitStarts :: (Seq DepItem)
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIlexCounter :: Int
              _hdIminReqInvokes :: (Map Ident (Set Ident))
              _hdIpp :: PP_Doc
              _hdIrank :: Int
              _tlIallReqInvokes :: (Map Ident (Set Ident))
              _tlIbannedInvokes :: (Map Ident (Set Ident))
              _tlIcodeIdCounter :: Int
              _tlIdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _tlIdistDataCons :: ConEnv
              _tlIdistDataSems :: DataSemEnv
              _tlIdistDatas :: DataEnv
              _tlIdistDefs :: DefsEnv
              _tlIdistItfs :: ItfEnv
              _tlIdistVisLocalDefs :: DefsEnv
              _tlIdistVisits :: VisitEnv
              _tlIerrs0 :: Errs
              _tlIerrs1 :: Errs
              _tlIerrs2 :: Errs
              _tlIerrs3 :: Errs
              _tlIerrs4 :: Errs
              _tlIerrs5 :: Errs
              _tlIexplInvokes :: (Map Ident (Set Ident))
              _tlIgathAttrSource :: AttrSourceMap
              _tlIgathAvoidVisits :: (Set DepItem)
              _tlIgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _tlIgathChildEffRanges :: (Map Ident (Set Ident))
              _tlIgathChildMinRanges :: (Map Ident [Ident])
              _tlIgathChildOcc :: (Map Ident Int)
              _tlIgathChildSource :: ChildSourceMap
              _tlIgathClauses :: ClausesEnv
              _tlIgathDataSems :: DataSemEnv
              _tlIgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _tlIgathDefs :: DefsEnv
              _tlIgathDeps :: Deps
              _tlIgathItemVisits :: (Map DepItem DepItem)
              _tlIgathLegalCycStmts :: (Set DepItem)
              _tlIgathMissingInvokes :: (Set (Ident,Ident))
              _tlIgathNextVisits :: (Map Ident (Maybe Ident))
              _tlIgathNonterms :: NontermEnv
              _tlIgathRenames :: RenameMap
              _tlIgathSemStarts :: (Seq DepItem)
              _tlIgathStmtPosMap :: (Map DepItem Pos)
              _tlIgathVisLocalDefs :: DefsEnv
              _tlIgathVisitEnds :: (Seq DepItem)
              _tlIgathVisitSource :: VisitSourceMap
              _tlIgathVisitStarts :: (Seq DepItem)
              _tlIhopps :: ([(Int, PP_Doc)])
              _tlIjsopps :: ([(Int, PP_Doc)])
              _tlIlexCounter :: Int
              _tlIminReqInvokes :: (Map Ident (Set Ident))
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2657, column 11)
              _lhsOpps =
                  ({-# LINE 2657 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 63211 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 628, column 11)
              _lhsOhopps =
                  ({-# LINE 628 "src/TargetHaskell.ag" #-}
                   (_hdIrank, _hdIhpp) : _tlIhopps
                   {-# LINE 63216 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 417, column 11)
              _lhsOjsopps =
                  ({-# LINE 417 "src/TargetJs.ag" #-}
                   (_hdIrank, _hdIjspp) : _tlIjsopps
                   {-# LINE 63221 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIallReqInvokes `unionWithUnion` _tlIallReqInvokes
                   {-# LINE 63226 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   _hdIbannedInvokes `unionWithUnion` _tlIbannedInvokes
                   {-# LINE 63231 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs0 Seq.>< _tlIerrs0
                   {-# LINE 63236 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs1 Seq.>< _tlIerrs1
                   {-# LINE 63241 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs2 Seq.>< _tlIerrs2
                   {-# LINE 63246 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs3 Seq.>< _tlIerrs3
                   {-# LINE 63251 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs4 Seq.>< _tlIerrs4
                   {-# LINE 63256 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _hdIerrs5 Seq.>< _tlIerrs5
                   {-# LINE 63261 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   _hdIexplInvokes `unionWithUnion` _tlIexplInvokes
                   {-# LINE 63266 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   _hdIgathAttrSource `Map.union` _tlIgathAttrSource
                   {-# LINE 63271 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   _hdIgathAvoidVisits `Set.union` _tlIgathAvoidVisits
                   {-# LINE 63276 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   _hdIgathChildEffRanges `unionWithUnion` _tlIgathChildEffRanges
                   {-# LINE 63281 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   _hdIgathChildMinRanges `unionWithPlusplus` _tlIgathChildMinRanges
                   {-# LINE 63286 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   _hdIgathChildOcc `unionWithMin` _tlIgathChildOcc
                   {-# LINE 63291 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   _hdIgathChildSource `unionWithUnion` _tlIgathChildSource
                   {-# LINE 63296 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   _hdIgathDeflStmts `Map.union` _tlIgathDeflStmts
                   {-# LINE 63301 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   _hdIgathDeps Seq.>< _tlIgathDeps
                   {-# LINE 63306 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   _hdIgathItemVisits `Map.union` _tlIgathItemVisits
                   {-# LINE 63311 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   _hdIgathLegalCycStmts `Set.union` _tlIgathLegalCycStmts
                   {-# LINE 63316 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   _hdIgathMissingInvokes `Set.union` _tlIgathMissingInvokes
                   {-# LINE 63321 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   _hdIgathRenames `unionWithUnion` _tlIgathRenames
                   {-# LINE 63326 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   _hdIgathSemStarts Seq.>< _tlIgathSemStarts
                   {-# LINE 63331 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   _hdIgathStmtPosMap `Map.union` _tlIgathStmtPosMap
                   {-# LINE 63336 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitEnds Seq.>< _tlIgathVisitEnds
                   {-# LINE 63341 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   _hdIgathVisitSource `unionWithUnion` _tlIgathVisitSource
                   {-# LINE 63346 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   _hdIgathVisitStarts Seq.>< _tlIgathVisitStarts
                   {-# LINE 63351 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   _hdIminReqInvokes `unionWithUnion` _tlIminReqInvokes
                   {-# LINE 63356 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _tlIcodeIdCounter
                   {-# LINE 63361 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _tlIdistChildDefs
                   {-# LINE 63366 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _tlIdistDataCons
                   {-# LINE 63371 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _tlIdistDataSems
                   {-# LINE 63376 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _tlIdistDatas
                   {-# LINE 63381 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistDefs
                   {-# LINE 63386 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _tlIdistItfs
                   {-# LINE 63391 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIdistVisLocalDefs
                   {-# LINE 63396 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _tlIdistVisits
                   {-# LINE 63401 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _tlIgathChildDefs
                   {-# LINE 63406 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathClauses
                   {-# LINE 63411 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _tlIgathDataSems
                   {-# LINE 63416 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathDefs
                   {-# LINE 63421 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _tlIgathNextVisits
                   {-# LINE 63426 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _tlIgathNonterms
                   {-# LINE 63431 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _tlIgathVisLocalDefs
                   {-# LINE 63436 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _tlIlexCounter
                   {-# LINE 63441 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 63446 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 63451 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 63456 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 63461 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 63466 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 63471 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 63476 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 63481 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 63486 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 63491 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 63496 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 63501 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 63506 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 63511 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 63516 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 63521 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 63526 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 63531 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 63536 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 63541 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 63546 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 63551 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 63556 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 63561 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 63566 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 63571 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 63576 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 63581 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 63586 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 63591 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 63596 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 63601 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 63606 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 63611 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 63616 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 63621 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 63626 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 63631 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 63636 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 63641 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 63646 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 63651 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 63656 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 63661 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 63666 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 63671 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 63676 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 63681 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 63686 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 63691 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 63696 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 63701 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 63706 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 63711 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 63716 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 63721 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 63726 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 63731 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 63736 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallAvailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIallAvailInvokes
                   {-# LINE 63741 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallVisits =
                  ({-# LINE 277 "src/Transform.ag" #-}
                   _lhsIallVisits
                   {-# LINE 63746 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOallowCycVisits =
                  ({-# LINE 1915 "src/Transform.ag" #-}
                   _lhsIallowCycVisits
                   {-# LINE 63751 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOavailInvokes =
                  ({-# LINE 1748 "src/Transform.ag" #-}
                   _lhsIavailInvokes
                   {-# LINE 63756 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlObasename =
                  ({-# LINE 1397 "src/Transform.ag" #-}
                   _lhsIbasename
                   {-# LINE 63761 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOcoItf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIcoItf
                   {-# LINE 63766 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _hdIcodeIdCounter
                   {-# LINE 63771 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitAttrs =
                  ({-# LINE 896 "src/Transform.ag" #-}
                   _lhsIdirectVisitAttrs
                   {-# LINE 63776 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdirectVisitLocalAttrs =
                  ({-# LINE 903 "src/Transform.ag" #-}
                   _lhsIdirectVisitLocalAttrs
                   {-# LINE 63781 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 63786 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAllChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistAllChildMinRanges
                   {-# LINE 63791 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrSource =
                  ({-# LINE 2051 "src/Transform.ag" #-}
                   _lhsIdistAttrSource
                   {-# LINE 63796 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistAttrVisMap =
                  ({-# LINE 1376 "src/Transform.ag" #-}
                   _lhsIdistAttrVisMap
                   {-# LINE 63801 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _hdIdistChildDefs
                   {-# LINE 63806 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildEffRanges =
                  ({-# LINE 1606 "src/Transform.ag" #-}
                   _lhsIdistChildEffRanges
                   {-# LINE 63811 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildMinRanges =
                  ({-# LINE 1605 "src/Transform.ag" #-}
                   _lhsIdistChildMinRanges
                   {-# LINE 63816 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildOcc =
                  ({-# LINE 1300 "src/Transform.ag" #-}
                   _lhsIdistChildOcc
                   {-# LINE 63821 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistChildSource =
                  ({-# LINE 2111 "src/Transform.ag" #-}
                   _lhsIdistChildSource
                   {-# LINE 63826 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistCycVisMap =
                  ({-# LINE 1888 "src/Transform.ag" #-}
                   _lhsIdistCycVisMap
                   {-# LINE 63831 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _hdIdistDataCons
                   {-# LINE 63836 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDataMap =
                  ({-# LINE 1393 "src/Transform.ag" #-}
                   _lhsIdistDataMap
                   {-# LINE 63841 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _hdIdistDataSems
                   {-# LINE 63846 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _hdIdistDatas
                   {-# LINE 63851 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistDeflStmts =
                  ({-# LINE 1812 "src/Transform.ag" #-}
                   _lhsIdistDeflStmts
                   {-# LINE 63856 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistDefs
                   {-# LINE 63861 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistInhAttrs
                   {-# LINE 63866 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _hdIdistItfs
                   {-# LINE 63871 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRanks =
                  ({-# LINE 2329 "src/Transform.ag" #-}
                   _lhsIdistRanks
                   {-# LINE 63876 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistRenames =
                  ({-# LINE 595 "src/Transform.ag" #-}
                   _lhsIdistRenames
                   {-# LINE 63881 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistSynAttrs
                   {-# LINE 63886 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIdistVisLocalDefs
                   {-# LINE 63891 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisRankMap =
                  ({-# LINE 1858 "src/Transform.ag" #-}
                   _lhsIdistVisRankMap
                   {-# LINE 63896 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitInhAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitInhAttrs
                   {-# LINE 63901 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitOrder =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdistVisitOrder
                   {-# LINE 63906 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSource =
                  ({-# LINE 2130 "src/Transform.ag" #-}
                   _lhsIdistVisitSource
                   {-# LINE 63911 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdistVisitSynAttrs =
                  ({-# LINE 886 "src/Transform.ag" #-}
                   _lhsIdistVisitSynAttrs
                   {-# LINE 63916 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _hdIdistVisits
                   {-# LINE 63921 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOdoneVisits =
                  ({-# LINE 710 "src/Transform.ag" #-}
                   _lhsIdoneVisits
                   {-# LINE 63926 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOfullCyclicVisits =
                  ({-# LINE 1895 "src/Transform.ag" #-}
                   _lhsIfullCyclicVisits
                   {-# LINE 63931 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _hdIgathChildDefs
                   {-# LINE 63936 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathClauses
                   {-# LINE 63941 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _hdIgathDataSems
                   {-# LINE 63946 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathDefs
                   {-# LINE 63951 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _hdIgathNextVisits
                   {-# LINE 63956 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _hdIgathNonterms
                   {-# LINE 63961 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _hdIgathVisLocalDefs
                   {-# LINE 63966 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOhSpilledStmts =
                  ({-# LINE 590 "src/TargetHaskell.ag" #-}
                   _lhsIhSpilledStmts
                   {-# LINE 63971 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOindent =
                  ({-# LINE 2483 "src/Transform.ag" #-}
                   _lhsIindent
                   {-# LINE 63976 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOitf =
                  ({-# LINE 409 "src/Transform.ag" #-}
                   _lhsIitf
                   {-# LINE 63981 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOjsSpilledStmts =
                  ({-# LINE 385 "src/TargetJs.ag" #-}
                   _lhsIjsSpilledStmts
                   {-# LINE 63986 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _hdIlexCounter
                   {-# LINE 63991 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOnonterm =
                  ({-# LINE 241 "src/Transform.ag" #-}
                   _lhsInonterm
                   {-# LINE 63996 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 64001 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeDep
                   {-# LINE 64006 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOscopeReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIscopeReason
                   {-# LINE 64011 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOstmtSource =
                  ({-# LINE 2014 "src/Transform.ag" #-}
                   _lhsIstmtSource
                   {-# LINE 64016 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitBeginDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitBeginDep
                   {-# LINE 64021 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndDep =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndDep
                   {-# LINE 64026 "src/Transform.hs" #-})
              -- copy rule (down)
              _tlOvisitEndReason =
                  ({-# LINE 2150 "src/Transform.ag" #-}
                   _lhsIvisitEndReason
                   {-# LINE 64031 "src/Transform.hs" #-})
              ( _hdIallReqInvokes,_hdIbannedInvokes,_hdIcodeIdCounter,_hdIdistChildDefs,_hdIdistDataCons,_hdIdistDataSems,_hdIdistDatas,_hdIdistDefs,_hdIdistItfs,_hdIdistVisLocalDefs,_hdIdistVisits,_hdIerrs0,_hdIerrs1,_hdIerrs2,_hdIerrs3,_hdIerrs4,_hdIerrs5,_hdIexplInvokes,_hdIgathAttrSource,_hdIgathAvoidVisits,_hdIgathChildDefs,_hdIgathChildEffRanges,_hdIgathChildMinRanges,_hdIgathChildOcc,_hdIgathChildSource,_hdIgathClauses,_hdIgathDataSems,_hdIgathDeflStmts,_hdIgathDefs,_hdIgathDeps,_hdIgathItemVisits,_hdIgathLegalCycStmts,_hdIgathMissingInvokes,_hdIgathNextVisits,_hdIgathNonterms,_hdIgathRenames,_hdIgathSemStarts,_hdIgathStmtPosMap,_hdIgathVisLocalDefs,_hdIgathVisitEnds,_hdIgathVisitSource,_hdIgathVisitStarts,_hdIhpp,_hdIjspp,_hdIlexCounter,_hdIminReqInvokes,_hdIpp,_hdIrank) =
                  hd_ _hdOallAvailInvokes _hdOallVisits _hdOallowCycVisits _hdOavailInvokes _hdObasename _hdOcoItf _hdOcodeIdCounter _hdOdirectVisitAttrs _hdOdirectVisitLocalAttrs _hdOdistAliasses _hdOdistAllChildMinRanges _hdOdistAttrSource _hdOdistAttrVisMap _hdOdistChildDefs _hdOdistChildEffRanges _hdOdistChildMinRanges _hdOdistChildOcc _hdOdistChildSource _hdOdistCycVisMap _hdOdistDataCons _hdOdistDataMap _hdOdistDataSems _hdOdistDatas _hdOdistDeflStmts _hdOdistDefs _hdOdistInhAttrs _hdOdistItfs _hdOdistRanks _hdOdistRenames _hdOdistSynAttrs _hdOdistVisLocalDefs _hdOdistVisRankMap _hdOdistVisitInhAttrs _hdOdistVisitOrder _hdOdistVisitSource _hdOdistVisitSynAttrs _hdOdistVisits _hdOdoneVisits _hdOfullCyclicVisits _hdOgathChildDefs _hdOgathClauses _hdOgathDataSems _hdOgathDefs _hdOgathNextVisits _hdOgathNonterms _hdOgathVisLocalDefs _hdOhSpilledStmts _hdOindent _hdOitf _hdOjsSpilledStmts _hdOlexCounter _hdOnonterm _hdOopts _hdOscopeDep _hdOscopeReason _hdOstmtSource _hdOvisitBeginDep _hdOvisitEndDep _hdOvisitEndReason 
              ( _tlIallReqInvokes,_tlIbannedInvokes,_tlIcodeIdCounter,_tlIdistChildDefs,_tlIdistDataCons,_tlIdistDataSems,_tlIdistDatas,_tlIdistDefs,_tlIdistItfs,_tlIdistVisLocalDefs,_tlIdistVisits,_tlIerrs0,_tlIerrs1,_tlIerrs2,_tlIerrs3,_tlIerrs4,_tlIerrs5,_tlIexplInvokes,_tlIgathAttrSource,_tlIgathAvoidVisits,_tlIgathChildDefs,_tlIgathChildEffRanges,_tlIgathChildMinRanges,_tlIgathChildOcc,_tlIgathChildSource,_tlIgathClauses,_tlIgathDataSems,_tlIgathDeflStmts,_tlIgathDefs,_tlIgathDeps,_tlIgathItemVisits,_tlIgathLegalCycStmts,_tlIgathMissingInvokes,_tlIgathNextVisits,_tlIgathNonterms,_tlIgathRenames,_tlIgathSemStarts,_tlIgathStmtPosMap,_tlIgathVisLocalDefs,_tlIgathVisitEnds,_tlIgathVisitSource,_tlIgathVisitStarts,_tlIhopps,_tlIjsopps,_tlIlexCounter,_tlIminReqInvokes,_tlIpps) =
                  tl_ _tlOallAvailInvokes _tlOallVisits _tlOallowCycVisits _tlOavailInvokes _tlObasename _tlOcoItf _tlOcodeIdCounter _tlOdirectVisitAttrs _tlOdirectVisitLocalAttrs _tlOdistAliasses _tlOdistAllChildMinRanges _tlOdistAttrSource _tlOdistAttrVisMap _tlOdistChildDefs _tlOdistChildEffRanges _tlOdistChildMinRanges _tlOdistChildOcc _tlOdistChildSource _tlOdistCycVisMap _tlOdistDataCons _tlOdistDataMap _tlOdistDataSems _tlOdistDatas _tlOdistDeflStmts _tlOdistDefs _tlOdistInhAttrs _tlOdistItfs _tlOdistRanks _tlOdistRenames _tlOdistSynAttrs _tlOdistVisLocalDefs _tlOdistVisRankMap _tlOdistVisitInhAttrs _tlOdistVisitOrder _tlOdistVisitSource _tlOdistVisitSynAttrs _tlOdistVisits _tlOdoneVisits _tlOfullCyclicVisits _tlOgathChildDefs _tlOgathClauses _tlOgathDataSems _tlOgathDefs _tlOgathNextVisits _tlOgathNonterms _tlOgathVisLocalDefs _tlOhSpilledStmts _tlOindent _tlOitf _tlOjsSpilledStmts _tlOlexCounter _tlOnonterm _tlOopts _tlOscopeDep _tlOscopeReason _tlOstmtSource _tlOvisitBeginDep _tlOvisitEndDep _tlOvisitEndReason 
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
sem_Stmts_Nil :: T_Stmts 
sem_Stmts_Nil  =
    (\ _lhsIallAvailInvokes
       _lhsIallVisits
       _lhsIallowCycVisits
       _lhsIavailInvokes
       _lhsIbasename
       _lhsIcoItf
       _lhsIcodeIdCounter
       _lhsIdirectVisitAttrs
       _lhsIdirectVisitLocalAttrs
       _lhsIdistAliasses
       _lhsIdistAllChildMinRanges
       _lhsIdistAttrSource
       _lhsIdistAttrVisMap
       _lhsIdistChildDefs
       _lhsIdistChildEffRanges
       _lhsIdistChildMinRanges
       _lhsIdistChildOcc
       _lhsIdistChildSource
       _lhsIdistCycVisMap
       _lhsIdistDataCons
       _lhsIdistDataMap
       _lhsIdistDataSems
       _lhsIdistDatas
       _lhsIdistDeflStmts
       _lhsIdistDefs
       _lhsIdistInhAttrs
       _lhsIdistItfs
       _lhsIdistRanks
       _lhsIdistRenames
       _lhsIdistSynAttrs
       _lhsIdistVisLocalDefs
       _lhsIdistVisRankMap
       _lhsIdistVisitInhAttrs
       _lhsIdistVisitOrder
       _lhsIdistVisitSource
       _lhsIdistVisitSynAttrs
       _lhsIdistVisits
       _lhsIdoneVisits
       _lhsIfullCyclicVisits
       _lhsIgathChildDefs
       _lhsIgathClauses
       _lhsIgathDataSems
       _lhsIgathDefs
       _lhsIgathNextVisits
       _lhsIgathNonterms
       _lhsIgathVisLocalDefs
       _lhsIhSpilledStmts
       _lhsIindent
       _lhsIitf
       _lhsIjsSpilledStmts
       _lhsIlexCounter
       _lhsInonterm
       _lhsIopts
       _lhsIscopeDep
       _lhsIscopeReason
       _lhsIstmtSource
       _lhsIvisitBeginDep
       _lhsIvisitEndDep
       _lhsIvisitEndReason ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOhopps :: ([(Int, PP_Doc)])
              _lhsOjsopps :: ([(Int, PP_Doc)])
              _lhsOallReqInvokes :: (Map Ident (Set Ident))
              _lhsObannedInvokes :: (Map Ident (Set Ident))
              _lhsOerrs0 :: Errs
              _lhsOerrs1 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOexplInvokes :: (Map Ident (Set Ident))
              _lhsOgathAttrSource :: AttrSourceMap
              _lhsOgathAvoidVisits :: (Set DepItem)
              _lhsOgathChildEffRanges :: (Map Ident (Set Ident))
              _lhsOgathChildMinRanges :: (Map Ident [Ident])
              _lhsOgathChildOcc :: (Map Ident Int)
              _lhsOgathChildSource :: ChildSourceMap
              _lhsOgathDeflStmts :: (Map Ident (Bool,Maybe Int))
              _lhsOgathDeps :: Deps
              _lhsOgathItemVisits :: (Map DepItem DepItem)
              _lhsOgathLegalCycStmts :: (Set DepItem)
              _lhsOgathMissingInvokes :: (Set (Ident,Ident))
              _lhsOgathRenames :: RenameMap
              _lhsOgathSemStarts :: (Seq DepItem)
              _lhsOgathStmtPosMap :: (Map DepItem Pos)
              _lhsOgathVisitEnds :: (Seq DepItem)
              _lhsOgathVisitSource :: VisitSourceMap
              _lhsOgathVisitStarts :: (Seq DepItem)
              _lhsOminReqInvokes :: (Map Ident (Set Ident))
              _lhsOcodeIdCounter :: Int
              _lhsOdistChildDefs :: (Env QIdent (QIdent,QIdent))
              _lhsOdistDataCons :: ConEnv
              _lhsOdistDataSems :: DataSemEnv
              _lhsOdistDatas :: DataEnv
              _lhsOdistDefs :: DefsEnv
              _lhsOdistItfs :: ItfEnv
              _lhsOdistVisLocalDefs :: DefsEnv
              _lhsOdistVisits :: VisitEnv
              _lhsOgathChildDefs :: (Env QIdent (QIdent, QIdent))
              _lhsOgathClauses :: ClausesEnv
              _lhsOgathDataSems :: DataSemEnv
              _lhsOgathDefs :: DefsEnv
              _lhsOgathNextVisits :: (Map Ident (Maybe Ident))
              _lhsOgathNonterms :: NontermEnv
              _lhsOgathVisLocalDefs :: DefsEnv
              _lhsOlexCounter :: Int
              -- "src/Transform.ag"(line 2658, column 11)
              _lhsOpps =
                  ({-# LINE 2658 "src/Transform.ag" #-}
                   []
                   {-# LINE 64149 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 629, column 11)
              _lhsOhopps =
                  ({-# LINE 629 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 64154 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 418, column 11)
              _lhsOjsopps =
                  ({-# LINE 418 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 64159 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOallReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64164 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1647, column 53)
              _lhsObannedInvokes =
                  ({-# LINE 1647 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64169 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64174 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs1 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64179 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64184 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64189 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64194 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64199 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1648, column 50)
              _lhsOexplInvokes =
                  ({-# LINE 1648 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64204 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2052, column 39)
              _lhsOgathAttrSource =
                  ({-# LINE 2052 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64209 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1985, column 42)
              _lhsOgathAvoidVisits =
                  ({-# LINE 1985 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 64214 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1608, column 42)
              _lhsOgathChildEffRanges =
                  ({-# LINE 1608 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64219 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1607, column 42)
              _lhsOgathChildMinRanges =
                  ({-# LINE 1607 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64224 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1299, column 36)
              _lhsOgathChildOcc =
                  ({-# LINE 1299 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64229 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2112, column 40)
              _lhsOgathChildSource =
                  ({-# LINE 2112 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64234 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1813, column 37)
              _lhsOgathDeflStmts =
                  ({-# LINE 1813 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64239 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2190, column 30)
              _lhsOgathDeps =
                  ({-# LINE 2190 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64244 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1992, column 36)
              _lhsOgathItemVisits =
                  ({-# LINE 1992 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64249 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1998, column 39)
              _lhsOgathLegalCycStmts =
                  ({-# LINE 1998 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 64254 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1790, column 31)
              _lhsOgathMissingInvokes =
                  ({-# LINE 1790 "src/Transform.ag" #-}
                   Set.empty
                   {-# LINE 64259 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 587, column 35)
              _lhsOgathRenames =
                  ({-# LINE 587 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 64264 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1846, column 40)
              _lhsOgathSemStarts =
                  ({-# LINE 1846 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64269 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2029, column 36)
              _lhsOgathStmtPosMap =
                  ({-# LINE 2029 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64274 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitEnds =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64279 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 2131, column 40)
              _lhsOgathVisitSource =
                  ({-# LINE 2131 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64284 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1837, column 57)
              _lhsOgathVisitStarts =
                  ({-# LINE 1837 "src/Transform.ag" #-}
                   Seq.empty
                   {-# LINE 64289 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1655, column 55)
              _lhsOminReqInvokes =
                  ({-# LINE 1655 "src/Transform.ag" #-}
                   Map.empty
                   {-# LINE 64294 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOcodeIdCounter =
                  ({-# LINE 1825 "src/Transform.ag" #-}
                   _lhsIcodeIdCounter
                   {-# LINE 64299 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistChildDefs =
                  ({-# LINE 498 "src/Transform.ag" #-}
                   _lhsIdistChildDefs
                   {-# LINE 64304 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataCons =
                  ({-# LINE 308 "src/Transform.ag" #-}
                   _lhsIdistDataCons
                   {-# LINE 64309 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDataSems =
                  ({-# LINE 267 "src/Transform.ag" #-}
                   _lhsIdistDataSems
                   {-# LINE 64314 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 64319 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistDefs
                   {-# LINE 64324 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistItfs =
                  ({-# LINE 394 "src/Transform.ag" #-}
                   _lhsIdistItfs
                   {-# LINE 64329 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIdistVisLocalDefs
                   {-# LINE 64334 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOdistVisits =
                  ({-# LINE 423 "src/Transform.ag" #-}
                   _lhsIdistVisits
                   {-# LINE 64339 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChildDefs =
                  ({-# LINE 497 "src/Transform.ag" #-}
                   _lhsIgathChildDefs
                   {-# LINE 64344 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathClauses =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathClauses
                   {-# LINE 64349 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDataSems =
                  ({-# LINE 266 "src/Transform.ag" #-}
                   _lhsIgathDataSems
                   {-# LINE 64354 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathDefs
                   {-# LINE 64359 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNextVisits =
                  ({-# LINE 1550 "src/Transform.ag" #-}
                   _lhsIgathNextVisits
                   {-# LINE 64364 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathNonterms =
                  ({-# LINE 240 "src/Transform.ag" #-}
                   _lhsIgathNonterms
                   {-# LINE 64369 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVisLocalDefs =
                  ({-# LINE 993 "src/Transform.ag" #-}
                   _lhsIgathVisLocalDefs
                   {-# LINE 64374 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOlexCounter =
                  ({-# LINE 1276 "src/Transform.ag" #-}
                   _lhsIlexCounter
                   {-# LINE 64379 "src/Transform.hs" #-})
          in  ( _lhsOallReqInvokes,_lhsObannedInvokes,_lhsOcodeIdCounter,_lhsOdistChildDefs,_lhsOdistDataCons,_lhsOdistDataSems,_lhsOdistDatas,_lhsOdistDefs,_lhsOdistItfs,_lhsOdistVisLocalDefs,_lhsOdistVisits,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOexplInvokes,_lhsOgathAttrSource,_lhsOgathAvoidVisits,_lhsOgathChildDefs,_lhsOgathChildEffRanges,_lhsOgathChildMinRanges,_lhsOgathChildOcc,_lhsOgathChildSource,_lhsOgathClauses,_lhsOgathDataSems,_lhsOgathDeflStmts,_lhsOgathDefs,_lhsOgathDeps,_lhsOgathItemVisits,_lhsOgathLegalCycStmts,_lhsOgathMissingInvokes,_lhsOgathNextVisits,_lhsOgathNonterms,_lhsOgathRenames,_lhsOgathSemStarts,_lhsOgathStmtPosMap,_lhsOgathVisLocalDefs,_lhsOgathVisitEnds,_lhsOgathVisitSource,_lhsOgathVisitStarts,_lhsOhopps,_lhsOjsopps,_lhsOlexCounter,_lhsOminReqInvokes,_lhsOpps)))
-- Type --------------------------------------------------------
{-
   visit 0:
      inherited attributes:
         distAliasses         : Map Ident AliasType
         opts                 : Opts
      chained attributes:
         distDatas            : DataEnv
         gathDataCons         : ConEnv
         gathDatas            : DataEnv
      synthesized attributes:
         errs0                : Errs
         errs1                : Errs
         errs2                : Errs
         errs3                : Errs
         errs4                : Errs
         errs5                : Errs
         gathAliasses         : Map Ident AliasType
         gathDataMap          : DataMap
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         pp                   : PP_Doc
   alternatives:
      alternative Alias:
         child pos            : {Pos}
         child name           : {Ident}
         child type           : AliasType 
         child vars           : Vars 
         visit 0:
            local errs1_augmented_f1 : _
            inst  data        : Data 
            local errs1_augmented_syn : _
-}
-- cata
sem_Type :: Type  ->
            T_Type 
sem_Type (Type_Alias _pos _name _type _vars )  =
    (sem_Type_Alias _pos _name (sem_AliasType _type ) (sem_Vars _vars ) )
-- semantic domain
type T_Type  = (Map Ident AliasType) ->
               DataEnv ->
               ConEnv ->
               DataEnv ->
               Opts ->
               ( DataEnv,Errs,Errs,Errs,Errs,Errs,Errs,(Map Ident AliasType),ConEnv,DataMap,DataEnv,PP_Doc,PP_Doc,PP_Doc)
sem_Type_Alias :: Pos ->
                  Ident ->
                  T_AliasType  ->
                  T_Vars  ->
                  T_Type 
sem_Type_Alias pos_ name_ type_ vars_  =
    (\ _lhsIdistAliasses
       _lhsIdistDatas
       _lhsIgathDataCons
       _lhsIgathDatas
       _lhsIopts ->
         (let _lhsOerrs1 :: Errs
              _varsOgathVarsEnv :: VarsEnv
              _lhsOgathAliasses :: (Map Ident AliasType)
              data_val_ :: Data 
              _typeOpos :: Pos
              _typeOname :: Ident
              _typeOvars :: Vars 
              _lhsOpp :: PP_Doc
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOerrs0 :: Errs
              _lhsOerrs2 :: Errs
              _lhsOerrs3 :: Errs
              _lhsOerrs4 :: Errs
              _lhsOerrs5 :: Errs
              _lhsOgathDataMap :: DataMap
              _lhsOdistDatas :: DataEnv
              _lhsOgathDataCons :: ConEnv
              _lhsOgathDatas :: DataEnv
              _typeOdistDatas :: DataEnv
              _dataOdistAliasses :: (Map Ident AliasType)
              _dataOdistDatas :: DataEnv
              _dataOgathDataCons :: ConEnv
              _dataOgathDatas :: DataEnv
              _dataOopts :: Opts
              _typeIalias :: AliasType 
              _typeIdata :: Data
              _typeIdistDatas :: DataEnv
              _typeIhpp :: PP_Doc
              _typeIjspp :: PP_Doc
              _typeIpp :: PP_Doc
              _varsIgathVarsEnv :: VarsEnv
              _varsIhpps :: ([PP_Doc])
              _varsIjspps :: ([PP_Doc])
              _varsIself :: Vars 
              _varsIvars :: ([Ident])
              _dataIdistDatas :: DataEnv
              _dataIerrs0 :: Errs
              _dataIerrs1 :: Errs
              _dataIerrs2 :: Errs
              _dataIerrs3 :: Errs
              _dataIerrs4 :: Errs
              _dataIerrs5 :: Errs
              _dataIextraBlocks :: Blocks
              _dataIgathDataCons :: ConEnv
              _dataIgathDataMap :: DataMap
              _dataIgathDatas :: DataEnv
              _dataIhpp :: PP_Doc
              _dataIjspp :: PP_Doc
              _dataIpp :: PP_Doc
              -- augmented rule
              _lhsOerrs1 =
                  ({-# LINE 362 "src/Transform.ag" #-}
                   foldr ($) _errs1_augmented_syn [_errs1_augmented_f1]
                   {-# LINE 64491 "src/Transform.hs" #-})
              -- augment function
              _errs1_augmented_f1 =
                  ({-# LINE 362 "src/Transform.ag" #-}
                   addDefErrs' _varsIgathVarsEnv
                   {-# LINE 64496 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 361, column 3)
              _varsOgathVarsEnv =
                  ({-# LINE 361 "src/Transform.ag" #-}
                   emptyEnv
                   {-# LINE 64501 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1435, column 24)
              _lhsOgathAliasses =
                  ({-# LINE 1435 "src/Transform.ag" #-}
                   Map.singleton name_ _typeIalias
                   {-# LINE 64506 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1444, column 1)
              data_val_ =
                  ({-# LINE 1444 "src/Transform.ag" #-}
                   _typeIdata
                   {-# LINE 64511 "src/Transform.hs" #-})
              data_inst_ =
                  (sem_Data data_val_ )
              -- "src/Transform.ag"(line 1447, column 19)
              _typeOpos =
                  ({-# LINE 1447 "src/Transform.ag" #-}
                   pos_
                   {-# LINE 64518 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1448, column 19)
              _typeOname =
                  ({-# LINE 1448 "src/Transform.ag" #-}
                   name_
                   {-# LINE 64523 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1449, column 19)
              _typeOvars =
                  ({-# LINE 1449 "src/Transform.ag" #-}
                   _varsIself
                   {-# LINE 64528 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2450, column 3)
              _lhsOpp =
                  ({-# LINE 2450 "src/Transform.ag" #-}
                   "type" >#< show name_ >#< ":" >#< _typeIpp
                   {-# LINE 64533 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 189, column 3)
              _lhsOhpp =
                  ({-# LINE 189 "src/TargetHaskell.ag" #-}
                   "type" >#< name_ >#< hlist_sp _varsIhpps >#< "=" >#< _typeIhpp
                   {-# LINE 64538 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 119, column 3)
              _lhsOjspp =
                  ({-# LINE 119 "src/TargetJs.ag" #-}
                   empty
                   {-# LINE 64543 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs0 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs0
                   {-# LINE 64548 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _errs1_augmented_syn =
                  ({-# LINE 362 "src/Transform.ag" #-}
                   _dataIerrs1
                   {-# LINE 64553 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs2 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs2
                   {-# LINE 64558 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs3 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs3
                   {-# LINE 64563 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs4 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs4
                   {-# LINE 64568 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 106, column 45)
              _lhsOerrs5 =
                  ({-# LINE 106 "src/Transform.ag" #-}
                   _dataIerrs5
                   {-# LINE 64573 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1385, column 57)
              _lhsOgathDataMap =
                  ({-# LINE 1385 "src/Transform.ag" #-}
                   _dataIgathDataMap
                   {-# LINE 64578 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _dataIdistDatas
                   {-# LINE 64583 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _dataIgathDataCons
                   {-# LINE 64588 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _dataIgathDatas
                   {-# LINE 64593 "src/Transform.hs" #-})
              -- copy rule (down)
              _typeOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _lhsIdistDatas
                   {-# LINE 64598 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOdistAliasses =
                  ({-# LINE 1433 "src/Transform.ag" #-}
                   _lhsIdistAliasses
                   {-# LINE 64603 "src/Transform.hs" #-})
              -- copy rule (chain)
              _dataOdistDatas =
                  ({-# LINE 465 "src/Transform.ag" #-}
                   _typeIdistDatas
                   {-# LINE 64608 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOgathDataCons =
                  ({-# LINE 307 "src/Transform.ag" #-}
                   _lhsIgathDataCons
                   {-# LINE 64613 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOgathDatas =
                  ({-# LINE 318 "src/Transform.ag" #-}
                   _lhsIgathDatas
                   {-# LINE 64618 "src/Transform.hs" #-})
              -- copy rule (down)
              _dataOopts =
                  ({-# LINE 80 "src/Transform.ag" #-}
                   _lhsIopts
                   {-# LINE 64623 "src/Transform.hs" #-})
              ( _typeIalias,_typeIdata,_typeIdistDatas,_typeIhpp,_typeIjspp,_typeIpp) =
                  type_ _typeOdistDatas _typeOname _typeOpos _typeOvars 
              ( _varsIgathVarsEnv,_varsIhpps,_varsIjspps,_varsIself,_varsIvars) =
                  vars_ _varsOgathVarsEnv 
              ( _dataIdistDatas,_dataIerrs0,_dataIerrs1,_dataIerrs2,_dataIerrs3,_dataIerrs4,_dataIerrs5,_dataIextraBlocks,_dataIgathDataCons,_dataIgathDataMap,_dataIgathDatas,_dataIhpp,_dataIjspp,_dataIpp) =
                  data_inst_ _dataOdistAliasses _dataOdistDatas _dataOgathDataCons _dataOgathDatas _dataOopts 
          in  ( _lhsOdistDatas,_lhsOerrs0,_lhsOerrs1,_lhsOerrs2,_lhsOerrs3,_lhsOerrs4,_lhsOerrs5,_lhsOgathAliasses,_lhsOgathDataCons,_lhsOgathDataMap,_lhsOgathDatas,_lhsOhpp,_lhsOjspp,_lhsOpp)))
-- Var ---------------------------------------------------------
{-
   visit 0:
      chained attribute:
         gathVarsEnv          : VarsEnv
      synthesized attributes:
         hpp                  : PP_Doc
         jspp                 : PP_Doc
         self                 : SELF 
         vars                 : [Ident]
   alternatives:
      alternative Var:
         child name           : {Ident}
         visit 0:
            local gathVarsEnv_augmented_f1 : _
            local self        : _
            local gathVarsEnv_augmented_syn : _
-}
-- cata
sem_Var :: Var  ->
           T_Var 
sem_Var (Var_Var _name )  =
    (sem_Var_Var _name )
-- semantic domain
type T_Var  = VarsEnv ->
              ( VarsEnv,PP_Doc,PP_Doc,Var ,([Ident]))
sem_Var_Var :: Ident ->
               T_Var 
sem_Var_Var name_  =
    (\ _lhsIgathVarsEnv ->
         (let _lhsOgathVarsEnv :: VarsEnv
              _lhsOvars :: ([Ident])
              _lhsOhpp :: PP_Doc
              _lhsOjspp :: PP_Doc
              _lhsOself :: Var 
              -- augmented rule
              _lhsOgathVarsEnv =
                  ({-# LINE 358 "src/Transform.ag" #-}
                   foldr ($) _gathVarsEnv_augmented_syn [_gathVarsEnv_augmented_f1]
                   {-# LINE 64670 "src/Transform.hs" #-})
              -- augment function
              _gathVarsEnv_augmented_f1 =
                  ({-# LINE 358 "src/Transform.ag" #-}
                   extend name_ ()
                   {-# LINE 64675 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 1470, column 16)
              _lhsOvars =
                  ({-# LINE 1470 "src/Transform.ag" #-}
                   [name_]
                   {-# LINE 64680 "src/Transform.hs" #-})
              -- "src/TargetHaskell.ag"(line 536, column 3)
              _lhsOhpp =
                  ({-# LINE 536 "src/TargetHaskell.ag" #-}
                   text (show name_)
                   {-# LINE 64685 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 340, column 3)
              _lhsOjspp =
                  ({-# LINE 340 "src/TargetJs.ag" #-}
                   text (show name_)
                   {-# LINE 64690 "src/Transform.hs" #-})
              -- self rule
              _self =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   Var_Var name_
                   {-# LINE 64695 "src/Transform.hs" #-})
              -- self rule
              _lhsOself =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   _self
                   {-# LINE 64700 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathVarsEnv_augmented_syn =
                  ({-# LINE 358 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 64705 "src/Transform.hs" #-})
          in  ( _lhsOgathVarsEnv,_lhsOhpp,_lhsOjspp,_lhsOself,_lhsOvars)))
-- Vars --------------------------------------------------------
{-
   visit 0:
      chained attribute:
         gathVarsEnv          : VarsEnv
      synthesized attributes:
         hpps                 : [PP_Doc]
         jspps                : [PP_Doc]
         self                 : SELF 
         vars                 : [Ident]
   alternatives:
      alternative Cons:
         child hd             : Var 
         child tl             : Vars 
         visit 0:
            local self        : _
      alternative Nil:
         visit 0:
            local self        : _
-}
-- cata
sem_Vars :: Vars  ->
            T_Vars 
sem_Vars list  =
    (Prelude.foldr sem_Vars_Cons sem_Vars_Nil (Prelude.map sem_Var list) )
-- semantic domain
type T_Vars  = VarsEnv ->
               ( VarsEnv,([PP_Doc]),([PP_Doc]),Vars ,([Ident]))
sem_Vars_Cons :: T_Var  ->
                 T_Vars  ->
                 T_Vars 
sem_Vars_Cons hd_ tl_  =
    (\ _lhsIgathVarsEnv ->
         (let _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOvars :: ([Ident])
              _lhsOself :: Vars 
              _lhsOgathVarsEnv :: VarsEnv
              _hdOgathVarsEnv :: VarsEnv
              _tlOgathVarsEnv :: VarsEnv
              _hdIgathVarsEnv :: VarsEnv
              _hdIhpp :: PP_Doc
              _hdIjspp :: PP_Doc
              _hdIself :: Var 
              _hdIvars :: ([Ident])
              _tlIgathVarsEnv :: VarsEnv
              _tlIhpps :: ([PP_Doc])
              _tlIjspps :: ([PP_Doc])
              _tlIself :: Vars 
              _tlIvars :: ([Ident])
              -- "src/TargetHaskell.ag"(line 582, column 11)
              _lhsOhpps =
                  ({-# LINE 582 "src/TargetHaskell.ag" #-}
                   _hdIhpp : _tlIhpps
                   {-# LINE 64761 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 377, column 11)
              _lhsOjspps =
                  ({-# LINE 377 "src/TargetJs.ag" #-}
                   _hdIjspp : _tlIjspps
                   {-# LINE 64766 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1469, column 38)
              _lhsOvars =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   _hdIvars ++ _tlIvars
                   {-# LINE 64771 "src/Transform.hs" #-})
              -- self rule
              _self =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   (:) _hdIself _tlIself
                   {-# LINE 64776 "src/Transform.hs" #-})
              -- self rule
              _lhsOself =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   _self
                   {-# LINE 64781 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _tlIgathVarsEnv
                   {-# LINE 64786 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 64791 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _hdIgathVarsEnv
                   {-# LINE 64796 "src/Transform.hs" #-})
              ( _hdIgathVarsEnv,_hdIhpp,_hdIjspp,_hdIself,_hdIvars) =
                  hd_ _hdOgathVarsEnv 
              ( _tlIgathVarsEnv,_tlIhpps,_tlIjspps,_tlIself,_tlIvars) =
                  tl_ _tlOgathVarsEnv 
          in  ( _lhsOgathVarsEnv,_lhsOhpps,_lhsOjspps,_lhsOself,_lhsOvars)))
sem_Vars_Nil :: T_Vars 
sem_Vars_Nil  =
    (\ _lhsIgathVarsEnv ->
         (let _lhsOhpps :: ([PP_Doc])
              _lhsOjspps :: ([PP_Doc])
              _lhsOvars :: ([Ident])
              _lhsOself :: Vars 
              _lhsOgathVarsEnv :: VarsEnv
              -- "src/TargetHaskell.ag"(line 583, column 11)
              _lhsOhpps =
                  ({-# LINE 583 "src/TargetHaskell.ag" #-}
                   []
                   {-# LINE 64814 "src/Transform.hs" #-})
              -- "src/TargetJs.ag"(line 378, column 11)
              _lhsOjspps =
                  ({-# LINE 378 "src/TargetJs.ag" #-}
                   []
                   {-# LINE 64819 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 1469, column 38)
              _lhsOvars =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   []
                   {-# LINE 64824 "src/Transform.hs" #-})
              -- self rule
              _self =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   []
                   {-# LINE 64829 "src/Transform.hs" #-})
              -- self rule
              _lhsOself =
                  ({-# LINE 1469 "src/Transform.ag" #-}
                   _self
                   {-# LINE 64834 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathVarsEnv =
                  ({-# LINE 356 "src/Transform.ag" #-}
                   _lhsIgathVarsEnv
                   {-# LINE 64839 "src/Transform.hs" #-})
          in  ( _lhsOgathVarsEnv,_lhsOhpps,_lhsOjspps,_lhsOself,_lhsOvars)))
-- VisitAttr ---------------------------------------------------
{-
   visit 0:
      chained attribute:
         gathChns             : AttrEnv
      synthesized attributes:
         gathVisitLocalAttrs  : Map Ident String
         pp                   : PP_Doc
   alternatives:
      alternative Chn:
         child name           : {Ident}
         child type           : {String}
         visit 0:
            local gathChns_augmented_f1 : _
            local gathChns_augmented_syn : _
-}
-- cata
sem_VisitAttr :: VisitAttr  ->
                 T_VisitAttr 
sem_VisitAttr (VisitAttr_Chn _name _type )  =
    (sem_VisitAttr_Chn _name _type )
-- semantic domain
type T_VisitAttr  = AttrEnv ->
                    ( AttrEnv,(Map Ident String),PP_Doc)
sem_VisitAttr_Chn :: Ident ->
                     String ->
                     T_VisitAttr 
sem_VisitAttr_Chn name_ type_  =
    (\ _lhsIgathChns ->
         (let _lhsOgathChns :: AttrEnv
              _lhsOgathVisitLocalAttrs :: (Map Ident String)
              _lhsOpp :: PP_Doc
              -- augmented rule
              _lhsOgathChns =
                  ({-# LINE 232 "src/Transform.ag" #-}
                   foldr ($) _gathChns_augmented_syn [_gathChns_augmented_f1]
                   {-# LINE 64877 "src/Transform.hs" #-})
              -- augment function
              _gathChns_augmented_f1 =
                  ({-# LINE 232 "src/Transform.ag" #-}
                   extend [name_] type_
                   {-# LINE 64882 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 899, column 24)
              _lhsOgathVisitLocalAttrs =
                  ({-# LINE 899 "src/Transform.ag" #-}
                   Map.singleton name_ type_
                   {-# LINE 64887 "src/Transform.hs" #-})
              -- "src/Transform.ag"(line 2527, column 18)
              _lhsOpp =
                  ({-# LINE 2527 "src/Transform.ag" #-}
                   "chn" >#< name_ >#< "::" >#< type_
                   {-# LINE 64892 "src/Transform.hs" #-})
              -- copy rule (chain)
              _gathChns_augmented_syn =
                  ({-# LINE 232 "src/Transform.ag" #-}
                   _lhsIgathChns
                   {-# LINE 64897 "src/Transform.hs" #-})
          in  ( _lhsOgathChns,_lhsOgathVisitLocalAttrs,_lhsOpp)))
-- VisitAttrs --------------------------------------------------
{-
   visit 0:
      chained attribute:
         gathChns             : AttrEnv
      synthesized attributes:
         gathVisitLocalAttrs  : Map Ident String
         pps                  : [PP_Doc]
   alternatives:
      alternative Cons:
         child hd             : VisitAttr 
         child tl             : VisitAttrs 
      alternative Nil:
-}
-- cata
sem_VisitAttrs :: VisitAttrs  ->
                  T_VisitAttrs 
sem_VisitAttrs list  =
    (Prelude.foldr sem_VisitAttrs_Cons sem_VisitAttrs_Nil (Prelude.map sem_VisitAttr list) )
-- semantic domain
type T_VisitAttrs  = AttrEnv ->
                     ( AttrEnv,(Map Ident String),([PP_Doc]))
sem_VisitAttrs_Cons :: T_VisitAttr  ->
                       T_VisitAttrs  ->
                       T_VisitAttrs 
sem_VisitAttrs_Cons hd_ tl_  =
    (\ _lhsIgathChns ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOgathVisitLocalAttrs :: (Map Ident String)
              _lhsOgathChns :: AttrEnv
              _hdOgathChns :: AttrEnv
              _tlOgathChns :: AttrEnv
              _hdIgathChns :: AttrEnv
              _hdIgathVisitLocalAttrs :: (Map Ident String)
              _hdIpp :: PP_Doc
              _tlIgathChns :: AttrEnv
              _tlIgathVisitLocalAttrs :: (Map Ident String)
              _tlIpps :: ([PP_Doc])
              -- "src/Transform.ag"(line 2649, column 11)
              _lhsOpps =
                  ({-# LINE 2649 "src/Transform.ag" #-}
                   _hdIpp : _tlIpps
                   {-# LINE 64941 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 894, column 53)
              _lhsOgathVisitLocalAttrs =
                  ({-# LINE 894 "src/Transform.ag" #-}
                   _hdIgathVisitLocalAttrs `mappend` _tlIgathVisitLocalAttrs
                   {-# LINE 64946 "src/Transform.hs" #-})
              -- copy rule (up)
              _lhsOgathChns =
                  ({-# LINE 226 "src/Transform.ag" #-}
                   _tlIgathChns
                   {-# LINE 64951 "src/Transform.hs" #-})
              -- copy rule (down)
              _hdOgathChns =
                  ({-# LINE 226 "src/Transform.ag" #-}
                   _lhsIgathChns
                   {-# LINE 64956 "src/Transform.hs" #-})
              -- copy rule (chain)
              _tlOgathChns =
                  ({-# LINE 226 "src/Transform.ag" #-}
                   _hdIgathChns
                   {-# LINE 64961 "src/Transform.hs" #-})
              ( _hdIgathChns,_hdIgathVisitLocalAttrs,_hdIpp) =
                  hd_ _hdOgathChns 
              ( _tlIgathChns,_tlIgathVisitLocalAttrs,_tlIpps) =
                  tl_ _tlOgathChns 
          in  ( _lhsOgathChns,_lhsOgathVisitLocalAttrs,_lhsOpps)))
sem_VisitAttrs_Nil :: T_VisitAttrs 
sem_VisitAttrs_Nil  =
    (\ _lhsIgathChns ->
         (let _lhsOpps :: ([PP_Doc])
              _lhsOgathVisitLocalAttrs :: (Map Ident String)
              _lhsOgathChns :: AttrEnv
              -- "src/Transform.ag"(line 2650, column 11)
              _lhsOpps =
                  ({-# LINE 2650 "src/Transform.ag" #-}
                   []
                   {-# LINE 64977 "src/Transform.hs" #-})
              -- use rule "src/Transform.ag"(line 894, column 53)
              _lhsOgathVisitLocalAttrs =
                  ({-# LINE 894 "src/Transform.ag" #-}
                   mempty
                   {-# LINE 64982 "src/Transform.hs" #-})
              -- copy rule (chain)
              _lhsOgathChns =
                  ({-# LINE 226 "src/Transform.ag" #-}
                   _lhsIgathChns
                   {-# LINE 64987 "src/Transform.hs" #-})
          in  ( _lhsOgathChns,_lhsOgathVisitLocalAttrs,_lhsOpps)))